#!/usr/bin/env python3

__author__ = 'Sushain K. Cherivirala, Kevin Brubeck Unhammer'
__copyright__ = 'Copyright 2014--2021, Sushain K. Cherivirala, Kevin Brubeck Unhammer'
__credits__ = ['Sushain K. Cherivirala', 'Kevin Brubeck Unhammer', 'Jonathan North Washington', 'Shardul Chiplunkar', 'Daniel Swanson']
__license__ = 'GPLv3+'
__status__ = 'Production'
__version__ = '3.0.0'

import argparse
import base64
import getpass
import json
import os
import re
import shlex
import stat
import subprocess
import sys
import urllib.request
import zlib

if False:  # for mypy
    import http.client  # noqa: F401
    from typing import Dict, List, Optional, Tuple  # noqa: F401

# DO NOT MODIFY, USE `make` which calls `./updateBoostraper.py`
any_module_files = {'.gitattributes': b'c%0MHOUbNI$jQu0FU>42(alK&G7{5MZ6kbr5TYrmC8^0JiAg!Bwk1WSsa#rmIYs1XDkeiy30az=qpeah(=$t~Vq;0x4glQWW#I', '.gitignore': b'c$`H}I}U>|4Bc}SB%Fl{RO(WRcA+~8i2<wmAe<~ceI2UO<$bJY`{@QIib^-I&YUYR?~0+TxLKv)I*db3J1Tv949`p7D}6UFoXO)~K|Nx&k)rj*A($Yx<P^G$V2xcRYg3$Q0iTvrb2ho~&zAaxq71!nc~v?PGewDq<dBbEB7|G%wx>zjIo!_uqr_LL4|P67`v', 'AUTHORS': b'c$@<O00001', 'autogen.sh': b'c${UEQE%En49B0jPvHgBsR+nB2x*k99U58@o3!l-nZzNdrgz!hr3F>&v(I;FLkjm2*=PUk``hV$fOsoaY;z&Hu*ksW1eGNNwxmR6l2Skz4ogFs+z-Iv191$x0cZ|2&(adal{Imp6D(qeNE;w2Wmpw%Bv$J$w~OD?Q;?`(iuP`rVPQ#R+JFS9AnJXJCXi|Yd=g}K&-;Vv&s!tY{&lC*1^QcYK3FQzprdpwIzH;PV$^$)-Tw3#)!xbE0uvy%#Dp#wtsb4J=mOEdu3f!TAY5IYO3TQb7cXsN$YLT=t;kFNgItiUM3-AoL@6u3JwPG1PU|8rA9lk;t4!`<OoEI+E*Zhif%VDA7^!xQVZ<YBS-2FmYTgNhFjLFQs*etGeBvQ$pj0~e7mqkTH_ZA)oKzebgJnr79e~v!GhTqO5jnEd`jP6%hqsX-mCzt;1U$>40R7~9Nr~q^`}x(+z<-b9){gMLMS}LFHV*uySbp9t7dPwK`p@Pq>CAN;Gbc!Uj9HN;{VYtZzTIu+_up?9cMa*x)h5{-4S8j2Vc*v{`A^NhM~T^dc|V^mn^JB2vd-(+8d^JA_!U^8wSH>IGNRd8Kcc#W%8<ayX+z$IVJ7`@jpF7u{5V4V2W@pN2m', 'COPYING': b'c$~#uTXWmSl763Gf#Qp$Dp-z_bCNxADpj;h$J`@JT1mE#-xef>BGw?l#YHst*KdE_Jr{talG>L|?bfj*V5X<1?>8jL;eUTze@gzCUC-{OSIO<Cw^#Gag#LeaeLpitp2mNlZPONYmHd<@KmH^6_r9{pk3anIi!sS%z1=s(<GM@EF3<Uw$@|9I<i1{YyR5Ov`?|04tfRNnWL_;VlHb-{xBd0it5v(YsGG-Eznf(CWSf0WixzFNwaupJI-4h5oh)hfB&+fyFWRmt7JX+EdUiqUZScp!wkD}pNw=mq%VKG()+Twq>^HXR(uAH*mg}r~EUL$(=&*cMcS%;3_0HxO=G1ZdzuU%Un?-5y)Wg~e)@)^)tW0kE1?`qx>5jB+maOR5DMMV^Rp+5u)s1N#GH{f-TiYi2R#bTl(06t7t-WxY=vysbOEz`eB}d-fHrcW(mIMdCoZzpyZHvds=7zA=W#8!WUA9m5b>A>xdA$KX+qGMX(P9a4Rv}1|w|j!V>YA+WQq%qEiHoYURWA4R*k?^fKilz+=3qxcKCTet#OKfGIQ3(bZC<{lg*E`a?dcV|uEuV%f}X;10f)d07Ad+m>04TfK>tFR2gIjIkDkO6=9x2jloM1qh1>BBV9B=IlBkV#Zfl$?tM+;uKp%lx+N=dKK#4&8V$Tp}eYdU|#;<jsEVGJN!r!n8V@uE9(h=&KDdEf7R>_VKv9;MZfCCJ8cvAcc=WFcBHVtT-FsC?ALE&cG(3xn@8(RMOX@^vk3{c;#vkn(&*4dMgNJK&rCkg`|z?YoqbvKVf{<Oj-DOOlA*%j^jJoQ`98J4zq!pnWL#FDv9=pKNmN82&e@{49i^hG~Lui}}AjQ#fXI&Pa_TMBeoq)IBgGYn_IH{kTkeXHu7UpKF@CesYzSNXHXtDRkTLgg&>TE30S3J$l8eIm&tlmWseoaMIK<Bo6$SyNsFoLT!#|HRzcHw{>-;q%B-7c3X(rfXb09>k@XrENOm4MJbLB}OV1MOk#X3`O(NTZ*xiV*6qR3M8V>ixo)n*TeM)Ec_0KjtK!Q!e?a6yr;G7_iVE*Y2D`_X#3?la6F-IZLx}>pSprE!rYy#tR8mL6F+XVmi|@&7DkL+7PMeRDC84m8*3D<_JFW*<vd<!MB?=Jo|!InPn(GJ1Y4deX`LyNiwCM*6S**DE1{6yYLk{h+#4n)`d8t|gz@x_sH3d6APojUg^~!`+pA;bMGVuelWs@U(b;YLt2ujpPGm!JuVY;!x);b9TrMd4?8kG$If)3NF9;@Oe)Cv7Il3$DBMArAx-IK?Rl8|?gS6Z$mX1m&{?@T;?oaiC_f?Vi!X1a@FCUYRxFk8*ko>dXw<UzTaW~OeQO_hi8|acflLA9MkS-Up@q)-t#6NFp{H874aoDc0|J@gjReUr21+l7EKnqJm(R`y{WvvlmlBaTu0#?EDnaqF<u7cDK3<!EF>l8P6LNb_am%4B1SkMdt3CJDdprAka{TOfe^@fpFERRTGNDDbvk}c^0=0L(z2bD+XZu-g`9%IDZc%jIdwus5Hk^t%-*ZjyPtNIn055xqGQAyX<EM=h63E9w@FrR2cy6S3KZ??pogaIW*S|lqV0gSs}q9nbENKYJ*%p%K@c2A_dp*5F=Rwllwf@oNPCF<p}Z(v}^W@Lv6GV8owc48Wl^+Y6`_oR-2b9xKHq@X2WLPA2cmcZW$U9siIs=cp()oqv2d4{5OXGPtG%K$<Y!w$h9DHikfnna|?2(`wn(rZoZ<v^t!=6W(uL|H?i(eD;?rBzobmerOZ+<_?=8vH#c0?u-f6)_CVErE&_dnz2W@|NyREVb%!yPh~qfSqWeWnJa8m57^>U>Bo`IlQO<Uz%7L=uT_{ncbQIBY<cjvKjd(CEGln1h@Dz<lcQp|7syG`!Wyqw|hV}3~>`dqM`)k$D)L(VHIq@8lsuanU~wX+2Y`!Ph!KS6?317rfyZj=QXQm7#+--Pj!(CNs>k*+$TARw2_A$Kw|1KhQzA(2Vdd{hP4P?z9rd8H~$1eqbJDbvR&5fFVs>HO91y3#1RSZ-bo|l_9HG-q0+aqZDa+wt*g3v30S<RphT{Ehb^v}n4)8O08)eyC)SMQI0y!^Qsl>yEn|8Vw{hARdYIjPyicar?~==#>v!{q`OWn`9{%Bi)Y+=2WJi8~@(}5miI}H+zmAK3@_cmC3YUevS2+=bdt);?mDhJK%Yv?;%yuf*#iXW<hQ5_y&n8vTLL_K61&~Cn31vpcmxtSuyT^!*!G?|R_sm!V!q!(Gji^&^sc4OZK1pU7ZKjWiXPD=7<t?k2WI`%;LQhTf1=~*eN+!XmnGj@qP(v)^2ww7)v#R)?Ea02SY$7U|77^G4QO<K_`x6FLo^6@!@WVE1I(H9v#}La9ooDSDS0oA(B0X3a!8k}2!-Vxp)d?H0@Z%~&Cg4)65|#9H?!ILGz`zxt^|Aye6!1uiO%x^r`=D@s6<dS+ugQY_D?Ese<EI!I(`2%&X)SsNznds3Y@q-XcU68*z3gatUfrl2rGNHF26tzV#IA>U&Y4WuOA!6YS|KAp1wYk2v3Z2O9m_x#AYvoawL@?c9IXXul6IgU%Yvy5zEe@Ha2u9Iq7WR*rzJlT?ueLy#PoOQHu@jC>^qHlfai@9l8HCs@K+e(#Zx90I_~UN&j~^x&0qGU480sN137ZWho$B8m`N;D$iY*>$eyyIWKhL;H(Ta*F;I!{TG&D)Rx4T=E&^W`^y!nhAH*^{TbBMN2uDwLOzz-Q@Vr_H{s=4^Y=!N0X#?U{w}x*47L|IS;-wH4KC;bF5xO!qUgcgh){9Vlu%%4q6%Q%Y4#3Eb!-DO|er;iQb9h6HX$?II{Dc{y*(&VwWMu>X1zBhoa+_@AJqeBJR`d(5>Wc04>l!9UJ2C1Lv2`GnC+@CZUM4$Mh100C(59#?t83U02ym@Pm3yZM{)OLJ!WDk+KyDT9@BIwZ(ItsHrdWF3s8>mPrUa|B5g$TdDAYt|i-*h>7dmhPwq;={SmiZ%-5{8qS`kRuWg~S|*qvUC4;}^qK3{S0E8GKV+Exq$+E&6td`KbyvZiwp&RZ7CLDyu4IJQs4*%ge_#UKtMB8FGmSj$c<1Y<*gZD<W9jMo?BC9vyx3D?u<{7K}GPSjP7#gUi=2nvymqd#v3a-QQ`!j>_!iigobDcvmo%d!N=@`1Ntd&thlEt(Ak?>$V_tjUwPLt1z}LZtAc2;_qQM($|=J4}pStdPT|An3`I%)pxUBk4T)**!omTb=I_y+|D@mzh|Jexp{*JC^i<Bxd_%UuHhqwgDPSvi|z)5y6m3z%z*65uufPF~+h@P0s}nmygYoRmF>2BHYnEyEjBoizb6mn}~K)sT|A*<x#IbRJR(hTlp!F61g#TX_fNNvU7>P^4qyXLPZxtazXEh<lORG_9#OBWA<N!gi8`vb>+k2-dTcF3MK(<z>k~gapv*GIccco34*i|TT2A1n&<&wbrK1c2m6BciPR7#5(_^$Bpkjl0gfyR|E%hy_CTQ|qEJMagb*U|fQXHmjG&k(*?{G0+VnfYrKC#Cfk$Dhv17&(o?kL&-^fd~B}9CclMoRXR!~FcDQP_Kf(zv>6Oc>BN?0B?X9dV$e-4c-2Nc0Qqzdxy+f?ilY+sbNac+USl_6*^&k+{|wiRw8A<%{Qu%?UIFoj;$jl}tKfG2`xAWn+mnoLxRq_Q-lz*yu^if`5-2q+N?C7zYQ8P3XL`kVp7YVl?qldWB-DI8S@p7BYta?6gR;e171s>>Jb2D<tW^$uQZ3U!#*RtVkkoLlxqYsT!#NF6(wU0sV2u74m72!zP#2^Um$wA-jR7a5&|RiX(XlSB3+kinHEygXz}f%ak)X+3t2#;g9wknnz5vMNfps@i%9jh+j;>TSv&HDa%5mk_xfGnZtNa#CZ8Hp$ZMt89bBRJk{0Q6a3>_6v_1XBBvFz%dIWG>(F4*e*3rog$k;Ou2y-l4l(=$EL5G6U*+dkirVFg$0>p)@mrg#4tozG{SB>K(AwvV|bMie@sK(?02EursaTIV;vhH5?XVhiw`K?*x}xT?Tl>qJS;<29m_q5&yWB{WIUYg$BX1`){<np^$v-+kyG*uHQ4;fS-kv+0mVe={_Ko6#2%n+4g%4)F2K+6U|4~4il<tf7H7)|T_HM@n<#dH$2YcfAxXDC0>)%3z;4aRYCzC~!{mKc7MlWV3}e_%wj6qW>YS3(LiW4d3O!u0vNW*|$quXjyx0%X!CJ783zU`8<dKYcNZOX=601B8jul<ssVyEBAD@pDc2)1lIexTqGUL)jD{{^Y$!WpTWC8+zJY}Wm=Qf~pu^;+`e8HUmATxQxp>ZHaJpplQ2Vg}R6mo5mOBCbU`?GPFiBw++`zX`9a5-;=afj%Xrf?BsAfn-%q=QC{_R;3G&z&iawKYga<S;^+>+DIGj)XS5a6?;`Jc_b!B`Aj_2ricBiXllQLgtZVbUCh-#MP@HmNjq`QL4*1l1@fknN~241KP0@0jBhh9*12Zx0*uiGu04+VWUnVi!Oh2OdAr!>{}mWiGdtln$e?5YKlYp156N0@C7aGIxAPH@;CoVVi1HoqcKE)k}@On*(5X?1-v)HGS0!57@6evB%ke%Ve@csq8yi!Ku*k-a$oCWD=LWIWLmxSc++5q&$BO!X4!Ax2f)G~REmH`V6o#3BghFf$^wQ?jwol6+_Skzx5P&LpdRE6Vlb>uUjM*B-WIk4p&WVS7Li>5_|paCh|7C?lDvmF<#)oc?}45vX{(o)3^L-tSoKQT@wy&d9#koj$O3wrY~9?eeOOE`#7vj5Tvv5jKSG(1Z<%o#GvFu+3K82UtG*;{UNYU#fghDS^m#Z#WQ4tb?Nrd0`Rz?4I64IPY0aG6T8_CTKmL%sBQ$Il^!n?6{Nrcvlxa!u!lmLstRoResv6SgNa6qun(J|AXhX$=Fc?dPp{$f#@Gb))a9GV*(xtISLBzi(NQaEK8Q?5&`z6DW30oM0SK$K+;zgj6+1e}%CKwgTN7N$|vCov(X3V0Z3N<mlERjLONw|onQ<cSv%sCEh)eJ-Rv75zyq1fc~Yg<9OvJ*)n9maQT;<9a$3cE{AwGk>Ku6?1%)RTE^9$cC^j!nM3zg<Lp``OiJT}nVL)<Al@qY^H6FxAg5+JQ+U%Eh=a9ZEnDu_ojZvlRX2xR|cmEjj#>l;!+z2xB2#11Zq1LD?4ZdaW~iHrVyXe6x0o8$*;klT<M0a3Ny6AviReVE$Blg9wT<Po8|vCRhJGTQ2Lync^yfehEnpA*K8o02F`Of;`uy71^=(F}F7i#v?Nixo=VV#PJvyJypAC_Ba~uFH)*|unpH5fv&1r{|#jn&>CL~3<={H0qaP8Lfdb*HH2Oh0)?S?Ak>5~2!D@>?W42p)H41YC)!6;7f1RJ3{|x@#(^>Ka~EnU4qnpOiwlayRO>{9HQq#USNpeP6su`2t7#g(&^A_Nze<KKJ7?onqJB{JOG4N_3NjugN?+wesN!V`jq7M3NX7+hPbje>@5*X6aPfcIi?i+gzAuV9=1vG_#F|?8L7r7y@iM<SQ(3)2jveV~B<LCc0S=KvG%gS;OinP)L=U<=4>dy0hGi8&!msh3a1@D)GJkmA9ZGVBh$Yf<uocA(C%&lL*0!#aAPYIN(E?my(z&7p5dmq;k0Vv@rG?N&E~q5&%tV(u>A_IP>O&nft)gUaG}SA6%$mGJ-3e@MDPr172%bZVTu?P|Tp(CrNAdeZA1ubD^H!t6$!xDV`w*cK;;hKEDL{x?I}sMu;xew(Xe|LQ^4t}BxiD9f<mV{8@EfnQ_L)=*VT$FISkIFD;8jj0UfuvV8ebYHuklWLARn35vIMp}b*Iz2h|cCE_!K?{!Hy5x;!?gNad-(BdRt*=Lkax|<{joV3zyq13J$8yCCrCmD0Y2ewO5iRV#8@rcQi0`SiTQeAix$J)pr?E7uFGTV}r~J^oftor*IhI>>@S&RG0lmv>Hj8x*;OO-v;SOX9`3q=E_X6$43w}^0tM8G@ytN-?dSeI;ebw+_(^`m}abGr7DX67#L3V!TK+>JlQNPi3FfTqhBGfuTHNxGDtmD?6MuZKF-q9|G5)|nC3E*GQx-@A%|k?A>=-Tt>6}7+W9%wsn=wzs5*U5mvcgw4g)1e0>)kgiZC)k1GXfYf&9OpRD@ANZ$pepwDS^$P%QI~M#M&&jZGS%r^*J!O2Q{nsh57gQ81ki19E#v+pw+13BC2cWgA$_ym*nb5TA~oI6|Z6DcgISZB`X7t|U_8c&M-VF4jtx<b5OYGq<`dC>o3;SG|$y0j61w(S~wB!ip5+1=arldge@oS_A*R5-TuGSn7+lM|zk{2k;B(ul6=;By<}+BAPRbKRIJ^E841&5^KRsWMoQUNrD>wC}d6`y@MQvI+;$3tLj!uBgT|wGPxjEF2Nhq&&6#;!^fB7DL^4oJL+WcF+ENXau7!NU#ExEWk}g_S1rD&r5Zq^M#Oq;U1`CIB*5LC@TKCMhT1bB`sK}HrYe*qhq6|651ylbnB1AGu#gNSQ%6;+3lc0irRPYx4!z6x>a?OGy0Alf)C$QbjanTAFt*{c5~Zven-@jvf=Uu7u9wTKWy?(5QKZz7!9ZX^DlFlnVigxxj!W2&gD*PNGmrNp<s|aN!WoD^FM?fkg7FvXjWIjR9Vz-HGsAIurqU8grL%F(zTC&Tn3jUU5T%Z8{n-mwk4iEZ8Gvkj=`#OPHfIXpRaSi?(LtdGQB>YeQpaG>GVoXEZsY++Xp)j%PCPRt>S4GghoZDSpxyK&DGB3A<)5&30UUCOO3409B10k%Sl$8cA)2#4=QUV(sIY6}E6_r&DDoZYUvbFcA{F9waiM;Q4x?`Pd*=;`=#*{7t4gUg47x&6h9|L0D7+iE8EhHpA=e~e+Gk%+l{Wyb3vP;$MzYbDF$FI)O4PF2@G2wZty@sCWSiT8H`yxJ*ppn-b6jw1ZS%6LU*dnI{L7d8ISlhUfV`+AULc7;%S9!EyCa$KVQvshD1{DUf%NjiinLv^!q98dY_+SA2wbD#8}+p#F_Eh)Aszy27b2r5_!t2QKLJUKIP6hq1_lTA@si^#2Id$f-$@F3#$EVCc0SCe9EifG3<<$__+ikY69y&H&|Ev%_8W0B_z~ym_(~_!p;weoP1nMXG(0m)ycHMBpwcGRtL|aarP+owZi+UdbxnUKzdLuyt2SsrmpS$+Z&uD_uB{Cu#R=<~#G)%ML(fqKiLyaB3G^PU+@eyx<3ncNdMLE)Z*bVu<aNL3R(;9!Qf<gO(ACuCli+!kJ=I*c$d*U;=(=s<3M$v#5Y!XbYDFbhaC_2ZGC<UzuG)0_E!&E<RM8Q6`7$CR(q);oZPfCSj=~ZyZ`}LdhSBDU9D*4n<MxVBa5H+;pclqLDOY5_BZ$wMjmdc{nE(Qu+f1a&jsZi3kvAicqJ0FpyR2vp4j4r3AST!aQ0jRPYg$l+D6-!`!0jtunr#96hW68PMb1F5H31sqpr(Y)tQIgj47sy#CH!3KcEmxRv!vpGyYirz#i9zq4IQh_+Z431v^f$3srG?s#d`A1?ghOf_=>Q$6S#TQ>cl|=sTZ<G+O`g(8?GL203alg$qwF^p3wHRMP~=#Au43r9;J$QtY$RX*cDX|VbE7BN7e8R0cEf_3oYZMBpOm{DP7c75fK9tDw1<aX%4407na@pVLk|yvp|{4CetF(`D&0vs}4kE9Ex>9Up+o-CuzO7DrcqLwBiQF*bTKok+m<KTjZPhB&Mjt%xx8MqE?Ko;^=5-`e7SjaGNM=(aP#b$9dCE>#Mf5>x*vh?NTEiG?%KJ9Sv^|A#7PW(obXw|Bn_NTXR%}$+?H|ZHH72B`$32_Zso_lT$o~7W`flNO45lM|wD>W5_wERI%Z%t6CDkksU~HciapnNg)_}`<S;zG^tJ3VtEfR&V_rv+$;{J8m2p4P;|%L&Bt?JwiLr3`BA5iepsQGnb8uC%i`snOAp(T%h6r-hzYviB7`ip5t{p9o(*i{@z6v^(OdF#l`1Kj1N3-mF8*v$C<^ZYWybjgYVPNj!y>!2tqzh<5LC8Y`9cbp&dedptQ14BwqkJ~QpX~F+(rb;Q&E@Ph{uQPODWmo9?p7+>c*8S<4{$XEt|S+<At<D;~8EMsc`b1oi)q>xj656lzF5xiC^|H5wT^758Rj!!W<7A(ELa;su@0AFl@$!bLzYD?#^>0A?<nv(T2VQz=SB$W=s=(g|rAK-VvbG;s^D#7+b$wB-4<Wd9W^^I*EQ85*%m;YiwM40~*(Q>4Wg5YdZtYYCVp0R7evb*Be$=ntmGV)LuxrU6|uQ$j+H&pfuOy$|fWy=F%N(Mv^p;nh|Mo3+={aHcK;2T&x}kvIeynz872)P7>=o=y^g_8*94kDC|Ze->ynMuA%jLTW$AjI>&)*%7=WCaRMFgO|-V8tBzp7O)7bWNh0kF=Ab+T#dD&7+_8_J;ABCJ1gnmf#^4y4&JB=O6cV4CTFYgQZ{zaWS*I;Z5OW;xK~i7PW;iWzc7jS2c`j-e>UK3>RPPiFdJj&V&a4psW9JSys`S1%56K1&v6vI!Lr$nrOf`3`aS`^IhB>KW-5sY7-KYnS_a3eL2)k+BR)=fkP83)A<_7Y(e(Z7HL59k>A~@8s5Tr){^tZ@e0%|x1WfWk7M`?MwfN+aj`}|o!F)UN!KZWGSJ1t0JZ_<@tAiss27q`h2&WP|aDOb+y0yX0zhc<crcNV6ve;&i|1~#TkLfrXwQ+8XLC$GLj3r`e&mXw<>dy&+rpvzBW;N6`&5b6&b7h62Yw(=sHadkOaLA|8sV0mQXY!_XCet8b|_cd=sDc<)Q=wQ0Z$D;DiZJ=2NKXlxlm{H+|Blxp~p%ogdi!ij~w!Jor9{Mnh0FwFfOW`Q_IbDukHlFNt8j`3=T)c~60GKM<$Uh{#&$BM#oA5rm12}AC&rwEL3Nn#w0kMs$>Kbxpa6GAFRQH3^2pgp}JRwk|;c;;;)e>a<v|-;>Ole4XZ>m9AT{uZJz{FjdMrIxI_rn?wNauEN+~mx4*^aJJD{sz)3uV?8M;~}Dz(&<JgA-ZpBV%;sa9!===Tvh_$<WbteX}tcNHtfmYq%Ic97TZd4iG6fDq<T~o3PGCc!KOZ$hC=v=8Z1}W%CASS58Fyz~zX1<!uPCJLNho0L-~|Nu3_2-3uwT7q2H%0dcG>DN@kMshYP;oJD7FX33F*1c9x3RxZGD*BNY+gK2agKI0cmq6OKqkU{`>f1yTMT3ZG+(Xr_l>HlMjB@pHC<WW*S?x&4r=M6LSc;gt<@Y}eCz3qwdp0r@+6#Q|Fg25Ft_W<Z;d;>nOk+D#)4tx=wFJOzCnNltpAr$ZpXi(vRaECJ_gdy~Gb{&<RkXc+ZMVW(S$G}kbHvaUWAS>dZddyL&GpMv=T@%Bh<u)pKayD1#Gs2B~Eo&nu;Ej<O07x{>Yv^$`jzCI-;r+J@c2J5+;t_G(2lu1-j*&16YIJkj(9JMF8Mb6hdrCSi1LUDvFkR_}wq4XWB2K>F&G^Yv;7Cky5m$}t<%V5WogTmrrf9j=fQaMc>ID`hTn_FBFpgWHtVCE4*vjZ{+x0+fy_V3&ho~rwjd#>P%E&`@zmJ-Tom#?;@iQYO?;3@w#|B`+F(QsHhy#3Xyb&r1WsMATK#iQ0@~9m-=&Gu6vyy>70g1!Lp3n;ns?B7KKpJYRbaA7LugLRe_67s3G-oN#26XVuppA`f7>+ArhM_bJ|NKLevsJU|^d`6;!;|Po@@;Fz`k)EvFCo!HNQ};Oa3uEzpQNyDbQbgHXG!J83$YVcMT5$gVq?QRKd;<W*3i-?DaQ5FihX(>{5UfPH#8kAdrdHgRXu)xit%f-;)B51ddFFSlHgvD5BTc=j|~GkKCBnG5*YJLhTyMG<bXBBewjywE8p-N@Ii5!LvFrsdc{A?YjH%*@11MuMHgRnL;-2k_LlrN*-z}3)_y`rWp~2?t*$D;cr81qUWPRToc-g1qkmg&U4o~f#;B$bKS)R0s9nO<PR7X*nO!y{1}>D$rCh}UN&=I+{00?Cq5E-KElF->Qp)Y8r5u(Vax|Y!X3aumF2zMKxlV&WNr0OOEQJTdn^?$u>TqF$%ws8P;D&j@+0w!2p|}7Ul3F-&Sbls=gGkN!s14I<C$@NwGH@s2eK*lky7i7+!f=utf^mMvj<g;Mk`Ee8Q!NN!yFwLKz`+6E%eWye_l2cAb(&8fQDgdDy(5ao_+lb7SNOs&@o*|Hc~10N4YMi(?ds%I8yUEV{-t*&Qf<Udy|o|_XT22}^ul|#y`&=8{u&^5$O}51v}Cg=v^_~*X2Don#JLcbEZ&BUXN*m&WP&IjoTrfgnTW+7XM}vtN%oOeO&NF<kK_^)Y%tajdLN@YrRtVkM)wR?sEOfmxW>jdk3u=|yf2n-r`Xl#3}VzVyQ-}!IXs<~xl59$lOdNTJ}ZQ9bj7jwkV+F2=lTaww*wXp^4#?sNUlYa?fVxzkum2kN(sYol9Rj$64JRi2$-wKk+@)P`Qe$~;v)08>;ac{DUSOpPA2N&BY1K>0Tav_GyXdl^>?Ge#M<)bRlQxUP;zx(Hmko4$#cYoYF*|{+YEi~bJUU#mCt?erwr-AXb5!*O}u~LSWMS#>U~yfrmT)i=%jlqz%qv8)NG}Fd}2(S0EeT@Oz71NiiJ6`^itX&<^H)Mm4D`>4_Zolgi4S;dvs2`i41jpI0)=KWI<BVN+edKY9<YpjXaJ$D|P<yhO3)2>J<-#!#<(#NxMp3zrILr-B?REa;}o7W8F+#;myco1W);hF82f+apOlyIvPwjm=<#zCU9~an<yTm{MNT&HeqOla3u-~CUIj7wI9Fddq@UPhG94{+BHiB`8N2qA;n|!Xc|Y9PmLB%L(x(x^G&m*8aZ@3P^4n&yWgfxQ($-=rv;-MXM>xJxeDg4ZwWVtCDW@had5a$dZaZiHbzQn5S3Ab&}F9Os3$?<#1jty8yQND_m8#o9@$$s+QflZK2R9ulIlg)<s=Mz3xyRfysC3Xp?AETW*!ryNyx6{M|{ESAXLDqhLQH1Nqc92Ix@mCj%)bw1DJZ)lsTqqd8zYKX66iB?nv|xiSPss!niOp(t_)<aF@#HQti%ME-W6#zQ|OHXG{{=T@QYWFeH%Wx<66rEkcBc#X5Dx(WlAqkRl|iy$g>RdemxkO49E|C-FD!FGF!at?o-Iu2ijdk7e(c6Q^f>>|EtmKCp##O0j!K_It8bCXJl@v4&pb{_;dTd-7by+D`bMCw`Fo@CLcKL97cuAX8_qORf5e(;l45kw)Ci&g&klavGVh7^6Z^b5~#~Hh6Uas&uKHEKZFL1~(*PSVqh#0OMz+^O#`NO}f75{7+kw5?9-v8CTN~Z8B<k@JgDi4DckElN2GuU^<^rMQ}7KeRU0DC(cS|K+F--k#+M>sETCZqc|QGvqHs3;er%J(ZW_FkbG=)L=b+2dlZH7lgrM2@;julL^6LtA{~|y`1#mw^t35sx5;}%p%nlV5C1tP7B{%iM`kpW;)nAjGTjx5!G!=uq?PCtl&ECc9E7*U=4r(KaxoVHOd1D|^;VkUo1%TZ!y1=*6lmupH6tb5I%ryxqDB`;e9xW6U0}%yIh2KcvY`k=xh_Q-u<bJ`$P%-ej#=5km{cg&a#&PHdQ2}`WLq>1Aa;=1cS8kf?|dzKLOtR1z;)*Kb<Q6ilS6D4#MQyJRp<5C03C0j`O!kI+SkM86o&B$4V=|Y`-?rL18=%ILM8m+4FSJsM<Hw>WexdYI9KRi8Ezql9|yuYQ|(6^sKGiNBZjt`VE#x`uu7?$J$J?)8<8h@IvMsyr;DnGq%u796JOe~`y#e=8-{v?c?)701V?97p5(2UP=YipM?LL@TnwGAv2qYpX(We@*Wd<2F$MDUNx-O}QgeYub4?3akXl3<+8sGg=03n70EUtiR)gDYzu`KkIwTZyhrv_|9Zlont2!ibFNOIkRz@@W;{C>Ji*1&=k>*}hhrp{y5*MdC;0_mfO}Q;8CZDmu=jo(}QeoJMHxOyQh*pbt&ZK^>;L*Oh4=>56fBgDfln0U!1P8Y`N{MHcAKTiqsQ-S1m>#Z8yLB>=v$IDSSQ9CL&2o$&mzfSqph2t|-&i`t$u9HWa~h)VKmJ?tF>C0y@Xa(=U$idVXxS+2=Q}lcm|WBQ9G|+=QK=3)$S8nB<$<5Z=4=OY9ekK(Fjrg)Q%JUX6B(t;apj~ByT_SMcTgQ{_4>yP47a-XpE08QzQKy^3;r@!UT>WJHk$V*A&Ok*lqF}*Kjd+CJx_*_bVg)924K$<tztvrLtZR>S-#uiSjuhh=Gze>p>DCSj}4uE_ac~|^4SI_Xof1jt#!PCYb|SwO<#7I`%a8h>K#nx8iWMgh!oc;hDZe;J-nvs<sdE}hkq16e8Y@~pNvCAP9_4i9KZ`Xao1fZ->!nKOCCK&s5n24O(5Tb=`Eg!XXz~xFq=r_n^7sIcB$y+>LeEE(Z-+o(Uts%E(TcgE;uI|Rt=a~sxw`U+OT;no@Vs=rwdec2P+fbrI^Blte^Wl#s8@g&>NKF5h>L-l}H$oagd*I+Gz0Q39U~(`dN)<!B4cEOl&k0=5mBtukrAO(FYu~H|BT=GN<C>BK^Sx3NF;~Ep!J$*0{P_S8IJ}?*E0;rN$@Te&TwdrER2aFB<0Wy)N%!NfAK=t>Q)N$ECYU=;d!0$(^MeCb&P__}fdP@CeX!>RW_T*{TD`8eL64u!Rg`TrlR2ed>#a%x6gF0C4(W9&kuF9;}1&p+eh@>%)YkZP66In^&tAebkGc8$c;Vgm@uGM@h-w(2>uX@D~1~Mq(2K-BF&&ktg9sCZn?P0BY*#=(rd6MAc)kps)NgzPMa#K%F({ONix#VMo^pS7wB(iH3F21QDX1{=1Gm13z#ngCUjF9J`BRJSRT6qYk$#sB#b*521VxVhn+!gb*kl(2WUnb66PXZFa#Etlc3-ovC-4ghKh)a$UPDg<FK<PaZyV48Dl2oobIEJh(ujnD2Y}!Xo_zZU)N)`DB%OvcvD0Jwy6fLJRj@JwKLy(P}VdSoSqcss=R0B_C0Y-l;o539s(na6W&mMy~imow?-?0jxf1%p|Ustea4sYvQ{9sD7xb2X91%!pK}g*RmEs*GDQ`*fJ0)?%fGKmKNX&VUzVTAW9K-f4}gh;X+DZv^ZQu+=toSEScXY*Eh+R>D}G*`r&Kx{^kyUNN(?L{<xcdOp}Kj{(1JVhuQT*ayz^GIDdGUy-VJHHPhSMtNG>h?bR%~nts8Tlm2x%yM0K$e3)G)H(375{C<|)KTPq${5tt^H-DI4|G^7h-rRn@oB#3Q!F;&6dN;e{FI2sv-TB4jc6#?PpWOqF&+~V)7^Y-0y(h3I$(Q-Vhnr6i9(Z%}o)-C<{BwT&E=^{0UTF5O+q>EQJpn*#&p#5xGy3EF`ts`2JAx%m-qH%!HxJ3xoK8lMJ=~-QyXmuTbpS)_f1KT2exM(xZ|7HY!WTZP^?v?vO<OSTrULopr>p6mx&3r^dvia#NCbtn2qFA#e*e#ePN0bWk55y-5Mh_r_&B}3oMEr%%!aNB$4$Q8e1eLgb6>q1AO(n;CGTeMXO|E2&$ARy(l+;>KF$>1_YbtFnO<Eb*RxB4cY60Vxu4yAo?kK^?q;{s`5mxyd2@G%Rc@|@jDEh5;&PwxxN=p?A~CK(L9@@Gk5AWEz{K6`KR(e}K_$tMO0fR)kGmNoI-&{lWln(M_B>%ELKrE(LVpN^@s&vICi!^tZvGzEqJ(pKbNzYt_1?r-Av_0?oxZ&RV%`!UbB2c?0G4oX@1`H8f6VS9%D|pRKeC-B_qVglIsQR^Cwe3TxDr%d-_u!fwe$;JB$?73V+9bW+@twKi~s_>c7#KF<99KzXJPL{qD-!C?m>a(-SlCaFvRq~Z)bS=Zgx$GVji1bUVgeGe!~-ZgP^(pL>xH3mfOI2nZ@UK?~G$IrrY<^`PHYpG2vn78$uzLWCDzCLY}xkPYo_VnZKv4E<fnCB?DIentY(EcsrxVrtdz_nH_Z>0&=c6q0{jSibtWoUoPa^BKRbRr@;GzCY4xu<pZJTJ7Vx)IUwXve(#5TNTqG~qMsN(WsPA6(!3&*g|)s}rEtgXQc@ypU=rG$1VDR?a1sAs3{+hy+o{ivaZJmymQGMKwtVMrB(w%Gtwmdx=%44o$zp!MMlYU<GJ^d`%p|hGLLup(Hz+g~3=t99oh1W$P=1#1M~g|@kH@+m`H$$5@A<?R2*ZCL<hxE&Mv;_rJ-E{HuTXi{WUMLxZInUM@A|MWunS)$cI6EE$!X1y=s6y_&#@)VU2FcOZ%4hQsb)snPG%UPaBs~KbzcUmd9k81!%t_6ImDmaL}*mLCo%jGulus9&o4RO*nK38Ys69%Rc9Iu4CbqAo${8ys|lQQ9J<X`I2s`KZ*SbgWKl`C1s4%TW%lyDmUi$(OvCn<Ml++ShQp!6yb>>=p9f{z+f9FC_h;g5nhBg`4T~h(nw>g{FSzMBtKQFc<xkndHdW&K4d~?e-Hf;B{4ZK=C(@-CO<`Bapk#hHkp{>we%Gl)&dNHwJWqbZbh_VZ2VSCf?R&q=z7P7nR#&z$xb9#5_r?d8Ty)MK)Rcqt4IR%YK5Hds?ZCg#hM&_meCphogU~{#qmcHavthgG`JrcXaU22Roc`NYYor%klMZ|1V%gJm%2ZnTqt0A|25~0a8{b!p2^zeX3w{P+C2dz@%ZreE%J52p;dO7t6T}M7`Qa{wA#Spp8ijmBOxM1$d01I@dSRU_7tJCIxD<Dgh#i#=Hu-Jcb=zNGz1r<|7mrncQ8$mTT)D@q-wB{8O83xo6OT5*5D}4`9RHS2kMqoX#QB=K!qg~yD<s>Za)r(oE6Q!`hia8|83$WZC*|D7Rx;qD>5TFyf5w#$#ofRd4BPSCMj3V*5A4O@8f{tqP51r%FLUAn9m;5C#_9C!{ms><huPKF*pqp~cdFN!bbBJu|Ku;e?_OMl<;MIRR0qp)TVfvxOb*zaR}gOYP0>D*@Fw1F`632{kdMgHdcQ@uk<*2V{|cdlk74j{EB(2z)yJLA!-23T;+;uyvtmQUC$@vkbX%JZUjZgrIKTFdYWF`r&BOF#{fq+x)N`yMnUKLmbg`(vPkh~^g3Pt1D7EBWE%9}|M@56itHW0i+!y_9bIvtg@NY?Q$miBL>xBtOG6BqyOR(`KA&u|Hx?{qM|K`VgpHm+)j(piU`mCf_X!wPC)t<TW<!xe8^QTNIk;7*sjSu-qrCU5KjD$pdKQcLN8@@~J{?JCf5|LcaP$1US$YWaltk+(f?PTmP_jQ6t85ts;xw1$gK_FZDxWkT`D(W;0so%`e#a%p0_-N;95q4T$fKPY3x)mVg3T0r;spuZ6glv`{$<|<`4tLz3dYId>P(pL`Dz@u_OzC>N-oM(d_b&;}FU!Ymd9m&`C2r?`0k(^IBL', 'NEWS': b'c$@<O00001', 'ChangeLog': b'c$@<O00001'}  # noqa: E501
lttoolbox_language_module_files = {'{{languageCode}}.prob': b'c%1EBX>43q6`niq&A!;4#p|rL<9(YM@3Hf~aqKurZO8GJmP$2Fvownx*KtB<RYXMv0)g061Oib3MMW)3TS`SF5QwEzViOgmls0Mwq7)Dkzu+(Dy_tJwvqM$6wUXSKc)ss^_nh<Ya_)VTNbzg5vFp4P3w_v_x2>)%WFH8+9d2i2(BBj5i6^3ocru!dxjY!NV*zPQVi{AIB{r86<}!ja&*LZ-F@bq3ScSMB)47m&YMsGCPB=%x5gc&l35(=0PBMuTSfZaf+(FF;afliwtt6$1q{(MV&oe>2n4?caFzb;D`A%R#C9flTHY+FOIb{*XbdDa#xlHF9)K!}>(lnGgn{l1P*=vq-Gff>?$Zw^2!Ge-8U0HSB7{LOMEtZRNWMzeqbO~cL!4tTh^l8i%3N!>uPEfPcHfH4nvxz*O%;PE5n9xPso=GrGqaDvseX*!JIz31(Mo6w@)=Kj+Lmk~u5l6T&PnpKJVf0)v#yev%re9yVg$!Mwu-OdNGfb*khbglj;K)Q}^64|0C{dCnN=h+icFI~<5{GbDA-6?LD@I{aaT<`RGH&RTIIdEpzSjFyDnxxMX#LNT!x5U;DSc6`WR4lDJBM_}DUEqMkwa9zda2Ci+$Kn(wDxRK-)6KQ!^~crD0gG6D_w;)FNHv{o~^53scux1zgW-KP)*s^I=@c!cJ0}`RfYXssx8>viZjm=%idb78fDU4tQu?AlFLVH;k4yjSQu~?+L>h=ELM&68}bTui?hR)%WRwwuH1F0M*2#QI@6X%n>pu~JsRAuVkL7}_#7qrfwEF<+UqRUaG<<Yr8TK2Rq0go<oC(gMO}^}g<{(aHDlX#7HY<>?6Bo&v~Bux^F$TV?aa6MHtV$&s55PzLOX9K_iWpgOl;efO4{?9j6FJ>yQH!0Qzf@1R&wW2-9jn4bvSav%D=<d3sgEL>s@(D-pRPfQJ@<KaoAm|WsdK<ty`!-LWOyZ^SGf<GmhV;Qf;m=zqiH#A8{5dv;fg9#AIv>F%>VlQ(LyYRa;FaTfxydT5tjaMaSq!$%(0n!*riGd-s-{oJfz*R~D5i%tT*aER8n1!|8H+yk+GTK7SxsSyf$ATNesPqOo{=LsNT4XIEc8Gczl*GY4}r7jrWY^RhBl&MKIX`B{JkStYAt)vSiqvN{%GVHROg7GrT%&l*@G+ryezGizb3tc|s^4%W%KSU2lo36^9j*30@>KO10!Y={l-9nn60XJq+OvrnQ#i4rABl(=(f(qGos2LB&w|2E}bZ^2*U?&5COl|+dWB}#nk>Wc4Y|B`rP;pi*>NwqwD?ftjv^(EdKDC<nl=Z%fKeSeoIQKCeN5+zEMC{dzBi4rB=x+wph>E^`Ut}BTWB}$YiQKCeN5+zEMC{dzBi4rABlqgZ6M2Qk5N|Y#3qC|-jB}&{5|EoUmRMXL$4M$(S`22X{*AH^s?f$&`xZ8ClQKCeN5+zEMc%$HMe{YlDn<ei2dTwV+yfN|S->18MACM?fqC|-jB}%+eaJT=zy!`zI^7jx(lz3|+mQ4zOh6+<TGut>*%$%u=GmC{YtDQ5ONqarZten|%%)yyMXbvZ5PN6wnoVkSNa&zVun%l#fM`#`|XI`Os%Q!0&T3I<~<w7g3;H*Mu6+X^<Li71K^9#)%;4C1tK#;Sb(1MkmRSK=LinA)ARaJ9VEwt(y&T52KQ_ESc&}!>As}ovXh_jH;LSfFrLJLPYiwG?e<t!?+XpFO%&|-1U;zEnpb5<|3`UcJ#gx1i=S>qmFO?#R+YZ87<&73v2@Ya@A&RW|zYisAMUBtF`aMmHTj!w=xh1S`{S(nhdx;g9a;hB39oF$T+B~zTGdO7Ru<E&5Q>+9#NUugXUoDGO48VwF{HZ;uH@LtaL*^Eb5-eEl6GL1>QF!vizs+_ZApJTeHKPGtvCve${b!^~d#!%?vBsMc}%8XV0<04KgI>VZoe9xP)hE0YwhE;}BdX~Gfkx6z|%_cjcQq&pUQKi-k6uqvHatZ4yId0N>Lw8*v=S>SP<2cS!)D?wdvaTm}&@-IMI9}9KWs+Z1402Jo4Wf5zJ(FgIu5l$pSLwPZGE`5uVKeAG<Z@XzDJVfdN%~2tBpH!b>g^iN8hyUN4ZYvTxsjbF{km)VOswl8U(=^-lVZryLr<GYJg;|aL(PQatYY+?#4|cyBXKn|z!UnEtWy*X=rqY^aKTJjR#lo4V~SLYG>Dayd&%QuW;XOu=}WP1AG6ZcS19_lJ~9&?H|IU)TYp-nm6?sV{xX-mw|F)<y>q^7o4BptO!zB8QA*mlg@39e43Ab}#t(SICWmIx6pd*%4R30A1Hj7~UefRavFE6YuWEQ!!!sJ5*6^f;CoqQlHC)kfNuz0+#4$_^VXT2l{F;UrHOvDh&86TjhBU){jE$Jyj-ig4u$(g)9-*#(ld)k|;KuMZ#)h`g1{oV*O40_X0AqbcE~z5BsNLG-*PI#!mt)L>31&%|aj>96>L|mqg0zDBl;Xb9pHWsU?vSE32Q)WbRx9dovtM&*R!yP7;z+Qd&D`R|7%P$-#nR3i#l61nY&jxTT2S+8Wtv;FYpTYuR8u-~rNOEXZVB^Sv~Amww>Qh%=d)FHXkpEZ<HZ@?jfQuqrfv@9EiYl=PH_3KUXsc~n_n-)o$6cR^{d{&+=ZLae7y;>S+S;Id}psow?dObe@U@0tJ!9@D-Ok}x>UE#W2><H>_JDRBjgM_qt2MK-qqmR<8E>{ds;lLo;FX1x6|8Q)>D=&PnGvo^j8e}hJ1VdBmRAU&5yJnV}6YLG2zF7044)C7{H+b4hL{s08;@>2QU+)lMk~&91UWw2J<yosKsI}mTGaV7VoLUoprdY4$F0TZwM<P91r2{5Ke}1DvW!=I1|RXFwTdu8pc`}7s6N%<K751BG`=JQUvdd;7SDdMR0!v4@B^R2tF9agHe1aiie{3a1<Yj;-gV~EQ*gu@rfut8N;Vy_)H9+jp5-KJ{QC1WB5W0UyR{PF?>0WN8<QO9AAy&(Kx;y$76APBaX-8cp{E()#Kas_)Zg^Y{FB`c)A(iZNW1w_+BfXZN>N7aJ3CTXvYuR@uLp>xC1}w#7{f%^DaEsg<o{z`ELBO2fymUZxZ-z0>4Y*g(QBT!iy>Vp%*Xp;*WiJxetHp$1DAKwIA2|@!9}hAHbgn@s~mTbqH?^;cvrua~OXg#y^Jt2PPOQqy', 'apertium-{{languageCode}}.{{languageCode}}.acx': b'c${61OAf*?3`F-mh3P&CY*A>1#0@xs35HnYQ=GJv+Y?x_8;xe3o*ma1U?C}-)1lw#Z9fj3#f0HqxG3jQ%FqGWjZ$!;;)E{*^qhIYK&irafvz?JaDtdqzOthNo`f`<iNM!7?TvZygEdYhmFK9l+<%QZx)p9&+Eb_zT8vnmj0UBeiTPLQK3Hu%K>', 'apertium-{{languageCode}}.{{languageCode}}.dix': b'c$|$`OOG2x5WerPXof>Tig!qILBVmf#Ca_2!`Vl|Q&xMXZ1-lSd(sc@niB{CCnWA1P(VU(Kte*wAwfcl6aL5YOQ@c)y*pFwRaRPQrsw;rtG}wQ>UR6)NuIF@Xd{%o5nWk-Ct@HIl?pk!5gi`fX}ufW?5wp@kyu1<J?*TmG1h*g)nZ*33JJ`Pf$^*u^8r{kfJ_~)vsSC)QH$XY-<Um_ef9F|(`Ub&K6^6zcJO|3>*e=pclHC^p8Y=i?ezIKr_a9|-WlB;-xHg&KaM_l^kKG@Z_6FEJNs+)^z`|UMep%_y=V4cJ$dz$J$UuAJDfe6{r&HslLyBSPd=J{{KY5jcsXC`qe)?CydQOc%`_jVjHUif_(d6ZEbLgwiqT<X(6Cs-+zdl)WW?%!$&F}7IT^)GU=a~uPpbknlOg<Mkikh*$3Fl)xXf@|Bs>c+a+Nk1+bZQ{BnK4EUCq9SZ@3eY35@3o%D{kb%y8*IVSF#GB8>UuJY`Psqbn$hJTh(&)#liD1En$fxWxoyiIPW7mYEk~CrZ`Xw^Zx(**u-p*&C^MQ=p0$F$*1vE)>d$Aih4$`I!h*98uGo(t<vMurEA43fL~u69{-N2^#Zqk&_M6)@qV7I3@-zXxyrT7(Y;jlGB{JEiH9h+Ob}NPt=IuZ>f<~IZ#cMrr=#Y;!+qM7BQo$Z)8@3VKK{vNmy~Vc@0$xKbfXdJsiVonR#k(&ubVGFZW>RH~a)HV3`0b5r|Lflht`CP{F%^iIrnP)HG2Pou;RZ0b}N&Z{V*`1+N&(ic$q?{wjrEmFY_OH449`&%+z#*HZirI2%}~3qTL8b~FWtf#QD$P(Bopfb#%&o14UCA+&2Yma?y~5y-T1xehlY3g5?a=Q2(gm^upXx<E%M0-K<hIURtSKzmy_fIFsGvKqxrrX;C0<-7}1Rnou)>7D~OVy<$6-cfnk2?E86CkZV;N#aZxj-ep%yWkHGq1})I^`#3ro-?ct+ZUFWtosg(FIVgsI~vL=d>_zi6t?g<P*LwYtg~V$0(mciPPhXrY(rj*oAvEBjv+b;g_*`}Q&vZ<U{3;CJaG(gK}4pUwwTQv%Rty~G;IT>QN~cd6`?~L=ppt}R&b4L6-5@J1&V*=|AjPeCWOY9<+X<8i6z*Lvct295=kHfjgVyJ`%`SNfc~(z)R6JTA;G*&eKRzddgbXR;9Q~_K`C2vj!O>*#W)(neTOm3cz8Eq_6ORzKjYEL#1kFZ);f5mz~ddk9^%EvNy`UWsKmHHiE%juOC$sWfMa;G0=!<ORK{k@sASAJU1PI3`!(X2#WTt{P`aE@O?a1^F#%>6vL<i~hGiCmPaPu+J&y!Pdtx-cn3X+tswU53DnCw_pabw~k|mzzB*rmqDVa@MTT#`1r_8_N1*W{PW;kEVh!mLL4QxRP=67jpFIrCSZOzSS??=GSWu`Q~4qcX&1-!D`j^|fW|BMQS@27t6q+*nxT}vw{xtLbN-pjFa2Ks#&RbTKMblOFyopstV{_9TLR5#do{#2gs@g>GjF#=<FT_zqsF6NmP#3Bn3@ugba+S&75AX8m>m`L$N#RaxtJ1qb`uw14HjHq;&a$3Nda6mM}$mestqE1_M%BOZLI$q71l<~qzj9TRhb!%9bp}AiItA|X>OCSy|=0ho<^Xd9$H{ZMd#(!V_`r@A#Pd`T$f-29u9u=vwa=GN4?Sp`YB&YoI{<q`W4>?}DwLLJ(=>*L6a<Z|t#q~Ho7LUX_$HHud%h&NzRgT2lc*97=Nq@kNNX%;xHs&M!9XRf9aXcpS5%hap=>EOkhX=cFdW)GqKJu);bPj{Kv~5-!-x9|5)v#avq+`~6nEwY^{T-V', 'apertium-{{languageCode}}.{{languageCode}}.rlx': b'c${@oOK;jh5Wf3Yj6x1rB5P>XOVU<C)KpdpRDjweTI|8zu->uu0p;IkmXM%U>1CyznQy+wZV#r)I<HRyI3gIt3OqrDJ7o}#jr8DU?Z7n@bOl?4l8jRoS{`(0Jem@DT&q@jv`)a3Eciw_z(2C>G!B4_KEW<%4bD>s+;Zqax+_d1-||`USgiBq3ckS2XYut09+IR7znM^)S3Qh#uw#Of+Lla|2Bi)zGAFZQwT6jw$Q$|wTpG_Vg$L-t_)O`eomTp?L6)a{gBB#rDHvEOQwJ?A&|B%J4p!<US>=;;v6!=%Vh0g}(Sii`3Ndk-L*pJ;RX2VBMO1Cb$G{{U&~D@6I4F{3{<!#+v$zx%OXwd`D5lUKy=YEfZ2!%~kv|1fdc~G^q%|Em{Ou`r(0Zv1Pc&pb&>03!wg{8)Dvu$z`~qb|#JRL6*v*Xn!0qihsS9&yo=Tz=X2tvmj3$@vMavQ$1zV!K=S$;#cb{bk<+N~B5Y;{_>yM)Gt-f|^OQCb3CaN_Geyf*C7Qc?Stk>VwR<^CQSIiy{%2Z?wYJC!9YZ3O@hv8_L4L`jDyz{}6RZ?fy6-TvKLUtU93T<3*u4I!p@aFr!tp9<GFO`in)#e?1@(jd~5ts', 'apertium-{{languageCode}}.post-{{languageCode}}.dix': b'c$|$=O;5ux488YPnA}^#4WTq#5J!Xr`~a`@R*N=?l5AuDp7di|4<PLj>Dhix@}8}qe}*0o9HKZ|tB2}d0o%s4Vt2Lr`g|=P)w3ydD^1D_3MW$lXzG1O8%}77F^ny5<5*ZQ<g2WLrdDrmZxv2GxUfd-DXd!NXly#ThWe=He6H{rWh{m?%B6(-4~uVN$xSSG6Knq$OXDnS)_xH@*~OEYAZ@J%lI&DEd9GDVWZO(!^y|B_gcsh5<vf!Vgd-d!bz;X4K*xbA_+W-ECI5tYly9lXb4aouDi?NB2H#yw<&G@}N-n@QpTPwNu^A3D{-i3)<;kl=zmnJ+O_=T9pwZZ`3c-+_v*BuhzurM%HB~$t!^=L*HstNX^?DV*-La}=', 'apertium-{{languageCode}}.pc.in': b'c${^O%L>9U5JmU-idnc7_d+4y1KcPmxRoIp>p+tUlPMHR|J|yfD_8fy<=mol=b`cCt=`c<;r0p5V*HrNRSl7~@evJG#OB~vSV)cg^fk+I>@c@IwzQE*)8yO{6RqL@U`sV97h}n5*mGv1Wi>Q{Bw8NQNy`B{FvVPBA4mangdn-j6=#E1F(p*Ei^328`knDt()vdG>+XCxoQ~ePC;CcT0R', 'configure.ac': b'c${^R(Q1P*6o&8f6uDGzu~xc^!3tR#oM=qu5;`a&WL@T@I;B`PkiL7XZP`tGclh}}&N)9OTI4jRFU}OrrY-=O=s1g|v%;<2cIB>yeP5ZMVrL4QncD96?;c!DP=F@G(D$}BWpzr;S-JaHNb`ACzPqk{@crL%Q=$uqnr$&AKEA2C0JHHVjg{mKCv><`<UG=NnE)V?NRwwu63zHRrS#Rog61+-%!8LbaQ+BGbdLh}3Z6>IdHTfPJXm#I(^MbL-$|HV7f2L(a9xB06rgZ`02Z1haYj<Lpks+#NuiE4GPAK?Wo6;ba!|WIK6wCJp?r$', 'Makefile.am': b'c$~FXO>f#j5IuW;#VBw9DK>3yMWMnCG(sXE1y|~!5?buFS!KPpcGoRUn*ZMM2Ok041POe@Gy7&e^B(gWjk7+a(SUpU$U-g{goy&0GG%xc+t1H}$|$1|yG;W2@<PsAxIxI+o!ouw9n|^i&W02Be%RYwrP(S{+k|-T!`;xE&2Ojo_tOdVEX(>ytaaR>nMvYAh0cP@ng}(<iJlH(5tGLc<$>zVK`cFbDpkn>4xil=C06-4LK@&LxdtwMkp&C_oP%T<qJ#=vjDt&Us1SCHz0ud;1T57ZC%A^Z{(=jvhG$lIhROh(JPq<$>MrTibY21X$=RoeyxC4}LSvj97)7NHGM}mQljYd7y3lN`+0u4483A8y8bz!Pi+)kT18SHZaNqDmQuPO#H^dUg_LDdTCGaOS`^Q14zuLRRnrQX6IH9;urxoAQGB1DFngTghT$&vBFGNo~1^YADKG+hzV5MVUa};s?ohL)4N5_;V+SsqVwBLk_uyw#SjTapGn)e@6h9bEjO)H7lkOQN{@}u&zFZa#gC65%1!O$qWs3`OQye{~ON;BQrye-P^O0c{K*cv{7ox!Jq@Hdwlw^4kN<-<NZ{_uzQ;LZo5nb)h+ez6m*IyKh^kr@ZU1IbhwJIyZ_p;fF2XBCT!^mJ4%qf$WHWMO#zD!3A1V?yTp=3pLh)vb1>hTlu37?>r4Tt~R|0zk=8#fugC29j2O4VX?c<yUJo$04;K2!I4AS8%(dmsGLNI=Qnm!A?Cyb&q$#{0C>?dM={8c1UQM(#Ob8WXL0|0zKHTvk7k#3#cM>hk`yKGRfUYS*Re|M(JozRJttO2O(?Ag6odjBJru{zP2&B5gJWqo;w~FVD0)f-fRtqGjA|@Xg6DLwXpq8TvXUOaSz0KA~?An58cVP(Res3dcHqEUoa}GJ`&4TG1w|B{SB1uyoA&}rp@{Hg+bIVAQ6bg{AB`H-gGd9{4HoE4U;~*LT9mV8rW!Q!45&7D~A0JmZZaU!x%U@h#ebZ_4kpfq~ec8g)62rVe}Pxl`<WLfcXIr!|jV*B<%H(_x}JFOl7_', 'modes.xml': b'c%03Y&rZWI494$$3d{GjATAu*?tru>fCn(C7b4|Pm84~8+Pjmof{;dqsxgV1W7+=s`x2$z?5%;3L)6|icw62eu#>*iPBr-SxE1%fX^YzWj$>OC03RVZvfSX|V92R~6hGwT@hGeh{R@J2F_AG1zH!7hH|4fo_iVJ|({V}!uL9Y5lu05dB#2l1tjIMxZI)Oi4asNTu6))GtFN)uJa@)c-??=)E&sa=#g4;eGSnIwnRf*hiIloj#^2t?8AqzMoM84>u&UFM?0<JkdN+a~5C)-IC>wP&Qr&?NDUjslcSt>lqz5a`_WQ~5wRWF^>BD#j1RYtc', 'corpus/{{languageCode}}.tagged': b'c$|yN$S*BUE!GE9HhFe71vz#qTycp-srpH&Hf2dUsTDx6qSRuLXhvdQN~J!Sv`I|K0txBq>)8~i=9K{10POY|6#', 'apertium-{{languageCode}}.{{languageCode}}.udx': b'c$|fl%Wk7E6o%L7vvkvT&4Pg@N~I8#o2IMC-~;0dY-(esBlY128Xt2rt)eK(_y0beo4Ky8tFrxepAB#d(%TW0uC8|-$;QeWN+Xon{LFnXtK7(uE|XS1GM*c$D#lV=Xo-?!M%xKNy)CDoC*TUaSb{<iQT2l9OEG~u{|}KE#~LmmleLg#>&sBAv4U6%e)?B|x2>@R4z@hVNzEGYUi$<e@E}Mfxc7kkam*i)KaKg5;i)JqqlA!4059mkt-X389W_cq(!Rf6dG9-7DyH^W#yG2?>x>a8;2PM9Lpx6j+4N)x*sC1mw2>RIGp(jtOk_PD8OxStKNu_f#`Ec`3ewu!+Ad}Ff_<$qV#-IB;D?AQR};HkxRG$wiDPrwlE?WhX2*Za-U?Nr7rM|1x61Xx9qB8t1ZHE$9SdbA%8eM1_SB~Pd)s_b4uweA3y;YTF8uxAYD>F72gnNenB1AZf6g_*CUT9BkIuX9w`J_jplx(|F-!r+2E^wmI2oLl4p>w~I<R!(;$4Gs#r_M4p~qKDE!RvqtW81@U!D)Y3?+k!49p}+<ScNTo6W&L*tl+tqm1_F2+vD|@nPRX!~8JDhVi#lV6H*1k6wB~X<P7EAhdA^O`_~;!ax7EwB3byFB+mh9Ns^qamFYGoyQ;)7sC%R365LZmK{gd*jVGm_5xg(LTwi-d_MK&R+wQ4MgO#@k1#R*2a!?{9R', 'README': b'c$~FYQE%Hu41T{~L9_*$6qbx4*d79OSdn6F9<~%|f?*g2>nu^$EvGx}?i9z!`rk+1S+X4`2!bU>fLIiHBtL#6&$qW)nnf=c_?v9;`}bogWQQ)OzRhmOcPF-@cZK-yydNPh8s&lhq=AoXx6oQ+wPME_h5(?G<rV+0t%KV;G3W4mBZFAk9!ff>_XvT{z0deqh<EU-bzNh%U8s_LNF(*ilfJF@j^0yVpg|{tvgQHxuhNCg)|u}R%Lam6EGU<ImBl&!(<_H9n&3tDydNR{AUu{zYcPlvA;S4<ZI>L5w{=)bhoFoPQfsUtFggTl_1xaT!A~FHDE}dUe@Nni5o_s>NqVikE*D2p_&z^kp*XD*^p!;q#s+BR6%xWL@Mt_vV2R+cv@PXa0ar|0dj&Ea!*aRI2S>Sei(H5k+jfen@ciI>R@Z1EC~m6=Fh@pb1Z5IK^o{LxMejh)HF3+r-@OmudPATUMKPDY5pO{D!E$b<hOE9;B*~}zq!ztHdSWP8Jym94YLQRbka(5*riiXlR?L@Tb6`ObR;)UnN18PU_m*l{jxg2Ewp82Rm6*q3tTigjX;pZQ+IF02O02TxZGc8z$E4O-M^GvmWYiHuoGL&?FqJ{CAi7C)jw0(;qdVAQ6+6AZ6D74gbPgl<UWL@y(ui>i1SgHxsna^C+=SyY6fzuyRmZ(ZfzUC|63eDU^w5CsD|?t~LO^+|QM^tJTnDrdzl0*oD3Ds+6zPy%l(%q+F&k^L=#q@xM9lj&#XV`WavDDLOf3%STv&48JCNXZdV<r71?E1n^w#YG<`ceAVXMWse91j`7Z8MlbZOnygv1C<2%SHkPM7LR?KD`FOixo>v%%wxOFx^hW*b(C3-sYdx^Raw3Aaez4X;4ff$*SSGYlOkJK3FOf~N_g=Z8M!)OShn251ypcy)31>FgK+Wy634G$p=*e>dYTt00HFTQ6&Q0f;TzabY<0y$<4kp3f@+-L``y8IF&f{Y7c?ktAH7=dZ*&`19e#pYI7OYL~wbo@Q_e87<SzZm(3y^p|cGz3-WH&d$lny>dS5BB9ihR6jL-r=J)<8L-b2VidKmG66n2NxY+uQ`GBo8W(9+xt<F3NI0GKVPE<frVm<iU|;#=`f_63Q{m{VC&EDnv7EB&sG2@)gw5=hB%)z>X=uwjPqqGp9W8un2t_QeQ3e{92_-I{&u>~y0gT^cdAAlod_hfMx!iGB(7I^T^n8I<;F0<0#7y2FQ+^QBM=dWsAv=?1HeSkRTOA|5pzh*4@O{@=7hY^Q$J=AW-g<xELZ{uuduO;X#LY^BH^?%i%eIVL1hn#W%Nz0Vp|9(oS?KdL^r@r^%nb%IIz2z3Um~vu?E;7d%9VNT5DnqSYH&aj!tbtpI-1di^c!tJsl81*gN7(k?&Iafm$UP4M7Z_0!wE5})O|&n#yu2oHq_{f_B#Qdi~j%`)K_x'}  # noqa: E501
hfst_language_module_files = {'{{languageCode}}.prob': b'c%1EBX>43q6`niq&A!;4#p|rL<9(YM@3Hf~aqKurZO8GJmP$2Fvownx*KtB<RYXMv0)g061Oib3MMW)3TS`SF5QwEzViOgmls0Mwq7)Dkzu+(Dy_tJwvqM$6wUXSKc)ss^_nh<Ya_)VTNbzg5vFp4P3w_v_x2>)%WFH8+9d2i2(BBj5i6^3ocru!dxjY!NV*zPQVi{AIB{r86<}!ja&*LZ-F@bq3ScSMB)47m&YMsGCPB=%x5gc&l35(=0PBMuTSfZaf+(FF;afliwtt6$1q{(MV&oe>2n4?caFzb;D`A%R#C9flTHY+FOIb{*XbdDa#xlHF9)K!}>(lnGgn{l1P*=vq-Gff>?$Zw^2!Ge-8U0HSB7{LOMEtZRNWMzeqbO~cL!4tTh^l8i%3N!>uPEfPcHfH4nvxz*O%;PE5n9xPso=GrGqaDvseX*!JIz31(Mo6w@)=Kj+Lmk~u5l6T&PnpKJVf0)v#yev%re9yVg$!Mwu-OdNGfb*khbglj;K)Q}^64|0C{dCnN=h+icFI~<5{GbDA-6?LD@I{aaT<`RGH&RTIIdEpzSjFyDnxxMX#LNT!x5U;DSc6`WR4lDJBM_}DUEqMkwa9zda2Ci+$Kn(wDxRK-)6KQ!^~crD0gG6D_w;)FNHv{o~^53scux1zgW-KP)*s^I=@c!cJ0}`RfYXssx8>viZjm=%idb78fDU4tQu?AlFLVH;k4yjSQu~?+L>h=ELM&68}bTui?hR)%WRwwuH1F0M*2#QI@6X%n>pu~JsRAuVkL7}_#7qrfwEF<+UqRUaG<<Yr8TK2Rq0go<oC(gMO}^}g<{(aHDlX#7HY<>?6Bo&v~Bux^F$TV?aa6MHtV$&s55PzLOX9K_iWpgOl;efO4{?9j6FJ>yQH!0Qzf@1R&wW2-9jn4bvSav%D=<d3sgEL>s@(D-pRPfQJ@<KaoAm|WsdK<ty`!-LWOyZ^SGf<GmhV;Qf;m=zqiH#A8{5dv;fg9#AIv>F%>VlQ(LyYRa;FaTfxydT5tjaMaSq!$%(0n!*riGd-s-{oJfz*R~D5i%tT*aER8n1!|8H+yk+GTK7SxsSyf$ATNesPqOo{=LsNT4XIEc8Gczl*GY4}r7jrWY^RhBl&MKIX`B{JkStYAt)vSiqvN{%GVHROg7GrT%&l*@G+ryezGizb3tc|s^4%W%KSU2lo36^9j*30@>KO10!Y={l-9nn60XJq+OvrnQ#i4rABl(=(f(qGos2LB&w|2E}bZ^2*U?&5COl|+dWB}#nk>Wc4Y|B`rP;pi*>NwqwD?ftjv^(EdKDC<nl=Z%fKeSeoIQKCeN5+zEMC{dzBi4rB=x+wph>E^`Ut}BTWB}$YiQKCeN5+zEMC{dzBi4rABlqgZ6M2Qk5N|Y#3qC|-jB}&{5|EoUmRMXL$4M$(S`22X{*AH^s?f$&`xZ8ClQKCeN5+zEMc%$HMe{YlDn<ei2dTwV+yfN|S->18MACM?fqC|-jB}%+eaJT=zy!`zI^7jx(lz3|+mQ4zOh6+<TGut>*%$%u=GmC{YtDQ5ONqarZten|%%)yyMXbvZ5PN6wnoVkSNa&zVun%l#fM`#`|XI`Os%Q!0&T3I<~<w7g3;H*Mu6+X^<Li71K^9#)%;4C1tK#;Sb(1MkmRSK=LinA)ARaJ9VEwt(y&T52KQ_ESc&}!>As}ovXh_jH;LSfFrLJLPYiwG?e<t!?+XpFO%&|-1U;zEnpb5<|3`UcJ#gx1i=S>qmFO?#R+YZ87<&73v2@Ya@A&RW|zYisAMUBtF`aMmHTj!w=xh1S`{S(nhdx;g9a;hB39oF$T+B~zTGdO7Ru<E&5Q>+9#NUugXUoDGO48VwF{HZ;uH@LtaL*^Eb5-eEl6GL1>QF!vizs+_ZApJTeHKPGtvCve${b!^~d#!%?vBsMc}%8XV0<04KgI>VZoe9xP)hE0YwhE;}BdX~Gfkx6z|%_cjcQq&pUQKi-k6uqvHatZ4yId0N>Lw8*v=S>SP<2cS!)D?wdvaTm}&@-IMI9}9KWs+Z1402Jo4Wf5zJ(FgIu5l$pSLwPZGE`5uVKeAG<Z@XzDJVfdN%~2tBpH!b>g^iN8hyUN4ZYvTxsjbF{km)VOswl8U(=^-lVZryLr<GYJg;|aL(PQatYY+?#4|cyBXKn|z!UnEtWy*X=rqY^aKTJjR#lo4V~SLYG>Dayd&%QuW;XOu=}WP1AG6ZcS19_lJ~9&?H|IU)TYp-nm6?sV{xX-mw|F)<y>q^7o4BptO!zB8QA*mlg@39e43Ab}#t(SICWmIx6pd*%4R30A1Hj7~UefRavFE6YuWEQ!!!sJ5*6^f;CoqQlHC)kfNuz0+#4$_^VXT2l{F;UrHOvDh&86TjhBU){jE$Jyj-ig4u$(g)9-*#(ld)k|;KuMZ#)h`g1{oV*O40_X0AqbcE~z5BsNLG-*PI#!mt)L>31&%|aj>96>L|mqg0zDBl;Xb9pHWsU?vSE32Q)WbRx9dovtM&*R!yP7;z+Qd&D`R|7%P$-#nR3i#l61nY&jxTT2S+8Wtv;FYpTYuR8u-~rNOEXZVB^Sv~Amww>Qh%=d)FHXkpEZ<HZ@?jfQuqrfv@9EiYl=PH_3KUXsc~n_n-)o$6cR^{d{&+=ZLae7y;>S+S;Id}psow?dObe@U@0tJ!9@D-Ok}x>UE#W2><H>_JDRBjgM_qt2MK-qqmR<8E>{ds;lLo;FX1x6|8Q)>D=&PnGvo^j8e}hJ1VdBmRAU&5yJnV}6YLG2zF7044)C7{H+b4hL{s08;@>2QU+)lMk~&91UWw2J<yosKsI}mTGaV7VoLUoprdY4$F0TZwM<P91r2{5Ke}1DvW!=I1|RXFwTdu8pc`}7s6N%<K751BG`=JQUvdd;7SDdMR0!v4@B^R2tF9agHe1aiie{3a1<Yj;-gV~EQ*gu@rfut8N;Vy_)H9+jp5-KJ{QC1WB5W0UyR{PF?>0WN8<QO9AAy&(Kx;y$76APBaX-8cp{E()#Kas_)Zg^Y{FB`c)A(iZNW1w_+BfXZN>N7aJ3CTXvYuR@uLp>xC1}w#7{f%^DaEsg<o{z`ELBO2fymUZxZ-z0>4Y*g(QBT!iy>Vp%*Xp;*WiJxetHp$1DAKwIA2|@!9}hAHbgn@s~mTbqH?^;cvrua~OXg#y^Jt2PPOQqy', 'apertium-{{languageCode}}.{{languageCode}}.lexc': b'c$~eJ-EP!46vyxV6epkv&@#yd64ItCP*t&-is`g;Di*0!k;mgCrb!(9(P>q&;vu-)eF7eVyM2^>l0A;&NwlKs4Z;^0pP&Cew$Je#M{p!nSIJtIg3%hz6m9j!GOnPI3T|&}+Lo4<d`TPr=@TJGwl;!QROPFiW-V(?NCYQT8IT3&j&oK4qlTAK39d=}TN}TCzD2N<wncI^lDAx~k<iTt&m!30eBjK8D^8GW-kN?Of)#do%lM498_|}~*_IhgjgZb|X@wkw^P8^Xj<IG~CxQdnG}NurNj=E+v1^n>E%J|6hIQUxxAzJSRhKwchrtLIyfE<b{{l4%PDNRLM^SfF4eomvXyR!qu7wMb8b|&7=`aR&X`3~sqX~Js!8u*+7d)x0qP2@u>A?zPV{5A1#AEcKKo4megWhMHHyqZOj}28f<n~q+x!FqA=h9SAaB8e_`8$ti==;KTehHl!F7HX-A;V;MJ)$4moIm(}JAz|4g%g<L?-}gF0e%nhyShV<C-?q-=>Ev!)w{!k<0YI*X$WyQ-1T6OoQxL~t%;DAPIcH8HSvEBpS=toqHX{#zghf3_v~jz725({!Mi?`$FRIx_EVx7;z>v)t>#((orVzh+<zHbS6Rkslh_lIggTNXeK?Z|2xN*pi}!XY-t#0I$&jpQB#|exP>Zs7=E=XGzl;oxo<8;EDSPTQFGoKw9RU(Q3e_r$A9>M(P^Yr^fhYfb-Ib>djRAh!l_Z4U!Y2NnP_zR6YvKVdj~|DUmBo)exd>${i!VGmA2sKmJQ+1ldh&jEs`tH}?(8(&YfPn<Rxz$KG%91dEKRrKQY5tF$_U#eQk6YPR|a1hEN?l@TfWW1!<27@sq*>ntFwm-ek~ZL+<Ve@yIKfsa#`e|Hr}`N!Wb#*wY<)0yUA;Q&F-DDKad%|iA)rN<+!seJU-q@o#Wd&b>p^rDNOH*X_gcs?TvIT+Vo2BZTec6KOC4B+RSCcClgCNzg;IxHfe>U>11o$ZNh|3Y{%O+;TxO&iRSZXzor|>bm}&cRHmu#J&aqGkpBQP88H6', 'apertium-{{languageCode}}.{{languageCode}}.lexd': b'c$~de(N5bi6n*zs82SK6G<grGs6tFdD{a?y8xld0<G6_-iG%I5R0wGwvB&KT_ypeiDf^OLJ4q=Tj2AXPB**ujd+i+i-n8(UkVPU=5pzmXJe4F@QAwG^Ga>QaT}tw}BrzM1jNRWO)WRboH5N0h3dU%HDbXwzk~0Oq!@Ps-XyJh<b7PsWEnk=njfF&4oyyXUt{ByP&P?7z#d6)T_6Z=CQ`TmA#Pb*zWlnWTG#55yTyjwnd&?qW)<&~Vz09%5GGf;$gsNy=Kw1jm8v9Kt>UBN=vRQFP<hAjowX=o$Y^L$e9|XB3jCq{A#7GMwtMoPn%;0MhrnnVIuDw<KrW^c&G7CZbtT~jWi78UM;3zF6Nv%?`HB3O8G9}Uk4k3rcYMF&1H4Cj(x97_;hC?`zh{z?d-*=dN_~mhihj@%fxCiek?&4#3p2BnT3LiFH<$Krtp;31_JsA%s$Xv>?5E_qJZ18D5OVMcKb|KV1IX^uf4xTX(+-oDcX8|0C*MZaek2=EW;}d*t#T(+m>$HEWW1~$YBSMKN74z(~sx+LNx__cR6W6I~+;fn#h6X=P9CT3Q1LS)(^gXmy!!6XV%HM0FU*Eph7!cYwEx_AHM>X>Zqn)Y+csppjDtd1ltsd$c_f`*R^;p-lw|azhKbsjqnEq&(0MTw$*WNDjFRLQ<{7d9t)Mozz?bYTz<onIWedN0hcFm1}Yo$afDN`Oy60Hm6xo*sLQicu{nM(>LH7_$aWw((VrXqARqBN84X9aE8$)b(81;6G_6X6IMTZ`N0N(W*VJaq#T@H&5@p`}AF2}qE$MbNbTU;*0-dLJg!R-fH+YMbxhGxfC=A`QiDK=LSnPoQsxbZbi+{wI{rI1ON-IY<UKMg{N_+Dv0U`kHH-iYn^NxN9eF$a8nj*~0zE^;cu)&6MtmjJ>RK0$%sct(hDM{RX!N|6l', 'apertium-{{languageCode}}.{{languageCode}}.twol': b'c$|fg%Wl&^6o&Wn6dy%d5_cVFrBpPel$+wT6(D3y(y=|nm&h}Yx$Y{JCt$^8gTx!KqHIQfFUC$K*dS&#=bV}E|IRpDr*fgJV9WvTlDiz@E|_qSDM#F=z2cY$JmeAWC693*dBTj4_6u`PaGyBiDeg1R1d;{rJLf3eH)0Y}G%sm?u_7a<p#4CJ`@xzDL;Dp=jr&Q%YupuY1cSHZ!TXV9us_;`+d_oO8X->0MrG`I(cbWA>(UE!@q+6kx8Zsl)3bZB2hHkCdD6~I<>f|U>NwV~*!18=+jM)qrHXT1Bp9pm9ihF%oxOd0yf-@yPbOY&mx$+nop*kr7ajQqGiA!US}HU0MQZJO6a<Z4>7iV!%IZ2FmQ~Vsg3wCeDUwJ=g=(Tq7D+7=6?F>HbP~>Q9u`(rk!{NC8fH9grEL#fn&mLoL0<$5T?8Agn&4R5v#v3Xjh&Xc`s-ujx%FbWEb}1s)8M~?^FP7=e$)jC@f$Q&!6^', 'apertium-{{languageCode}}.{{languageCode}}.twoc': b'c$}qAO>fgc6uj@R7>aTsBFj0@LlF&uQmB%k3J|h3?z6qb-nG2Xb=osh`30Q#xFGQlI8iQ^{}*eU1TH8@>}hsp-n@ASX`ZMhvA_ZDqrSoe9HM@U2_9mKM|h0p8b^47V?0H3g=eVW;{-Fz(R{)J&ryHCDPExdh?fEiOVnR+215M>5n?3Jc!TB#R!EV-pm_(2`Wtc-aA-b*QKJ5i3KyuaaVZ1_uLieWJa|36)52j7dpb|IbPomY3Na^kLYx#7={5GZ^V^BeQ$|~LxKW22bylY2Blc#L*>gg!IB}>nC$?l{io-;k7_QHVNO4)vo|vqC7kO_VfzJRy>yUD8QTqanZ((xbEuB~;R1hX>XoJ4$#t83f*}h`Sb{pxeZMLIQ-XHysl{(e83jV9o4a~^dvIxnI{U>40$5K{$rAI2Kf_0gVY!P>ioU`(bi31fFs)AIRxKuF(?Ipo<GGE+0G)zUnl}&$zIiI%D+y#a%97S4oAGy><o@=V)k>=Bum`0ALHlsfVW1m|tN1@GR;#Ik`;Nth<znj`cJ59&7$P>#dWE}>fHI56V4ZHr<_Q0QVniqH', 'apertium-{{languageCode}}.{{languageCode}}.rlx': b'c${@oOK;jh5Wf3Yj6x1rB5P>XOVU<C)KpdpRDjweTI|8zu->uu0p;IkmXM%U>1CyznQy+wZV#r)I<HRyI3gIt3OqrDJ7o}#jr8DU?Z7n@bOl?4l8jRoS{`(0Jem@DT&q@jv`)a3Eciw_z(2C>G!B4_KEW<%4bD>s+;Zqax+_d1-||`USgiBq3ckS2XYut09+IR7znM^)S3Qh#uw#Of+Lla|2Bi)zGAFZQwT6jw$Q$|wTpG_Vg$L-t_)O`eomTp?L6)a{gBB#rDHvEOQwJ?A&|B%J4p!<US>=;;v6!=%Vh0g}(Sii`3Ndk-L*pJ;RX2VBMO1Cb$G{{U&~D@6I4F{3{<!#+v$zx%OXwd`D5lUKy=YEfZ2!%~kv|1fdc~G^q%|Em{Ou`r(0Zv1Pc&pb&>03!wg{8)Dvu$z`~qb|#JRL6*v*Xn!0qihsS9&yo=Tz=X2tvmj3$@vMavQ$1zV!K=S$;#cb{bk<+N~B5Y;{_>yM)Gt-f|^OQCb3CaN_Geyf*C7Qc?Stk>VwR<^CQSIiy{%2Z?wYJC!9YZ3O@hv8_L4L`jDyz{}6RZ?fy6-TvKLUtU93T<3*u4I!p@aFr!tp9<GFO`in)#e?1@(jd~5ts', 'apertium-{{languageCode}}.post-{{languageCode}}.dix': b'c$|$=O;5ux488YPnA}^#4WTq#5J!Xr`~a`@R*N=?l5AuDp7di|4<PLj>Dhix@}8}qe}*0o9HKZ|tB2}d0o%s4Vt2Lr`g|=P)w3ydD^1D_3MW$lXzG1O8%}77F^ny5<5*ZQ<g2WLrdDrmZxv2GxUfd-DXd!NXly#ThWe=He6H{rWh{m?%B6(-4~uVN$xSSG6Knq$OXDnS)_xH@*~OEYAZ@J%lI&DEd9GDVWZO(!^y|B_gcsh5<vf!Vgd-d!bz;X4K*xbA_+W-ECI5tYly9lXb4aouDi?NB2H#yw<&G@}N-n@QpTPwNu^A3D{-i3)<;kl=zmnJ+O_=T9pwZZ`3c-+_v*BuhzurM%HB~$t!^=L*HstNX^?DV*-La}=', 'apertium-{{languageCode}}.pc.in': b'c${^O%L>9U5JmU-idnc7_d+4y1KcPmxRoIp>p+tUlPMHR|J|yfD_8fy<=mol=b`cCt=`c<;r0p5V*HrNRSl7~@evJG#OB~vSV)cg^fk+I>@c@IwzQE*)8yO{6RqL@U`sV97h}n5*mGv1Wi>Q{Bw8NQNy`B{FvVPBA4mangdn-j6=#E1F(p*Ei^328`knDt()vdG>+XCxoQ~ePC;CcT0R', 'apertium-{{languageCode}}.{{languageCode}}.spellrelax': b'c$|yo;#5=!&C5)yR7fnyFD@y{FUUw$C@!hYNiF8$j8?GMQixViSJ2S4(*!b96BKF`PVEK~j~Zrz$r&JlJqocv2vi!YpqH=51v1hxIXShUL?JV;ptMAxJhLPtA4sQUCMFkUmSiR)j6S>&Vs;|b0Ipa7H*YN>', 'configure.ac': b'c${@pU2ozr5PZ+CSXD?Dq!6H0@8Klw<Vy@h<m*W2Rf>@11_Kcxj!0;GiumtmCs3%MezJCFc4yXJWDtLfr}&S0uRq?m6$Kf@a;;E}P|kK`vfn~gr8HaZ>592@%MORR22oG%>pgj?Dz>Fb+C=G*(m7KMzBp3WWtsozcHfdsqMv{|->vFM7kx=>E6AxO5i|=u2Ticl=uf>7L4PNTvdB^x4}%bjeV+4Osh}|lvE$n)#OfG5VIs3$;A7hsGRE|k!8sz!8w5>91iR?Bja6RcEKM~K(J{7t5`<IB9jQ^L!!r7kvQ7h-YYH4s)Fh4~WHMf}c#~u+c%kuzWs7<H0=-@qWm99&sv7DmO`8#&QyCY^q_yq7DB*<x3Wzm?CEr28w+v{U@|dOtlpOLT-he+D5o3&v32{7gX5*m7t@)c?muW`!WSLl$!FGUQ!C8@gE8&grHo!C3()gEBcTuB~iKg$ZvmO}0`#)Alkw+(2{nY4Us-Mij&jIxGdtnGZj?iP`q2=CqqW&e$czzz*XcP?YTBj?t&S+xPp}P-8^IZ(jHLcL{Tx1JbpBqSRU-}aZaBU3vcp6$WM}yP9m5v_t@4AqB4VSGnkhL3F|M51?7(HkZuO1|-uM1qes*)v1+56%K+Q!eO1~S=<vnPul;fI6RTc0=+%QftoiR&%)W}!b5d+g8+TPEUvez~1`9t-3D0RsO#oB', 'Makefile.am': b'c$~Fb>u=jO5dSRx6+~<x@iy6Qzs;+=c!}EvaFQW*w|)o~C=@NTl_i0c66f{5?<i64hwVfT5G2+ee|Nk)-a~Y!)9MfEbnv<HlP;J|@xtZU@F@3Lu+pENY{Rhv!=fjyNnc)2yMj9iO~)5s-j7Oh{u<9F7vuBEC{d+*6teaZnvbu(Oy;wjlgsn-%L_cxH0>H`F}-gDzPobyqQ6`SzlL<noEnPZ`+e)NM6;+<gC{AKaFU?VN;I!>mB-y%T>i<jaC<G+A=JV1B@>uA#12e~O>mw=1-4wn7NHNBBYeZQ^%WRY{D%7`^~9iW{)VOeTV{haShI#ThGXKsWWzE5#1I`D-i-o21`kcXpM0K<zsyGZ9oF@KDd#Rntw#dHU>XG%#tNbU``mDZ84$|b54^}AiDCVF*A6{A#NDGf`g;8wJuxEEB&RN)5#0TVbr*M!(bE%K+`uzZflW4GlMUENLBG6&Qf#_5i&CzpefhXXh9qTV5W|<?&)DMB!{FG%Q^p6=t3&)L6j#8WUcDLnYFdM>^i~F{CL%4A0jM>L;h@EaTl*j2Zv$g&(&{}{>!FCXdc=!2>XBhodMI~Bo^@Qm!MUW~0pzXDeG~Qu=aMGp5@oPZP#o}}OOkhbbs9IhY75lV+Ntfs<C`9_itRLoX-F*6lFXtsBJRp_1=X43Q!XfhIC$TPr+=u0tPka;C~i&79NuO%t0R3k8<Uo8O!i~r_SDSbZDZp!s8Jfzs&0hgU2{hDOqtrv^d!3{=G;NY)`;+o>vykL?=inp$!N;sP21VvqAj+QL)h<jHXMg^n=PJ+3~1{Iqg{o|piK%Zd#{+oR!q<|Ek#EJp~{}W%JdmE;WsSw`ejmQ!m}nkYTKOJ#=2ypl+@G~rd-A5kW-7Uy-4aTE^QwR>L)W$l_#p~U(hP=1!;S^y^?hcs|qo#K4ol_*gRdB7KE(LcH2z;xP~1{o#ecrO1DRIoAgUXJY@V1O`ht89vO5)zhj+X-BGPj-EdieO}6$bTs25ms2T~&gwCVv-9Ad(PemhU)<BCJIUU=)fvskTWmPg8-(Ht^(I#bLzOpu6#xUvGf=Kq0Hwk@{t#blE8;R5Qs0owpDZLFWi#b+iq!su`&gniC{+&yD?N7M5F3Xe}R2&{XBvj^uq{5Xt<+nhZF=X7Npr*MehxXP9CG+T;po0^}$zeJE5|PCzqKQu?mnM2-jokRLOOY!f?Ov8Qj$t)5O=sy_i0U|aoy)d+W3ao+;u*b(rIEPJ3}0a1;C*xVuBN#7bq;TSsj`*B<5Svpc9Kbv31fB3tibS@>tG((RJ5N3i?2>=A`++&hgMVz_E!jIvhToTNy*QBywps#^O$wKK?wDHm&2!p5!ik<HB-*zt6w`uLmFRUeIbpYg$>9L*<rpC42QiI<pbuJblqRC>^M{_*<+>eU2cjhA;RZSNJT+m@4;U}5SjFDKuzYGO!$58K_(7eVBN$picx%c{O<Tr26(Je!Wx6g#!ELEw|b2<)mz5tAp;%fff8`$tikgifkT@1(}a>yAQ@!TXGoP4QYm;2w(H{$d3~x4SEW*|?dxDNI>nhpYT?@V`Q%gv9wxrX)4;Y!i*rBN_u#+ILG-uVJ;?O;N*g8eM_yc&s;R&tRr+2z-gywd!Igzxp+)jaz=6_69r&$4#yWn!PO3u6saNu5_m!m#kw(eV#Rq@>^2b3M2&DlrSz8s<wUbU#ne$a58SFgn{*W~c>+!!M+r6i}G-^LL1;;)z?Kg*6+*o1Xu&lkNT6t?X#Kh%Zkgd*AEc7DD{bi(w%tr699>CdDGke>LMTHgO@ivfUwf&7xzR$15H>YQ_`3PU<dUs8$?a#IAn&z>7jTx?q`;Qtv*#yZu)M_de^%Ai(0xFJ-H=_$>Exb96>Q&oD1Sg$E_p?#&Bm7{oXkQBIV4Pg$-xM#|Z%oFA>Ka+#`z7TR`%8*t3&d<{V(69(&ca*e4M>8M8ZhAooT!^+iGylE0ASQTif*NQ1F<wX9mLFoj0Xqx5K50NVN@imuM>>q9V`Ai{%3OY_490gIs1Duo#t8auOpoAun=`jSk)=5YtZp@JRgIG`EN1w05~VBhmiNvg0iq+7HkPi$@xts<diYQ4p}qtP7rcj`E7tmav0S~p3+y4x0d1UKkQ$9WxzCiL$_UG*u(tS2;>(L&Ms#2@pKx3^%@59?$POFHa|VP>UEDcIjpxOaCiy74`4_XZQ_=4%#Psu$Tuf8HJrd}zaE@SC*zCHXVb|njJ!fzBO>LhXhNDU2MfN4IvgAY)joDRr*Jsi#zpd7-4MfZh<mR2<>_Vk1`i7g^Snc-Y{6m&%ekX3TOFG@6c@c69X(+8DRhStL|;M2bzDR?9K(JPkW@Jp(65OD`Tiqhhjak^kboBHgDeu*y5jl&>7vZV', 'modes.xml': b'c%02u%Wi`(5WMFrEZ+@ndg&pML#3X2>f-}kvvI8YfowylqWpW;O(I2&NChcU4~S*G>)Dw>_F~x?O<M3lIa|=%?1mDs!d1%3g1)^zvU|ELXA9#h2<2=>$ahFAH&D>+R&y&GF5v-_yB&)grzuf3M6Pu~KOxW(d$6lkHE3mF|CtirNzct;r}ZjC7NSSkFvpm%7n)zH70%Qy08=*N@E{^RR%882>Eno51$D@O4w|Jwv$W9(N`8R31dGr7Fy^rn`%btm@}$r2N*U+t^(d)yWS9_yZF(r5k>yQvh_}k#mF?v_j)sO#j5l06_tDhDoO^oC66j^~#*vX=!C&Wz9O4P$O<+mnQeI2rZ-1>b93h9|c->7PRiy$q|6M8JY)csLJq}wHw2*g%vFNz~e5Xaj{lwbtgLEl;0Td1JzW', 'corpus/{{languageCode}}.tagged': b'c$|yN$S*BUE!GE9HhFe71vz#qTycp-srpH&Hf2dUsTDx6qSRuLXhvdQN~J!Sv`I|K0txBq>)8~i=9K{10POY|6#', 'README': b'c$~FYZExE)5dO|zap(p#DJ;1~uzd*7VMU6y`LLx(6AZ&JShPe*oM}=cDZjwYf8QM``6W&oXiE(PmXCMj!{=VL*(k27mRI68J{Na)=aBJ6STEaove~X(m;%=__V#%{jNR1I0e-oLcipitH`*vk2P^0SK*RGH{g%eU<{su0ey_P_YturG8?{b=r+ptXK4<I|{Az4d8)Yh);~89YwRWg)%A>81lq;cy<z5>7i25gPePYVQHA3VycwSX_mj{*EwfLu%R?LO=jwR3gVeAj&V=0vaEkuEg(EXJ%OM>G}>6hFJklJ~!lqdo*y!9qGy6hh3d?xU*nN<l%Wrcr~_r|EHS;5IqZ{aNcA$@a7>b>`(^v5V&NT>4ZEC}DEXHi&}&Ub2W$a=Gp<wS{9LA&EmSbLqmChcy8$hs_}R|_K?Xybv<q4U<@gmz*CO958oW{z|gK*6AlnF06buv{+F9$;#0l`?i==8dE%dw$+O$c4~>Z@cGTm<l3(%l9ZibhT+!fos603d7dG-z~CZTaEt6vTVv-&At!Lpu6c3l5!zYl8&QCS}X8ha1^RXr}s&arDHP0kWF2kg`)*8C=|2Zh8a>=km`0n)GP_yOAL>EOH*mh9K)uyxk!UEI*r26wF<Ei$~1J-c(KChmmX@q2$$+^9Y`s-=Rt?{IHiXIY0AA?LpUb-If#s1Z;yk$fTcqpPI8Xb1R5&>`A+&+Gq`5k0^=>$PQ@f{xU?g}r4cfm_;o{RjzDl5YcR^jm_xn>*B0jVz$YR6IyA@JbI6heQIv9(#T^bQ-XkRd)<!4cJT$f=Hf_83cBoCtv8dsHEFBQ{g(aar;6v=+jnUnLcPU8>uG%BETqHLr?By5vE*?**1;}47T^c(Zp;$oeedEr@<E5O*gX{{D@nys{=}(-H-zU@cWEWEGMmYaXQt%*NB5xsbcR>Zb^vDM$nkMS#vZKQq$*7bdd#+DXx_XQN^rJJ15)VtfffqMd@2}3m<86pAFLW+mz?WT3ObSThem70#)L7V_?Y0qF;acU{|J<KikFfg(L`lDWh}mDH5-tP@`RDmPLB$=5bzk5Ae0;h{j|6CwXMddxv^a&N>)D>?UgqfYoYH~YHQQmiyW4L&LtzzzVHID8)pxmpQ2f%UVNl3o2L-=+JKES5Lm{w&O8I|)GSFFMK~O$%Undxo-bO|ukWjT_p%adEpoTMK)oK_jG$2qHnBrJVrS|Z_ax4T`0wosTDb{bkL-_=p#yEd0E#%iRJ!%!$qQ!0sH8z}oyn!`SJmEn(?Qs+9z#OG2I2?ynrL0hVHI(0-<uICeb^*}3F_q;_9RhK|t>jqaI*JeQ4Ud4f7zhmwLWc0B!8YLHNU|FqIEt_#-)bE5tV6i(MS~M37G+6ME4as&9Rq_1cIj$PIl6rg_uZR7!U7gzLk<ZI3nPCXJNUDg<5!_=KiRe8=}##?%ITAqw+@+|a6Q?+O-%O6A^Rv)6MB+so5ooG%?5<<W>nK@t$S#q#QBM4pMGKu(;YT{s^IZOl7~qKlyvx-vE{@0wk&@pp-bc7fiA5?s)a|R%j*k#%l@v{&H#fz+B_|-5E}U-H8?>D@^@c8-kO~<_8F%zuAGT;3pR2Lxp%iWAFr-IW59J!rz4E0T(t$>G|WO_w5DQ<GbR$AvVQ@iq-?J', 'apertium-{{languageCode}}.{{languageCode}}.udx': b'c$|fl%Wk7E6o%L7vvkvT&4Pg@N~I8#o2IMC-~;0dY-(esBlY128Xt2rt)eK(_y0beo4Ky8tFrxepAB#d(%TW0uC8|-$;QeWN+Xon{LFnXtK7(uE|XS1GM*c$D#lV=Xo-?!M%xKNy)CDoC*TUaSb{<iQT2l9OEG~u{|}KE#~LmmleLg#>&sBAv4U6%e)?B|x2>@R4z@hVNzEGYUi$<e@E}Mfxc7kkam*i)KaKg5;i)JqqlA!4059mkt-X389W_cq(!Rf6dG9-7DyH^W#yG2?>x>a8;2PM9Lpx6j+4N)x*sC1mw2>RIGp(jtOk_PD8OxStKNu_f#`Ec`3ewu!+Ad}Ff_<$qV#-IB;D?AQR};HkxRG$wiDPrwlE?WhX2*Za-U?Nr7rM|1x61Xx9qB8t1ZHE$9SdbA%8eM1_SB~Pd)s_b4uweA3y;YTF8uxAYD>F72gnNenB1AZf6g_*CUT9BkIuX9w`J_jplx(|F-!r+2E^wmI2oLl4p>w~I<R!(;$4Gs#r_M4p~qKDE!RvqtW81@U!D)Y3?+k!49p}+<ScNTo6W&L*tl+tqm1_F2+vD|@nPRX!~8JDhVi#lV6H*1k6wB~X<P7EAhdA^O`_~;!ax7EwB3byFB+mh9Ns^qamFYGoyQ;)7sC%R365LZmK{gd*jVGm_5xg(LTwi-d_MK&R+wQ4MgO#@k1#R*2a!?{9R', 'MANIFEST.txt': b'c$}S)NeTin5JmU7i|rXid)XT=ATg;9!OB1e420a>*ey5&8se__{P%0h8L1YL3OE`Lr3}`YE6G{T+Jp;2;)GgoK}NO9zurcuen#GCDNE8nF`T@(n$baqyTP?*tym}d9DU*XdOA!Sc58fSRW3IfHb}j$;VmFKK)U5`gb(T~qb|mbo~4Km2Fl1pZ!k-&wIZsben<+d#o6fh?TM%m(Dlg36FHBE(=?I?qVn;^'}  # noqa: E501
bilingual_module_files = {'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode1}}-{{languageCode2}}.lrx': b'c$}S)O-{rx42AbSg~<}p7ItVfKSD@|1uF#W$kTY*h%~O8ln#gD6kLo<$}kI9AXb)~=g%+C%gw%b@JbRa`<1$?E)|e(*jV4L)brC_d960<Vkx7eur2_WXJwfRz*A=f9NN%y%z*+Z@+9rYJ1W2cu_K6rJ~)ht4ZH(2@I<0u>d1qQkN|^FLxv1&-#|^)8&zfcjWO`XqX17nZwWBj*jW$R${IQnx_~hxpLvx~Nb)A>w&Zv^I6!DeYbf!`a$Ov}=h4hx_86NE9Q8e}=Ee1IFJF!$wqd1wb*^Snk_B?q#G~%?^^^1ntTQo(SI-XSn({1ioR3HEi#*W9I4tUVvM;v6fh5|ouUOjLsqcBxk#$Q^hlmo%=tDBv(cU)b^z17ouJevR5O3LsbSdj&xy6upKTv;wJp5}0#is+#PW4W>*8>VVM^2+R+Osde8x70Af<->&Cy%P>%K', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode2}}-{{languageCode1}}.lrx': b'c$}S)O-{rx42AbSg~<}p7ItVfKSD@|1uF#W$kTY*h%~O8ln#gD6kLo<$}kI9AXb)~=g%+C%gw%b@JbRa`<1$?E)|e(*jV4L)brC_d960<Vkx7eur2_WXJwfRz*A=f9NN%y%z*+Z@+9rYJ1W2cu_K6rJ~)ht4ZH(2@I<0u>d1qQkN|^FLxv1&-#|^)8&zfcjWO`XqX17nZwWBj*jW$R${IQnx_~hxpLvx~Nb)A>w&Zv^I6!DeYbf!`a$Ov}=h4hx_86NE9Q8e}=Ee1IFJF!$wqd1wb*^Snk_B?q#G~%?^^^1ntTQo(SI-XSn({1ioR3HEi#*W9I4tUVvM;v6fh5|ouUOjLsqcBxk#$Q^hlmo%=tDBv(cU)b^z17ouJevR5O3LsbSdj&xy6upKTv;wJp5}0#is+#PW4W>*8>VVM^2+R+Osde8x70Af<->&Cy%P>%K', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode1}}-{{languageCode2}}.t1x': b'c$}3~%Wm5+5WM><SmsthVw+QH&<>0uX%9hCq%LwKSc#U2@FDPF=kvRy<XDdsNG<|7<j&5{2&C69TA_n*URtxlU&}8T2~*ixnr4OnY;TJze7#=K;JEQS;ZQAhJgTt5)jpbMyj~zgy{H0|7jRZoJop3x+;0)^8mn=K0uERqgU~4O#=}|p8I!(*^fhw^FHHC^MLv9sgOa(nsbU_28%j?5)RD7_`*X_#k7UD0qn7Eyyl2loZF=CNp0Ld}Mg3Q}j&@Ab-Jh~(UO7AD$v|QX!Uv2@%N>OJIz+ywL>TS?d87OAz6|KF!egA0SDJ46+<C71q;RO*MI}z6(;8J)Ye;Z~A8&r#ZI<Zw&HeUld<zx|XU^SENSB5g$DagDDk#r=2Lv{bETH*cMuuzAlOc#6*6DjIoexje)p+7d`VGcV2d<N21uT+lc@(myBpr<F$((?yIAg4oY*A}{$`N^4gRG!1f@Hz4<K8MUON@+ZD9Q5;<|hLKC>h#ANlIj#W1klY?jHe&lYT0S#iQ^xx=Q$EuHA>wE(tlxXIb)AxFDl0t!pwuz9$Xvsw~-t?V?glyl~wr@qyBJT;22tyB9}x$4wJ?BiJu49sBw4w0*eP_A{_N)q5D3vZi6u1ZV4*9bv(;@KK&q<BLt59#`gr1Geb6I&+nmSB>LZb5~w|>zRuJ?EVKX7pch', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode2}}-{{languageCode1}}.t1x': b'c$}3~%Wm5+5WM><SmsthVw+QH&<>0uX%9hCq%LwKSc#U2@FDPF=kvRy<XDdsNG<|7<j&5{2&C69TA_n*URtxlU&}8T2~*ixnr4OnY;TJze7#=K;JEQS;ZQAhJgTt5)jpbMyj~zgy{H0|7jRZoJop3x+;0)^8mn=K0uERqgU~4O#=}|p8I!(*^fhw^FHHC^MLv9sgOa(nsbU_28%j?5)RD7_`*X_#k7UD0qn7Eyyl2loZF=CNp0Ld}Mg3Q}j&@Ab-Jh~(UO7AD$v|QX!Uv2@%N>OJIz+ywL>TS?d87OAz6|KF!egA0SDJ46+<C71q;RO*MI}z6(;8J)Ye;Z~A8&r#ZI<Zw&HeUld<zx|XU^SENSB5g$DagDDk#r=2Lv{bETH*cMuuzAlOc#6*6DjIoexje)p+7d`VGcV2d<N21uT+lc@(myBpr<F$((?yIAg4oY*A}{$`N^4gRG!1f@Hz4<K8MUON@+ZD9Q5;<|hLKC>h#ANlIj#W1klY?jHe&lYT0S#iQ^xx=Q$EuHA>wE(tlxXIb)AxFDl0t!pwuz9$Xvsw~-t?V?glyl~wr@qyBJT;22tyB9}x$4wJ?BiJu49sBw4w0*eP_A{_N)q5D3vZi6u1ZV4*9bv(;@KK&q<BLt59#`gr1Geb6I&+nmSB>LZb5~w|>zRuJ?EVKX7pch', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode1}}-{{languageCode2}}.t2x': b'c$}3~%Wm5+5WM><SmjngVv|#9&<Tv9k3*0Ysf!*7MqbNA_z;$)lg}@yM@`8M;M~OF?#%3v6uW)ZiW~r)v}RRYR-Xz2rnXyYnpN?8^R2utZf_P$8V^|SgL%GL5W*bPJ~otF*p;>LE`bpqmLxL$x-WV#!VxN^2Ti<aT(?Ev-m5;2yNnKeog_WgoI4TTV{Rp_lNZ6w6CUj(IM;N|R59(JN)F_6&4ZXo#${48K|cZZv{RbCe$JvrjW*}$fW+j%`OAWsR$x4y;}8n`_#IdOksa%#Cx=y$B~Jgf_TzR^r$$Fhxm64bMwjWE)K+USepNhv{eHJzlKj-$m>8hRybMU6y_sDEI;&@*)6Cj!$VN_AXS|L%resT6>rz%EW)`g}(0L+nm8H9IPF=mPZF~&IPm39y*<m#E%V<6gqba;;<U_QK<}Yo*K9uF+5u6QJgIjjpd+*yNr7!YXR-y&;GU&=;(;@Ur>Wq(f$=7@rl;ZFzbgSSUt!I?32ZZ0l3%?Vl38Df1Q%K}L9{y||E;cBP+X3=!u5%c<vZmp2dbHcnWx~DX{=Gb-@WpzY{$bpCjBEjgI&xK4*9{7-1y)y|2j;SjasLIYGK2j', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode2}}-{{languageCode1}}.t2x': b'c$}3~%Wm5+5WM><SmjngVv|#9&<Tv9k3*0Ysf!*7MqbNA_z;$)lg}@yM@`8M;M~OF?#%3v6uW)ZiW~r)v}RRYR-Xz2rnXyYnpN?8^R2utZf_P$8V^|SgL%GL5W*bPJ~otF*p;>LE`bpqmLxL$x-WV#!VxN^2Ti<aT(?Ev-m5;2yNnKeog_WgoI4TTV{Rp_lNZ6w6CUj(IM;N|R59(JN)F_6&4ZXo#${48K|cZZv{RbCe$JvrjW*}$fW+j%`OAWsR$x4y;}8n`_#IdOksa%#Cx=y$B~Jgf_TzR^r$$Fhxm64bMwjWE)K+USepNhv{eHJzlKj-$m>8hRybMU6y_sDEI;&@*)6Cj!$VN_AXS|L%resT6>rz%EW)`g}(0L+nm8H9IPF=mPZF~&IPm39y*<m#E%V<6gqba;;<U_QK<}Yo*K9uF+5u6QJgIjjpd+*yNr7!YXR-y&;GU&=;(;@Ur>Wq(f$=7@rl;ZFzbgSSUt!I?32ZZ0l3%?Vl38Df1Q%K}L9{y||E;cBP+X3=!u5%c<vZmp2dbHcnWx~DX{=Gb-@WpzY{$bpCjBEjgI&xK4*9{7-1y)y|2j;SjasLIYGK2j', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode1}}-{{languageCode2}}.t3x': b'c$}4!O;6)65Qgvl6(*b$FPzva1yx9^N~~bDD&lAj=`^+KkH{aCpTFb8-K6aWZkgA9pLaZV>W5FQ*atc<tyvT|)sKRqY3xRtc2T^pf0cK|!~Lx8tPjmDn*IHZvD#x3Xn(oEZP`HZNhCR!j6fbuC<d7pNGxSQ%?xN<6kVi6o=rTvdN98vpXWgcZW@^ClxW`F7?{K%F+l67o%S>@tzQOa^m*b3oCH#t@;Y!36%5={&S02gTvT{uq;J+(t!YGy;&Ju*{4^gs@2ClM=2(wP9$+3V|8L-DjvD&N3BblMR#dAvEz|WV*)h6dy8nXFxu~tf&MF*JhNP*n<`Znqr=c}ZM?4)%9sqSaKBQTFRhF~A=xuZj`gw2Oh0x78KghkTphFjA)RlE@ukgp@q^CI-OR<eg3H$`zDg1`@3tN|25zlxKzrnN-S`>dkI<b0rTfbbd9T>kwC;DT3g(#FYt&k=-yNUfsM6e=!mvaohUT)GKDtvH6iw@Mts&4OE2U>%xZhvNSS<<-w0Ye-&vH', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode2}}-{{languageCode1}}.t3x': b'c$}4!O;6)65Qgvl6(*b$FPzva1yx9^N~~bDD&lAj=`^+KkH{aCpTFb8-K6aWZkgA9pLaZV>W5FQ*atc<tyvT|)sKRqY3xRtc2T^pf0cK|!~Lx8tPjmDn*IHZvD#x3Xn(oEZP`HZNhCR!j6fbuC<d7pNGxSQ%?xN<6kVi6o=rTvdN98vpXWgcZW@^ClxW`F7?{K%F+l67o%S>@tzQOa^m*b3oCH#t@;Y!36%5={&S02gTvT{uq;J+(t!YGy;&Ju*{4^gs@2ClM=2(wP9$+3V|8L-DjvD&N3BblMR#dAvEz|WV*)h6dy8nXFxu~tf&MF*JhNP*n<`Znqr=c}ZM?4)%9sqSaKBQTFRhF~A=xuZj`gw2Oh0x78KghkTphFjA)RlE@ukgp@q^CI-OR<eg3H$`zDg1`@3tN|25zlxKzrnN-S`>dkI<b0rTfbbd9T>kwC;DT3g(#FYt&k=-yNUfsM6e=!mvaohUT)GKDtvH6iw@Mts&4OE2U>%xZhvNSS<<-w0Ye-&vH', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode1}}-{{languageCode2}}.lsx': b'c$}S7%Z}496kWGpVa#kB!w!v{jE2YX9$==!Qw(wwPvbUqGPawx><|K0NbFgl!Uh&dNJuPNcA4@Y{S%xxZKHGswN$Edb8_!J$H%_LTm4P|Vk#sHxeYH`7a*YA4L!!2Haw{B)Gom-r;0u1DxE>Z0H{GkZ769(1Ze~mI@Jm$LFAJLRSwxshRLgw*VECL>1dd|ZCrM*oV@q0CLidv<XiG}I({=9zdPD#UiWXXo5}aqt@iEUPUkM)4eupClV8*E$LRj?1F<LfC&S4nRiAwB9wejW_n#l}!``F*<H3`cPcfSFX>RG!BdG%u0lf<1wIC`XaS4e;3E-voazU)u+F!yXE%))L$`FilVLH@S%|)7cCNqU9m^zp_xQ84p7y5Ba|B=QK{a2P+%EZWUEYZbh(Zws##cR>=)5-W+O;R&YZDU+sz0v;eqK`)BN(zh3;oR1Bl2$6o6|a-@AAMI8R&Z$+nv*JNHs^qOHtZ0_;cVO$;hxUZE>;1+=V~?mNPl&oNg!wx5SPjvJ5;1iaW*iHWmy~G84tT0M7|)BJ_m<kS7CjeoQ*uc$CO_zJrB~1v+8wbt(J<_E`Xq8!?Yx=fWXy4iAzMj*HQMU;K0cQ$>JDe6y#rp`Px8E%34YirV}!)(j!<na)!j1s}C3|v(Eb!Cu~7m>Tb41UmIo%^redyx2|4qX8InLVOMCYH#5V0rJ_xQdaTVX5>cU8w_}B(nIUL9M_$Y?>uToQU)6BA>H', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode2}}-{{languageCode1}}.lsx': b'c$}S7%Z}496kWGpVa#kB!w!v{jE2YX9$==!Qw(wwPvbUqGPawx><|K0NbFgl!Uh&dNJuPNcA4@Y{S%xxZKHGswN$Edb8_!J$H%_LTm4P|Vk#sHxeYH`7a*YA4L!!2Haw{B)Gom-r;0u1DxE>Z0H{GkZ769(1Ze~mI@Jm$LFAJLRSwxshRLgw*VECL>1dd|ZCrM*oV@q0CLidv<XiG}I({=9zdPD#UiWXXo5}aqt@iEUPUkM)4eupClV8*E$LRj?1F<LfC&S4nRiAwB9wejW_n#l}!``F*<H3`cPcfSFX>RG!BdG%u0lf<1wIC`XaS4e;3E-voazU)u+F!yXE%))L$`FilVLH@S%|)7cCNqU9m^zp_xQ84p7y5Ba|B=QK{a2P+%EZWUEYZbh(Zws##cR>=)5-W+O;R&YZDU+sz0v;eqK`)BN(zh3;oR1Bl2$6o6|a-@AAMI8R&Z$+nv*JNHs^qOHtZ0_;cVO$;hxUZE>;1+=V~?mNPl&oNg!wx5SPjvJ5;1iaW*iHWmy~G84tT0M7|)BJ_m<kS7CjeoQ*uc$CO_zJrB~1v+8wbt(J<_E`Xq8!?Yx=fWXy4iAzMj*HQMU;K0cQ$>JDe6y#rp`Px8E%34YirV}!)(j!<na)!j1s}C3|v(Eb!Cu~7m>Tb41UmIo%^redyx2|4qX8InLVOMCYH#5V0rJ_xQdaTVX5>cU8w_}B(nIUL9M_$Y?>uToQU)6BA>H', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode1}}-{{languageCode2}}.rtx': b'c$}S*T}#6-7=`ciD^9_S6}FCf+2NpWbqur{vBe9KQP*@v*AJ3Z5%Is9EZuNgZw!Pq=QPdpp0|#3GKk|Kh-13AOyUsJAP(nCx(IKH^W!~IHpL?oxIizOL2g|=QSTsYM6)s3vNE&oe1^hBfgDASxwbN<*6O`x+RRuEUS@hNz}0q46f31MYQZGxR4U|+0?)ZtIC90u<QIu1UMBG>iLuh;A&t6VeXKpp<XP}BNwen;)zE3IwAm@+9$=5gcky_LL@T2ow;hOaFdxwHjxKbpG`a3d)D}O1U42`&&Y-_9-bB(j5tvB2@3;x3blLG?&FiDbbM!{ukMt{n6HRx+B{+;xudVu^v7KZcwn@u%yP;?}OQ!K+8U0muw8CJ5(mQMaDBTx);QZb;=3>-#s1NIF!9F}-jS)U!t_5YXYQ%;~UvHk2s{P^cjlXa&t(j1~DZEN-_sTG6m4RTJMo9k3{&8e@Rf!_qaasK5@U*I49`z(&(hB;|', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode2}}-{{languageCode1}}.rtx': b'c$}S*T}#6-7=`ciD^9_S6}FCf+2NpWbqur{vBe9KQP*@v*AJ3Z5%Is9EZuNgZw!Pq=QPdpp0|#3GKk|Kh-13AOyUsJAP(nCx(IKH^W!~IHpL?oxIizOL2g|=QSTsYM6)s3vNE&oe1^hBfgDASxwbN<*6O`x+RRuEUS@hNz}0q46f31MYQZGxR4U|+0?)ZtIC90u<QIu1UMBG>iLuh;A&t6VeXKpp<XP}BNwen;)zE3IwAm@+9$=5gcky_LL@T2ow;hOaFdxwHjxKbpG`a3d)D}O1U42`&&Y-_9-bB(j5tvB2@3;x3blLG?&FiDbbM!{ukMt{n6HRx+B{+;xudVu^v7KZcwn@u%yP;?}OQ!K+8U0muw8CJ5(mQMaDBTx);QZb;=3>-#s1NIF!9F}-jS)U!t_5YXYQ%;~UvHk2s{P^cjlXa&t(j1~DZEN-_sTG6m4RTJMo9k3{&8e@Rf!_qaasK5@U*I49`z(&(hB;|', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode1}}-{{languageCode2}}.arx': b'c%0o>-*3|}5Pn|&iX$&b&@>DQ2~BCI2?=Qrn<6xLo!r=M%o01Yoo@X1obwynINi#i<E{R2-+g!fF7`D%f5=kUFr~Q^bMJKa&I2Z5Nx4|hy{|W){g2-H0>W3m5B?h;gxzj``2J!NDz;ioCMTh0u|a!3CyHduAex;%2`Ni?#&NvB(Mi}Y`#6_DLbPwlTF*Vrgz*BqDGYix6~wB81*Axs$))xxL?TF@$O_(pk2YY9g32mr&1w+CVn&g}7>=kBTwC&<mp-nItQX2aba)a=l0GiF%^!#h*h8Eal+_c8rF(@sXtqc6VX#{^t(vSwOpNYQg`-*mb%t<a$5}TVcCU6ys7T?iEf0i#ANF7uN9={nhV6xeUn3s}bnZYNwayiD*yn1@o(t;Ly4YcFS4RM1S7zdD^k6E5I}WGbFiOLb2D>;akc~?qn?26K2~n?)qd04!Uf)LPYOh~pZRKS|-H~O=>e6e5)@2lV&Bxqe#ftVLQI0ACjn0CB#jZrR*KFlLg2B(dwvL0ouR|O^E4VAF_LFg3q&6>$aK9*yiF3cqj!EtZ@Op{4{NJ>3ta7*SzJF2v&*}G&5_ZulhdP$3ygdC=+)*`CHwo9U<{PGgfPV_r9wUK>AJDy>!6bOq<5qkl8;~p997SdGW!*Fv^Y%4;x!*P2KG+5{^n^6KAjc&8H_~@0@X5mkx`k_52#69zG}|Mk(e-{g?R9_yaSVj<_E9QOGRKy&3}Kx61-0ZWpVv_fw`ADn1EEwgtr>+Wtfa!8j%0btrr=!>N-}iCG`BRSFq_T1%G+ob+T+|_iwBST>6lOR*GcPr^Gfa|@%Jo#YMX{bVjunp{nEQQxPI`UZJFCYM7HVUusm;+$P|!!k&<srEvIl%`2ioeKrNsUq@qks;a(Ogg^UqVNyH@R&?+n@;<Z7!05`g?ORI%`H_>k#!l3$l$dZ_RVOka{X8H_iCC21uL2%FS_>7>64KK2pRO@mksM(QQYm*ih_x4KCB4rcn?k5luZ*B', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode2}}-{{languageCode1}}.arx': b'c%0o>-*3|}5Pn|&iX$&b&@>DQ2~BCI2?=Qrn<6xLo!r=M%o01Yoo@X1obwynINi#i<E{R2-+g!fF7`D%f5=kUFr~Q^bMJKa&I2Z5Nx4|hy{|W){g2-H0>W3m5B?h;gxzj``2J!NDz;ioCMTh0u|a!3CyHduAex;%2`Ni?#&NvB(Mi}Y`#6_DLbPwlTF*Vrgz*BqDGYix6~wB81*Axs$))xxL?TF@$O_(pk2YY9g32mr&1w+CVn&g}7>=kBTwC&<mp-nItQX2aba)a=l0GiF%^!#h*h8Eal+_c8rF(@sXtqc6VX#{^t(vSwOpNYQg`-*mb%t<a$5}TVcCU6ys7T?iEf0i#ANF7uN9={nhV6xeUn3s}bnZYNwayiD*yn1@o(no`ZWl-FV^?D0Z1h|zfjiEo-Y`nTkp;Urs*jCJADcan!3j~XkE1wCp<drc=}NC(V{PGOMBR~P%IeB%hSp^idCj-nV8M#^8&Qrb0*%aqfyJ&ux7TdpK!U-~y|#>lzOO?ZKP$K^s`iU<T%<NHi*Uavj)`->%#KO!2k?4{x%}U>ajbH;&%S?A{?F<6kP>#$Du+6js=Pe?Q`}MYQa1_Lu;v@4fq;Js)gB{(h#$~Boxvn{)#FxtA{&q^+#E$^?`7RI7xVTteYxK?-9Fd`H1vctyCBCT`!~{eDe%d|1-gZ6SqO*{MKs$ZrP1|%Iqfxo191$5@%B+FP%_7ku?%6H`vtY+E1%a<3%6w0<pZHqF|8SeDXgTzmX2h3%BJ955lS+2#Wc4xrZAh$yvo~X7TV+7UW*5h`stWY^Vdo1ee+80CGqzxerlVBLt-EP2>sH#IJkcBpzWC3|3kLv<FGt$l*km2dy$fFOf9EyQTYKMxIitS5Tv3^P2pY^DTRy?QAxxk=+G)GCgQb0xd1o1uS=_iemBu?9KxXbcgT{Md|_G^DrWi&X(h(wXF+h!@A!<MiVZKanN;g?CaBqwTWgaR7Wei_(jsLO>+UB|I&Wn', 'modes.xml': b'c%0pt&2ri>5XaBuDO69cB9(IK0mz{<eS-F!5kxkc%Cako#2JQbAE1xeC#n1eCb29T5r*~zSkmr)clGr%v-=|D;E77bGBJ<P^iu?=SY?k)B=hL|x3BPXbibI)((I9{#bg4&>?4F=yX8bA8<Nm3rUC7C;Loq$ubyJ_6vBE;IUER*(s}e|D10+40!%1PIG;x^R7D`6;*l;lN&RzS3>uR;%PD7qE+*S8iysn3IVY%UD_dojNRl=_*Rj&jJX#q+&y*!=4Og5fMHN5*J_AUN)ep0n@ewMgWTUe*lkv1PAKflm-?xqPMZcI;(nxuZ+8(CQNZ-cqRPtiFWa0$R0zeezU%iMy|A&g~c4d7;riV+!^%=6VuZUe%N62nhPaV^`MD<q_l11NHs^-X8>D`Fx^-pptHQS_6lO&-Mzy#dj04ZhAHXT($4s{!upK5N2ch6EsTP^j0tHLt3R8ffwoLP$g9MWaHIE$A{swELBrm|zkvJ#eodY6ok+aI_r8rNx{Yfh~ttV%@$$=8`Aj&!x%ENb@sd}Mh^mxZmmt(11tSgkkWhij=erM8#y>=9_xiC}!~%<yqjW*-0(n#w9E7Yh}Kg^EuNHP4j3Y@~N#k=_mNr&TD;7Akcy@mQdyTeDG=OY>-Tw1<YDfv7!_JIm|TFpbT@V?!6-=LD#(n^0}y*l49s&F&v^rtOWmkC5a05*|J!ZcyM>Z7$bd*CpI!Z&20YqFw1a=}KJ+vfii<0vb8F>F!7o%mY)D59g@X(9B%ZvImp$S4loLZo<9XgnYOOzY&W<xXD@0)3~Wu<%PJZ-}mLXso%dhH{sXZ<eKCmszz}W?s5~}bAd(QS*qqH0(^dM>X+i;CVb3IBl0tXn?kbG(bg97Jm6%XTGt6qcD?ToPIlK<4^9^8{}4F!N8k-k*5OwOP8O}c;A9<sec)t~>I+WR;r|ynS<a2?04IyMlflXHqS+Ii>|3=jIH4nOa{fc%0;gd?Zg4^!aB{ti_X8)pA|G%<gWyzumj68c1w*;jR{', 'apertium-{{languageCode1}}-{{languageCode2}}.{{languageCode1}}-{{languageCode2}}.dix': b'c$|$`OOG2x5WerP=$J!5iq|B$px`*##Ca@icAb4BJY}_K%64yNx+nect~r4aa6;nF0R<!k2P7n<91<j?IN^URzl53@d)G5nUS*{{xct>u)m7D1)o$N7P7^T!>y**g8<*GLZ3xhjiIpB*ZyfC3X};IE(OGN9D)NYscG_7JLbNY5o1zOtr9t>H2$^JKIRGyPkeH)&(QM|h_Cnl|8?&dguU>t9^8A;R=TB$f4sJ%bUVR^TXFtI0+3&O8PF{R-^5VPUozdO#J+(Re<M4yWA0}JreZ6gVW`E6|oxJ!l>pgj3cirCWr>}qV`>%fv2eaq1zyJMn^6==<@ki5-zxbrxI<>c!TX!)GUEyxUUpGw$CJ}M|N#%!f;z;?i(xpa6jKRX<2y+^NvC$1t{fn+QwoTBDRvnl%2(V{O23BYeKN%!&+^FIof*o8EC|8k87>(4#HI4fwmPIB96fQ%BKZkFGW0fe(=L(g916#9jao=EmFRoG;%gM6JTp^dPP>J-R3xh_*#$Fg0i^V5B7NCfXJ`B33JWe|@rmB6*G~ZlX#*?b{Mx48;FpB4CW|qq?WX35LUp2FAi9ppMrQXyY>>=>J$oP=qF3=NTJl6z`b-Ad?8nyS9)C|hhAh6`#WQ2U*WJXU@>bCaOZSBW)1wJw(g1==(+N3~ZVk`yk*pbxANj``PjrvC7EjZB<sdACX&MvQ`k;1QBJyJcCVYf_jRrbzX7!ogcVVGa|37n(l7_CSlKB^k4>cv0<-UTeI6dR(Yg<`0go^cMGo2R~pzf2=|*?Ex_QK0l!DEx|!SHiDS_*J_MueD!K@!JqQbI`y*54;Vu1cyxXzXKRP3?Kog4EVluQAjv+s1KH6u80xnxOBM+cOwel!*&-ENe>tY3hoAGqGZe^=q152P{)k7g#&nFvQw>EbJH;?s!ctg!Za!|b3wXG;9Aa2O3>RTEhYietYj3?1{6iX@o-E9f!~FEdEjnC4Ahq{q_}5z%kwKwTh@aBE^k-j2qzkbRpoQQni0?Ngz2ac0`^%oR7~A#pa!>L1vjMGxZdAxqYTjzmu8x`O<k^9>`VgMJW&RCAQGmOj+o69+W_x3QhSCP!^qWJ#w~4Nhd4_`CM}*-WeKOoH2>27bJe7q5H)$)UMpA`d4k<2CcKy!6)_d)lqM(No8o{4^hdmHhC(iu1osa0&Cy!w726HtTx4oVDMoXON9U8`0?pxGz#Jx$zfD;E%s9_?JldILWSMJi*_{H{JAysHhfmO64ic`#1g6D=6xbFCOaf4bFDt<3RZPQJ9~osBQ%TQQAI|w1QRZ<+88fXbC{u@br5h7qf+?#5w_sRQG32G=l%x9yqqM6=<MXwWC&5(0voMv*=@BdgFO8hyX-#4t<EGKcw7JzN$M00+AMpWGJXjO7*K{fdk>3WfP+{x4;M#4R8qc}rG&c8x;khJ?#gD^~Bt-)+dE2e|leBn3yK<=)D#ndLDjYF>ngJG%mpYcHQ@T=pykbzTg0mMZ)Ss&&m$kD_JL!x~aL{(;+qKncw~|iVb|UHIlF*ggP5!mTe^hM2JfJ0&h0dqzpWS%>+J*nV{PpEOFQ0vm$c2egecr9-25Pb;)(YvRg61r%%Y;!nr$e!=%Bpl2(K3piwRUUyH;T19XluLROt2BSYlZEx_t~{p>qtFT>k@m8S0P=;_d+3Q-Ng4WZZR_HpAo%*+QwYc--e_9mdqJO(C<lQ`}cMp?eDyGF0WfnyrrD)n_<8Fy~3^K8U7#r@W=r', 'Makefile.am': b'c$~dk>vG$+68<ed#ZKi+q9l|n_@AdvtvXImW*jGD>qqA_t%edIi3xZq2_^Dz{aAgC^Gs*KD@XzmWlP61@gxLxv6pWb3t-dl@Ab#(_u+%{l`cF+VG+h~f6ts?xptQH+VSb=;lZ}+pUA_5wO<+fmUT70{&jR#Ep!pOV(s)hX?zy~e7d=O_x`uh+0l!Xa$skFA%lE`oE0DJVv1$`GQPdM9)Gwzb0QjZZ|&n)&Im^*<C|YEC%4m!j~_mKyoR%0@ALh=w+KQ$U3!!;XJqxN`9o*TLqCic!<iTKK3lbk4-bOUOtxAi96l?@>~+9n&-bZY%&M5>tfM%b)ftN~y;P8FFrOH+O?@7IC`C?34Z@-@#e8VUn%o8QkSt(Jr<up{C7UCR=E7{V^pXaTFtni3S`Y_Giz1R2%I4(rS+Z%(PUv3>#bWxcKA2JGeCDfl@U=Fdk2VS}oG8DZNZw0X6@KP*@$lc0n|Z!^WjaZ9Vgxg(*;qr?1T*ObW+H*P&bR?)Qh~WXuL)+8usSdkJ(!6MW}*c%F@m{mGBudD8CnHqB7u3-qG*G8qyjV1f|=|HW}*Z$QG%J2U^YUTlu#~#Y*~Gnth@xgV9wSq1s8X(fF`gE9hRh<m=`46Va)b%yGUNc(4|pwJak_};lU_Inhnx8feS-14a5$ZoLc8jG|d^GTYKN=#BLh~A@js`#(>98khtqPjg$TFsS=v3%mUAbP5n>dnT+bvQdW;~JBq!4gZ(c!`Y9hcdRfkPIJbHNk2c?MB5<ji0(RK`E~s)^jP5UVj?*GoN4P7iCo8#R^Sk`?Vdl9Wf{M;pAv}lQ;b*Yn*(><tCI0JgNF|Bsl5V0@kvGy}!JQq1LB!TcCP~MiKK%aYt3O`mTF%2@?r<95AFxL{RcvBdS7m{GLPA|h%VObNSJZNgiV0$oQF~_<C0$=_(X+KgP1UwGDrKWE;bL4YSJyPxEus!GUi=6)AA#)|IGETEe|$YMX!@eI_TV08KY(q+()%Wo2?rnfKp4=iHc_dquu4rX6#VF1Etn*gQpjr0$P%dC{=u)U;ve&)!|oCf6Qi0YO)^5!QJ!NIwO^HN)P<oc>u6^F4Z={*lVdnOpWc2NUtCVlkC)FYJh#c(iOQz%-+$mIFw&S<c1U1qA`{b;JdfKS;OCe4OCPr)KO}elEUXEm#+qiS3T_Q%QhexrX_fBIPFM9>P<VR$X?lBeF&ZeQpm~SO|442>dhzdz@nj%2nq23?S8ovU`n3=eyDoJuttFUe_+Y|#egrJeKZ#{~=doYRurx=%Q!v?~gB=Uc`55WcM(ATLkOFFC=3FHUJ#(!mQ#N^7o=bp#2pV0=oO+T@d|QU?L?P^6WR#*<<va}8EZmHqfP;FPnMcC?0$Dq|RWMQ~r&L*?3LO2Jt5J#GIH`6Hp7N?<9k|2twnO~m>gMrr)V^|%&uE9lG)mSLxjOgMMKr4-fjbSF?*iXK1}*!>dDUzSGyB@5$PRlh9@J>;a4!rryKa5o)tnRc0a475;-Ct-?A##V#i&oOX7*_~NZj>zHVX49HIVM?@~P!tZmxEZ1g+5w@-)5u@yXsMyHr@D5x%4yHdTdHzpXG;SdE!oD=dkubA?r>F|q7kVKs<MOb=aQHJ93<!czFMUiCC@+p5?g1I3glRam6C7w)#yQ!A|2@+LcUuw%yxtHrssPbrvdJ-JJTr6B3VcT0t(p^(x&X;xU|2{_nRVRd$^Tw&Fdlc~aLUY~Xj9z}&k_EllY_u%@fV!xPHRahG2>fEEMuym?)tg!Si0%luutgy&#d+tsZ7HO7=?fRq{5c&#>v@0wne`CCvE36KYpwysIVUa-@4Nt1DT1GR-)3L(JyuIi9@_rvC&T@&{ws;O;2e^=Lyw<8KXfdKmpLHS`6iuRii;lK=>m`mq^DvA=*g(8y^gwSGs<TJ+aNYG#fYZ?;%WQAlehg8+daGR|za%a>DTEl#mnU($W=xqgqb%R0WZu$Cqnfw;6xo4y{m`MyD@0*EbHH!0UNgn0pIOydeXR9}#(FaE$6D`D3FQ~Bc<FP!xriGl_6`v?>I*4hqoU_U__myrK8BUv|K>2y#RH99%6Nw^uUG8KQf|M?#O#3C>xyo?Il3XCjLr|4z|;*cS`)DtO@zPXKx>-W$b+bPl&}2ijupK;qA>t}ZSlO34cX47)g{wWpb8_}7KM&7m7I!xhJ(QFmdEQkU&qB${{pLv1MZx8KSsN^NNZjkSA}RPtO(F@7>^EEXv}Gn$P=25&3ircOA_Uh=@}-K|51ycY+3X~xu|$u-EB=7ct+!r{Tr8TF)lfTamg0rlKmN1(FfG-Xw$klZ5zU0x>RbUCu(}B<!I0Gipk*<+NU~*{(mckXzLj>Y9BJ2yFi;s^C>{ZWZ$Y~XA>TKv$e3_{!MrJ+vH|Eef$1)a@G?+pRHa`znz<gu^`e8lbl-atJCqp#9~?olYnvf#3+S{IWaRQ1#?wLpH3VcG%?JE<tEmt6FAW-j2%5s$KVH23`?Bkwn(jS6SMP@jno~9^U~hK;l^hNf&BZd!_hem<cnlIZFS^NTfO+M7oQ!y$gUL!$H~fxX?e0dmW*{QF6iEgCQJCf^5!c@R^ghtFr!7gCUt>_(23XSP9jd<jwj=@Jhm$I7{JrZT2-~^=_&D3w!_x{FTtRv=a)ybahz-!KQYT|<WIKn&$st_K#Pk2ovxNNEH+Mb`k1lwPAviSC(L7t)dBkb4)}^f;`lV}+<grU(>NZN@sRe7ijw)ehlF3&2~XSWKwNS$>LYwSz5?I*O2Pg@tRNKd$y}VSA~yx3oxP}<shguQ+<1zxtfHA1iyFsfAs!=7>kY;S3GfR>onRg9KejKfF2~pJ-d|nb!Wp#PHy7*XYFa%z_Q8%9*_|yMPTL7h`2JPpRNObCpNdCc%s2@Zuf9e00NaHj*bBs7K%tdN>{cp4T23hp1#8>qR`0yV`At5884QP9Z?UL8NJNj2hP0#^?MoW*2&?%1KVBtV+5', 'README': b'c%02yZExE)5dO|zaYzfaDQpFHuzd*7VOff<0oJu>Qw+l}Sd4U%I8&lVQgMPT|9y9q{F-`c;s}djz%oTX$LH=jiacFkYgy%u%<)%Q;^^iEWR=48TI=}c<_Kb0qxGsOhs&EMCgmX;Ez~_0uOIg##95&n&{tM)+|2~$R-u;4LS`&@D=Vj^S5*$@=x2!42APhcxJ5C7-wNsB$~2IWk;Wl-wz*;?nes2$ITGR(oPDdU+wP>%?~SbsqfM?7si~LLSB|Wi>>d~&rS(IT4PA|x6yRl^^JMOUA>NYHR7I3ZB4R3_uP=~DdynMKnSt7<%DVwLL~zY{fih(ydpxo<7RAc&J#vILvq*?f_;;f$mPlj8@Nqvv{7yldDXpPGOv8jTqscH&%$dy3q(!3Tywn=g5G~nwlb9;&E=xH@x~!-9kXuzwf3)|;=yP)kFMoIqhtYS@XrH^!<<_=--?m;Tr<43JG>)P}YP`Ny*`&yvr@Q>q^&bV8?$*r>_o|Ga<O;QxqZRzyi6z#$wqsWYwpU*rwmxPFGTv@)ykT#=W^cUB-gwnskko0`CQfS50pS7rn)G)?5~>^yV1{5ZF(rv34f&>xnS%63Fq_Sy`Sc=Va}v^tDQl%Eu#c~zpVbAna<?mLB?+^P7U~&<DZ0WmI;DFc&o!+K2L5U&#I~tOU2z<fh@8<Vo(FX?y()uYcA=;xI%p-<SiT>W_pEhFXM_P-QO{SNI67dQ9IMC`ap*^R$C({3@#B!x@d`ZmBn$$eIlrJBNEY79tSKos8k=AQ6e1?I;25G)TMT}1%Hyq7&(XBlEmFk8A@$7EWlSmPi*@^hmY1Vz_EEct(tlcRV0B<Yjwjz$JhOEI1x+FfBH}rj6)jaSIw=Ji0WClC)|s)>c7ZCquieqX!Awonnvz1x!D&l)GG{kQrI(ZQtI5(&;tZYdMQ)wb+oh>>O9%&~B)x=!dId7$Rkw3YAUjxJ-2|r%McvH>$<#L$NY4TTduJcsd;m{m*k2wiGBnzQf0oPHFog)d;bAV8Nb|=lDP{>O{>$X}E|cS1CP#Og9JdK`9K6+uxLx{7oUwq|!SVBt$7k>2ZRwjDz=#)^hq&%BycQ_DRT^DLV^-qhYwi{Naj%VA^euf-O5s0W_5r&OL-;A=VMCjuR3*HrkoGD(h?1hIru{JTqh1&hEHgUciL*X!!_nT{r_%Pye06)b6Vb2c)$T;M!aj`XXm_GpTtDt7qT@jHl(N_cJwAn)?n-ql>_e&c7uCalqIwvpel*TMnV{~<bSvxwnRe%jFseHlSby11m<hO#FcU13|Lkp(_{P!`CUDNemh1lx_|BZS!tTtu3q3*gmDk$#5^#cL^1t9^D6%-z7<Lp-Aly4M-U_=T<9V4uyPlGpfP0Cx3(VgrN4t4Xhe^{oC>!k+9g)(f5b<4kZ-spn-d&OtTqgio$+|FB_M-yXPsYnu|Hs|j!6F^(nkSO;J9FL&yEEr5`tz7~9w^Czi!Mt|(_UP&twrgZY=j$aA(_j;tJUN_&a+(MxwF92TEDCFeIjuu*cUF3kpm}-D)MA`eih;!>N=eBT~pV_`rgV*p(0+ewYFfl`3^(bP&t!c4i@h^c;%3Z4|VeQGMv9bE9Z}vwPNR+Ec=lgUDTGXD9SlT6>_=z^wY@^#LwovV}6aGY!YP_u_6a@H+V@c<iE}KgT=6YAwDC5)Xub3FQt)Gc>Lw;-G@(~NrT<h{(wZ5=q4qmp_0Z0LYkRX=Rx+7_!o4nknj', 'configure.ac': b'c$}4#U2mH(6o&8l6~34>A`u!$yNgQQ<WicTKwx}q-B4t?jYF&wh`{NhMf~^KIBZFqMw)~oa(v#$@9{YXS||wZ(Eh5L`jy#J6lfu5>cnaa*Q8=}vjV$aj*D!AGcv_1Vl++vIAS)<OatjaH}rvc+3m;*(_BXJo^qhE%K0mbi0mm##@5#t7r*E;)jO?TR#_Xlfd515DbQ<cK`@DZ4^C`RToC#r1iw!dC76tmHMXq@^8CBRwIdY<b{IQ}r-5#3@c9M|^-sFdJCW|jvG2RL{(}Z`#>z5(EVoi{B?QWDM;B<hsM!ha_&$m?AQq*<XeImnra9%#8Vxn@lnsTz(1)izbtNFzen7%r^sktHPPTpFvlfVfZtBCHG?~}ibF9b?U<hwr`+!xGHLmbuP9$q6Sdzruw@_T*^|Gw+IWnBWVC;wR0NlwWcc5Rk+%DR|D|Xg#Xj@4bIo}Q)SLA6^)%1mQWO?A6B+grm28_q;d_?L`3-b1)+3zRJfcO!!xxjf%#8^ehxmQz0c=NU&L@KxeTe-^9ILV7f$PPn4RMQ{j2F%OiBLhp!w{C$&SpkWrMa^)YlliR2!OH3q(Z!rB`0We!rMb>@G}BW49CMEnIFSLaqXn63fYyJD)>oH&4*)IKx1ifr_yt6ST!Zr$&5^z^qh*0uRc?5r>t$IoT4d5{+l7o0o@6LTX4KRW#~|0<-qcxp>U(9=2o86D7WMu|q=g;GyYY~J&DS*ZU1R34G4r*t)2MfhnQx4l?T7`)n>bU;P44V=;QS;G68@?6@H6jSE@tZwnnlvy', 'gt2apertium.cg3r': b'c%02!$!;9U5xwgx2+d`5XcMBmk3fjxCK?pg!=@w{Fi@zjPIebr+tkt|kG{;!z<B;Zzu?_hYy2bgCC-RkA~G^H9>5n5FzSr=US{PI8JQK`{A}kuZ`M=3R<of~MR{EoJ7c~cc0PYTTaQrs$#_3LdGz{VzVrFPlbz4=)y<PHta*3|K+$_(sQ}RbdZ0p}@<35wm4bi~fpP1R6*jV>MphjH9RXVesLFcYW4r6Fr<N;xcIBUac&P27xhdM#Lkj~9)6zqEzXA|G9Msl;=zj_54AK$QT&OjIO`{70uMFs0J5tcvO4S7PyJe#qMEeYjjJnA!p$iPI^KvMw%8}mW64q)hn;k4M1mIXYSeF=~J)v|>nX)6x9Hw~%9}L<(&WF+BnSwGW7h~S6%siuDa5fjcSJc9tq85&E%!-D3-1ob0`f&qj-)Aip9W}r()!+wt(iXd$97b~878#TnahqHGHV<K60gId}JyQlm=bGw*rUrvL=oFV{O$&2|K3kH{p4D9svrv+!ouNmS<WL$=*9Ov`9#jY^0<I4bxy~7MY#^?Bog1uXx&fhqfKl}~fZYU8576kH|2&7TSGixh3vKEVzq!;OemrK|usx#zvz;}@_VWeq!iIL?#e~4*fj8(;E&0(rhaPpg4^Z=>QU>vTnya4zqW|?kKOoZk@y=mYx{A!FU_agA&>ld00rU)@XB=t)X~~!8?T82g*kS5#k1N~tw6OF3+RRSZU$fbn_ick<!w?8kG|_W2E;g)wa7_(CQ`jjsMYxN)eDDExJ~bG(JN$IuJq}p^>j67c_nrP^;GPBdIQYzhtomYYst@a@9Ne?u9tWRU&{zMmfgXO<`2Kx~@#HI-{V%6baH-F~4i=z?0-@IxV%LNiz_05<)w`z(7I#o}wpJ}CUQIQ|51=+!X5^cGZK<~R8(@JLGp)OE$hsScth+I20tXl-Ka?v~<M>AWbYKq~e(e2re><q%!x9~18dO%4<QhP|dgwM7w}9LjgVC>Z91@UqPGbV<;?xpN2)Cxm!LjYe+Dvqr_sa4;6fN~mW7}n=?j7*FsPbX64`(hE_(q!9oiy|7*qW8;Ted1k<+?QI4t%=mW(B-yX5X7;=C%3gvz?>klY_VCSHsTneWALsY@58=(Y~T@MO9TcaI-2KxH(j6R8M~WiI^U5=V+uq?mF{))7DR6I{x)f4(%cICk{PB=+7MbDL~)<{x2N+nZf?bv7a04ZyfuD!T!#%UmENm9Q&2QeDC14v2ODX-b5ao(qn#xF2P+NFZ0Jc9Yphh84WciIE9ponKd%&B-0qGNpXYWh6Gm{u1s(nye>V~A1SUeT;h364(IJ-{Sk8m`pRSd5psI}tG)_DfR71u=SZB~?g&uqU^0h?^1D*J48&nFc}qxMRdC#m?~%S<*RaS1UAXJc+@slryYBFGx0mowoO$}jq5lgm9nSUgC3@c1-{{i!Uw`X;a;TLhbSWfqPvjwS<B1zisQb|py2Od?sw^x6MMLr6akWu8Xbj_yj&(bOzWr4XJ5_t9`XV265ZTf9<(*-7e^=Ms{bJaCt_$Bl;di^c*{*rWi+xz37g}-Pp8Mk9IY0+m?4joeNAJ#!@Ea_C;j4S%+kgPWw4)2WDX{m6_%?ioj#E8*4w^wtj9#v;Hat0>&*+)f2%f943(sCe)Kn8W)q>u)p%%*exoGj)0Ql-)@cR20gkgqs!GVWwUe9NT3#??zVV#AmLt~ts_;r|_$d#C#_?b0DKDWB&o0q@w6`@R&wrn+BlC|cS$468TEmjk3R~O2n_9Cdg5VaSq_9Cv05Ov!sMBkq;-m-C_!CH9hM+U{f*<KyIw0;I92kSCc(4Snr@1qo~h&4QUVetzO89xhrY~Q?yppITfUO2ZCF6V|V#_Lu}tP`zLv_`Z-(faJqZGYw-nqyz)K~Lta?Rn6)-xP93_}w6P0y#wF4&)4xD+G>^as%%K(gnN&(DK`3>E%nzN-dX^mWq;2QR1r57d3?7(}7W%X&fPf<?!K7q4Sq`)ui+hom34=AmMv`(XwRJkIN~^<k2V6Ov#+m!4s3O335XDYUNT!Sme}Z^ywc{<|L(>a*<}r>-OIt9EW92Qc5WoIVHTUAu)3JyFcWWKK~u*O(t1cZWVwZKMaHZKlh#C2p5*+vTnJK046&sYoGF3VVSovwVT`Ajm%k6pg6BMt@PyIxa!sjXf~%RnpBl{HC2XkK+=>eIp=FjtOHQ#<yI~s=qxTMRpl4N8jRjpW)pzSV>Z%dHomouXo?SQ6OC;%k^7o*Kr#omMnG@3R2RyOys^Yh0OsqDAN(>nD-djM1CL_>liddMdmGR1?Np7^w(tF{Fo4M_%T@vS@xwZIergRtfBe9Cuw;Ed0B3PQ?s^WTfS_ukPW|yirQdHY>ntvSNf;-eopvUdOul(6GRjp8^cQVyzDz(yztR_@q}PlMcEH8tf@L%1A;D@*qSibghI31Hx?D+e!N_3h{K&#_4X*pc7{bhTt-<Muwu~t=l5r8`)^!T{wpDrW9%jm%EWi8XN7s342)bl!@Vu>#f}?NQ7$IG)6w%d6NxJe8*I81)>sPY=b{zc<^QMzPE^sxG`4sJ^1neQON5C@#e7^C2`d;D`8l&80^u@rb>Jji4k01J`fHJoTo}D?k^b?l)dH?}>D~E(r>F+-0$0t`BsMNJ@{Je#0RYhNC#F_jkWp6iOumPhyzT0%chKrN?HkZ#59zQyD&(hH*8O>7BCK1ij&?ae5=6_4se<DAh&b7b2ID~l>iFD(B-92+a0QW4o$H8Y7{C`Qi%Pjk)yAt=ooj6Rk_XLaF`sLZ_E103aTyK1vkUBTP9#ZEl(pw@s?OT)RGIX{^TZraW!6aQ(NWo=0jfzQnw7F>2J9^azMBPq}@1HRuI(s>l)hZBWON3&nE*5PQY6pXHaZ@@;Qwkz`*{&XD`EnTh>=kY~tIL)|Y-ktyYP^%6j(X@s&}?>fKT0vQn!&FKQk7=-Wt^xn<KNIZd9bG1j@Q(Q#Q0E{8d@kz3%HjUQRFFBcvaR)C`W*VG;A-?mKKOv)S|@vb$!d$1+7>RjuDY~oCv>J-pq=s72?*Si3&Q}7PD^iFo-Ih$5WN~=#4y{0Wp)QS$wB9OtDoPE&xxrEcmvhjIT3+1(LFCt~)u)r&Za8n~?3AjwJD(gr>6OV}Ib;*<m$qxU{IoXo%TK>pcKP*KOznD3Ut@mB}rEav@AfUgsm1u$Oa^=r_+`s5JsorhP8EYTIg7<YN(xSNmNy5+f^;8=+eG5K5R6p+<TUk84p(Gx016P$rzELzJlk>lW82JQ`IvUQHQ&3vA>{WBmJI5^t4``;i>cWCbZriK6bNdx|KZcmn10<D>ZDX&xROpNHO&iqMCc_e;kIia9CJ(n)a*Zq!}HG{#PevcswGr7|l3Ov+!kje3amHKNH1v<4&>>p<dpmHT@G$vZ@41-5QU2RpPs+Cl;U(UvEJkW?@vE#yOCs2mJZ1zSP_lCp5n1jnN$j^aP7AdUf)XD2Ej`7wq1?AoJog{f~s?bOFphjA;ALAXlGW;F|kB%Vb<k-MUFKyCB+pZaLxkMgE)J8p$#NwNk|kZggSc!8Eqxv<Je&kVQsQRxP=Dub~c>DNE+nJZ&NG@fpHidKOR&p1Tm3UR*;{)vwFWpnF<SZ1V-%9c`;6tIMe!bF?+D@F3y1!3~k1u>ndAQJ~_ctRx3hM+%DU+{2XHwANA$g6^pvF@TRyNVzk0Y)UEzY($1*Qn(23)|8PU@uB4*fQ4yNEzGM$t~?gW+UG9rFU1aH=EH=$*L4=sE&v=Bz`|``bd2TppXY)52SIxGp!B}MfiLKk}|e}B$dl}qDT`G<R#KS#AZzGLXbo+1t3hn5g0k20+dEmK+#yn;nUpv*g6lr3n+Y}(d|7j4ZhDH#>J|26S7uqEh%V+(a=O7VXvjpE2)eE$q3*@Y@2(b-0UQ#eMn-l7nvAh;I<s%8jgsn$<8D@vMAS0pc(*(Wb{63RN`%xCP++;CW1T4#@nGNgTG=RO;+X2IwfI~=45ityp)A7ua!{@7tOl|E?4Ls;i@Lq)2t-z0<(%@6NJm1SZK^Y(1iqZ58^rk5(;FX5Frc%EO>!JhOM)e^3N!-%t*Eba{A4DQvb|ciVnWc9bM;w7(FoxBAB~66+=Np?gtX#eEeNCI%JUKu7HZj5BN(#^eTWPa}yLuM=>JSQM5%@sSQy(Ox`4tHYjNQUTvKzB&uS9@CVL7!w*=Q08Jrb0XG$Eog`ayt$%xQ!fZfL$osZaOo(PE2@^ArIvAof49Z5jtfFcZH&%GuF!k33d!DhmDEXUhLuB&ZQ%lnCpCG=RD#djDR4FMThX93i2My7d27%bpb9zIRFNbq{n}^`f+`_!gdyvcF2<J*~OOdKut^qS4;gQDaqHrTG6Ulpo5wSZ`M*x?xI1$ANB>DSvM}U-NY4HzMVWH26W$YtaaPcK^eEp^KK%51d2+qvT+bL0Ysj6UOczM>VD&8WjB1`bFN;1g<6;!3R;S(GpgjLyaRmHxcw32Mz4y4Gsc8~(muVjz1#iV=Nuo=t-i=>5tzmht3SxDZ~X@Qx0aaN#2COuJ@%y+`H-07*}%V})Urs!eRGnzLsXMJ0!!IRbs1uJ4#k_ukA)9>0WhfV>FWz9ugi^5VeA~{etiCC&dc6xQ*mLj?%r*6iV{(uyJ{==OvayS;}WsDC_uK3h4G#jCj$l<YDxV(S!b2d6&`M!^KI+C-YEN;2N09+RAq{J>t?4VEWp2b9pka(z<K7<a&U^Lrta<>7+9}Rr;To#{YWR7-fdY2kmrTm|IjRZ(pIdV-oMgo2Wq=UbaO?oW?83Izqa~|nT2f3H<E4o~Wi^coSjq|Px2FPYwPV#S6?x+Vvf0LQ~Yd7}O1M|ZJ_Ok=?qXYJngT?w(HHY}~*<rm_4f`vR#rmSH9o4jT_y;7rNI$_}>t@J@r1=?+A=!^{78~2*hBbEuzn7uEVt;qAG%<CXFIhN!XPVry*4`h(Pl)dn{Dk<?qyGTxRI)|', 'MANIFEST.txt': b'c$~GA(F%hg6o&78mkGHi7+aU!>;=Z5%p|oigFt-u*_vZ)1!LxwaL(c5JBJ^kr`qsQ9;_9h*a(cCyNYJceN>2Z_?H=>Cj|dP$=6Kwgj&n%TiJ}Njp47)m@I*GBy_`+q%e(xZkQfZn0jc4fpbeH#E`%~61oxN;bHHe;I2&q_ekiv`wU%#gF7hbn@+?23qXoLWQM+3`z@sJ40w`a{|zcWp#oZ3b3rjkbj?qfB1dJXYR*ROYvpo8#;Fj1m?6Odm+Yv~tL5As!>})g'}  # noqa: E501
english_lang_names = {'aaa': 'Ghotuo', 'aab': 'Alumu-Tesu', 'aac': 'Ari', 'aad': 'Amal', 'aae': 'Arbëreshë Albanian', 'aaf': 'Aranadan', 'aag': 'Ambrak', 'aah': "Abu' Arapesh", 'aai': 'Arifama-Miniafia', 'aak': 'Ankave', 'aal': 'Afade', 'aan': 'Anambé', 'aao': 'Algerian Saharan Arabic', 'aap': 'Pará Arára', 'aaq': 'Eastern Abnaki', 'aar': 'Afar', 'aas': 'Aasáx', 'aat': 'Arvanitika Albanian', 'aau': 'Abau', 'aaw': 'Solong', 'aax': 'Mandobo Atas', 'aaz': 'Amarasi', 'aba': 'Abé', 'abb': 'Bankon', 'abc': 'Ambala Ayta', 'abd': 'Manide', 'abe': 'Western Abnaki', 'abf': 'Abai Sungai', 'abg': 'Abaga', 'abh': 'Tajiki Arabic', 'abi': 'Abidji', 'abj': 'Aka-Bea', 'abk': 'Abkhazian', 'abl': 'Lampung Nyo', 'abm': 'Abanyom', 'abn': 'Abua', 'abo': 'Abon', 'abp': 'Abellen Ayta', 'abq': 'Abaza', 'abr': 'Abron', 'abs': 'Ambonese Malay', 'abt': 'Ambulas', 'abu': 'Abure', 'abv': 'Baharna Arabic', 'abw': 'Pal', 'abx': 'Inabaknon', 'aby': 'Aneme Wake', 'abz': 'Abui', 'aca': 'Achagua', 'acb': 'Áncá', 'acd': 'Gikyode', 'ace': 'Achinese', 'acf': 'Saint Lucian Creole French', 'ach': 'Acoli', 'aci': 'Aka-Cari', 'ack': 'Aka-Kora', 'acl': 'Akar-Bale', 'acm': 'Mesopotamian Arabic', 'acn': 'Achang', 'acp': 'Eastern Acipa', 'acq': "Ta'izzi-Adeni Arabic", 'acr': 'Achi', 'acs': 'Acroá', 'act': 'Achterhoeks', 'acu': 'Achuar-Shiwiar', 'acv': 'Achumawi', 'acw': 'Hijazi Arabic', 'acx': 'Omani Arabic', 'acy': 'Cypriot Arabic', 'acz': 'Acheron', 'ada': 'Adangme', 'adb': 'Adabe', 'add': 'Lidzonka', 'ade': 'Adele', 'adf': 'Dhofari Arabic', 'adg': 'Andegerebinha', 'adh': 'Adhola', 'adi': 'Adi', 'adj': 'Adioukrou', 'adl': 'Galo', 'adn': 'Adang', 'ado': 'Abu', 'adq': 'Adangbe', 'adr': 'Adonara', 'ads': 'Adamorobe Sign Language', 'adt': 'Adnyamathanha', 'adu': 'Aduge', 'adw': 'Amundava', 'adx': 'Amdo Tibetan', 'ady': 'Adyghe', 'adz': 'Adzera', 'aea': 'Areba', 'aeb': 'Tunisian Arabic', 'aec': 'Saidi Arabic', 'aed': 'Argentine Sign Language', 'aee': 'Northeast Pashai', 'aek': 'Haeke', 'ael': 'Ambele', 'aem': 'Arem', 'aen': 'Armenian Sign Language', 'aeq': 'Aer', 'aer': 'Eastern Arrernte', 'aes': 'Alsea', 'aeu': 'Akeu', 'aew': 'Ambakich', 'aey': 'Amele', 'aez': 'Aeka', 'afb': 'Gulf Arabic', 'afd': 'Andai', 'afe': 'Putukwam', 'afg': 'Afghan Sign Language', 'afh': 'Afrihili', 'afi': 'Akrukay', 'afk': 'Nanubae', 'afn': 'Defaka', 'afo': 'Eloyi', 'afp': 'Tapei', 'afr': 'Afrikaans', 'afs': 'Afro-Seminole Creole', 'aft': 'Afitti', 'afu': 'Awutu', 'afz': 'Obokuitai', 'aga': 'Aguano', 'agb': 'Legbo', 'agc': 'Agatu', 'agd': 'Agarabi', 'age': 'Angal', 'agf': 'Arguni', 'agg': 'Angor', 'agh': 'Ngelima', 'agi': 'Agariya', 'agj': 'Argobba', 'agk': 'Isarog Agta', 'agl': 'Fembe', 'agm': 'Angaataha', 'agn': 'Agutaynen', 'ago': 'Tainae', 'agq': 'Aghem', 'agr': 'Aguaruna', 'ags': 'Esimbi', 'agt': 'Central Cagayan Agta', 'agu': 'Aguacateco', 'agv': 'Remontado Dumagat', 'agw': 'Kahua', 'agx': 'Aghul', 'agy': 'Southern Alta', 'agz': 'Mt. Iriga Agta', 'aha': 'Ahanta', 'ahb': 'Axamb', 'ahg': 'Qimant', 'ahh': 'Aghu', 'ahi': 'Tiagbamrin Aizi', 'ahk': 'Akha', 'ahl': 'Igo', 'ahm': 'Mobumrin Aizi', 'ahn': 'Àhàn', 'aho': 'Ahom', 'ahp': 'Aproumu Aizi', 'ahr': 'Ahirani', 'ahs': 'Ashe', 'aht': 'Ahtena', 'aia': 'Arosi', 'aib': 'Ainu', 'aic': 'Ainbai', 'aid': 'Alngith', 'aie': 'Amara', 'aif': 'Agi', 'aig': 'Antigua and Barbuda Creole English', 'aih': 'Ai-Cham', 'aii': 'Assyrian Neo-Aramaic', 'aij': 'Lishanid Noshan', 'aik': 'Ake', 'ail': 'Aimele', 'aim': 'Aimol', 'ain': 'Ainu', 'aio': 'Aiton', 'aip': 'Burumakok', 'aiq': 'Aimaq', 'air': 'Airoran', 'ait': 'Arikem', 'aiw': 'Aari', 'aix': 'Aighon', 'aiy': 'Ali', 'aja': 'Aja', 'ajg': 'Aja', 'aji': 'Ajië', 'ajn': 'Andajin', 'ajp': 'South Levantine Arabic', 'ajt': 'Judeo-Tunisian Arabic', 'aju': 'Judeo-Moroccan Arabic', 'ajw': 'Ajawa', 'ajz': 'Amri Karbi', 'aka': 'Akan', 'akb': 'Batak Angkola', 'akc': 'Mpur', 'akd': 'Ukpet-Ehom', 'ake': 'Akawaio', 'akf': 'Akpa', 'akg': 'Anakalangu', 'akh': 'Angal Heneng', 'aki': 'Aiome', 'akj': 'Aka-Jeru', 'akk': 'Akkadian', 'akl': 'Aklanon', 'akm': 'Aka-Bo', 'ako': 'Akurio', 'akp': 'Siwu', 'akq': 'Ak', 'akr': 'Araki', 'aks': 'Akaselem', 'akt': 'Akolet', 'aku': 'Akum', 'akv': 'Akhvakh', 'akw': 'Akwa', 'akx': 'Aka-Kede', 'aky': 'Aka-Kol', 'akz': 'Alabama', 'ala': 'Alago', 'alc': 'Qawasqar', 'ald': 'Alladian', 'ale': 'Aleut', 'alf': 'Alege', 'alh': 'Alawa', 'ali': 'Amaimon', 'alj': 'Alangan', 'alk': 'Alak', 'all': 'Allar', 'alm': 'Amblong', 'aln': 'Gheg Albanian', 'alo': 'Larike-Wakasihu', 'alp': 'Alune', 'alq': 'Algonquin', 'alr': 'Alutor', 'als': 'Tosk Albanian', 'alt': 'Southern Altai', 'alu': "'Are'are", 'alw': 'Alaba-K’abeena', 'alx': 'Amol', 'aly': 'Alyawarr', 'alz': 'Alur', 'ama': 'Amanayé', 'amb': 'Ambo', 'amc': 'Amahuaca', 'ame': "Yanesha'", 'amf': 'Hamer-Banna', 'amg': 'Amurdak', 'amh': 'Amharic', 'ami': 'Amis', 'amj': 'Amdang', 'amk': 'Ambai', 'aml': 'War-Jaintia', 'amm': 'Ama', 'amn': 'Amanab', 'amo': 'Amo', 'amp': 'Alamblak', 'amq': 'Amahai', 'amr': 'Amarakaeri', 'ams': 'Southern Amami-Oshima', 'amt': 'Amto', 'amu': 'Guerrero Amuzgo', 'amv': 'Ambelau', 'amw': 'Western Neo-Aramaic', 'amx': 'Anmatyerre', 'amy': 'Ami', 'amz': 'Atampaya', 'ana': 'Andaqui', 'anb': 'Andoa', 'anc': 'Ngas', 'and': 'Ansus', 'ane': 'Xârâcùù', 'anf': 'Animere', 'ang': 'Old English', 'anh': 'Nend', 'ani': 'Andi', 'anj': 'Anor', 'ank': 'Goemai', 'anl': 'Anu-Hkongso Chin', 'anm': 'Anal', 'ann': 'Obolo', 'ano': 'Andoque', 'anp': 'Angika', 'anq': 'Jarawa', 'anr': 'Andh', 'ans': 'Anserma', 'ant': 'Antakarinya', 'anu': 'Anuak', 'anv': 'Denya', 'anw': 'Anaang', 'anx': 'Andra-Hus', 'any': 'Anyin', 'anz': 'Anem', 'aoa': 'Angolar', 'aob': 'Abom', 'aoc': 'Pemon', 'aod': 'Andarum', 'aoe': 'Angal Enen', 'aof': 'Bragat', 'aog': 'Angoram', 'aoh': 'Arma', 'aoi': 'Anindilyakwa', 'aoj': 'Mufian', 'aok': 'Arhö', 'aol': 'Alor', 'aom': 'Ömie', 'aon': 'Bumbita Arapesh', 'aor': 'Aore', 'aos': 'Taikat', 'aot': 'Atong', 'aou': "A'ou", 'aox': 'Atorada', 'aoz': 'Uab Meto', 'apb': "Sa'a", 'apc': 'North Levantine Arabic', 'apd': 'Sudanese Arabic', 'ape': 'Bukiyip', 'apf': 'Pahanan Agta', 'apg': 'Ampanang', 'aph': 'Athpariya', 'api': 'Apiaká', 'apj': 'Jicarilla Apache', 'apk': 'Kiowa Apache', 'apl': 'Lipan Apache', 'apm': 'Mescalero-Chiricahua Apache', 'apn': 'Apinayé', 'apo': 'Ambul', 'app': 'Apma', 'apq': 'A-Pucikwar', 'apr': 'Arop-Lokep', 'aps': 'Arop-Sissano', 'apt': 'Apatani', 'apu': 'Apurinã', 'apv': 'Alapmunte', 'apw': 'Western Apache', 'apx': 'Aputai', 'apy': 'Apalaí', 'apz': 'Safeyoka', 'aqc': 'Archi', 'aqd': 'Ampari Dogon', 'aqg': 'Arigidi', 'aqm': 'Atohwaim', 'aqn': 'Northern Alta', 'aqp': 'Atakapa', 'aqr': 'Arhâ', 'aqt': 'Angaité', 'aqz': 'Akuntsu', 'ara': 'Arabic', 'arb': 'Standard Arabic', 'arc': 'Aramaic', 'ard': 'Arabana', 'are': 'Western Arrarnta', 'arg': 'Aragonese', 'arh': 'Arhuaco', 'ari': 'Arikara', 'arj': 'Arapaso', 'ark': 'Arikapú', 'arl': 'Arabela', 'arn': 'Mapuche', 'aro': 'Araona', 'arp': 'Arapaho', 'arq': 'Algerian Arabic', 'arr': 'Karo', 'ars': 'Najdi Arabic', 'aru': 'Aruá', 'arv': 'Arbore', 'arw': 'Arawak', 'arx': 'Aruá', 'ary': 'Moroccan Arabic', 'arz': 'Egyptian Arabic', 'asa': 'Asu', 'asb': 'Assiniboine', 'asc': 'Casuarina Coast Asmat', 'ase': 'American Sign Language', 'asf': 'Auslan', 'asg': 'Cishingini', 'ash': 'Abishira', 'asi': 'Buruwai', 'asj': 'Sari', 'ask': 'Ashkun', 'asl': 'Asilulu', 'asm': 'Assamese', 'asn': 'Xingú Asuriní', 'aso': 'Dano', 'asp': 'Algerian Sign Language', 'asq': 'Austrian Sign Language', 'asr': 'Asuri', 'ass': 'Ipulo', 'ast': 'Asturian', 'asu': 'Tocantins Asurini', 'asv': 'Asoa', 'asw': 'Australian Aborigines Sign Language', 'asx': 'Muratayak', 'asy': 'Yaosakor Asmat', 'asz': 'As', 'ata': 'Pele-Ata', 'atb': 'Zaiwa', 'atc': 'Atsahuaca', 'atd': 'Ata Manobo', 'ate': 'Atemble', 'atg': 'Ivbie North-Okpela-Arhe', 'ati': 'Attié', 'atj': 'Atikamekw', 'atk': 'Ati', 'atl': 'Mt. Iraya Agta', 'atm': 'Ata', 'atn': 'Ashtiani', 'ato': 'Atong', 'atp': 'Pudtol Atta', 'atq': 'Aralle-Tabulahan', 'atr': 'Waimiri-Atroari', 'ats': 'Gros Ventre', 'att': 'Pamplona Atta', 'atu': 'Reel', 'atv': 'Northern Altai', 'atw': 'Atsugewi', 'atx': 'Arutani', 'aty': 'Aneityum', 'atz': 'Arta', 'aua': 'Asumboa', 'aub': 'Alugu', 'auc': 'Waorani', 'aud': 'Anuta', 'aug': 'Aguna', 'auh': 'Aushi', 'aui': 'Anuki', 'auj': 'Awjilah', 'auk': 'Heyo', 'aul': 'Aulua', 'aum': 'Asu', 'aun': 'Molmo One', 'auo': 'Auyokawa', 'aup': 'Makayam', 'auq': 'Anus', 'aur': 'Aruek', 'aut': 'Austral', 'auu': 'Auye', 'auw': 'Awyi', 'aux': 'Aurá', 'auy': 'Awiyaana', 'auz': 'Uzbeki Arabic', 'ava': 'Avaric', 'avb': 'Avau', 'avd': 'Alviri-Vidari', 'ave': 'Avestan', 'avi': 'Avikam', 'avk': 'Kotava', 'avl': 'Eastern Egyptian Bedawi Arabic', 'avm': 'Angkamuthi', 'avn': 'Avatime', 'avo': 'Agavotaguerra', 'avs': 'Aushiri', 'avt': 'Au', 'avu': 'Avokaya', 'avv': 'Avá-Canoeiro', 'awa': 'Awadhi', 'awb': 'Awa', 'awc': 'Cicipu', 'awe': 'Awetí', 'awg': 'Anguthimri', 'awh': 'Awbono', 'awi': 'Aekyom', 'awk': 'Awabakal', 'awm': 'Arawum', 'awn': 'Awngi', 'awo': 'Awak', 'awr': 'Awera', 'aws': 'South Awyu', 'awt': 'Araweté', 'awu': 'Central Awyu', 'awv': 'Jair Awyu', 'aww': 'Awun', 'awx': 'Awara', 'awy': 'Edera Awyu', 'axb': 'Abipon', 'axe': 'Ayerrerenge', 'axg': 'Mato Grosso Arára', 'axk': 'Yaka', 'axl': 'Lower Southern Aranda', 'axm': 'Middle Armenian', 'axx': 'Xârâgurè', 'aya': 'Awar', 'ayb': 'Ayizo Gbe', 'ayc': 'Southern Aymara', 'ayd': 'Ayabadhu', 'aye': 'Ayere', 'ayg': 'Ginyanga', 'ayh': 'Hadrami Arabic', 'ayi': 'Leyigha', 'ayk': 'Akuku', 'ayl': 'Libyan Arabic', 'aym': 'Aymara', 'ayn': 'Sanaani Arabic', 'ayo': 'Ayoreo', 'ayp': 'North Mesopotamian Arabic', 'ayq': 'Ayi', 'ayr': 'Central Aymara', 'ays': 'Sorsogon Ayta', 'ayt': 'Magbukun Ayta', 'ayu': 'Ayu', 'ayy': 'Tayabas Ayta', 'ayz': 'Mai Brat', 'aza': 'Azha', 'azb': 'South Azerbaijani', 'azd': 'Eastern Durango Nahuatl', 'aze': 'Azerbaijani', 'azg': 'San Pedro Amuzgos Amuzgo', 'azj': 'North Azerbaijani', 'azm': 'Ipalapa Amuzgo', 'azn': 'Western Durango Nahuatl', 'azo': 'Awing', 'azt': 'Faire Atta', 'azz': 'Highland Puebla Nahuatl', 'baa': 'Babatana', 'bab': 'Bainouk-Gunyuño', 'bac': 'Badui', 'bae': 'Baré', 'baf': 'Nubaca', 'bag': 'Tuki', 'bah': 'Bahamas Creole English', 'baj': 'Barakai', 'bak': 'Bashkir', 'bal': 'Baluchi', 'bam': 'Bambara', 'ban': 'Balinese', 'bao': 'Waimaha', 'bap': 'Bantawa', 'bar': 'Bavarian', 'bas': 'Basaa', 'bau': 'Bada', 'bav': 'Vengo', 'baw': 'Bambili-Bambui', 'bax': 'Bamun', 'bay': 'Batuley', 'bba': 'Baatonum', 'bbb': 'Barai', 'bbc': 'Batak Toba', 'bbd': 'Bau', 'bbe': 'Bangba', 'bbf': 'Baibai', 'bbg': 'Barama', 'bbh': 'Bugan', 'bbi': 'Barombi', 'bbj': 'Ghomala', 'bbk': 'Babanki', 'bbl': 'Bats', 'bbm': 'Babango', 'bbn': 'Uneapa', 'bbo': 'Northern Bobo Madaré', 'bbp': 'West Central Banda', 'bbq': 'Bamali', 'bbr': 'Girawa', 'bbs': 'Bakpinka', 'bbt': 'Mburku', 'bbu': 'Kulung', 'bbv': 'Karnai', 'bbw': 'Baba', 'bbx': 'Bubia', 'bby': 'Befang', 'bbz': 'Babalia Creole Arabic', 'bca': 'Central Bai', 'bcb': 'Bainouk-Samik', 'bcc': 'Southern Balochi', 'bcd': 'North Babar', 'bce': 'Bamenyam', 'bcf': 'Bamu', 'bcg': 'Baga Pokur', 'bch': 'Bariai', 'bci': 'Baoulé', 'bcj': 'Bardi', 'bck': 'Bunuba', 'bcl': 'Central Bikol', 'bcm': 'Bannoni', 'bcn': 'Bali', 'bco': 'Kaluli', 'bcp': 'Bali', 'bcq': 'Bench', 'bcr': 'Babine', 'bcs': 'Kohumono', 'bct': 'Bendi', 'bcu': 'Awad Bing', 'bcv': 'Shoo-Minda-Nye', 'bcw': 'Bana', 'bcy': 'Bacama', 'bcz': 'Bainouk-Gunyaamolo', 'bda': 'Bayot', 'bdb': 'Basap', 'bdc': 'Emberá-Baudó', 'bdd': 'Bunama', 'bde': 'Bade', 'bdf': 'Biage', 'bdg': 'Bonggi', 'bdh': 'Baka', 'bdi': 'Burun', 'bdj': 'Bai', 'bdk': 'Budukh', 'bdl': 'Indonesian Bajau', 'bdm': 'Buduma', 'bdn': 'Baldemu', 'bdo': 'Morom', 'bdp': 'Bende', 'bdq': 'Bahnar', 'bdr': 'West Coast Bajau', 'bds': 'Burunge', 'bdt': 'Bokoto', 'bdu': 'Oroko', 'bdv': 'Bodo Parja', 'bdw': 'Baham', 'bdx': 'Budong-Budong', 'bdy': 'Bandjalang', 'bdz': 'Badeshi', 'bea': 'Beaver', 'beb': 'Bebele', 'bec': 'Iceve-Maci', 'bed': 'Bedoanas', 'bee': 'Byangsi', 'bef': 'Benabena', 'beg': 'Belait', 'beh': 'Biali', 'bei': "Bekati'", 'bej': 'Beja', 'bek': 'Bebeli', 'bel': 'Belarusian', 'bem': 'Bemba', 'ben': 'Bengali', 'beo': 'Beami', 'bep': 'Besoa', 'beq': 'Beembe', 'bes': 'Besme', 'bet': 'Guiberoua Béte', 'beu': 'Blagar', 'bev': 'Daloa Bété', 'bew': 'Betawi', 'bex': 'Jur Modo', 'bey': 'Beli', 'bez': 'Bena', 'bfa': 'Bari', 'bfb': 'Pauri Bareli', 'bfc': 'Panyi Bai', 'bfd': 'Bafut', 'bfe': 'Betaf', 'bff': 'Bofi', 'bfg': 'Busang Kayan', 'bfh': 'Blafe', 'bfi': 'British Sign Language', 'bfj': 'Bafanji', 'bfk': 'Ban Khor Sign Language', 'bfl': 'Banda-Ndélé', 'bfm': 'Mmen', 'bfn': 'Bunak', 'bfo': 'Malba Birifor', 'bfp': 'Beba', 'bfq': 'Badaga', 'bfr': 'Bazigar', 'bfs': 'Southern Bai', 'bft': 'Balti', 'bfu': 'Gahri', 'bfw': 'Bondo', 'bfx': 'Bantayanon', 'bfy': 'Bagheli', 'bfz': 'Mahasu Pahari', 'bga': 'Gwamhi-Wuri', 'bgb': 'Bobongko', 'bgc': 'Haryanvi', 'bgd': 'Rathwi Bareli', 'bge': 'Bauria', 'bgf': 'Bangandu', 'bgg': 'Bugun', 'bgi': 'Giangan', 'bgj': 'Bangolan', 'bgk': 'Bit', 'bgl': 'Bo', 'bgn': 'Western Balochi', 'bgo': 'Baga Koga', 'bgp': 'Eastern Balochi', 'bgq': 'Bagri', 'bgr': 'Bawm Chin', 'bgs': 'Tagabawa', 'bgt': 'Bughotu', 'bgu': 'Mbongno', 'bgv': 'Warkay-Bipim', 'bgw': 'Bhatri', 'bgx': 'Balkan Gagauz Turkish', 'bgy': 'Benggoi', 'bgz': 'Banggai', 'bha': 'Bharia', 'bhb': 'Bhili', 'bhc': 'Biga', 'bhd': 'Bhadrawahi', 'bhe': 'Bhaya', 'bhf': 'Odiai', 'bhg': 'Binandere', 'bhh': 'Bukharic', 'bhi': 'Bhilali', 'bhj': 'Bahing', 'bhl': 'Bimin', 'bhm': 'Bathari', 'bhn': 'Bohtan Neo-Aramaic', 'bho': 'Bhojpuri', 'bhp': 'Bima', 'bhq': 'Tukang Besi South', 'bhr': 'Bara Malagasy', 'bhs': 'Buwal', 'bht': 'Bhattiyali', 'bhu': 'Bhunjia', 'bhv': 'Bahau', 'bhw': 'Biak', 'bhx': 'Bhalay', 'bhy': 'Bhele', 'bhz': 'Bada', 'bia': 'Badimaya', 'bib': 'Bissa', 'bic': 'Bikaru', 'bid': 'Bidiyo', 'bie': 'Bepour', 'bif': 'Biafada', 'big': 'Biangai', 'bij': 'Vaghat-Ya-Bijim-Legeri', 'bik': 'Bikol', 'bil': 'Bile', 'bim': 'Bimoba', 'bin': 'Bini', 'bio': 'Nai', 'bip': 'Bila', 'biq': 'Bipi', 'bir': 'Bisorio', 'bis': 'Bislama', 'bit': 'Berinomo', 'biu': 'Biete', 'biv': 'Southern Birifor', 'biw': 'Kol', 'bix': 'Bijori', 'biy': 'Birhor', 'biz': 'Baloi', 'bja': 'Budza', 'bjb': 'Banggarla', 'bjc': 'Bariji', 'bje': 'Biao-Jiao Mien', 'bjf': 'Barzani Jewish Neo-Aramaic', 'bjg': 'Bidyogo', 'bjh': 'Bahinemo', 'bji': 'Burji', 'bjj': 'Kanauji', 'bjk': 'Barok', 'bjl': 'Bulu', 'bjm': 'Bajelani', 'bjn': 'Banjar', 'bjo': 'Mid-Southern Banda', 'bjp': 'Fanamaket', 'bjr': 'Binumarien', 'bjs': 'Bajan', 'bjt': 'Balanta-Ganja', 'bju': 'Busuu', 'bjv': 'Bedjond', 'bjw': 'Bakwé', 'bjx': 'Banao Itneg', 'bjy': 'Bayali', 'bjz': 'Baruga', 'bka': 'Kyak', 'bkc': 'Baka', 'bkd': 'Binukid', 'bkf': 'Beeke', 'bkg': 'Buraka', 'bkh': 'Bakoko', 'bki': 'Baki', 'bkj': 'Pande', 'bkk': 'Brokskat', 'bkl': 'Berik', 'bkm': 'Kom', 'bkn': 'Bukitan', 'bko': "Kwa'", 'bkp': 'Boko', 'bkq': 'Bakairí', 'bkr': 'Bakumpai', 'bks': 'Northern Sorsoganon', 'bkt': 'Boloki', 'bku': 'Buhid', 'bkv': 'Bekwarra', 'bkw': 'Bekwel', 'bkx': 'Baikeno', 'bky': 'Bokyi', 'bkz': 'Bungku', 'bla': 'Siksika', 'blb': 'Bilua', 'blc': 'Bella Coola', 'bld': 'Bolango', 'ble': 'Balanta-Kentohe', 'blf': 'Buol', 'blg': 'Balau', 'blh': 'Kuwaa', 'bli': 'Bolia', 'blj': 'Bolongan', 'blk': "Pa'o Karen", 'bll': 'Biloxi', 'blm': 'Beli', 'bln': 'Southern Catanduanes Bikol', 'blo': 'Anii', 'blp': 'Blablanga', 'blq': 'Baluan-Pam', 'blr': 'Blang', 'bls': 'Balaesang', 'blt': 'Tai Dam', 'blv': 'Kibala', 'blw': 'Balangao', 'blx': 'Mag-Indi Ayta', 'bly': 'Notre', 'blz': 'Balantak', 'bma': 'Lame', 'bmb': 'Bembe', 'bmc': 'Biem', 'bmd': 'Baga Manduri', 'bme': 'Limassa', 'bmf': 'Bom-Kim', 'bmg': 'Bamwe', 'bmh': 'Kein', 'bmi': 'Bagirmi', 'bmj': 'Bote-Majhi', 'bmk': 'Ghayavi', 'bml': 'Bomboli', 'bmm': 'Northern Betsimisaraka Malagasy', 'bmn': 'Bina', 'bmo': 'Bambalang', 'bmp': 'Bulgebi', 'bmq': 'Bomu', 'bmr': 'Muinane', 'bms': 'Bilma Kanuri', 'bmt': 'Biao Mon', 'bmu': 'Somba-Siawari', 'bmv': 'Bum', 'bmw': 'Bomwali', 'bmx': 'Baimak', 'bmz': 'Baramu', 'bna': 'Bonerate', 'bnb': 'Bookan', 'bnc': 'Bontok', 'bnd': 'Banda', 'bne': 'Bintauna', 'bnf': 'Masiwang', 'bng': 'Benga', 'bni': 'Bangi', 'bnj': 'Eastern Tawbuid', 'bnk': 'Bierebo', 'bnl': 'Boon', 'bnm': 'Batanga', 'bnn': 'Bunun', 'bno': 'Bantoanon', 'bnp': 'Bola', 'bnq': 'Bantik', 'bnr': 'Butmas-Tur', 'bns': 'Bundeli', 'bnu': 'Bentong', 'bnv': 'Bonerif', 'bnw': 'Bisis', 'bnx': 'Bangubangu', 'bny': 'Bintulu', 'bnz': 'Beezen', 'boa': 'Bora', 'bob': 'Aweer', 'bod': 'Tibetan', 'boe': 'Mundabli', 'bof': 'Bolon', 'bog': 'Bamako Sign Language', 'boh': 'Boma', 'boi': 'Barbareño', 'boj': 'Anjam', 'bok': 'Bonjo', 'bol': 'Bole', 'bom': 'Berom', 'bon': 'Bine', 'boo': 'Tiemacèwè Bozo', 'bop': 'Bonkiman', 'boq': 'Bogaya', 'bor': 'Borôro', 'bos': 'Bosnian', 'bot': 'Bongo', 'bou': 'Bondei', 'bov': 'Tuwuli', 'bow': 'Rema', 'box': 'Buamu', 'boy': 'Bodo', 'boz': 'Tiéyaxo Bozo', 'bpa': 'Daakaka', 'bpb': 'Barbacoas', 'bpd': 'Banda-Banda', 'bpg': 'Bonggo', 'bph': 'Botlikh', 'bpi': 'Bagupi', 'bpj': 'Binji', 'bpk': 'Orowe', 'bpl': 'Broome Pearling Lugger Pidgin', 'bpm': 'Biyom', 'bpn': 'Dzao Min', 'bpo': 'Anasi', 'bpp': 'Kaure', 'bpq': 'Banda Malay', 'bpr': 'Koronadal Blaan', 'bps': 'Sarangani Blaan', 'bpt': 'Barrow Point', 'bpu': 'Bongu', 'bpv': 'Bian Marind', 'bpw': 'Bo', 'bpx': 'Palya Bareli', 'bpy': 'Bishnupriya', 'bpz': 'Bilba', 'bqa': 'Tchumbuli', 'bqb': 'Bagusa', 'bqc': 'Boko', 'bqd': 'Bung', 'bqf': 'Baga Kaloum', 'bqg': 'Bago-Kusuntu', 'bqh': 'Baima', 'bqi': 'Bakhtiari', 'bqj': 'Bandial', 'bqk': 'Banda-Mbrès', 'bql': 'Bilakura', 'bqm': 'Wumboko', 'bqn': 'Bulgarian Sign Language', 'bqo': 'Balo', 'bqp': 'Busa', 'bqq': 'Biritai', 'bqr': 'Burusu', 'bqs': 'Bosngun', 'bqt': 'Bamukumbit', 'bqu': 'Boguru', 'bqv': 'Koro Wachi', 'bqw': 'Buru', 'bqx': 'Baangi', 'bqy': 'Bengkala Sign Language', 'bqz': 'Bakaka', 'bra': 'Braj', 'brb': 'Lave', 'brc': 'Berbice Creole Dutch', 'brd': 'Baraamu', 'bre': 'Breton', 'brf': 'Bera', 'brg': 'Baure', 'brh': 'Brahui', 'bri': 'Mokpwe', 'brj': 'Bieria', 'brk': 'Birked', 'brl': 'Birwa', 'brm': 'Barambu', 'brn': 'Boruca', 'bro': 'Brokkat', 'brp': 'Barapasi', 'brq': 'Breri', 'brr': 'Birao', 'brs': 'Baras', 'brt': 'Bitare', 'bru': 'Eastern Bru', 'brv': 'Western Bru', 'brw': 'Bellari', 'brx': 'Bodo', 'bry': 'Burui', 'brz': 'Bilbil', 'bsa': 'Abinomn', 'bsb': 'Brunei Bisaya', 'bsc': 'Bassari', 'bse': 'Wushi', 'bsf': 'Bauchi', 'bsg': 'Bashkardi', 'bsh': 'Kati', 'bsi': 'Bassossi', 'bsj': 'Bangwinji', 'bsk': 'Burushaski', 'bsl': 'Basa-Gumna', 'bsm': 'Busami', 'bsn': 'Barasana-Eduria', 'bso': 'Buso', 'bsp': 'Baga Sitemu', 'bsq': 'Bassa', 'bsr': 'Bassa-Kontagora', 'bss': 'Akoose', 'bst': 'Basketo', 'bsu': 'Bahonsuai', 'bsv': 'Baga Sobané', 'bsw': 'Baiso', 'bsx': 'Yangkam', 'bsy': 'Sabah Bisaya', 'bta': 'Bata', 'btc': 'Bati', 'btd': 'Batak Dairi', 'bte': 'Gamo-Ningi', 'btf': 'Birgit', 'btg': 'Gagnoa Bété', 'bth': 'Biatah Bidayuh', 'bti': 'Burate', 'btj': 'Bacanese Malay', 'btm': 'Batak Mandailing', 'btn': 'Ratagnon', 'bto': 'Rinconada Bikol', 'btp': 'Budibud', 'btq': 'Batek', 'btr': 'Baetora', 'bts': 'Batak Simalungun', 'btt': 'Bete-Bendi', 'btu': 'Batu', 'btv': 'Bateri', 'btw': 'Butuanon', 'btx': 'Batak Karo', 'bty': 'Bobot', 'btz': 'Batak Alas-Kluet', 'bua': 'Buriat', 'bub': 'Bua', 'buc': 'Bushi', 'bud': 'Ntcham', 'bue': 'Beothuk', 'buf': 'Bushoong', 'bug': 'Buginese', 'buh': 'Younuo Bunu', 'bui': 'Bongili', 'buj': 'Basa-Gurmana', 'buk': 'Bugawac', 'bul': 'Bulgarian', 'bum': 'Bulu', 'bun': 'Sherbro', 'buo': 'Terei', 'bup': 'Busoa', 'buq': 'Brem', 'bus': 'Bokobaru', 'but': 'Bungain', 'buu': 'Budu', 'buv': 'Bun', 'buw': 'Bubi', 'bux': 'Boghom', 'buy': 'Bullom So', 'buz': 'Bukwen', 'bva': 'Barein', 'bvb': 'Bube', 'bvc': 'Baelelea', 'bvd': 'Baeggu', 'bve': 'Berau Malay', 'bvf': 'Boor', 'bvg': 'Bonkeng', 'bvh': 'Bure', 'bvi': 'Belanda Viri', 'bvj': 'Baan', 'bvk': 'Bukat', 'bvl': 'Bolivian Sign Language', 'bvm': 'Bamunka', 'bvn': 'Buna', 'bvo': 'Bolgo', 'bvp': 'Bumang', 'bvq': 'Birri', 'bvr': 'Burarra', 'bvt': 'Bati', 'bvu': 'Bukit Malay', 'bvv': 'Baniva', 'bvw': 'Boga', 'bvx': 'Dibole', 'bvy': 'Baybayanon', 'bvz': 'Bauzi', 'bwa': 'Bwatoo', 'bwb': 'Namosi-Naitasiri-Serua', 'bwc': 'Bwile', 'bwd': 'Bwaidoka', 'bwe': 'Bwe Karen', 'bwf': 'Boselewa', 'bwg': 'Barwe', 'bwh': 'Bishuo', 'bwi': 'Baniwa', 'bwj': 'Láá Láá Bwamu', 'bwk': 'Bauwaki', 'bwl': 'Bwela', 'bwm': 'Biwat', 'bwn': 'Wunai Bunu', 'bwo': 'Boro', 'bwp': 'Mandobo Bawah', 'bwq': 'Southern Bobo Madaré', 'bwr': 'Bura-Pabir', 'bws': 'Bomboma', 'bwt': 'Bafaw-Balong', 'bwu': 'Buli', 'bww': 'Bwa', 'bwx': 'Bu-Nao Bunu', 'bwy': 'Cwi Bwamu', 'bwz': 'Bwisi', 'bxa': 'Tairaha', 'bxb': 'Belanda Bor', 'bxc': 'Molengue', 'bxd': 'Pela', 'bxe': 'Birale', 'bxf': 'Bilur', 'bxg': 'Bangala', 'bxh': 'Buhutu', 'bxi': 'Pirlatapa', 'bxj': 'Bayungu', 'bxk': 'Bukusu', 'bxl': 'Jalkunan', 'bxm': 'Mongolia Buriat', 'bxn': 'Burduna', 'bxo': 'Barikanchi', 'bxp': 'Bebil', 'bxq': 'Beele', 'bxr': 'Russia Buriat', 'bxs': 'Busam', 'bxu': 'China Buriat', 'bxv': 'Berakou', 'bxw': 'Bankagooma', 'bxz': 'Binahari', 'bya': 'Batak', 'byb': 'Bikya', 'byc': 'Ubaghara', 'byd': "Benyadu'", 'bye': 'Pouye', 'byf': 'Bete', 'byg': 'Baygo', 'byh': 'Bhujel', 'byi': 'Buyu', 'byj': 'Bina', 'byk': 'Biao', 'byl': 'Bayono', 'bym': 'Bidjara', 'byn': 'Blin', 'byo': 'Biyo', 'byp': 'Bumaji', 'byq': 'Basay', 'byr': 'Baruya', 'bys': 'Burak', 'byt': 'Berti', 'byv': 'Medumba', 'byw': 'Belhariya', 'byx': 'Qaqet', 'byz': 'Banaro', 'bza': 'Bandi', 'bzb': 'Andio', 'bzc': 'Southern Betsimisaraka Malagasy', 'bzd': 'Bribri', 'bze': 'Jenaama Bozo', 'bzf': 'Boikin', 'bzg': 'Babuza', 'bzh': 'Mapos Buang', 'bzi': 'Bisu', 'bzj': 'Belize Kriol English', 'bzk': 'Nicaragua Creole English', 'bzl': 'Boano', 'bzm': 'Bolondo', 'bzn': 'Boano', 'bzo': 'Bozaba', 'bzp': 'Kemberano', 'bzq': 'Buli', 'bzr': 'Biri', 'bzs': 'Brazilian Sign Language', 'bzt': 'Brithenig', 'bzu': 'Burmeso', 'bzv': 'Naami', 'bzw': 'Basa', 'bzx': 'Kɛlɛngaxo Bozo', 'bzy': 'Obanliku', 'bzz': 'Evant', 'caa': 'Chortí', 'cab': 'Garifuna', 'cac': 'Chuj', 'cad': 'Caddo', 'cae': 'Lehar', 'caf': 'Southern Carrier', 'cag': 'Nivaclé', 'cah': 'Cahuarano', 'caj': 'Chané', 'cak': 'Kaqchikel', 'cal': 'Carolinian', 'cam': 'Cemuhî', 'can': 'Chambri', 'cao': 'Chácobo', 'cap': 'Chipaya', 'caq': 'Car Nicobarese', 'car': 'Carib', 'cas': 'Tsimané', 'cat': 'Catalan', 'cav': 'Cavineña', 'caw': 'Callawalla', 'cax': 'Chiquitano', 'cay': 'Cayuga', 'caz': 'Canichana', 'cbb': 'Cabiyarí', 'cbc': 'Carapana', 'cbd': 'Carijona', 'cbg': 'Chimila', 'cbi': 'Chachi', 'cbj': 'Ede Cabe', 'cbk': 'Chavacano', 'cbl': 'Bualkhaw Chin', 'cbn': 'Nyahkur', 'cbo': 'Izora', 'cbq': 'Tsucuba', 'cbr': 'Cashibo-Cacataibo', 'cbs': 'Cashinahua', 'cbt': 'Chayahuita', 'cbu': 'Candoshi-Shapra', 'cbv': 'Cacua', 'cbw': 'Kinabalian', 'cby': 'Carabayo', 'cca': 'Cauca', 'ccc': 'Chamicuro', 'ccd': 'Cafundo Creole', 'cce': 'Chopi', 'ccg': 'Samba Daka', 'cch': 'Atsam', 'ccj': 'Kasanga', 'ccl': 'Cutchi-Swahili', 'ccm': 'Malaccan Creole Malay', 'cco': 'Comaltepec Chinantec', 'ccp': 'Chakma', 'ccr': 'Cacaopera', 'cda': 'Choni', 'cde': 'Chenchu', 'cdf': 'Chiru', 'cdg': 'Chamari', 'cdh': 'Chambeali', 'cdi': 'Chodri', 'cdj': 'Churahi', 'cdm': 'Chepang', 'cdn': 'Chaudangsi', 'cdo': 'Min Dong Chinese', 'cdr': 'Cinda-Regi-Tiyal', 'cds': 'Chadian Sign Language', 'cdy': 'Chadong', 'cdz': 'Koda', 'cea': 'Lower Chehalis', 'ceb': 'Cebuano', 'ceg': 'Chamacoco', 'cek': 'Eastern Khumi Chin', 'cen': 'Cen', 'ces': 'Czech', 'cet': 'Centúúm', 'cey': 'Ekai Chin', 'cfa': 'Dijim-Bwilim', 'cfd': 'Cara', 'cfg': 'Como Karim', 'cfm': 'Falam Chin', 'cga': 'Changriwa', 'cgc': 'Kagayanen', 'cgg': 'Chiga', 'cgk': 'Chocangacakha', 'cha': 'Chamorro', 'chb': 'Chibcha', 'chc': 'Catawba', 'chd': 'Highland Oaxaca Chontal', 'che': 'Chechen', 'chf': 'Tabasco Chontal', 'chg': 'Chagatai', 'chh': 'Chinook', 'chj': 'Ojitlán Chinantec', 'chk': 'Chuukese', 'chl': 'Cahuilla', 'chm': 'Mari', 'chn': 'Chinook Jargon', 'cho': 'Choctaw', 'chp': 'Chipewyan', 'chq': 'Quiotepec Chinantec', 'chr': 'Cherokee', 'cht': 'Cholón', 'chu': 'Church Slavic', 'chv': 'Chuvash', 'chw': 'Chuwabu', 'chx': 'Chantyal', 'chy': 'Cheyenne', 'chz': 'Ozumacín Chinantec', 'cia': 'Cia-Cia', 'cib': 'Ci Gbe', 'cic': 'Chickasaw', 'cid': 'Chimariko', 'cie': 'Cineni', 'cih': 'Chinali', 'cik': 'Chitkuli Kinnauri', 'cim': 'Cimbrian', 'cin': 'Cinta Larga', 'cip': 'Chiapanec', 'cir': 'Tiri', 'ciw': 'Chippewa', 'ciy': 'Chaima', 'cja': 'Western Cham', 'cje': 'Chru', 'cjh': 'Upper Chehalis', 'cji': 'Chamalal', 'cjk': 'Chokwe', 'cjm': 'Eastern Cham', 'cjn': 'Chenapian', 'cjo': 'Ashéninka Pajonal', 'cjp': 'Cabécar', 'cjs': 'Shor', 'cjv': 'Chuave', 'cjy': 'Jinyu Chinese', 'ckb': 'Sorani Kurdish', 'ckh': 'Chak', 'ckl': 'Cibak', 'ckn': 'Kaang Chin', 'cko': 'Anufo', 'ckq': 'Kajakse', 'ckr': 'Kairak', 'cks': 'Tayo', 'ckt': 'Chukot', 'cku': 'Koasati', 'ckv': 'Kavalan', 'ckx': 'Caka', 'cky': 'Cakfem-Mushere', 'ckz': 'Cakchiquel-Quiché Mixed Language', 'cla': 'Ron', 'clc': 'Chilcotin', 'cld': 'Chaldean Neo-Aramaic', 'cle': 'Lealao Chinantec', 'clh': 'Chilisso', 'cli': 'Chakali', 'clj': 'Laitu Chin', 'clk': 'Idu-Mishmi', 'cll': 'Chala', 'clm': 'Clallam', 'clo': 'Lowland Oaxaca Chontal', 'clt': 'Lautu Chin', 'clu': 'Caluyanun', 'clw': 'Chulym', 'cly': 'Eastern Highland Chatino', 'cma': 'Maa', 'cme': 'Cerma', 'cmg': 'Classical Mongolian', 'cmi': 'Emberá-Chamí', 'cml': 'Campalagian', 'cmm': 'Michigamea', 'cmn': 'Mandarin Chinese', 'cmo': 'Central Mnong', 'cmr': 'Mro-Khimi Chin', 'cms': 'Messapic', 'cmt': 'Camtho', 'cna': 'Changthang', 'cnb': 'Chinbon Chin', 'cnc': 'Côông', 'cng': 'Northern Qiang', 'cnh': 'Hakha Chin', 'cni': 'Asháninka', 'cnk': 'Khumi Chin', 'cnl': 'Lalana Chinantec', 'cno': 'Con', 'cnr': 'Montenegrin', 'cns': 'Central Asmat', 'cnt': 'Tepetotutla Chinantec', 'cnu': 'Chenoua', 'cnw': 'Ngawn Chin', 'cnx': 'Middle Cornish', 'coa': 'Cocos Islands Malay', 'cob': 'Chicomuceltec', 'coc': 'Cocopa', 'cod': 'Cocama-Cocamilla', 'coe': 'Koreguaje', 'cof': 'Colorado', 'cog': 'Chong', 'coh': 'Chonyi-Dzihana-Kauma', 'coj': 'Cochimi', 'cok': 'Santa Teresa Cora', 'col': 'Columbia-Wenatchi', 'com': 'Comanche', 'con': 'Cofán', 'coo': 'Comox', 'cop': 'Coptic', 'coq': 'Coquille', 'cor': 'Cornish', 'cos': 'Corsican', 'cot': 'Caquinte', 'cou': 'Wamey', 'cov': 'Cao Miao', 'cow': 'Cowlitz', 'cox': 'Nanti', 'coz': 'Chochotec', 'cpa': 'Palantla Chinantec', 'cpb': 'Ucayali-Yurúa Ashéninka', 'cpc': 'Ajyíninka Apurucayali', 'cpg': 'Cappadocian Greek', 'cpi': 'Chinese Pidgin English', 'cpn': 'Cherepon', 'cpo': 'Kpeego', 'cps': 'Capiznon', 'cpu': 'Pichis Ashéninka', 'cpx': 'Pu-Xian Chinese', 'cpy': 'South Ucayali Ashéninka', 'cqd': 'Chuanqiandian Cluster Miao', 'cra': 'Chara', 'crb': 'Island Carib', 'crc': 'Lonwolwol', 'crd': "Coeur d'Alene", 'cre': 'Cree', 'crf': 'Caramanta', 'crg': 'Michif', 'crh': 'Crimean Tatar', 'cri': 'Sãotomense', 'crj': 'Southern East Cree', 'crk': 'Plains Cree', 'crl': 'Northern East Cree', 'crm': 'Moose Cree', 'crn': 'El Nayar Cora', 'cro': 'Crow', 'crq': "Iyo'wujwa Chorote", 'crr': 'Carolina Algonquian', 'crs': 'Seselwa Creole French', 'crt': "Iyojwa'ja Chorote", 'crv': 'Chaura', 'crw': 'Chrau', 'crx': 'Carrier', 'cry': 'Cori', 'crz': 'Cruzeño', 'csa': 'Chiltepec Chinantec', 'csb': 'Kashubian', 'csc': 'Catalan Sign Language', 'csd': 'Chiangmai Sign Language', 'cse': 'Czech Sign Language', 'csf': 'Cuba Sign Language', 'csg': 'Chilean Sign Language', 'csh': 'Asho Chin', 'csi': 'Coast Miwok', 'csj': 'Songlai Chin', 'csk': 'Jola-Kasa', 'csl': 'Chinese Sign Language', 'csm': 'Central Sierra Miwok', 'csn': 'Colombian Sign Language', 'cso': 'Sochiapam Chinantec', 'csq': 'Croatia Sign Language', 'csr': 'Costa Rican Sign Language', 'css': 'Southern Ohlone', 'cst': 'Northern Ohlone', 'csv': 'Sumtu Chin', 'csw': 'Swampy Cree', 'csy': 'Siyin Chin', 'csz': 'Coos', 'cta': 'Tataltepec Chatino', 'ctc': 'Chetco', 'ctd': 'Tedim Chin', 'cte': 'Tepinapa Chinantec', 'ctg': 'Chittagonian', 'cth': 'Thaiphum Chin', 'ctl': 'Tlacoatzintepec Chinantec', 'ctm': 'Chitimacha', 'ctn': 'Chhintange', 'cto': 'Emberá-Catío', 'ctp': 'Western Highland Chatino', 'cts': 'Northern Catanduanes Bikol', 'ctt': 'Wayanad Chetti', 'ctu': 'Chol', 'ctz': 'Zacatepec Chatino', 'cua': 'Cua', 'cub': 'Cubeo', 'cuc': 'Usila Chinantec', 'cug': 'Chungmboko', 'cuh': 'Chuka', 'cui': 'Cuiba', 'cuj': 'Mashco Piro', 'cuk': 'San Blas Kuna', 'cul': 'Culina', 'cuo': 'Cumanagoto', 'cup': 'Cupeño', 'cuq': 'Cun', 'cur': 'Chhulung', 'cut': 'Teutila Cuicatec', 'cuu': 'Tai Ya', 'cuv': 'Cuvok', 'cuw': 'Chukwa', 'cux': 'Tepeuxila Cuicatec', 'cuy': 'Cuitlatec', 'cvg': 'Chug', 'cvn': 'Valle Nacional Chinantec', 'cwa': 'Kabwa', 'cwb': 'Maindo', 'cwd': 'Woods Cree', 'cwe': 'Kwere', 'cwg': 'Chewong', 'cwt': 'Kuwaataay', 'cya': 'Nopala Chatino', 'cyb': 'Cayubaba', 'cym': 'Welsh', 'cyo': 'Cuyonon', 'czh': 'Huizhou Chinese', 'czk': 'Knaanic', 'czn': 'Zenzontepec Chatino', 'czo': 'Min Zhong Chinese', 'czt': 'Zotung Chin', 'daa': 'Dangaléat', 'dac': 'Dambi', 'dad': 'Marik', 'dae': 'Duupa', 'dag': 'Dagbani', 'dah': 'Gwahatike', 'dai': 'Day', 'daj': 'Dar Fur Daju', 'dak': 'Dakota', 'dal': 'Dahalo', 'dam': 'Damakawa', 'dan': 'Danish', 'dao': 'Daai Chin', 'daq': 'Dandami Maria', 'dar': 'Dargwa', 'das': 'Daho-Doo', 'dau': 'Dar Sila Daju', 'dav': 'Taita', 'daw': 'Davawenyo', 'dax': 'Dayi', 'daz': 'Dao', 'dba': 'Bangime', 'dbb': 'Deno', 'dbd': 'Dadiya', 'dbe': 'Dabe', 'dbf': 'Edopi', 'dbg': 'Dogul Dom Dogon', 'dbi': 'Doka', 'dbj': "Ida'an", 'dbl': 'Dyirbal', 'dbm': 'Duguri', 'dbn': 'Duriankere', 'dbo': 'Dulbu', 'dbp': 'Duwai', 'dbq': 'Daba', 'dbr': 'Dabarre', 'dbt': 'Ben Tey Dogon', 'dbu': 'Bondum Dom Dogon', 'dbv': 'Dungu', 'dbw': 'Bankan Tey Dogon', 'dby': 'Dibiyaso', 'dcc': 'Deccan', 'dcr': 'Negerhollands', 'dda': 'Dadi Dadi', 'ddd': 'Dongotono', 'dde': 'Doondo', 'ddg': 'Fataluku', 'ddi': 'West Goodenough', 'ddj': 'Jaru', 'ddn': 'Dendi', 'ddo': 'Dido', 'ddr': 'Dhudhuroa', 'dds': 'Donno So Dogon', 'ddw': 'Dawera-Daweloor', 'dec': 'Dagik', 'ded': 'Dedua', 'dee': 'Dewoin', 'def': 'Dezfuli', 'deg': 'Degema', 'deh': 'Dehwari', 'dei': 'Demisa', 'dek': 'Dek', 'del': 'Delaware', 'dem': 'Dem', 'den': 'Slave', 'dep': 'Pidgin Delaware', 'deq': 'Dendi', 'der': 'Deori', 'des': 'Desano', 'deu': 'German', 'dev': 'Domung', 'dez': 'Dengese', 'dga': 'Southern Dagaare', 'dgb': 'Bunoge Dogon', 'dgc': 'Casiguran Dumagat Agta', 'dgd': 'Dagaari Dioula', 'dge': 'Degenan', 'dgg': 'Doga', 'dgh': 'Dghwede', 'dgi': 'Northern Dagara', 'dgk': 'Dagba', 'dgl': 'Andaandi', 'dgn': 'Dagoman', 'dgo': 'Dogri', 'dgr': 'Dogrib', 'dgs': 'Dogoso', 'dgt': "Ndra'ngith", 'dgu': 'Degaru', 'dgw': 'Daungwurrung', 'dgx': 'Doghoro', 'dgz': 'Daga', 'dhd': 'Dhundari', 'dhg': 'Dhangu-Djangu', 'dhi': 'Dhimal', 'dhl': 'Dhalandji', 'dhm': 'Zemba', 'dhn': 'Dhanki', 'dho': 'Dhodia', 'dhr': 'Dhargari', 'dhs': 'Dhaiso', 'dhu': 'Dhurga', 'dhv': 'Dehu', 'dhw': 'Dhanwar', 'dhx': 'Dhungaloo', 'dia': 'Dia', 'dib': 'South Central Dinka', 'dic': 'Lakota Dida', 'did': 'Didinga', 'dif': 'Dieri', 'dig': 'Digo', 'dih': 'Kumiai', 'dii': 'Dimbong', 'dij': 'Dai', 'dik': 'Southwestern Dinka', 'dil': 'Dilling', 'dim': 'Dime', 'din': 'Dinka', 'dio': 'Dibo', 'dip': 'Northeastern Dinka', 'diq': 'Dimli', 'dir': 'Dirim', 'dis': 'Dimasa', 'diu': 'Diriku', 'div': 'Divehi', 'diw': 'Northwestern Dinka', 'dix': 'Dixon Reef', 'diy': 'Diuwe', 'diz': 'Ding', 'dja': 'Djadjawurrung', 'djb': 'Djinba', 'djc': 'Dar Daju Daju', 'djd': 'Djamindjung', 'dje': 'Zarma', 'djf': 'Djangun', 'dji': 'Djinang', 'djj': 'Djeebbana', 'djk': 'Eastern Maroon Creole', 'djm': 'Jamsay Dogon', 'djn': 'Jawoyn', 'djo': 'Jangkang', 'djr': 'Djambarrpuyngu', 'dju': 'Kapriman', 'djw': 'Djawi', 'dka': 'Dakpakha', 'dkk': 'Dakka', 'dkr': 'Kuijau', 'dks': 'Southeastern Dinka', 'dkx': 'Mazagway', 'dlg': 'Dolgan', 'dlk': 'Dahalik', 'dlm': 'Dalmatian', 'dln': 'Darlong', 'dma': 'Duma', 'dmb': 'Mombo Dogon', 'dmc': 'Gavak', 'dmd': 'Madhi Madhi', 'dme': 'Dugwor', 'dmg': 'Upper Kinabatangan', 'dmk': 'Domaaki', 'dml': 'Dameli', 'dmm': 'Dama', 'dmo': 'Kemedzung', 'dmr': 'East Damar', 'dms': 'Dampelas', 'dmu': 'Dubu', 'dmv': 'Dumpas', 'dmw': 'Mudburra', 'dmx': 'Dema', 'dmy': 'Demta', 'dna': 'Upper Grand Valley Dani', 'dnd': 'Daonda', 'dne': 'Ndendeule', 'dng': 'Dungan', 'dni': 'Lower Grand Valley Dani', 'dnj': 'Dan', 'dnk': 'Dengka', 'dnn': 'Dzùùngoo', 'dno': 'Ndrulo', 'dnr': 'Danaru', 'dnt': 'Mid Grand Valley Dani', 'dnu': 'Danau', 'dnv': 'Danu', 'dnw': 'Western Dani', 'dny': 'Dení', 'doa': 'Dom', 'dob': 'Dobu', 'doc': 'Northern Dong', 'doe': 'Doe', 'dof': 'Domu', 'doh': 'Dong', 'doi': 'Dogri', 'dok': 'Dondo', 'dol': 'Doso', 'don': 'Toura', 'doo': 'Dongo', 'dop': 'Lukpa', 'doq': 'Dominican Sign Language', 'dor': "Dori'o", 'dos': 'Dogosé', 'dot': 'Dass', 'dov': 'Dombe', 'dow': 'Doyayo', 'dox': 'Bussa', 'doy': 'Dompo', 'doz': 'Dorze', 'dpp': 'Papar', 'drb': 'Dair', 'drc': 'Minderico', 'drd': 'Darmiya', 'dre': 'Dolpo', 'drg': 'Rungus', 'dri': "C'Lela", 'drl': 'Paakantyi', 'drn': 'West Damar', 'dro': 'Daro-Matu Melanau', 'drq': 'Dura', 'drr': 'Dororo', 'drs': 'Gedeo', 'drt': 'Drents', 'dru': 'Rukai', 'dry': 'Darai', 'dsb': 'Lower Sorbian', 'dse': 'Dutch Sign Language', 'dsh': 'Daasanach', 'dsi': 'Disa', 'dsl': 'Danish Sign Language', 'dsn': 'Dusner', 'dso': 'Desiya', 'dsq': 'Tadaksahak', 'dta': 'Daur', 'dtb': 'Labuk-Kinabatangan Kadazan', 'dtd': 'Ditidaht', 'dth': 'Adithinngithigh', 'dti': 'Ana Tinga Dogon', 'dtk': 'Tene Kan Dogon', 'dtm': 'Tomo Kan Dogon', 'dtn': 'Daatsʼíin', 'dto': 'Tommo So Dogon', 'dtp': 'Kadazan Dusun', 'dtr': 'Lotud', 'dts': 'Toro So Dogon', 'dtt': 'Toro Tegu Dogon', 'dtu': 'Tebul Ure Dogon', 'dty': 'Dotyali', 'dua': 'Duala', 'dub': 'Dubli', 'duc': 'Duna', 'due': 'Umiray Dumaget Agta', 'duf': 'Dumbea', 'dug': 'Duruma', 'duh': 'Dungra Bhil', 'dui': 'Dumun', 'duk': 'Uyajitaya', 'dul': 'Alabat Island Agta', 'dum': 'Middle Dutch', 'dun': 'Dusun Deyah', 'duo': 'Dupaninan Agta', 'dup': 'Duano', 'duq': 'Dusun Malang', 'dur': 'Dii', 'dus': 'Dumi', 'duu': 'Drung', 'duv': 'Duvle', 'duw': 'Dusun Witu', 'dux': 'Duungooma', 'duy': 'Dicamay Agta', 'duz': 'Duli-Gey', 'dva': 'Duau', 'dwa': 'Diri', 'dwr': 'Dawro', 'dws': 'Dutton World Speedwords', 'dwu': 'Dhuwal', 'dww': 'Dawawa', 'dwy': 'Dhuwaya', 'dwz': 'Dewas Rai', 'dya': 'Dyan', 'dyb': 'Dyaberdyaber', 'dyd': 'Dyugun', 'dyg': 'Villa Viciosa Agta', 'dyi': 'Djimini Senoufo', 'dym': 'Yanda Dom Dogon', 'dyn': 'Dyangadi', 'dyo': 'Jola-Fonyi', 'dyu': 'Dyula', 'dyy': 'Djabugay', 'dza': 'Tunzu', 'dze': 'Djiwarli', 'dzg': 'Dazaga', 'dzl': 'Dzalakha', 'dzn': 'Dzando', 'dzo': 'Dzongkha', 'eaa': 'Karenggapa', 'ebg': 'Ebughu', 'ebk': 'Eastern Bontok', 'ebo': 'Teke-Ebo', 'ebr': 'Ebrié', 'ebu': 'Embu', 'ecr': 'Eteocretan', 'ecs': 'Ecuadorian Sign Language', 'ecy': 'Eteocypriot', 'eee': 'E', 'efa': 'Efai', 'efe': 'Efe', 'efi': 'Efik', 'ega': 'Ega', 'egl': 'Emilian', 'ego': 'Eggon', 'egy': 'Ancient Egyptian', 'ehu': 'Ehueun', 'eip': 'Eipomek', 'eit': 'Eitiep', 'eiv': 'Askopan', 'eja': 'Ejamat', 'eka': 'Ekajuk', 'ekc': 'Eastern Karnic', 'eke': 'Ekit', 'ekg': 'Ekari', 'eki': 'Eki', 'ekk': 'Standard Estonian', 'ekl': 'Kol', 'ekm': 'Elip', 'eko': 'Koti', 'ekp': 'Ekpeye', 'ekr': 'Yace', 'eky': 'Eastern Kayah', 'ele': 'Elepi', 'elh': 'El Hugeirat', 'eli': 'Nding', 'elk': 'Elkei', 'ell': 'Greek', 'elm': 'Eleme', 'elo': 'El Molo', 'elu': 'Elu', 'elx': 'Elamite', 'ema': 'Emai-Iuleha-Ora', 'emb': 'Embaloh', 'eme': 'Emerillon', 'emg': 'Eastern Meohang', 'emi': 'Mussau-Emira', 'emk': 'Eastern Maninkakan', 'emm': 'Mamulique', 'emn': 'Eman', 'emp': 'Northern Emberá', 'ems': 'Pacific Gulf Yupik', 'emu': 'Eastern Muria', 'emw': 'Emplawas', 'emx': 'Erromintxela', 'emy': 'Epigraphic Mayan', 'ena': 'Apali', 'enb': 'Markweeta', 'enc': 'En', 'end': 'Ende', 'enf': 'Forest Enets', 'eng': 'English', 'enh': 'Tundra Enets', 'enl': 'Enlhet', 'enm': 'Middle English', 'enn': 'Engenni', 'eno': 'Enggano', 'enq': 'Enga', 'enr': 'Emumu', 'enu': 'Enu', 'env': 'Enwan', 'enw': 'Enwan', 'enx': 'Enxet', 'eot': 'Beti', 'epi': 'Epie', 'epo': 'Esperanto', 'era': 'Eravallan', 'erg': 'Sie', 'erh': 'Eruwa', 'eri': 'Ogea', 'erk': 'South Efate', 'ero': 'Horpa', 'err': 'Erre', 'ers': 'Ersu', 'ert': 'Eritai', 'erw': 'Erokwanas', 'ese': 'Ese Ejja', 'esg': 'Aheri Gondi', 'esh': 'Eshtehardi', 'esi': 'North Alaskan Inupiatun', 'esk': 'Northwest Alaska Inupiatun', 'esl': 'Egypt Sign Language', 'esm': 'Esuma', 'esn': 'Salvadoran Sign Language', 'eso': 'Estonian Sign Language', 'esq': 'Esselen', 'ess': 'Central Siberian Yupik', 'est': 'Estonian', 'esu': 'Central Yupik', 'esy': 'Eskayan', 'etb': 'Etebi', 'etc': 'Etchemin', 'eth': 'Ethiopian Sign Language', 'etn': 'Eton', 'eto': 'Eton', 'etr': 'Edolo', 'ets': 'Yekhee', 'ett': 'Etruscan', 'etu': 'Ejagham', 'etx': 'Eten', 'etz': 'Semimi', 'eus': 'Basque', 'eve': 'Even', 'evh': 'Uvbie', 'evn': 'Evenki', 'ewe': 'Ewe', 'ewo': 'Ewondo', 'ext': 'Extremaduran', 'eya': 'Eyak', 'eyo': 'Keiyo', 'eza': 'Ezaa', 'eze': 'Uzekwe', 'faa': 'Fasu', 'fab': "Fa d'Ambu", 'fad': 'Wagi', 'faf': 'Fagani', 'fag': 'Finongan', 'fah': 'Baissa Fali', 'fai': 'Faiwol', 'faj': 'Faita', 'fak': 'Fang', 'fal': 'South Fali', 'fam': 'Fam', 'fan': 'Fang', 'fao': 'Faroese', 'fap': 'Paloor', 'far': 'Fataleka', 'fas': 'Persian', 'fat': 'Fanti', 'fau': 'Fayu', 'fax': 'Fala', 'fay': 'Southwestern Fars', 'faz': 'Northwestern Fars', 'fbl': 'West Albay Bikol', 'fcs': 'Quebec Sign Language', 'fer': 'Feroge', 'ffi': 'Foia Foia', 'ffm': 'Maasina Fulfulde', 'fgr': 'Fongoro', 'fia': 'Nobiin', 'fie': 'Fyer', 'fij': 'Fijian', 'fil': 'Filipino', 'fin': 'Finnish', 'fip': 'Fipa', 'fir': 'Firan', 'fit': 'Tornedalen Finnish', 'fiw': 'Fiwaga', 'fkk': 'Kirya-Konzəl', 'fkv': 'Kven Finnish', 'fla': "Kalispel-Pend d'Oreille", 'flh': 'Foau', 'fli': 'Fali', 'fll': 'North Fali', 'fln': 'Flinders Island', 'flr': 'Fuliiru', 'fly': 'Flaaitaal', 'fmp': "Fe'fe'", 'fmu': 'Far Western Muria', 'fnb': 'Fanbak', 'fng': 'Fanagalo', 'fni': 'Fania', 'fod': 'Foodo', 'foi': 'Foi', 'fom': 'Foma', 'fon': 'Fon', 'for': 'Fore', 'fos': 'Siraya', 'fpe': 'Fernando Po Creole English', 'fqs': 'Fas', 'fra': 'French', 'frc': 'Cajun French', 'frd': 'Fordata', 'frk': 'Frankish', 'frm': 'Middle French', 'fro': 'Old French', 'frp': 'Arpitan', 'frq': 'Forak', 'frr': 'Northern Frisian', 'frs': 'Eastern Frisian', 'frt': 'Fortsenal', 'fry': 'Western Frisian', 'fse': 'Finnish Sign Language', 'fsl': 'French Sign Language', 'fss': 'Finland-Swedish Sign Language', 'fub': 'Adamawa Fulfulde', 'fuc': 'Pulaar', 'fud': 'East Futuna', 'fue': 'Borgu Fulfulde', 'fuf': 'Pular', 'fuh': 'Western Niger Fulfulde', 'fui': 'Bagirmi Fulfulde', 'fuj': 'Ko', 'ful': 'Fulah', 'fum': 'Fum', 'fun': 'Fulniô', 'fuq': 'Central-Eastern Niger Fulfulde', 'fur': 'Friulian', 'fut': 'Futuna-Aniwa', 'fuu': 'Furu', 'fuv': 'Nigerian Fulfulde', 'fuy': 'Fuyug', 'fvr': 'Fur', 'fwa': 'Fwâi', 'fwe': 'Fwe', 'gaa': 'Ga', 'gab': 'Gabri', 'gac': 'Mixed Great Andamanese', 'gad': 'Gaddang', 'gae': 'Guarequena', 'gaf': 'Gende', 'gag': 'Gagauz', 'gah': 'Alekano', 'gai': 'Borei', 'gaj': 'Gadsup', 'gak': 'Gamkonora', 'gal': 'Galolen', 'gam': 'Kandawo', 'gan': 'Gan Chinese', 'gao': 'Gants', 'gap': 'Gal', 'gaq': "Gata'", 'gar': 'Galeya', 'gas': 'Adiwasi Garasia', 'gat': 'Kenati', 'gau': 'Mudhili Gadaba', 'gaw': 'Nobonob', 'gax': 'Borana-Arsi-Guji Oromo', 'gay': 'Gayo', 'gaz': 'West Central Oromo', 'gba': 'Gbaya', 'gbb': 'Kaytetye', 'gbd': 'Karajarri', 'gbe': 'Niksek', 'gbf': 'Gaikundi', 'gbg': 'Gbanziri', 'gbh': 'Defi Gbe', 'gbi': 'Galela', 'gbj': 'Bodo Gadaba', 'gbk': 'Gaddi', 'gbl': 'Gamit', 'gbm': 'Garhwali', 'gbn': "Mo'da", 'gbo': 'Northern Grebo', 'gbp': 'Gbaya-Bossangoa', 'gbq': 'Gbaya-Bozoum', 'gbr': 'Gbagyi', 'gbs': 'Gbesi Gbe', 'gbu': 'Gagadu', 'gbv': 'Gbanu', 'gbw': 'Gabi-Gabi', 'gbx': 'Eastern Xwla Gbe', 'gby': 'Gbari', 'gbz': 'Zoroastrian Dari', 'gcc': 'Mali', 'gcd': 'Ganggalida', 'gce': 'Galice', 'gcf': 'Guadeloupean Creole French', 'gcl': 'Grenadian Creole English', 'gcn': 'Gaina', 'gcr': 'Guianese Creole French', 'gct': 'Colonia Tovar German', 'gda': 'Gade Lohar', 'gdb': 'Pottangi Ollar Gadaba', 'gdc': 'Gugu Badhun', 'gdd': 'Gedaged', 'gde': 'Gude', 'gdf': 'Guduf-Gava', 'gdg': "Ga'dang", 'gdh': 'Gadjerawang', 'gdi': 'Gundi', 'gdj': 'Gurdjar', 'gdk': 'Gadang', 'gdl': 'Dirasha', 'gdm': 'Laal', 'gdn': 'Umanakaina', 'gdo': 'Ghodoberi', 'gdq': 'Mehri', 'gdr': 'Wipi', 'gds': 'Ghandruk Sign Language', 'gdt': 'Kungardutyi', 'gdu': 'Gudu', 'gdx': 'Godwari', 'gea': 'Geruma', 'geb': 'Kire', 'gec': 'Gboloo Grebo', 'ged': 'Gade', 'geg': 'Gengle', 'geh': 'Hutterite German', 'gei': 'Gebe', 'gej': 'Gen', 'gek': 'Ywom', 'gel': "ut-Ma'in", 'geq': 'Geme', 'ges': 'Geser-Gorom', 'gev': 'Eviya', 'gew': 'Gera', 'gex': 'Garre', 'gey': 'Enya', 'gez': 'Geez', 'gfk': 'Patpatar', 'gft': 'Gafat', 'gga': 'Gao', 'ggb': 'Gbii', 'ggd': 'Gugadj', 'gge': 'Gurr-goni', 'ggg': 'Gurgula', 'ggk': 'Kungarakany', 'ggl': 'Ganglau', 'ggt': 'Gitua', 'ggu': 'Gagu', 'ggw': 'Gogodala', 'gha': 'Ghadamès', 'ghc': 'Hiberno-Scottish Gaelic', 'ghe': 'Southern Ghale', 'ghh': 'Northern Ghale', 'ghk': 'Geko Karen', 'ghl': 'Ghulfan', 'ghn': 'Ghanongga', 'gho': 'Ghomara', 'ghr': 'Ghera', 'ghs': 'Guhu-Samane', 'ght': 'Kuke', 'gia': 'Kija', 'gib': 'Gibanawa', 'gic': 'Gail', 'gid': 'Gidar', 'gie': 'Gaɓogbo', 'gig': 'Goaria', 'gih': 'Githabul', 'gil': 'Gilbertese', 'gim': 'Gimi', 'gin': 'Hinukh', 'gip': 'Gimi', 'giq': 'Green Gelao', 'gir': 'Red Gelao', 'gis': 'North Giziga', 'git': 'Gitxsan', 'giu': 'Mulao', 'giw': 'White Gelao', 'gix': 'Gilima', 'giy': 'Giyug', 'giz': 'South Giziga', 'gji': 'Geji', 'gjk': 'Kachi Koli', 'gjm': 'Gunditjmara', 'gjn': 'Gonja', 'gjr': 'Gurindji Kriol', 'gju': 'Gujari', 'gka': 'Guya', 'gkd': 'Magɨ', 'gke': 'Ndai', 'gkn': 'Gokana', 'gko': 'Kok-Nar', 'gkp': 'Guinea Kpelle', 'gku': 'ǂUngkue', 'gla': 'Scottish Gaelic', 'glc': 'Bon Gula', 'gld': 'Nanai', 'gle': 'Irish', 'glg': 'Galician', 'glh': 'Northwest Pashai', 'gli': 'Guliguli', 'glj': 'Gula Iro', 'glk': 'Gilaki', 'gll': 'Garlali', 'glo': 'Galambu', 'glr': 'Glaro-Twabo', 'glu': 'Gula', 'glv': 'Manx', 'glw': 'Glavda', 'gly': 'Gule', 'gma': 'Gambera', 'gmb': "Gula'alaa", 'gmd': 'Mághdì', 'gmg': 'Magɨyi', 'gmh': 'Middle High German', 'gml': 'Middle Low German', 'gmm': 'Gbaya-Mbodomo', 'gmn': 'Gimnime', 'gmu': 'Gumalu', 'gmv': 'Gamo', 'gmx': 'Magoma', 'gmy': 'Mycenaean Greek', 'gmz': 'Mgbolizhia', 'gna': 'Kaansa', 'gnb': 'Gangte', 'gnc': 'Guanche', 'gnd': 'Zulgo-Gemzek', 'gne': 'Ganang', 'gng': 'Ngangam', 'gnh': 'Lere', 'gni': 'Gooniyandi', 'gnj': 'Ngen', 'gnk': 'ǁGana', 'gnl': 'Gangulu', 'gnm': 'Ginuman', 'gnn': 'Gumatj', 'gno': 'Northern Gondi', 'gnq': 'Gana', 'gnr': 'Gureng Gureng', 'gnt': 'Guntai', 'gnu': 'Gnau', 'gnw': 'Western Bolivian Guaraní', 'gnz': 'Ganzi', 'goa': 'Guro', 'gob': 'Playero', 'goc': 'Gorakor', 'god': 'Godié', 'goe': 'Gongduk', 'gof': 'Gofa', 'gog': 'Gogo', 'goh': 'Old High German', 'goi': 'Gobasi', 'goj': 'Gowlan', 'gok': 'Gowli', 'gol': 'Gola', 'gom': 'Goan Konkani', 'gon': 'Gondi', 'goo': 'Gone Dau', 'gop': 'Yeretuar', 'goq': 'Gorap', 'gor': 'Gorontalo', 'gos': 'Gronings', 'got': 'Gothic', 'gou': 'Gavar', 'gow': 'Gorowa', 'gox': 'Gobu', 'goy': 'Goundo', 'goz': 'Gozarkhani', 'gpa': 'Gupa-Abawa', 'gpe': 'Ghanaian Pidgin English', 'gpn': 'Taiap', 'gqa': "Ga'anda", 'gqi': 'Guiqiong', 'gqn': 'Guana', 'gqr': 'Gor', 'gqu': 'Qau', 'gra': 'Rajput Garasia', 'grb': 'Grebo', 'grc': 'Ancient Greek', 'grd': 'Guruntum-Mbaaru', 'grg': 'Madi', 'grh': 'Gbiri-Niragu', 'gri': 'Ghari', 'grj': 'Southern Grebo', 'grm': 'Kota Marudu Talantang', 'grn': 'Guarani', 'gro': 'Groma', 'grq': 'Gorovu', 'grr': 'Taznatit', 'grs': 'Gresi', 'grt': 'Garo', 'gru': 'Kistane', 'grv': 'Central Grebo', 'grw': 'Gweda', 'grx': 'Guriaso', 'gry': 'Barclayville Grebo', 'grz': 'Guramalum', 'gse': 'Ghanaian Sign Language', 'gsg': 'German Sign Language', 'gsl': 'Gusilay', 'gsm': 'Guatemalan Sign Language', 'gsn': 'Nema', 'gso': 'Southwest Gbaya', 'gsp': 'Wasembo', 'gss': 'Greek Sign Language', 'gsw': 'Swiss German', 'gta': 'Guató', 'gtu': 'Aghu-Tharnggala', 'gua': 'Shiki', 'gub': 'Guajajára', 'guc': 'Wayuu', 'gud': 'Yocoboué Dida', 'gue': 'Gurindji', 'guf': 'Gupapuyngu', 'gug': 'Paraguayan Guaraní', 'guh': 'Guahibo', 'gui': 'Eastern Bolivian Guaraní', 'guj': 'Gujarati', 'guk': 'Gumuz', 'gul': 'Sea Island Creole English', 'gum': 'Guambiano', 'gun': 'Mbyá Guaraní', 'guo': 'Guayabero', 'gup': 'Gunwinggu', 'guq': 'Aché', 'gur': 'Farefare', 'gus': 'Guinean Sign Language', 'gut': 'Maléku Jaíka', 'guu': 'Yanomamö', 'guw': 'Gun', 'gux': 'Gourmanchéma', 'guz': 'Gusii', 'gva': 'Guana', 'gvc': 'Guanano', 'gve': 'Duwet', 'gvf': 'Golin', 'gvj': 'Guajá', 'gvl': 'Gulay', 'gvm': 'Gurmana', 'gvn': 'Kuku-Yalanji', 'gvo': 'Gavião Do Jiparaná', 'gvp': 'Pará Gavião', 'gvr': 'Gurung', 'gvs': 'Gumawana', 'gvy': 'Guyani', 'gwa': 'Mbato', 'gwb': 'Gwa', 'gwc': 'Kalami', 'gwd': 'Gawwada', 'gwe': 'Gweno', 'gwf': 'Gowro', 'gwg': 'Moo', 'gwi': 'Gwichʼin', 'gwj': 'ǀGwi', 'gwm': 'Awngthim', 'gwn': 'Gwandara', 'gwr': 'Gwere', 'gwt': 'Gawar-Bati', 'gwu': 'Guwamu', 'gww': 'Kwini', 'gwx': 'Gua', 'gxx': 'Wè Southern', 'gya': 'Northwest Gbaya', 'gyb': 'Garus', 'gyd': 'Kayardild', 'gye': 'Gyem', 'gyf': 'Gungabula', 'gyg': 'Gbayi', 'gyi': 'Gyele', 'gyl': 'Gayil', 'gym': 'Ngäbere', 'gyn': 'Guyanese Creole English', 'gyo': 'Gyalsumdo', 'gyr': 'Guarayu', 'gyy': 'Gunya', 'gza': 'Ganza', 'gzi': 'Gazi', 'gzn': 'Gane', 'haa': 'Han', 'hab': 'Hanoi Sign Language', 'hac': 'Gurani', 'had': 'Hatam', 'hae': 'Eastern Oromo', 'haf': 'Haiphong Sign Language', 'hag': 'Hanga', 'hah': 'Hahon', 'hai': 'Haida', 'haj': 'Hajong', 'hak': 'Hakka Chinese', 'hal': 'Halang', 'ham': 'Hewa', 'han': 'Hangaza', 'hao': 'Hakö', 'hap': 'Hupla', 'haq': 'Ha', 'har': 'Harari', 'has': 'Haisla', 'hat': 'Haitian', 'hau': 'Hausa', 'hav': 'Havu', 'haw': 'Hawaiian', 'hax': 'Southern Haida', 'hay': 'Haya', 'haz': 'Hazaragi', 'hba': 'Hamba', 'hbb': 'Huba', 'hbn': 'Heiban', 'hbo': 'Ancient Hebrew', 'hbs': 'Serbo-Croatian', 'hbu': 'Habu', 'hca': 'Andaman Creole Hindi', 'hch': 'Huichol', 'hdn': 'Northern Haida', 'hds': 'Honduras Sign Language', 'hdy': 'Hadiyya', 'hea': 'Northern Qiandong Miao', 'heb': 'Hebrew', 'hed': 'Herdé', 'heg': 'Helong', 'heh': 'Hehe', 'hei': 'Heiltsuk', 'hem': 'Hemba', 'her': 'Herero', 'hgm': 'Haiǁom', 'hgw': 'Haigwai', 'hhi': 'Hoia Hoia', 'hhr': 'Kerak', 'hhy': 'Hoyahoya', 'hia': 'Lamang', 'hib': 'Hibito', 'hid': 'Hidatsa', 'hif': 'Fiji Hindi', 'hig': 'Kamwe', 'hih': 'Pamosu', 'hii': 'Hinduri', 'hij': 'Hijuk', 'hik': 'Seit-Kaitetu', 'hil': 'Hiligaynon', 'hin': 'Hindi', 'hio': 'Tsoa', 'hir': 'Himarimã', 'hit': 'Hittite', 'hiw': 'Hiw', 'hix': 'Hixkaryána', 'hji': 'Haji', 'hka': 'Kahe', 'hke': 'Hunde', 'hkk': 'Hunjara-Kaina Ke', 'hkn': 'Mel-Khaonh', 'hks': 'Hong Kong Sign Language', 'hla': 'Halia', 'hlb': 'Halbi', 'hld': 'Halang Doan', 'hle': 'Hlersu', 'hlt': 'Matu Chin', 'hlu': 'Hieroglyphic Luwian', 'hma': 'Southern Mashan Hmong', 'hmb': 'Humburi Senni Songhay', 'hmc': 'Central Huishui Hmong', 'hmd': 'Large Flowery Miao', 'hme': 'Eastern Huishui Hmong', 'hmf': 'Hmong Don', 'hmg': 'Southwestern Guiyang Hmong', 'hmh': 'Southwestern Huishui Hmong', 'hmi': 'Northern Huishui Hmong', 'hmj': 'Ge', 'hmk': 'Maek', 'hml': 'Luopohe Hmong', 'hmm': 'Central Mashan Hmong', 'hmn': 'Hmong', 'hmo': 'Hiri Motu', 'hmp': 'Northern Mashan Hmong', 'hmq': 'Eastern Qiandong Miao', 'hmr': 'Hmar', 'hms': 'Southern Qiandong Miao', 'hmt': 'Hamtai', 'hmu': 'Hamap', 'hmv': 'Hmong Dô', 'hmw': 'Western Mashan Hmong', 'hmy': 'Southern Guiyang Hmong', 'hmz': 'Hmong Shua', 'hna': 'Mina', 'hnd': 'Southern Hindko', 'hne': 'Chhattisgarhi', 'hnh': 'ǁAni', 'hni': 'Hani', 'hnj': 'Hmong Njua', 'hnn': 'Hanunoo', 'hno': 'Northern Hindko', 'hns': 'Caribbean Hindustani', 'hnu': 'Hung', 'hoa': 'Hoava', 'hob': 'Mari', 'hoc': 'Ho', 'hod': 'Holma', 'hoe': 'Horom', 'hoh': 'Hobyót', 'hoi': 'Holikachuk', 'hoj': 'Hadothi', 'hol': 'Holu', 'hom': 'Homa', 'hoo': 'Holoholo', 'hop': 'Hopi', 'hor': 'Horo', 'hos': 'Ho Chi Minh City Sign Language', 'hot': 'Hote', 'hov': 'Hovongan', 'how': 'Honi', 'hoy': 'Holiya', 'hoz': 'Hozo', 'hpo': 'Hpon', 'hps': "Hawai'i Sign Language", 'hra': 'Hrangkhol', 'hrc': 'Niwer Mil', 'hre': 'Hre', 'hrk': 'Haruku', 'hrm': 'Horned Miao', 'hro': 'Haroi', 'hrp': 'Nhirrpi', 'hrt': 'Hértevin', 'hru': 'Hruso', 'hrv': 'Croatian', 'hrw': 'Warwar Feni', 'hrx': 'Hunsrik', 'hrz': 'Harzani', 'hsb': 'Upper Sorbian', 'hsh': 'Hungarian Sign Language', 'hsl': 'Hausa Sign Language', 'hsn': 'Xiang Chinese', 'hss': 'Harsusi', 'hti': 'Hoti', 'hto': 'Minica Huitoto', 'hts': 'Hadza', 'htu': 'Hitu', 'htx': 'Middle Hittite', 'hub': 'Huambisa', 'huc': 'ǂHua', 'hud': 'Huaulu', 'hue': 'San Francisco Del Mar Huave', 'huf': 'Humene', 'hug': 'Huachipaeri', 'huh': 'Huilliche', 'hui': 'Huli', 'huj': 'Northern Guiyang Hmong', 'huk': 'Hulung', 'hul': 'Hula', 'hum': 'Hungana', 'hun': 'Hungarian', 'huo': 'Hu', 'hup': 'Hupa', 'huq': 'Tsat', 'hur': 'Halkomelem', 'hus': 'Huastec', 'hut': 'Humla', 'huu': 'Murui Huitoto', 'huv': 'San Mateo Del Mar Huave', 'huw': 'Hukumina', 'hux': 'Nüpode Huitoto', 'huy': 'Hulaulá', 'huz': 'Hunzib', 'hvc': 'Haitian Vodoun Culture Language', 'hve': 'San Dionisio Del Mar Huave', 'hvk': 'Haveke', 'hvn': 'Sabu', 'hvv': 'Santa María Del Mar Huave', 'hwa': 'Wané', 'hwc': "Hawai'i Creole English", 'hwo': 'Hwana', 'hya': 'Hya', 'hye': 'Armenian', 'hyw': 'Western Armenian', 'iai': 'Iaai', 'ian': 'Iatmul', 'iar': 'Purari', 'iba': 'Iban', 'ibb': 'Ibibio', 'ibd': 'Iwaidja', 'ibe': 'Akpes', 'ibg': 'Ibanag', 'ibh': 'Bih', 'ibl': 'Ibaloi', 'ibm': 'Agoi', 'ibn': 'Ibino', 'ibo': 'Igbo', 'ibr': 'Ibuoro', 'ibu': 'Ibu', 'iby': 'Ibani', 'ica': 'Ede Ica', 'ich': 'Etkywan', 'icl': 'Icelandic Sign Language', 'icr': 'Islander Creole English', 'ida': 'Idakho-Isukha-Tiriki', 'idb': 'Indo-Portuguese', 'idc': 'Idon', 'idd': 'Ede Idaca', 'ide': 'Idere', 'idi': 'Idi', 'ido': 'Ido', 'idr': 'Indri', 'ids': 'Idesa', 'idt': 'Idaté', 'idu': 'Idoma', 'ifa': 'Amganad Ifugao', 'ifb': 'Batad Ifugao', 'ife': 'Ifè', 'iff': 'Ifo', 'ifk': 'Tuwali Ifugao', 'ifm': 'Teke-Fuumu', 'ifu': 'Mayoyao Ifugao', 'ify': 'Keley-I Kallahan', 'igb': 'Ebira', 'ige': 'Igede', 'igg': 'Igana', 'igl': 'Igala', 'igm': 'Kanggape', 'ign': 'Ignaciano', 'igo': 'Isebe', 'igs': 'Interglossa', 'igw': 'Igwe', 'ihb': 'Iha Based Pidgin', 'ihi': 'Ihievbe', 'ihp': 'Iha', 'ihw': 'Bidhawal', 'iii': 'Sichuan Yi', 'iin': 'Thiin', 'ijc': 'Izon', 'ije': 'Biseni', 'ijj': 'Ede Ije', 'ijn': 'Kalabari', 'ijs': 'Southeast Ijo', 'ike': 'Eastern Canadian Inuktitut', 'iki': 'Iko', 'ikk': 'Ika', 'ikl': 'Ikulu', 'iko': 'Olulumo-Ikom', 'ikp': 'Ikpeshi', 'ikr': 'Ikaranggal', 'iks': 'Inuit Sign Language', 'ikt': 'Inuinnaqtun', 'iku': 'Inuktitut', 'ikv': 'Iku-Gora-Ankwa', 'ikw': 'Ikwere', 'ikx': 'Ik', 'ikz': 'Ikizu', 'ila': 'Ile Ape', 'ilb': 'Ila', 'ile': 'Interlingue', 'ilg': 'Garig-Ilgar', 'ili': 'Ili Turki', 'ilk': 'Ilongot', 'ilm': 'Iranun', 'ilo': 'Iloko', 'ilp': 'Iranun', 'ils': 'International Sign', 'ilu': "Ili'uun", 'ilv': 'Ilue', 'ima': 'Mala Malasar', 'imi': 'Anamgura', 'iml': 'Miluk', 'imn': 'Imonda', 'imo': 'Imbongu', 'imr': 'Imroing', 'ims': 'Marsian', 'imy': 'Milyan', 'ina': 'Interlingua', 'inb': 'Inga', 'ind': 'Indonesian', 'ing': "Degexit'an", 'inh': 'Ingush', 'inj': 'Jungle Inga', 'inl': 'Indonesian Sign Language', 'inm': 'Minaean', 'inn': 'Isinai', 'ino': 'Inoke-Yate', 'inp': 'Iñapari', 'ins': 'Indian Sign Language', 'int': 'Intha', 'inz': 'Ineseño', 'ior': 'Inor', 'iou': 'Tuma-Irumu', 'iow': 'Iowa-Oto', 'ipi': 'Ipili', 'ipk': 'Inupiaq', 'ipo': 'Ipiko', 'iqu': 'Iquito', 'iqw': 'Ikwo', 'ire': 'Iresim', 'irh': 'Irarutu', 'iri': 'Rigwe', 'irk': 'Iraqw', 'irn': 'Irántxe', 'irr': 'Ir', 'iru': 'Irula', 'irx': 'Kamberau', 'iry': 'Iraya', 'isa': 'Isabi', 'isc': 'Isconahua', 'isd': 'Isnag', 'ise': 'Italian Sign Language', 'isg': 'Irish Sign Language', 'ish': 'Esan', 'isi': 'Nkem-Nkum', 'isk': 'Ishkashimi', 'isl': 'Icelandic', 'ism': 'Masimasi', 'isn': 'Isanzu', 'iso': 'Isoko', 'isr': 'Israeli Sign Language', 'ist': 'Istriot', 'isu': 'Isu', 'ita': 'Italian', 'itb': 'Binongan Itneg', 'itd': 'Southern Tidung', 'ite': 'Itene', 'iti': 'Inlaod Itneg', 'itk': 'Judeo-Italian', 'itl': 'Itelmen', 'itm': 'Itu Mbon Uzo', 'ito': 'Itonama', 'itr': 'Iteri', 'its': 'Isekiri', 'itt': 'Maeng Itneg', 'itv': 'Itawit', 'itw': 'Ito', 'itx': 'Itik', 'ity': 'Moyadan Itneg', 'itz': 'Itzá', 'ium': 'Iu Mien', 'ivb': 'Ibatan', 'ivv': 'Ivatan', 'iwk': 'I-Wak', 'iwm': 'Iwam', 'iwo': 'Iwur', 'iws': 'Sepik Iwam', 'ixc': 'Ixcatec', 'ixl': 'Ixil', 'iya': 'Iyayu', 'iyo': 'Mesaka', 'iyx': 'Yaka', 'izh': 'Ingrian', 'izr': 'Izere', 'izz': 'Izii', 'jaa': 'Jamamadí', 'jab': 'Hyam', 'jac': "Popti'", 'jad': 'Jahanka', 'jae': 'Yabem', 'jaf': 'Jara', 'jah': 'Jah Hut', 'jaj': 'Zazao', 'jak': 'Jakun', 'jal': 'Yalahatan', 'jam': 'Jamaican Creole English', 'jan': 'Jandai', 'jao': 'Yanyuwa', 'jaq': 'Yaqay', 'jas': 'New Caledonian Javanese', 'jat': 'Jakati', 'jau': 'Yaur', 'jav': 'Javanese', 'jax': 'Jambi Malay', 'jay': 'Yan-nhangu', 'jaz': 'Jawe', 'jbe': 'Judeo-Berber', 'jbi': 'Badjiri', 'jbj': 'Arandai', 'jbk': 'Barikewa', 'jbn': 'Nafusi', 'jbo': 'Lojban', 'jbr': 'Jofotek-Bromnya', 'jbt': 'Jabutí', 'jbu': 'Jukun Takum', 'jbw': 'Yawijibaya', 'jcs': 'Jamaican Country Sign Language', 'jct': 'Krymchak', 'jda': 'Jad', 'jdg': 'Jadgali', 'jdt': 'Judeo-Tat', 'jeb': 'Jebero', 'jee': 'Jerung', 'jeh': 'Jeh', 'jei': 'Yei', 'jek': 'Jeri Kuo', 'jel': 'Yelmek', 'jen': 'Dza', 'jer': 'Jere', 'jet': 'Manem', 'jeu': 'Jonkor Bourmataguil', 'jgb': 'Ngbee', 'jge': 'Judeo-Georgian', 'jgk': 'Gwak', 'jgo': 'Ngomba', 'jhi': 'Jehai', 'jhs': 'Jhankot Sign Language', 'jia': 'Jina', 'jib': 'Jibu', 'jic': 'Tol', 'jid': 'Bu', 'jie': 'Jilbe', 'jig': 'Jingulu', 'jih': 'sTodsde', 'jii': 'Jiiddu', 'jil': 'Jilim', 'jim': 'Jimi', 'jio': 'Jiamao', 'jiq': 'Guanyinqiao', 'jit': 'Jita', 'jiu': 'Youle Jinuo', 'jiv': 'Shuar', 'jiy': 'Buyuan Jinuo', 'jje': 'Jejueo', 'jjr': 'Bankal', 'jka': 'Kaera', 'jkm': 'Mobwa Karen', 'jko': 'Kubo', 'jkp': 'Paku Karen', 'jkr': 'Koro', 'jku': 'Labir', 'jle': 'Ngile', 'jls': 'Jamaican Sign Language', 'jma': 'Dima', 'jmb': 'Zumbun', 'jmc': 'Machame', 'jmd': 'Yamdena', 'jmi': 'Jimi', 'jml': 'Jumli', 'jmn': 'Makuri Naga', 'jmr': 'Kamara', 'jms': 'Mashi', 'jmw': 'Mouwase', 'jmx': 'Western Juxtlahuaca Mixtec', 'jna': 'Jangshung', 'jnd': 'Jandavra', 'jng': 'Yangman', 'jni': 'Janji', 'jnj': 'Yemsa', 'jnl': 'Rawat', 'jns': 'Jaunsari', 'job': 'Joba', 'jod': 'Wojenaka', 'jog': 'Jogi', 'jor': 'Jorá', 'jos': 'Jordanian Sign Language', 'jow': 'Jowulu', 'jpa': 'Jewish Palestinian Aramaic', 'jpn': 'Japanese', 'jpr': 'Judeo-Persian', 'jqr': 'Jaqaru', 'jra': 'Jarai', 'jrb': 'Judeo-Arabic', 'jrr': 'Jiru', 'jrt': 'Jorto', 'jru': 'Japrería', 'jsl': 'Japanese Sign Language', 'jua': 'Júma', 'jub': 'Wannu', 'juc': 'Jurchen', 'jud': 'Worodougou', 'juh': 'Hõne', 'jui': 'Ngadjuri', 'juk': 'Wapan', 'jul': 'Jirel', 'jum': 'Jumjum', 'jun': 'Juang', 'juo': 'Jiba', 'jup': 'Hupdë', 'jur': 'Jurúna', 'jus': 'Jumla Sign Language', 'jut': 'Jutish', 'juu': 'Ju', 'juw': 'Wãpha', 'juy': 'Juray', 'jvd': 'Javindo', 'jvn': 'Caribbean Javanese', 'jwi': 'Jwira-Pepesa', 'jya': 'Jiarong', 'jye': 'Judeo-Yemeni Arabic', 'jyy': 'Jaya', 'kaa': 'Kara-Kalpak', 'kab': 'Kabyle', 'kac': 'Kachin', 'kad': 'Adara', 'kae': 'Ketangalan', 'kaf': 'Katso', 'kag': 'Kajaman', 'kah': 'Kara', 'kai': 'Karekare', 'kaj': 'Jju', 'kak': 'Kalanguya', 'kal': 'Kalaallisut', 'kam': 'Kamba', 'kan': 'Kannada', 'kao': 'Xaasongaxango', 'kap': 'Bezhta', 'kaq': 'Capanahua', 'kas': 'Kashmiri', 'kat': 'Georgian', 'kau': 'Kanuri', 'kav': 'Katukína', 'kaw': 'Kawi', 'kax': 'Kao', 'kay': 'Kamayurá', 'kaz': 'Kazakh', 'kba': 'Kalarko', 'kbb': 'Kaxuiâna', 'kbc': 'Kadiwéu', 'kbd': 'Kabardian', 'kbe': 'Kanju', 'kbg': 'Khamba', 'kbh': 'Camsá', 'kbi': 'Kaptiau', 'kbj': 'Kari', 'kbk': 'Grass Koiari', 'kbl': 'Kanembu', 'kbm': 'Iwal', 'kbn': 'Kare', 'kbo': 'Keliko', 'kbp': 'Kabiyè', 'kbq': 'Kamano', 'kbr': 'Kafa', 'kbs': 'Kande', 'kbt': 'Abadi', 'kbu': 'Kabutra', 'kbv': 'Dera', 'kbw': 'Kaiep', 'kbx': 'Ap Ma', 'kby': 'Manga Kanuri', 'kbz': 'Duhwa', 'kca': 'Khanty', 'kcb': 'Kawacha', 'kcc': 'Lubila', 'kcd': 'Ngkâlmpw Kanum', 'kce': 'Kaivi', 'kcf': 'Ukaan', 'kcg': 'Tyap', 'kch': 'Vono', 'kci': 'Kamantan', 'kcj': 'Kobiana', 'kck': 'Kalanga', 'kcl': 'Kela', 'kcm': 'Gula', 'kcn': 'Nubi', 'kco': 'Kinalakna', 'kcp': 'Kanga', 'kcq': 'Kamo', 'kcr': 'Katla', 'kcs': 'Koenoem', 'kct': 'Kaian', 'kcu': 'Kami', 'kcv': 'Kete', 'kcw': 'Kabwari', 'kcx': 'Kachama-Ganjule', 'kcy': 'Korandje', 'kcz': 'Konongo', 'kda': 'Worimi', 'kdc': 'Kutu', 'kdd': 'Yankunytjatjara', 'kde': 'Makonde', 'kdf': 'Mamusi', 'kdg': 'Seba', 'kdh': 'Tem', 'kdi': 'Kumam', 'kdj': 'Karamojong', 'kdk': 'Numèè', 'kdl': 'Tsikimba', 'kdm': 'Kagoma', 'kdn': 'Kunda', 'kdp': 'Kaningdon-Nindem', 'kdq': 'Koch', 'kdr': 'Karaim', 'kdt': 'Kuy', 'kdu': 'Kadaru', 'kdw': 'Koneraw', 'kdx': 'Kam', 'kdy': 'Keder', 'kdz': 'Kwaja', 'kea': 'Kabuverdianu', 'keb': 'Kélé', 'kec': 'Keiga', 'ked': 'Kerewe', 'kee': 'Eastern Keres', 'kef': 'Kpessi', 'keg': 'Tese', 'keh': 'Keak', 'kei': 'Kei', 'kej': 'Kadar', 'kek': 'Kekchí', 'kel': 'Kela', 'kem': 'Kemak', 'ken': 'Kenyang', 'keo': 'Kakwa', 'kep': 'Kaikadi', 'keq': 'Kamar', 'ker': 'Kera', 'kes': 'Kugbo', 'ket': 'Ket', 'keu': 'Akebu', 'kev': 'Kanikkaran', 'kew': 'West Kewa', 'kex': 'Kukna', 'key': 'Kupia', 'kez': 'Kukele', 'kfa': 'Kodava', 'kfb': 'Northwestern Kolami', 'kfc': 'Konda-Dora', 'kfd': 'Korra Koraga', 'kfe': 'Kota', 'kff': 'Koya', 'kfg': 'Kudiya', 'kfh': 'Kurichiya', 'kfi': 'Kannada Kurumba', 'kfj': 'Kemiehua', 'kfk': 'Kinnauri', 'kfl': 'Kung', 'kfm': 'Khunsari', 'kfn': 'Kuk', 'kfo': 'Koro', 'kfp': 'Korwa', 'kfq': 'Korku', 'kfr': 'Kachhi', 'kfs': 'Bilaspuri', 'kft': 'Kanjari', 'kfu': 'Katkari', 'kfv': 'Kurmukar', 'kfw': 'Kharam Naga', 'kfx': 'Kullu Pahari', 'kfy': 'Kumaoni', 'kfz': 'Koromfé', 'kga': 'Koyaga', 'kgb': 'Kawe', 'kge': 'Komering', 'kgf': 'Kube', 'kgg': 'Kusunda', 'kgi': 'Selangor Sign Language', 'kgj': 'Gamale Kham', 'kgk': 'Kaiwá', 'kgl': 'Kunggari', 'kgm': 'Karipúna', 'kgn': 'Karingani', 'kgo': 'Krongo', 'kgp': 'Kaingang', 'kgq': 'Kamoro', 'kgr': 'Abun', 'kgs': 'Kumbainggar', 'kgt': 'Somyev', 'kgu': 'Kobol', 'kgv': 'Karas', 'kgw': 'Karon Dori', 'kgx': 'Kamaru', 'kgy': 'Kyerung', 'kha': 'Khasi', 'khb': 'Lü', 'khc': 'Tukang Besi North', 'khd': 'Bädi Kanum', 'khe': 'Korowai', 'khf': 'Khuen', 'khg': 'Khams Tibetan', 'khh': 'Kehu', 'khj': 'Kuturmi', 'khk': 'Halh Mongolian', 'khl': 'Lusi', 'khm': 'Khmer', 'khn': 'Khandesi', 'kho': 'Khotanese', 'khp': 'Kapori', 'khq': 'Koyra Chiini', 'khr': 'Kharia', 'khs': 'Kasua', 'kht': 'Khamti', 'khu': 'Nkhumbi', 'khv': 'Khvarshi', 'khw': 'Khowar', 'khx': 'Kanu', 'khy': 'Kele', 'khz': 'Keapara', 'kia': 'Kim', 'kib': 'Koalib', 'kic': 'Kickapoo', 'kid': 'Koshin', 'kie': 'Kibet', 'kif': 'Eastern Parbate Kham', 'kig': 'Kimaama', 'kih': 'Kilmeri', 'kii': 'Kitsai', 'kij': 'Kilivila', 'kik': 'Kikuyu', 'kil': 'Kariya', 'kim': 'Karagas', 'kin': 'Kinyarwanda', 'kio': 'Kiowa', 'kip': 'Sheshi Kham', 'kiq': 'Kosadle', 'kir': 'Kyrgyz', 'kis': 'Kis', 'kit': 'Agob', 'kiu': 'Kirmanjki', 'kiv': 'Kimbu', 'kiw': 'Northeast Kiwai', 'kix': 'Khiamniungan Naga', 'kiy': 'Kirikiri', 'kiz': 'Kisi', 'kja': 'Mlap', 'kjb': "Q'anjob'al", 'kjc': 'Coastal Konjo', 'kjd': 'Southern Kiwai', 'kje': 'Kisar', 'kjf': 'Khalaj', 'kjg': 'Khmu', 'kjh': 'Khakas', 'kji': 'Zabana', 'kjj': 'Khinalugh', 'kjk': 'Highland Konjo', 'kjl': 'Western Parbate Kham', 'kjm': 'Kháng', 'kjn': 'Kunjen', 'kjo': 'Harijan Kinnauri', 'kjp': 'Pwo Eastern Karen', 'kjq': 'Western Keres', 'kjr': 'Kurudu', 'kjs': 'East Kewa', 'kjt': 'Phrae Pwo Karen', 'kju': 'Kashaya', 'kjv': 'Kaikavian Literary Language', 'kjx': 'Ramopa', 'kjy': 'Erave', 'kjz': 'Bumthangkha', 'kka': 'Kakanda', 'kkb': 'Kwerisa', 'kkc': 'Odoodee', 'kkd': 'Kinuku', 'kke': 'Kakabe', 'kkf': 'Kalaktang Monpa', 'kkg': 'Mabaka Valley Kalinga', 'kkh': 'Khün', 'kki': 'Kagulu', 'kkj': 'Kako', 'kkk': 'Kokota', 'kkl': 'Kosarek Yale', 'kkm': 'Kiong', 'kkn': 'Kon Keu', 'kko': 'Karko', 'kkp': 'Gugubera', 'kkq': 'Kaiku', 'kkr': 'Kir-Balar', 'kks': 'Giiwo', 'kkt': 'Koi', 'kku': 'Tumi', 'kkv': 'Kangean', 'kkw': 'Teke-Kukuya', 'kkx': 'Kohin', 'kky': 'Guugu Yimidhirr', 'kkz': 'Kaska', 'kla': 'Klamath-Modoc', 'klb': 'Kiliwa', 'klc': 'Kolbila', 'kld': 'Gamilaraay', 'kle': 'Kulung', 'klf': 'Kendeje', 'klg': 'Tagakaulo', 'klh': 'Weliki', 'kli': 'Kalumpang', 'klj': 'Turkic Khalaj', 'klk': 'Kono', 'kll': 'Kagan Kalagan', 'klm': 'Migum', 'kln': 'Kalenjin', 'klo': 'Kapya', 'klp': 'Kamasa', 'klq': 'Rumu', 'klr': 'Khaling', 'kls': 'Kalasha', 'klt': 'Nukna', 'klu': 'Klao', 'klv': 'Maskelynes', 'klw': 'Tado', 'klx': 'Koluwawa', 'kly': 'Kalao', 'klz': 'Kabola', 'kma': 'Konni', 'kmb': 'Kimbundu', 'kmc': 'Southern Dong', 'kmd': 'Majukayang Kalinga', 'kme': 'Bakole', 'kmf': 'Kare', 'kmg': 'Kâte', 'kmh': 'Kalam', 'kmi': 'Kami', 'kmj': 'Kumarbhag Paharia', 'kmk': 'Limos Kalinga', 'kml': 'Tanudan Kalinga', 'kmm': 'Kom', 'kmn': 'Awtuw', 'kmo': 'Kwoma', 'kmp': 'Gimme', 'kmq': 'Kwama', 'kmr': 'Northern Kurdish', 'kms': 'Kamasau', 'kmt': 'Kemtuik', 'kmu': 'Kanite', 'kmv': 'Karipúna Creole French', 'kmw': 'Komo', 'kmx': 'Waboda', 'kmy': 'Koma', 'kmz': 'Khorasani Turkish', 'kna': 'Dera', 'knb': 'Lubuagan Kalinga', 'knc': 'Central Kanuri', 'knd': 'Konda', 'kne': 'Kankanaey', 'knf': 'Mankanya', 'kng': 'Koongo', 'kni': 'Kanufi', 'knj': 'Western Kanjobal', 'knk': 'Kuranko', 'knl': 'Keninjal', 'knm': 'Kanamarí', 'knn': 'Konkani', 'kno': 'Kono', 'knp': 'Kwanja', 'knq': 'Kintaq', 'knr': 'Kaningra', 'kns': 'Kensiu', 'knt': 'Panoan Katukína', 'knu': 'Kono', 'knv': 'Tabo', 'knw': 'Kung-Ekoka', 'knx': 'Kendayan', 'kny': 'Kanyok', 'knz': 'Kalamsé', 'koa': 'Konomala', 'koc': 'Kpati', 'kod': 'Kodi', 'koe': 'Kacipo-Balesi', 'kof': 'Kubi', 'kog': 'Cogui', 'koh': 'Koyo', 'koi': 'Komi-Permyak', 'kok': 'Konkani', 'kol': 'Kol', 'kom': 'Komi', 'kon': 'Kongo', 'koo': 'Konzo', 'kop': 'Waube', 'koq': 'Kota', 'kor': 'Korean', 'kos': 'Kosraean', 'kot': 'Lagwan', 'kou': 'Koke', 'kov': 'Kudu-Camo', 'kow': 'Kugama', 'koy': 'Koyukon', 'koz': 'Korak', 'kpa': 'Kutto', 'kpb': 'Mullu Kurumba', 'kpc': 'Curripaco', 'kpd': 'Koba', 'kpe': 'Kpelle', 'kpf': 'Komba', 'kpg': 'Kapingamarangi', 'kph': 'Kplang', 'kpi': 'Kofei', 'kpj': 'Karajá', 'kpk': 'Kpan', 'kpl': 'Kpala', 'kpm': 'Koho', 'kpn': 'Kepkiriwát', 'kpo': 'Ikposo', 'kpq': 'Korupun-Sela', 'kpr': 'Korafe-Yegha', 'kps': 'Tehit', 'kpt': 'Karata', 'kpu': 'Kafoa', 'kpv': 'Komi-Zyrian', 'kpw': 'Kobon', 'kpx': 'Mountain Koiali', 'kpy': 'Koryak', 'kpz': 'Kupsabiny', 'kqa': 'Mum', 'kqb': 'Kovai', 'kqc': 'Doromu-Koki', 'kqd': 'Koy Sanjaq Surat', 'kqe': 'Kalagan', 'kqf': 'Kakabai', 'kqg': 'Khe', 'kqh': 'Kisankasa', 'kqi': 'Koitabu', 'kqj': 'Koromira', 'kqk': 'Kotafon Gbe', 'kql': 'Kyenele', 'kqm': 'Khisa', 'kqn': 'Kaonde', 'kqo': 'Eastern Krahn', 'kqp': 'Kimré', 'kqq': 'Krenak', 'kqr': 'Kimaragang', 'kqs': 'Northern Kissi', 'kqt': 'Klias River Kadazan', 'kqu': 'Seroa', 'kqv': 'Okolod', 'kqw': 'Kandas', 'kqx': 'Mser', 'kqy': 'Koorete', 'kqz': 'Korana', 'kra': 'Kumhali', 'krb': 'Karkin', 'krc': 'Karachay-Balkar', 'krd': 'Kairui-Midiki', 'kre': 'Panará', 'krf': 'Koro', 'krh': 'Kurama', 'kri': 'Krio', 'krj': 'Kinaray-A', 'krk': 'Kerek', 'krl': 'Karelian', 'krn': 'Sapo', 'krp': 'Korop', 'krr': 'Krung', 'krs': 'Gbaya', 'krt': 'Tumari Kanuri', 'kru': 'Kurukh', 'krv': 'Kavet', 'krw': 'Western Krahn', 'krx': 'Karon', 'kry': 'Kryts', 'krz': 'Sota Kanum', 'ksa': 'Shuwa-Zamani', 'ksb': 'Shambala', 'ksc': 'Southern Kalinga', 'ksd': 'Kuanua', 'kse': 'Kuni', 'ksf': 'Bafia', 'ksg': 'Kusaghe', 'ksh': 'Colognian', 'ksi': 'Krisa', 'ksj': 'Uare', 'ksk': 'Kansa', 'ksl': 'Kumalu', 'ksm': 'Kumba', 'ksn': 'Kasiguranin', 'kso': 'Kofa', 'ksp': 'Kaba', 'ksq': 'Kwaami', 'ksr': 'Borong', 'kss': 'Southern Kisi', 'kst': 'Winyé', 'ksu': 'Khamyang', 'ksv': 'Kusu', 'ksw': "S'gaw Karen", 'ksx': 'Kedang', 'ksy': 'Kharia Thar', 'ksz': 'Kodaku', 'kta': 'Katua', 'ktb': 'Kambaata', 'ktc': 'Kholok', 'ktd': 'Kokata', 'kte': 'Nubri', 'ktf': 'Kwami', 'ktg': 'Kalkutung', 'kth': 'Karanga', 'kti': 'North Muyu', 'ktj': 'Plapo Krumen', 'ktk': 'Kaniet', 'ktl': 'Koroshi', 'ktm': 'Kurti', 'ktn': 'Karitiâna', 'kto': 'Kuot', 'ktp': 'Kaduo', 'ktq': 'Katabaga', 'kts': 'South Muyu', 'ktt': 'Ketum', 'ktu': 'Kituba', 'ktv': 'Eastern Katu', 'ktw': 'Kato', 'ktx': 'Kaxararí', 'kty': 'Kango', 'ktz': 'Juǀʼhoan', 'kua': 'Kuanyama', 'kub': 'Kutep', 'kuc': 'Kwinsu', 'kud': "'Auhelawa", 'kue': 'Kuman', 'kuf': 'Western Katu', 'kug': 'Kupa', 'kuh': 'Kushi', 'kui': 'Kuikúro-Kalapálo', 'kuj': 'Kuria', 'kuk': "Kepo'", 'kul': 'Kulere', 'kum': 'Kumyk', 'kun': 'Kunama', 'kuo': 'Kumukio', 'kup': 'Kunimaipa', 'kuq': 'Karipuna', 'kur': 'Kurdish', 'kus': 'Kusaal', 'kut': 'Kutenai', 'kuu': 'Upper Kuskokwim', 'kuv': 'Kur', 'kuw': 'Kpagua', 'kux': 'Kukatja', 'kuy': "Kuuku-Ya'u", 'kuz': 'Kunza', 'kva': 'Bagvalal', 'kvb': 'Kubu', 'kvc': 'Kove', 'kvd': 'Kui', 'kve': 'Kalabakan', 'kvf': 'Kabalai', 'kvg': 'Kuni-Boazi', 'kvh': 'Komodo', 'kvi': 'Kwang', 'kvj': 'Psikye', 'kvk': 'Korean Sign Language', 'kvl': 'Kayaw', 'kvm': 'Kendem', 'kvn': 'Border Kuna', 'kvo': 'Dobel', 'kvp': 'Kompane', 'kvq': 'Geba Karen', 'kvr': 'Kerinci', 'kvt': 'Lahta Karen', 'kvu': 'Yinbaw Karen', 'kvv': 'Kola', 'kvw': 'Wersing', 'kvx': 'Parkari Koli', 'kvy': 'Yintale Karen', 'kvz': 'Tsakwambo', 'kwa': 'Dâw', 'kwb': 'Kwa', 'kwc': 'Likwala', 'kwd': 'Kwaio', 'kwe': 'Kwerba', 'kwf': "Kwara'ae", 'kwg': 'Sara Kaba Deme', 'kwh': 'Kowiai', 'kwi': 'Awa-Cuaiquer', 'kwj': 'Kwanga', 'kwk': 'Kwakiutl', 'kwl': 'Kofyar', 'kwm': 'Kwambi', 'kwn': 'Kwangali', 'kwo': 'Kwomtari', 'kwp': 'Kodia', 'kwr': 'Kwer', 'kws': 'Kwese', 'kwt': 'Kwesten', 'kwu': 'Kwakum', 'kwv': 'Sara Kaba Náà', 'kww': 'Kwinti', 'kwx': 'Khirwar', 'kwy': 'San Salvador Kongo', 'kwz': 'Kwadi', 'kxa': 'Kairiru', 'kxb': 'Krobu', 'kxc': 'Konso', 'kxd': 'Brunei', 'kxf': 'Manumanaw Karen', 'kxh': 'Karo', 'kxi': 'Keningau Murut', 'kxj': 'Kulfa', 'kxk': 'Zayein Karen', 'kxl': 'Nepali Kurux', 'kxm': 'Northern Khmer', 'kxn': 'Kanowit-Tanjong Melanau', 'kxo': 'Kanoé', 'kxp': 'Wadiyara Koli', 'kxq': 'Smärky Kanum', 'kxr': 'Koro', 'kxs': 'Kangjia', 'kxt': 'Koiwat', 'kxu': 'Kui', 'kxv': 'Kuvi', 'kxw': 'Konai', 'kxx': 'Likuba', 'kxy': 'Kayong', 'kxz': 'Kerewo', 'kya': 'Kwaya', 'kyb': 'Butbut Kalinga', 'kyc': 'Kyaka', 'kyd': 'Karey', 'kye': 'Krache', 'kyf': 'Kouya', 'kyg': 'Keyagana', 'kyh': 'Karok', 'kyi': 'Kiput', 'kyj': 'Karao', 'kyk': 'Kamayo', 'kyl': 'Kalapuya', 'kym': 'Kpatili', 'kyn': 'Northern Binukidnon', 'kyo': 'Kelon', 'kyp': 'Kang', 'kyq': 'Kenga', 'kyr': 'Kuruáya', 'kys': 'Baram Kayan', 'kyt': 'Kayagar', 'kyu': 'Western Kayah', 'kyv': 'Kayort', 'kyw': 'Kudmali', 'kyx': 'Rapoisi', 'kyy': 'Kambaira', 'kyz': 'Kayabí', 'kza': 'Western Karaboro', 'kzb': 'Kaibobo', 'kzc': 'Bondoukou Kulango', 'kzd': 'Kadai', 'kze': 'Kosena', 'kzf': "Da'a Kaili", 'kzg': 'Kikai', 'kzi': 'Kelabit', 'kzk': 'Kazukuru', 'kzl': 'Kayeli', 'kzm': 'Kais', 'kzn': 'Kokola', 'kzo': 'Kaningi', 'kzp': 'Kaidipang', 'kzq': 'Kaike', 'kzr': 'Karang', 'kzs': 'Sugut Dusun', 'kzu': 'Kayupulau', 'kzv': 'Komyandaret', 'kzw': 'Karirí-Xocó', 'kzx': 'Kamarian', 'kzy': 'Kango', 'kzz': 'Kalabra', 'laa': 'Southern Subanen', 'lab': 'Linear A', 'lac': 'Lacandon', 'lad': 'Ladino', 'lae': 'Pattani', 'laf': 'Lafofa', 'lag': 'Langi', 'lah': 'Lahnda', 'lai': 'Lambya', 'laj': 'Lango', 'lak': 'Laka', 'lal': 'Lalia', 'lam': 'Lamba', 'lan': 'Laru', 'lao': 'Lao', 'lap': 'Laka', 'laq': 'Qabiao', 'lar': 'Larteh', 'las': 'Lama', 'lat': 'Latin', 'lau': 'Laba', 'lav': 'Latvian', 'law': 'Lauje', 'lax': 'Tiwa', 'lay': 'Lama Bai', 'laz': 'Aribwatsa', 'lbb': 'Label', 'lbc': 'Lakkia', 'lbe': 'Lak', 'lbf': 'Tinani', 'lbg': 'Laopang', 'lbi': "La'bi", 'lbj': 'Ladakhi', 'lbk': 'Central Bontok', 'lbl': 'Libon Bikol', 'lbm': 'Lodhi', 'lbn': 'Rmeet', 'lbo': 'Laven', 'lbq': 'Wampar', 'lbr': 'Lohorung', 'lbs': 'Libyan Sign Language', 'lbt': 'Lachi', 'lbu': 'Labu', 'lbv': 'Lavatbura-Lamusong', 'lbw': 'Tolaki', 'lbx': 'Lawangan', 'lby': 'Lamalama', 'lbz': 'Lardil', 'lcc': 'Legenyem', 'lcd': 'Lola', 'lce': 'Loncong', 'lcf': 'Lubu', 'lch': 'Luchazi', 'lcl': 'Lisela', 'lcm': 'Tungag', 'lcp': 'Western Lawa', 'lcq': 'Luhu', 'lcs': 'Lisabata-Nuniali', 'lda': 'Kla-Dan', 'ldb': 'Dũya', 'ldd': 'Luri', 'ldg': 'Lenyima', 'ldh': 'Lamja-Dengsa-Tola', 'ldi': 'Laari', 'ldj': 'Lemoro', 'ldk': 'Leelau', 'ldl': 'Kaan', 'ldm': 'Landoma', 'ldn': 'Láadan', 'ldo': 'Loo', 'ldp': 'Tso', 'ldq': 'Lufu', 'lea': 'Lega-Shabunda', 'leb': 'Lala-Bisa', 'lec': 'Leco', 'led': 'Lendu', 'lee': 'Lyélé', 'lef': 'Lelemi', 'leh': 'Lenje', 'lei': 'Lemio', 'lej': 'Lengola', 'lek': 'Leipon', 'lel': 'Lele', 'lem': 'Nomaande', 'len': 'Lenca', 'leo': 'Leti', 'lep': 'Lepcha', 'leq': 'Lembena', 'ler': 'Lenkau', 'les': 'Lese', 'let': 'Lesing-Gelimi', 'leu': 'Kara', 'lev': 'Lamma', 'lew': 'Ledo Kaili', 'lex': 'Luang', 'ley': 'Lemolang', 'lez': 'Lezghian', 'lfa': 'Lefa', 'lfn': 'Lingua Franca Nova', 'lga': 'Lungga', 'lgb': 'Laghu', 'lgg': 'Lugbara', 'lgh': 'Laghuu', 'lgi': 'Lengilu', 'lgk': 'Lingarak', 'lgl': 'Wala', 'lgm': 'Lega-Mwenga', 'lgn': "T'apo", 'lgq': 'Logba', 'lgr': 'Lengo', 'lgt': 'Pahi', 'lgu': 'Longgu', 'lgz': 'Ligenza', 'lha': 'Laha', 'lhh': 'Laha', 'lhi': 'Lahu Shi', 'lhl': 'Lahul Lohar', 'lhm': 'Lhomi', 'lhn': 'Lahanan', 'lhp': 'Lhokpu', 'lhs': 'Mlahsö', 'lht': 'Lo-Toga', 'lhu': 'Lahu', 'lia': 'West-Central Limba', 'lib': 'Likum', 'lic': 'Hlai', 'lid': 'Nyindrou', 'lie': 'Likila', 'lif': 'Limbu', 'lig': 'Ligbi', 'lih': 'Lihir', 'lij': 'Ligurian', 'lik': 'Lika', 'lil': 'Lillooet', 'lim': 'Limburgish', 'lin': 'Lingala', 'lio': 'Liki', 'lip': 'Sekpele', 'liq': 'Libido', 'lir': 'Liberian English', 'lis': 'Lisu', 'lit': 'Lithuanian', 'liu': 'Logorik', 'liv': 'Liv', 'liw': 'Col', 'lix': 'Liabuku', 'liy': 'Banda-Bambari', 'liz': 'Libinza', 'lja': 'Golpa', 'lje': 'Rampi', 'lji': 'Laiyolo', 'ljl': "Li'o", 'ljp': 'Lampung Api', 'ljw': 'Yirandali', 'ljx': 'Yuru', 'lka': 'Lakalei', 'lkb': 'Kabras', 'lkc': 'Kucong', 'lkd': 'Lakondê', 'lke': 'Kenyi', 'lkh': 'Lakha', 'lki': 'Laki', 'lkj': 'Remun', 'lkl': 'Laeko-Libuat', 'lkm': 'Kalaamaya', 'lkn': 'Lakon', 'lko': 'Khayo', 'lkr': 'Päri', 'lks': 'Kisa', 'lkt': 'Lakota', 'lku': 'Kungkari', 'lky': 'Lokoya', 'lla': 'Lala-Roba', 'llb': 'Lolo', 'llc': 'Lele', 'lld': 'Ladin', 'lle': 'Lele', 'llf': 'Hermit', 'llg': 'Lole', 'llh': 'Lamu', 'lli': 'Teke-Laali', 'llj': 'Ladji Ladji', 'llk': 'Lelak', 'lll': 'Lilau', 'llm': 'Lasalimu', 'lln': 'Lele', 'llp': 'North Efate', 'llq': 'Lolak', 'lls': 'Lithuanian Sign Language', 'llu': 'Lau', 'llx': 'Lauan', 'lma': 'East Limba', 'lmb': 'Merei', 'lmc': 'Limilngan', 'lmd': 'Lumun', 'lme': 'Pévé', 'lmf': 'South Lembata', 'lmg': 'Lamogai', 'lmh': 'Lambichhong', 'lmi': 'Lombi', 'lmj': 'West Lembata', 'lmk': 'Lamkang', 'lml': 'Hano', 'lmn': 'Lambadi', 'lmo': 'Lombard', 'lmp': 'Limbum', 'lmq': 'Lamatuka', 'lmr': 'Lamalera', 'lmu': 'Lamenu', 'lmv': 'Lomaiviti', 'lmw': 'Lake Miwok', 'lmx': 'Laimbue', 'lmy': 'Lamboya', 'lmz': 'Lumbee', 'lna': 'Langbashe', 'lnb': 'Mbalanhu', 'lnd': 'Lundayeh', 'lng': 'Langobardic', 'lnh': 'Lanoh', 'lni': "Daantanai'", 'lnj': 'Leningitij', 'lnl': 'South Central Banda', 'lnm': 'Langam', 'lnn': 'Lorediakarkar', 'lno': 'Lango', 'lns': "Lamnso'", 'lnu': 'Longuda', 'lnw': 'Lanima', 'lnz': 'Lonzo', 'loa': 'Loloda', 'lob': 'Lobi', 'loc': 'Inonhan', 'loe': 'Saluan', 'lof': 'Logol', 'log': 'Logo', 'loh': 'Narim', 'loi': 'Loma', 'loj': 'Lou', 'lok': 'Loko', 'lol': 'Mongo', 'lom': 'Loma', 'lon': 'Malawi Lomwe', 'loo': 'Lombo', 'lop': 'Lopa', 'loq': 'Lobala', 'lor': 'Téén', 'los': 'Loniu', 'lot': 'Otuho', 'lou': 'Louisiana Creole', 'lov': 'Lopi', 'low': 'Tampias Lobu', 'lox': 'Loun', 'loy': 'Loke', 'loz': 'Lozi', 'lpa': 'Lelepa', 'lpe': 'Lepki', 'lpn': 'Long Phuri Naga', 'lpo': 'Lipo', 'lpx': 'Lopit', 'lra': "Rara Bakati'", 'lrc': 'Northern Luri', 'lre': 'Laurentian', 'lrg': 'Laragia', 'lri': 'Marachi', 'lrk': 'Loarki', 'lrl': 'Lari', 'lrm': 'Marama', 'lrn': 'Lorang', 'lro': 'Laro', 'lrr': 'Southern Yamphu', 'lrt': 'Larantuka Malay', 'lrv': 'Larevat', 'lrz': 'Lemerig', 'lsa': 'Lasgerdi', 'lsd': 'Lishana Deni', 'lse': 'Lusengo', 'lsh': 'Lish', 'lsi': 'Lashi', 'lsl': 'Latvian Sign Language', 'lsm': 'Saamia', 'lsn': 'Tibetan Sign Language', 'lso': 'Laos Sign Language', 'lsp': 'Panamanian Sign Language', 'lsr': 'Aruop', 'lss': 'Lasi', 'lst': 'Trinidad and Tobago Sign Language', 'lsv': 'Sivia Sign Language', 'lsy': 'Mauritian Sign Language', 'ltc': 'Late Middle Chinese', 'ltg': 'Latgalian', 'lth': 'Thur', 'lti': 'Leti', 'ltn': 'Latundê', 'lto': 'Tsotso', 'lts': 'Tachoni', 'ltu': 'Latu', 'ltz': 'Luxembourgish', 'lua': 'Luba-Lulua', 'lub': 'Luba-Katanga', 'luc': 'Aringa', 'lud': 'Ludian', 'lue': 'Luvale', 'luf': 'Laua', 'lug': 'Ganda', 'lui': 'Luiseno', 'luj': 'Luna', 'luk': 'Lunanakha', 'lul': "Olu'bo", 'lum': 'Luimbi', 'lun': 'Lunda', 'luo': 'Luo', 'lup': 'Lumbu', 'luq': 'Lucumi', 'lur': 'Laura', 'lus': 'Mizo', 'lut': 'Lushootseed', 'luu': 'Lumba-Yakkha', 'luv': 'Luwati', 'luw': 'Luo', 'luy': 'Luyia', 'luz': 'Southern Luri', 'lva': "Maku'a", 'lvi': 'Lavi', 'lvk': 'Lavukaleve', 'lvs': 'Standard Latvian', 'lvu': 'Levuka', 'lwa': 'Lwalu', 'lwe': 'Lewo Eleng', 'lwg': 'Wanga', 'lwh': 'White Lachi', 'lwl': 'Eastern Lawa', 'lwm': 'Laomian', 'lwo': 'Luwo', 'lws': 'Malawian Sign Language', 'lwt': 'Lewotobi', 'lwu': 'Lawu', 'lww': 'Lewo', 'lya': 'Layakha', 'lyg': 'Lyngngam', 'lyn': 'Luyana', 'lzh': 'Literary Chinese', 'lzl': 'Litzlitz', 'lzn': 'Leinong Naga', 'lzz': 'Laz', 'maa': 'San Jerónimo Tecóatl Mazatec', 'mab': 'Yutanduchi Mixtec', 'mad': 'Madurese', 'mae': 'Bo-Rukul', 'maf': 'Mafa', 'mag': 'Magahi', 'mah': 'Marshallese', 'mai': 'Maithili', 'maj': 'Jalapa De Díaz Mazatec', 'mak': 'Makasar', 'mal': 'Malayalam', 'mam': 'Mam', 'man': 'Mandingo', 'maq': 'Chiquihuitlán Mazatec', 'mar': 'Marathi', 'mas': 'Masai', 'mat': 'San Francisco Matlatzinca', 'mau': 'Huautla Mazatec', 'mav': 'Sateré-Mawé', 'maw': 'Mampruli', 'max': 'North Moluccan Malay', 'maz': 'Central Mazahua', 'mba': 'Higaonon', 'mbb': 'Western Bukidnon Manobo', 'mbc': 'Macushi', 'mbd': 'Dibabawon Manobo', 'mbe': 'Molale', 'mbf': 'Baba Malay', 'mbh': 'Mangseng', 'mbi': 'Ilianen Manobo', 'mbj': 'Nadëb', 'mbk': 'Malol', 'mbl': 'Maxakalí', 'mbm': 'Ombamba', 'mbn': 'Macaguán', 'mbo': 'Mbo', 'mbp': 'Malayo', 'mbq': 'Maisin', 'mbr': 'Nukak Makú', 'mbs': 'Sarangani Manobo', 'mbt': 'Matigsalug Manobo', 'mbu': 'Mbula-Bwazza', 'mbv': 'Mbulungish', 'mbw': 'Maring', 'mbx': 'Mari', 'mby': 'Memoni', 'mbz': 'Amoltepec Mixtec', 'mca': 'Maca', 'mcb': 'Machiguenga', 'mcc': 'Bitur', 'mcd': 'Sharanahua', 'mce': 'Itundujia Mixtec', 'mcf': 'Matsés', 'mcg': 'Mapoyo', 'mch': 'Maquiritari', 'mci': 'Mese', 'mcj': 'Mvanip', 'mck': 'Mbunda', 'mcl': 'Macaguaje', 'mcm': 'Malaccan Creole Portuguese', 'mcn': 'Masana', 'mco': 'Coatlán Mixe', 'mcp': 'Makaa', 'mcq': 'Ese', 'mcr': 'Menya', 'mcs': 'Mambai', 'mct': 'Mengisa', 'mcu': 'Cameroon Mambila', 'mcv': 'Minanibai', 'mcw': 'Mawa', 'mcx': 'Mpiemo', 'mcy': 'South Watut', 'mcz': 'Mawan', 'mda': 'Mada', 'mdb': 'Morigi', 'mdc': 'Male', 'mdd': 'Mbum', 'mde': 'Maba', 'mdf': 'Moksha', 'mdg': 'Massalat', 'mdh': 'Maguindanaon', 'mdi': 'Mamvu', 'mdj': 'Mangbetu', 'mdk': 'Mangbutu', 'mdl': 'Maltese Sign Language', 'mdm': 'Mayogo', 'mdn': 'Mbati', 'mdp': 'Mbala', 'mdq': 'Mbole', 'mdr': 'Mandar', 'mds': 'Maria', 'mdt': 'Mbere', 'mdu': 'Mboko', 'mdv': 'Santa Lucía Monteverde Mixtec', 'mdw': 'Mbosi', 'mdx': 'Dizin', 'mdy': 'Male', 'mdz': 'Suruí Do Pará', 'mea': 'Menka', 'meb': 'Ikobi', 'mec': 'Marra', 'med': 'Melpa', 'mee': 'Mengen', 'mef': 'Megam', 'meh': 'Southwestern Tlaxiaco Mixtec', 'mei': 'Midob', 'mej': 'Meyah', 'mek': 'Mekeo', 'mel': 'Central Melanau', 'mem': 'Mangala', 'men': 'Mende', 'meo': 'Kedah Malay', 'mep': 'Miriwoong', 'meq': 'Merey', 'mer': 'Meru', 'mes': 'Masmaje', 'met': 'Mato', 'meu': 'Motu', 'mev': 'Mano', 'mew': 'Maaka', 'mey': 'Hassaniyya', 'mez': 'Menominee', 'mfa': 'Pattani Malay', 'mfb': 'Bangka', 'mfc': 'Mba', 'mfd': 'Mendankwe-Nkwen', 'mfe': 'Morisyen', 'mff': 'Naki', 'mfg': 'Mogofin', 'mfh': 'Matal', 'mfi': 'Wandala', 'mfj': 'Mefele', 'mfk': 'North Mofu', 'mfl': 'Putai', 'mfm': 'Marghi South', 'mfn': 'Cross River Mbembe', 'mfo': 'Mbe', 'mfp': 'Makassar Malay', 'mfq': 'Moba', 'mfr': 'Marrithiyel', 'mfs': 'Mexican Sign Language', 'mft': 'Mokerang', 'mfu': 'Mbwela', 'mfv': 'Mandjak', 'mfw': 'Mulaha', 'mfx': 'Melo', 'mfy': 'Mayo', 'mfz': 'Mabaan', 'mga': 'Middle Irish', 'mgb': 'Mararit', 'mgc': 'Morokodo', 'mgd': 'Moru', 'mge': 'Mango', 'mgf': 'Maklew', 'mgg': 'Mpumpong', 'mgh': 'Makhuwa-Meetto', 'mgi': 'Lijili', 'mgj': 'Abureni', 'mgk': 'Mawes', 'mgl': 'Maleu-Kilenge', 'mgm': 'Mambae', 'mgn': 'Mbangi', 'mgo': "Meta'", 'mgp': 'Eastern Magar', 'mgq': 'Malila', 'mgr': 'Mambwe-Lungu', 'mgs': 'Manda', 'mgt': 'Mongol', 'mgu': 'Mailu', 'mgv': 'Matengo', 'mgw': 'Matumbi', 'mgy': 'Mbunga', 'mgz': 'Mbugwe', 'mha': 'Manda', 'mhb': 'Mahongwe', 'mhc': 'Mocho', 'mhd': 'Mbugu', 'mhe': 'Besisi', 'mhf': 'Mamaa', 'mhg': 'Margu', 'mhi': "Ma'di", 'mhj': 'Mogholi', 'mhk': 'Mungaka', 'mhl': 'Mauwake', 'mhm': 'Makhuwa-Moniga', 'mhn': 'Mócheno', 'mho': 'Mashi', 'mhp': 'Balinese Malay', 'mhq': 'Mandan', 'mhr': 'Eastern Mari', 'mhs': 'Buru', 'mht': 'Mandahuaca', 'mhu': 'Digaro-Mishmi', 'mhw': 'Mbukushu', 'mhx': 'Maru', 'mhy': "Ma'anyan", 'mhz': 'Mor', 'mia': 'Miami', 'mib': 'Atatláhuca Mixtec', 'mic': 'Micmac', 'mid': 'Mandaic', 'mie': 'Ocotepec Mixtec', 'mif': 'Mofu-Gudur', 'mig': 'San Miguel El Grande Mixtec', 'mih': 'Chayuco Mixtec', 'mii': 'Chigmecatitlán Mixtec', 'mij': 'Abar', 'mik': 'Mikasuki', 'mil': 'Peñoles Mixtec', 'mim': 'Alacatlatzala Mixtec', 'min': 'Minangkabau', 'mio': 'Pinotepa Nacional Mixtec', 'mip': 'Apasco-Apoala Mixtec', 'miq': 'Mískito', 'mir': 'Isthmus Mixe', 'mis': 'Uncoded languages', 'mit': 'Southern Puebla Mixtec', 'miu': 'Cacaloxtepec Mixtec', 'miw': 'Akoye', 'mix': 'Mixtepec Mixtec', 'miy': 'Ayutla Mixtec', 'miz': 'Coatzospan Mixtec', 'mjb': 'Makalero', 'mjc': 'San Juan Colorado Mixtec', 'mjd': 'Northwest Maidu', 'mje': 'Muskum', 'mjg': 'Tu', 'mjh': 'Mwera', 'mji': 'Kim Mun', 'mjj': 'Mawak', 'mjk': 'Matukar', 'mjl': 'Mandeali', 'mjm': 'Medebur', 'mjn': 'Ma', 'mjo': 'Malankuravan', 'mjp': 'Malapandaram', 'mjq': 'Malaryan', 'mjr': 'Malavedan', 'mjs': 'Miship', 'mjt': 'Sauria Paharia', 'mju': 'Manna-Dora', 'mjv': 'Mannan', 'mjw': 'Karbi', 'mjx': 'Mahali', 'mjy': 'Mahican', 'mjz': 'Majhi', 'mka': 'Mbre', 'mkb': 'Mal Paharia', 'mkc': 'Siliput', 'mkd': 'Macedonian', 'mke': 'Mawchi', 'mkf': 'Miya', 'mkg': 'Mak', 'mki': 'Dhatki', 'mkj': 'Mokilese', 'mkk': 'Byep', 'mkl': 'Mokole', 'mkm': 'Moklen', 'mkn': 'Kupang Malay', 'mko': 'Mingang Doso', 'mkp': 'Moikodi', 'mkq': 'Bay Miwok', 'mkr': 'Malas', 'mks': 'Silacayoapan Mixtec', 'mkt': 'Vamale', 'mku': 'Konyanka Maninka', 'mkv': 'Mafea', 'mkw': 'Kituba', 'mkx': 'Kinamiging Manobo', 'mky': 'East Makian', 'mkz': 'Makasae', 'mla': 'Malo', 'mlb': 'Mbule', 'mlc': 'Cao Lan', 'mle': 'Manambu', 'mlf': 'Mal', 'mlg': 'Malagasy', 'mlh': 'Mape', 'mli': 'Malimpung', 'mlj': 'Miltu', 'mlk': 'Ilwana', 'mll': 'Malua Bay', 'mlm': 'Mulam', 'mln': 'Malango', 'mlo': 'Mlomp', 'mlp': 'Bargam', 'mlq': 'Western Maninkakan', 'mlr': 'Vame', 'mls': 'Masalit', 'mlt': 'Maltese', 'mlu': "To'abaita", 'mlv': 'Motlav', 'mlw': 'Moloko', 'mlx': 'Malfaxal', 'mlz': 'Malaynon', 'mma': 'Mama', 'mmb': 'Momina', 'mmc': 'Michoacán Mazahua', 'mmd': 'Maonan', 'mme': 'Mae', 'mmf': 'Mundat', 'mmg': 'North Ambrym', 'mmh': 'Mehináku', 'mmi': 'Musar', 'mmj': 'Majhwar', 'mmk': 'Mukha-Dora', 'mml': 'Man Met', 'mmm': 'Maii', 'mmn': 'Mamanwa', 'mmo': 'Mangga Buang', 'mmp': 'Siawi', 'mmq': 'Musak', 'mmr': 'Western Xiangxi Miao', 'mmt': 'Malalamai', 'mmu': 'Mmaala', 'mmv': 'Miriti', 'mmw': 'Emae', 'mmx': 'Madak', 'mmy': 'Migaama', 'mmz': 'Mabaale', 'mna': 'Mbula', 'mnb': 'Muna', 'mnc': 'Manchu', 'mnd': 'Mondé', 'mne': 'Naba', 'mnf': 'Mundani', 'mng': 'Eastern Mnong', 'mnh': 'Mono', 'mni': 'Manipuri', 'mnj': 'Munji', 'mnk': 'Mandinka', 'mnl': 'Tiale', 'mnm': 'Mapena', 'mnn': 'Southern Mnong', 'mnp': 'Min Bei Chinese', 'mnq': 'Minriq', 'mnr': 'Mono', 'mns': 'Mansi', 'mnu': 'Mer', 'mnv': 'Rennell-Bellona', 'mnw': 'Mon', 'mnx': 'Manikion', 'mny': 'Manyawa', 'mnz': 'Moni', 'moa': 'Mwan', 'moc': 'Mocoví', 'mod': 'Mobilian', 'moe': 'Montagnais', 'mog': 'Mongondow', 'moh': 'Mohawk', 'moi': 'Mboi', 'moj': 'Monzombo', 'mok': 'Morori', 'mom': 'Mangue', 'mon': 'Mongolian', 'moo': 'Monom', 'mop': 'Mopán Maya', 'moq': 'Mor', 'mor': 'Moro', 'mos': 'Mossi', 'mot': 'Barí', 'mou': 'Mogum', 'mov': 'Mohave', 'mow': 'Moi', 'mox': 'Molima', 'moy': 'Shekkacho', 'moz': 'Mukulu', 'mpa': 'Mpoto', 'mpb': 'Malak Malak', 'mpc': 'Mangarrayi', 'mpd': 'Machinere', 'mpe': 'Majang', 'mpg': 'Marba', 'mph': 'Maung', 'mpi': 'Mpade', 'mpj': 'Martu Wangka', 'mpk': 'Mbara', 'mpl': 'Middle Watut', 'mpm': 'Yosondúa Mixtec', 'mpn': 'Mindiri', 'mpo': 'Miu', 'mpp': 'Migabac', 'mpq': 'Matís', 'mpr': 'Vangunu', 'mps': 'Dadibi', 'mpt': 'Mian', 'mpu': 'Makuráp', 'mpv': 'Mungkip', 'mpw': 'Mapidian', 'mpx': 'Misima-Panaeati', 'mpy': 'Mapia', 'mpz': 'Mpi', 'mqa': 'Maba', 'mqb': 'Mbuko', 'mqc': 'Mangole', 'mqe': 'Matepi', 'mqf': 'Momuna', 'mqg': 'Kota Bangun Kutai Malay', 'mqh': 'Tlazoyaltepec Mixtec', 'mqi': 'Mariri', 'mqj': 'Mamasa', 'mqk': 'Rajah Kabunsuwan Manobo', 'mql': 'Mbelime', 'mqm': 'South Marquesan', 'mqn': 'Moronene', 'mqo': 'Modole', 'mqp': 'Manipa', 'mqq': 'Minokok', 'mqr': 'Mander', 'mqs': 'West Makian', 'mqt': 'Mok', 'mqu': 'Mandari', 'mqv': 'Mosimo', 'mqw': 'Murupi', 'mqx': 'Mamuju', 'mqy': 'Manggarai', 'mqz': 'Pano', 'mra': 'Mlabri', 'mrb': 'Marino', 'mrc': 'Maricopa', 'mrd': 'Western Magar', 'mre': "Martha's Vineyard Sign Language", 'mrf': 'Elseng', 'mrg': 'Mising', 'mrh': 'Mara Chin', 'mri': 'Maori', 'mrj': 'Western Mari', 'mrk': 'Hmwaveke', 'mrl': 'Mortlockese', 'mrm': 'Merlav', 'mrn': 'Cheke Holo', 'mro': 'Mru', 'mrp': 'Morouas', 'mrq': 'North Marquesan', 'mrr': 'Maria', 'mrs': 'Maragus', 'mrt': 'Marghi Central', 'mru': 'Mono', 'mrv': 'Mangareva', 'mrw': 'Maranao', 'mrx': 'Maremgi', 'mry': 'Mandaya', 'mrz': 'Marind', 'msa': 'Malay', 'msb': 'Masbatenyo', 'msc': 'Sankaran Maninka', 'msd': 'Yucatec Maya Sign Language', 'mse': 'Musey', 'msf': 'Mekwei', 'msg': 'Moraid', 'msh': 'Masikoro Malagasy', 'msi': 'Sabah Malay', 'msj': 'Ma', 'msk': 'Mansaka', 'msl': 'Molof', 'msm': 'Agusan Manobo', 'msn': 'Vurës', 'mso': 'Mombum', 'msp': 'Maritsauá', 'msq': 'Caac', 'msr': 'Mongolian Sign Language', 'mss': 'West Masela', 'msu': 'Musom', 'msv': 'Maslam', 'msw': 'Mansoanka', 'msx': 'Moresada', 'msy': 'Aruamu', 'msz': 'Momare', 'mta': 'Cotabato Manobo', 'mtb': 'Anyin Morofo', 'mtc': 'Munit', 'mtd': 'Mualang', 'mte': 'Mono', 'mtf': 'Murik', 'mtg': 'Una', 'mth': 'Munggui', 'mti': 'Maiwa', 'mtj': 'Moskona', 'mtk': "Mbe'", 'mtl': 'Montol', 'mtm': 'Mator', 'mtn': 'Matagalpa', 'mto': 'Totontepec Mixe', 'mtp': 'Wichí Lhamtés Nocten', 'mtq': 'Muong', 'mtr': 'Mewari', 'mts': 'Yora', 'mtt': 'Mota', 'mtu': 'Tututepec Mixtec', 'mtv': "Asaro'o", 'mtw': 'Southern Binukidnon', 'mtx': 'Tidaá Mixtec', 'mty': 'Nabi', 'mua': 'Mundang', 'mub': 'Mubi', 'muc': 'Ajumbu', 'mud': 'Mednyj Aleut', 'mue': 'Media Lengua', 'mug': 'Musgu', 'muh': 'Mündü', 'mui': 'Musi', 'muj': 'Mabire', 'muk': 'Mugom', 'mul': 'Multiple Languages', 'mum': 'Maiwala', 'muo': 'Nyong', 'mup': 'Malvi', 'muq': 'Eastern Xiangxi Miao', 'mur': 'Murle', 'mus': 'Creek', 'mut': 'Western Muria', 'muu': 'Yaaku', 'muv': 'Muthuvan', 'mux': 'Bo-Ung', 'muy': 'Muyang', 'muz': 'Mursi', 'mva': 'Manam', 'mvb': 'Mattole', 'mvd': 'Mamboru', 'mve': 'Marwari', 'mvf': 'Peripheral Mongolian', 'mvg': 'Yucuañe Mixtec', 'mvh': 'Mulgi', 'mvi': 'Miyako', 'mvk': 'Mekmek', 'mvl': 'Mbara', 'mvm': 'Muya', 'mvn': 'Minaveha', 'mvo': 'Marovo', 'mvp': 'Duri', 'mvq': 'Moere', 'mvr': 'Marau', 'mvs': 'Massep', 'mvt': 'Mpotovoro', 'mvu': 'Marfa', 'mvv': 'Tagal Murut', 'mvw': 'Machinga', 'mvx': 'Meoswar', 'mvy': 'Indus Kohistani', 'mvz': 'Mesqan', 'mwa': 'Mwatebu', 'mwb': 'Juwal', 'mwc': 'Are', 'mwe': 'Mwera', 'mwf': 'Murrinh-Patha', 'mwg': 'Aiklep', 'mwh': 'Mouk-Aria', 'mwi': 'Labo', 'mwk': 'Kita Maninkakan', 'mwl': 'Mirandese', 'mwm': 'Sar', 'mwn': 'Nyamwanga', 'mwo': 'Central Maewo', 'mwp': 'Kala Lagaw Ya', 'mwq': 'Mün Chin', 'mwr': 'Marwari', 'mws': 'Mwimbi-Muthambi', 'mwt': 'Moken', 'mwu': 'Mittu', 'mwv': 'Mentawai', 'mww': 'Hmong Daw', 'mwz': 'Moingi', 'mxa': 'Northwest Oaxaca Mixtec', 'mxb': 'Tezoatlán Mixtec', 'mxc': 'Manyika', 'mxd': 'Modang', 'mxe': 'Mele-Fila', 'mxf': 'Malgbe', 'mxg': 'Mbangala', 'mxh': 'Mvuba', 'mxi': 'Mozarabic', 'mxj': 'Miju-Mishmi', 'mxk': 'Monumbo', 'mxl': 'Maxi Gbe', 'mxm': 'Meramera', 'mxn': 'Moi', 'mxo': 'Mbowe', 'mxp': 'Tlahuitoltepec Mixe', 'mxq': 'Juquila Mixe', 'mxr': 'Murik', 'mxs': 'Huitepec Mixtec', 'mxt': 'Jamiltepec Mixtec', 'mxu': 'Mada', 'mxv': 'Metlatónoc Mixtec', 'mxw': 'Namo', 'mxx': 'Mahou', 'mxy': 'Southeastern Nochixtlán Mixtec', 'mxz': 'Central Masela', 'mya': 'Burmese', 'myb': 'Mbay', 'myc': 'Mayeka', 'mye': 'Myene', 'myf': 'Bambassi', 'myg': 'Manta', 'myh': 'Makah', 'myj': 'Mangayat', 'myk': 'Mamara Senoufo', 'myl': 'Moma', 'mym': "Me'en", 'myo': 'Anfillo', 'myp': 'Pirahã', 'myr': 'Muniche', 'mys': 'Mesmes', 'myu': 'Mundurukú', 'myv': 'Erzya', 'myw': 'Muyuw', 'myx': 'Masaaba', 'myy': 'Macuna', 'myz': 'Classical Mandaic', 'mza': 'Santa María Zacatepec Mixtec', 'mzb': 'Tumzabt', 'mzc': 'Madagascar Sign Language', 'mzd': 'Malimba', 'mze': 'Morawa', 'mzg': 'Monastic Sign Language', 'mzh': 'Wichí Lhamtés Güisnay', 'mzi': 'Ixcatlán Mazatec', 'mzj': 'Manya', 'mzk': 'Nigeria Mambila', 'mzl': 'Mazatlán Mixe', 'mzm': 'Mumuye', 'mzn': 'Mazanderani', 'mzo': 'Matipuhy', 'mzp': 'Movima', 'mzq': 'Mori Atas', 'mzr': 'Marúbo', 'mzs': 'Macanese', 'mzt': 'Mintil', 'mzu': 'Inapang', 'mzv': 'Manza', 'mzw': 'Deg', 'mzx': 'Mawayana', 'mzy': 'Mozambican Sign Language', 'mzz': 'Maiadomu', 'naa': 'Namla', 'nab': 'Southern Nambikuára', 'nac': 'Narak', 'nae': "Naka'ela", 'naf': 'Nabak', 'nag': 'Naga Pidgin', 'naj': 'Nalu', 'nak': 'Nakanai', 'nal': 'Nalik', 'nam': "Ngan'gityemerri", 'nan': 'Min Nan Chinese', 'nao': 'Naaba', 'nap': 'Neapolitan', 'naq': 'Nama', 'nar': 'Iguta', 'nas': 'Naasioi', 'nat': 'Ca̱hungwa̱rya̱', 'nau': 'Nauru', 'nav': 'Navajo', 'naw': 'Nawuri', 'nax': 'Nakwi', 'nay': 'Ngarrindjeri', 'naz': 'Coatepec Nahuatl', 'nba': 'Nyemba', 'nbb': 'Ndoe', 'nbc': 'Chang Naga', 'nbd': 'Ngbinda', 'nbe': 'Konyak Naga', 'nbg': 'Nagarchal', 'nbh': 'Ngamo', 'nbi': 'Mao Naga', 'nbj': 'Ngarinyman', 'nbk': 'Nake', 'nbl': 'South Ndebele', 'nbm': "Ngbaka Ma'bo", 'nbn': 'Kuri', 'nbo': 'Nkukoli', 'nbp': 'Nnam', 'nbq': 'Nggem', 'nbr': 'Numana', 'nbs': 'Namibian Sign Language', 'nbt': 'Na', 'nbu': 'Rongmei Naga', 'nbv': 'Ngamambo', 'nbw': 'Southern Ngbandi', 'nby': 'Ningera', 'nca': 'Iyo', 'ncb': 'Central Nicobarese', 'ncc': 'Ponam', 'ncd': 'Nachering', 'nce': 'Yale', 'ncf': 'Notsi', 'ncg': "Nisga'a", 'nch': 'Central Huasteca Nahuatl', 'nci': 'Classical Nahuatl', 'ncj': 'Northern Puebla Nahuatl', 'nck': 'Na-kara', 'ncl': 'Michoacán Nahuatl', 'ncm': 'Nambo', 'ncn': 'Nauna', 'nco': 'Sibe', 'ncq': 'Northern Katang', 'ncr': 'Ncane', 'ncs': 'Nicaraguan Sign Language', 'nct': 'Chothe Naga', 'ncu': 'Chumburung', 'ncx': 'Central Puebla Nahuatl', 'ncz': 'Natchez', 'nda': 'Ndasa', 'ndb': 'Kenswei Nsei', 'ndc': 'Ndau', 'ndd': 'Nde-Nsele-Nta', 'nde': 'North Ndebele', 'ndf': 'Nadruvian', 'ndg': 'Ndengereko', 'ndh': 'Ndali', 'ndi': 'Samba Leko', 'ndj': 'Ndamba', 'ndk': 'Ndaka', 'ndl': 'Ndolo', 'ndm': 'Ndam', 'ndn': 'Ngundi', 'ndo': 'Ndonga', 'ndp': 'Ndo', 'ndq': 'Ndombe', 'ndr': 'Ndoola', 'nds': 'Low German', 'ndt': 'Ndunga', 'ndu': 'Dugun', 'ndv': 'Ndut', 'ndw': 'Ndobo', 'ndx': 'Nduga', 'ndy': 'Lutos', 'ndz': 'Ndogo', 'nea': "Eastern Ngad'a", 'neb': 'Toura', 'nec': 'Nedebang', 'ned': 'Nde-Gbite', 'nee': 'Nêlêmwa-Nixumwak', 'nef': 'Nefamese', 'neg': 'Negidal', 'neh': 'Nyenkha', 'nei': 'Neo-Hittite', 'nej': 'Neko', 'nek': 'Neku', 'nem': 'Nemi', 'nen': 'Nengone', 'neo': 'Ná-Meo', 'nep': 'Nepali', 'neq': 'North Central Mixe', 'ner': 'Yahadian', 'nes': 'Bhoti Kinnauri', 'net': 'Nete', 'neu': 'Neo', 'nev': 'Nyaheun', 'new': 'Newari', 'nex': 'Neme', 'ney': 'Neyo', 'nez': 'Nez Perce', 'nfa': 'Dhao', 'nfd': 'Ahwai', 'nfl': 'Ayiwo', 'nfr': 'Nafaanra', 'nfu': 'Mfumte', 'nga': 'Ngbaka', 'ngb': 'Northern Ngbandi', 'ngc': 'Ngombe', 'ngd': 'Ngando', 'nge': 'Ngemba', 'ngg': 'Ngbaka Manza', 'ngh': 'Nǁng', 'ngi': 'Ngizim', 'ngj': 'Ngie', 'ngk': 'Dalabon', 'ngl': 'Lomwe', 'ngm': "Ngatik Men's Creole", 'ngn': 'Ngwo', 'ngo': 'Ngoni', 'ngp': 'Ngulu', 'ngq': 'Ngurimi', 'ngr': 'Engdewu', 'ngs': 'Gvoko', 'ngt': 'Kriang', 'ngu': 'Guerrero Nahuatl', 'ngv': 'Nagumi', 'ngw': 'Ngwaba', 'ngx': 'Nggwahyi', 'ngy': 'Tibea', 'ngz': 'Ngungwel', 'nha': 'Nhanda', 'nhb': 'Beng', 'nhc': 'Tabasco Nahuatl', 'nhd': 'Chiripá', 'nhe': 'Eastern Huasteca Nahuatl', 'nhf': 'Nhuwala', 'nhg': 'Tetelcingo Nahuatl', 'nhh': 'Nahari', 'nhi': 'Zacatlán-Ahuacatlán-Tepetzintla Nahuatl', 'nhk': 'Isthmus-Cosoleacaque Nahuatl', 'nhm': 'Morelos Nahuatl', 'nhn': 'Central Nahuatl', 'nho': 'Takuu', 'nhp': 'Isthmus-Pajapan Nahuatl', 'nhq': 'Huaxcaleca Nahuatl', 'nhr': 'Naro', 'nht': 'Ometepec Nahuatl', 'nhu': 'Noone', 'nhv': 'Temascaltepec Nahuatl', 'nhw': 'Western Huasteca Nahuatl', 'nhx': 'Isthmus-Mecayapan Nahuatl', 'nhy': 'Northern Oaxaca Nahuatl', 'nhz': 'Santa María La Alta Nahuatl', 'nia': 'Nias', 'nib': 'Nakame', 'nid': 'Ngandi', 'nie': 'Niellim', 'nif': 'Nek', 'nig': 'Ngalakgan', 'nih': 'Nyiha', 'nii': 'Nii', 'nij': 'Ngaju', 'nik': 'Southern Nicobarese', 'nil': 'Nila', 'nim': 'Nilamba', 'nin': 'Ninzo', 'nio': 'Nganasan', 'niq': 'Nandi', 'nir': 'Nimboran', 'nis': 'Nimi', 'nit': 'Southeastern Kolami', 'niu': 'Niuean', 'niv': 'Gilyak', 'niw': 'Nimo', 'nix': 'Hema', 'niy': 'Ngiti', 'niz': 'Ningil', 'nja': 'Nzanyi', 'njb': 'Nocte Naga', 'njd': 'Ndonde Hamba', 'njh': 'Lotha Naga', 'nji': 'Gudanji', 'njj': 'Njen', 'njl': 'Njalgulgule', 'njm': 'Angami Naga', 'njn': 'Liangmai Naga', 'njo': 'Ao Naga', 'njr': 'Njerep', 'njs': 'Nisa', 'njt': 'Ndyuka-Trio Pidgin', 'nju': 'Ngadjunmaya', 'njx': 'Kunyi', 'njy': 'Njyem', 'njz': 'Nyishi', 'nka': 'Nkoya', 'nkb': 'Khoibu Naga', 'nkc': 'Nkongho', 'nkd': 'Koireng', 'nke': 'Duke', 'nkf': 'Inpui Naga', 'nkg': 'Nekgini', 'nkh': 'Khezha Naga', 'nki': 'Thangal Naga', 'nkj': 'Nakai', 'nkk': 'Nokuku', 'nkm': 'Namat', 'nkn': 'Nkangala', 'nko': 'Nkonya', 'nkp': 'Niuatoputapu', 'nkq': 'Nkami', 'nkr': 'Nukuoro', 'nks': 'North Asmat', 'nkt': 'Nyika', 'nku': 'Bouna Kulango', 'nkv': 'Nyika', 'nkw': 'Nkutu', 'nkx': 'Nkoroo', 'nkz': 'Nkari', 'nla': 'Ngombale', 'nlc': 'Nalca', 'nld': 'Dutch', 'nle': 'East Nyala', 'nlg': 'Gela', 'nli': 'Grangali', 'nlj': 'Nyali', 'nlk': 'Ninia Yali', 'nll': 'Nihali', 'nlm': 'Mankiyali', 'nlo': 'Ngul', 'nlq': 'Lao Naga', 'nlu': 'Nchumbulu', 'nlv': 'Orizaba Nahuatl', 'nlw': 'Walangama', 'nlx': 'Nahali', 'nly': 'Nyamal', 'nlz': 'Nalögo', 'nma': 'Maram Naga', 'nmb': 'Big Nambas', 'nmc': 'Ngam', 'nmd': 'Ndumu', 'nme': 'Mzieme Naga', 'nmf': 'Tangkhul Naga', 'nmg': 'Kwasio', 'nmh': 'Monsang Naga', 'nmi': 'Nyam', 'nmj': 'Ngombe', 'nmk': 'Namakura', 'nml': 'Ndemli', 'nmm': 'Manangba', 'nmn': 'ǃXóõ', 'nmo': 'Moyon Naga', 'nmp': 'Nimanbur', 'nmq': 'Nambya', 'nmr': 'Nimbari', 'nms': 'Letemboi', 'nmt': 'Namonuito', 'nmu': 'Northeast Maidu', 'nmv': 'Ngamini', 'nmw': 'Nimoa', 'nmx': 'Nama', 'nmy': 'Namuyi', 'nmz': 'Nawdm', 'nna': 'Nyangumarta', 'nnb': 'Nande', 'nnc': 'Nancere', 'nnd': 'West Ambae', 'nne': 'Ngandyera', 'nnf': 'Ngaing', 'nng': 'Maring Naga', 'nnh': 'Ngiemboon', 'nni': 'North Nuaulu', 'nnj': 'Nyangatom', 'nnk': 'Nankina', 'nnl': 'Northern Rengma Naga', 'nnm': 'Namia', 'nnn': 'Ngete', 'nno': 'Norwegian Nynorsk', 'nnp': 'Wancho Naga', 'nnq': 'Ngindo', 'nnr': 'Narungga', 'nnt': 'Nanticoke', 'nnu': 'Dwang', 'nnv': 'Nugunu', 'nnw': 'Southern Nuni', 'nny': 'Nyangga', 'nnz': "Nda'nda'", 'noa': 'Woun Meu', 'nob': 'Norwegian Bokmål', 'noc': 'Nuk', 'nod': 'Northern Thai', 'noe': 'Nimadi', 'nof': 'Nomane', 'nog': 'Nogai', 'noh': 'Nomu', 'noi': 'Noiri', 'noj': 'Nonuya', 'nok': 'Nooksack', 'nol': 'Nomlaki', 'nom': 'Nocamán', 'non': 'Old Norse', 'nop': 'Numanggang', 'noq': 'Ngongo', 'nor': 'Norwegian', 'nos': 'Eastern Nisu', 'not': 'Nomatsiguenga', 'nou': 'Ewage-Notu', 'nov': 'Novial', 'now': 'Nyambo', 'noy': 'Noy', 'noz': 'Nayi', 'npa': 'Nar Phu', 'npb': 'Nupbikha', 'npg': 'Ponyo-Gongwang Naga', 'nph': 'Phom Naga', 'npi': 'Nepali', 'npl': 'Southeastern Puebla Nahuatl', 'npn': 'Mondropolon', 'npo': 'Pochuri Naga', 'nps': 'Nipsan', 'npu': 'Puimei Naga', 'npx': 'Noipx', 'npy': 'Napu', 'nqg': 'Southern Nago', 'nqk': 'Kura Ede Nago', 'nql': 'Ngendelengo', 'nqm': 'Ndom', 'nqn': 'Nen', 'nqo': 'N’Ko', 'nqq': 'Kyan-Karyaw Naga', 'nqy': 'Akyaung Ari Naga', 'nra': 'Ngom', 'nrb': 'Nara', 'nrc': 'Noric', 'nre': 'Southern Rengma Naga', 'nrf': 'Jèrriais', 'nrg': 'Narango', 'nri': 'Chokri Naga', 'nrk': 'Ngarla', 'nrl': 'Ngarluma', 'nrm': 'Narom', 'nrn': 'Norn', 'nrp': 'North Picene', 'nrr': 'Norra', 'nrt': 'Northern Kalapuya', 'nru': 'Narua', 'nrx': 'Ngurmbur', 'nrz': 'Lala', 'nsa': 'Sangtam Naga', 'nsc': 'Nshi', 'nsd': 'Southern Nisu', 'nse': 'Nsenga', 'nsf': 'Northwestern Nisu', 'nsg': 'Ngasa', 'nsh': 'Ngoshie', 'nsi': 'Nigerian Sign Language', 'nsk': 'Naskapi', 'nsl': 'Norwegian Sign Language', 'nsm': 'Sumi Naga', 'nsn': 'Nehan', 'nso': 'Northern Sotho', 'nsp': 'Nepalese Sign Language', 'nsq': 'Northern Sierra Miwok', 'nsr': 'Maritime Sign Language', 'nss': 'Nali', 'nst': 'Tase Naga', 'nsu': 'Sierra Negra Nahuatl', 'nsv': 'Southwestern Nisu', 'nsw': 'Navut', 'nsx': 'Nsongo', 'nsy': 'Nasal', 'nsz': 'Nisenan', 'ntd': 'Northern Tidung', 'nte': 'Nathembo', 'ntg': 'Ngantangarra', 'nti': 'Natioro', 'ntj': 'Ngaanyatjarra', 'ntk': 'Ikoma-Nata-Isenye', 'ntm': 'Nateni', 'nto': 'Ntomba', 'ntp': 'Northern Tepehuan', 'ntr': 'Delo', 'ntu': 'Natügu', 'ntw': 'Nottoway', 'ntx': 'Tangkhul Naga', 'nty': 'Mantsi', 'ntz': 'Natanzi', 'nua': 'Yuanga', 'nuc': 'Nukuini', 'nud': 'Ngala', 'nue': 'Ngundu', 'nuf': 'Nusu', 'nug': 'Nungali', 'nuh': 'Ndunda', 'nui': 'Ngumbi', 'nuj': 'Nyole', 'nuk': 'Nuu-chah-nulth', 'nul': 'Nusa Laut', 'num': "Niuafo'ou", 'nun': 'Anong', 'nuo': 'Nguôn', 'nup': 'Nupe-Nupe-Tako', 'nuq': 'Nukumanu', 'nur': 'Nukuria', 'nus': 'Nuer', 'nut': 'Nung', 'nuu': 'Ngbundu', 'nuv': 'Northern Nuni', 'nuw': 'Nguluwan', 'nux': 'Mehek', 'nuy': 'Nunggubuyu', 'nuz': 'Tlamacazapa Nahuatl', 'nvh': 'Nasarian', 'nvm': 'Namiae', 'nvo': 'Nyokon', 'nwa': 'Nawathinehena', 'nwb': 'Nyabwa', 'nwc': 'Classical Newari', 'nwe': 'Ngwe', 'nwg': 'Ngayawung', 'nwi': 'Southwest Tanna', 'nwm': 'Nyamusa-Molo', 'nwo': 'Nauo', 'nwr': 'Nawaru', 'nwx': 'Middle Newar', 'nwy': 'Nottoway-Meherrin', 'nxa': 'Nauete', 'nxd': 'Ngando', 'nxe': 'Nage', 'nxg': "Ngad'a", 'nxi': 'Nindi', 'nxk': 'Koki Naga', 'nxl': 'South Nuaulu', 'nxm': 'Numidian', 'nxn': 'Ngawun', 'nxo': 'Ndambomo', 'nxq': 'Naxi', 'nxr': 'Ninggerum', 'nxu': 'Narau', 'nxx': 'Nafri', 'nya': 'Nyanja', 'nyb': 'Nyangbo', 'nyc': 'Nyanga-li', 'nyd': 'Nyore', 'nye': 'Nyengo', 'nyf': 'Giryama', 'nyg': 'Nyindu', 'nyh': 'Nyikina', 'nyi': 'Ama', 'nyj': 'Nyanga', 'nyk': 'Nyaneka', 'nyl': 'Nyeu', 'nym': 'Nyamwezi', 'nyn': 'Nyankole', 'nyo': 'Nyoro', 'nyp': "Nyang'i", 'nyq': 'Nayini', 'nyr': 'Nyiha', 'nys': 'Nyungar', 'nyt': 'Nyawaygi', 'nyu': 'Nyungwe', 'nyv': 'Nyulnyul', 'nyw': 'Nyaw', 'nyx': 'Nganyaywana', 'nyy': 'Nyakyusa-Ngonde', 'nza': 'Tigon Mbembe', 'nzb': 'Njebi', 'nzd': 'Nzadi', 'nzi': 'Nzima', 'nzk': 'Nzakara', 'nzm': 'Zeme Naga', 'nzs': 'New Zealand Sign Language', 'nzu': 'Teke-Nzikou', 'nzy': 'Nzakambay', 'nzz': 'Nanga Dama Dogon', 'oaa': 'Orok', 'oac': 'Oroch', 'oar': 'Old Aramaic', 'oav': 'Old Avar', 'obi': 'Obispeño', 'obk': 'Southern Bontok', 'obl': 'Oblo', 'obm': 'Moabite', 'obo': 'Obo Manobo', 'obr': 'Old Burmese', 'obt': 'Old Breton', 'obu': 'Obulom', 'oca': 'Ocaina', 'och': 'Old Chinese', 'oci': 'Occitan', 'oco': 'Old Cornish', 'ocu': 'Atzingo Matlatzinca', 'oda': 'Odut', 'odk': 'Od', 'odt': 'Old Dutch', 'odu': 'Odual', 'ofo': 'Ofo', 'ofs': 'Old Frisian', 'ofu': 'Efutop', 'ogb': 'Ogbia', 'ogc': 'Ogbah', 'oge': 'Old Georgian', 'ogg': 'Ogbogolo', 'ogo': 'Khana', 'ogu': 'Ogbronuagum', 'oht': 'Old Hittite', 'ohu': 'Old Hungarian', 'oia': 'Oirata', 'oin': 'Inebu One', 'ojb': 'Northwestern Ojibwa', 'ojc': 'Central Ojibwa', 'ojg': 'Eastern Ojibwa', 'oji': 'Ojibwa', 'ojp': 'Old Japanese', 'ojs': 'Severn Ojibwa', 'ojv': 'Ontong Java', 'ojw': 'Western Ojibwa', 'oka': 'Okanagan', 'okb': 'Okobo', 'okd': 'Okodia', 'oke': 'Okpe', 'okg': 'Koko Babangk', 'okh': 'Koresh-e Rostam', 'oki': 'Okiek', 'okj': 'Oko-Juwoi', 'okk': 'Kwamtim One', 'okl': 'Old Kentish Sign Language', 'okm': 'Middle Korean', 'okn': 'Oki-No-Erabu', 'oko': 'Old Korean', 'okr': 'Kirike', 'oks': 'Oko-Eni-Osayen', 'oku': 'Oku', 'okv': 'Orokaiva', 'okx': 'Okpe', 'ola': 'Walungge', 'old': 'Mochi', 'ole': 'Olekha', 'olk': 'Olkol', 'olm': 'Oloma', 'olo': 'Livvi', 'olr': 'Olrat', 'olt': 'Old Lithuanian', 'olu': 'Kuvale', 'oma': 'Omaha-Ponca', 'omb': 'East Ambae', 'omc': 'Mochica', 'omg': 'Omagua', 'omi': 'Omi', 'omk': 'Omok', 'oml': 'Ombo', 'omn': 'Minoan', 'omo': 'Utarmbung', 'omp': 'Old Manipuri', 'omr': 'Old Marathi', 'omt': 'Omotik', 'omu': 'Omurano', 'omw': 'South Tairora', 'omx': 'Old Mon', 'ona': 'Ona', 'onb': 'Lingao', 'one': 'Oneida', 'ong': 'Olo', 'oni': 'Onin', 'onj': 'Onjob', 'onk': 'Kabore One', 'onn': 'Onobasulu', 'ono': 'Onondaga', 'onp': 'Sartang', 'onr': 'Northern One', 'ons': 'Ono', 'ont': 'Ontenu', 'onu': 'Unua', 'onw': 'Old Nubian', 'onx': 'Onin Based Pidgin', 'ood': "Tohono O'odham", 'oog': 'Ong', 'oon': 'Önge', 'oor': 'Oorlams', 'oos': 'Old Ossetic', 'opa': 'Okpamheri', 'opk': 'Kopkaka', 'opm': 'Oksapmin', 'opo': 'Opao', 'opt': 'Opata', 'opy': 'Ofayé', 'ora': 'Oroha', 'orc': 'Orma', 'ore': 'Orejón', 'org': 'Oring', 'orh': 'Oroqen', 'ori': 'Oriya', 'orm': 'Oromo', 'orn': 'Orang Kanaq', 'oro': 'Orokolo', 'orr': 'Oruma', 'ors': 'Orang Seletar', 'ort': 'Adivasi Oriya', 'oru': 'Ormuri', 'orv': 'Old Russian', 'orw': 'Oro Win', 'orx': 'Oro', 'ory': 'Odia', 'orz': 'Ormu', 'osa': 'Osage', 'osc': 'Oscan', 'osi': 'Osing', 'oso': 'Ososo', 'osp': 'Old Spanish', 'oss': 'Ossetic', 'ost': 'Osatu', 'osu': 'Southern One', 'osx': 'Old Saxon', 'ota': 'Ottoman Turkish', 'otb': 'Old Tibetan', 'otd': 'Ot Danum', 'ote': 'Mezquital Otomi', 'oti': 'Oti', 'otk': 'Old Turkish', 'otl': 'Tilapa Otomi', 'otm': 'Eastern Highland Otomi', 'otn': 'Tenango Otomi', 'otq': 'Querétaro Otomi', 'otr': 'Otoro', 'ots': 'Estado de México Otomi', 'ott': 'Temoaya Otomi', 'otu': 'Otuke', 'otw': 'Ottawa', 'otx': 'Texcatepec Otomi', 'oty': 'Old Tamil', 'otz': 'Ixtenco Otomi', 'oua': 'Tagargrent', 'oub': 'Glio-Oubi', 'oue': 'Oune', 'oui': 'Old Uighur', 'oum': 'Ouma', 'ovd': 'Elfdalian', 'owi': 'Owiniga', 'owl': 'Old Welsh', 'oyb': 'Oy', 'oyd': 'Oyda', 'oym': 'Wayampi', 'oyy': "Oya'oya", 'ozm': 'Koonzime', 'pab': 'Parecís', 'pac': 'Pacoh', 'pad': 'Paumarí', 'pae': 'Pagibete', 'paf': 'Paranawát', 'pag': 'Pangasinan', 'pah': 'Tenharim', 'pai': 'Pe', 'pak': 'Parakanã', 'pal': 'Pahlavi', 'pam': 'Pampanga', 'pan': 'Punjabi', 'pao': 'Northern Paiute', 'pap': 'Papiamento', 'paq': 'Parya', 'par': 'Panamint', 'pas': 'Papasena', 'pat': 'Papitalai', 'pau': 'Palauan', 'pav': 'Pakaásnovos', 'paw': 'Pawnee', 'pax': 'Pankararé', 'pay': 'Pech', 'paz': 'Pankararú', 'pbb': 'Páez', 'pbc': 'Patamona', 'pbe': 'Mezontla Popoloca', 'pbf': 'Coyotepec Popoloca', 'pbg': 'Paraujano', 'pbh': "E'ñapa Woromaipu", 'pbi': 'Parkwa', 'pbl': 'Mak', 'pbm': 'Puebla Mazatec', 'pbn': 'Kpasam', 'pbo': 'Papel', 'pbp': 'Badyara', 'pbr': 'Pangwa', 'pbs': 'Central Pame', 'pbt': 'Southern Pashto', 'pbu': 'Northern Pashto', 'pbv': 'Pnar', 'pby': 'Pyu', 'pca': 'Santa Inés Ahuatempan Popoloca', 'pcb': 'Pear', 'pcc': 'Bouyei', 'pcd': 'Picard', 'pce': 'Ruching Palaung', 'pcf': 'Paliyan', 'pcg': 'Paniya', 'pch': 'Pardhan', 'pci': 'Duruwa', 'pcj': 'Parenga', 'pck': 'Paite Chin', 'pcl': 'Pardhi', 'pcm': 'Nigerian Pidgin', 'pcn': 'Piti', 'pcp': 'Pacahuara', 'pcw': 'Pyapun', 'pda': 'Anam', 'pdc': 'Pennsylvania German', 'pdi': 'Pa Di', 'pdn': 'Podena', 'pdo': 'Padoe', 'pdt': 'Plautdietsch', 'pdu': 'Kayan', 'pea': 'Peranakan Indonesian', 'peb': 'Eastern Pomo', 'ped': 'Mala', 'pee': 'Taje', 'pef': 'Northeastern Pomo', 'peg': 'Pengo', 'peh': 'Bonan', 'pei': 'Chichimeca-Jonaz', 'pej': 'Northern Pomo', 'pek': 'Penchal', 'pel': 'Pekal', 'pem': 'Phende', 'peo': 'Old Persian', 'pep': 'Kunja', 'peq': 'Southern Pomo', 'pes': 'Iranian Persian', 'pev': 'Pémono', 'pex': 'Petats', 'pey': 'Petjo', 'pez': 'Eastern Penan', 'pfa': 'Pááfang', 'pfe': 'Peere', 'pfl': 'Pfaelzisch', 'pga': 'Sudanese Creole Arabic', 'pgd': 'Gāndhārī', 'pgg': 'Pangwali', 'pgi': 'Pagi', 'pgk': 'Rerep', 'pgl': 'Primitive Irish', 'pgn': 'Paelignian', 'pgs': 'Pangseng', 'pgu': 'Pagu', 'pgz': 'Papua New Guinean Sign Language', 'pha': 'Pa-Hng', 'phd': 'Phudagi', 'phg': 'Phuong', 'phh': 'Phukha', 'phk': 'Phake', 'phl': 'Phalura', 'phm': 'Phimbi', 'phn': 'Phoenician', 'pho': 'Phunoi', 'phq': "Phana'", 'phr': 'Pahari-Potwari', 'pht': 'Phu Thai', 'phu': 'Phuan', 'phv': 'Pahlavani', 'phw': 'Phangduwali', 'pia': 'Pima Bajo', 'pib': 'Yine', 'pic': 'Pinji', 'pid': 'Piaroa', 'pie': 'Piro', 'pif': 'Pingelapese', 'pig': 'Pisabo', 'pih': 'Pitcairn-Norfolk', 'pii': 'Pini', 'pij': 'Pijao', 'pil': 'Yom', 'pim': 'Powhatan', 'pin': 'Piame', 'pio': 'Piapoco', 'pip': 'Pero', 'pir': 'Piratapuyo', 'pis': 'Pijin', 'pit': 'Pitta Pitta', 'piu': 'Pintupi-Luritja', 'piv': 'Pileni', 'piw': 'Pimbwe', 'pix': 'Piu', 'piy': 'Piya-Kwonci', 'piz': 'Pije', 'pjt': 'Pitjantjatjara', 'pka': 'Ardhamāgadhī Prākrit', 'pkb': 'Pokomo', 'pkc': 'Paekche', 'pkg': 'Pak-Tong', 'pkh': 'Pankhu', 'pkn': 'Pakanha', 'pko': 'Pökoot', 'pkp': 'Pukapuka', 'pkr': 'Attapady Kurumba', 'pks': 'Pakistan Sign Language', 'pkt': 'Maleng', 'pku': 'Paku', 'pla': 'Miani', 'plb': 'Polonombauk', 'plc': 'Central Palawano', 'pld': 'Polari', 'ple': "Palu'e", 'plg': 'Pilagá', 'plh': 'Paulohi', 'pli': 'Pali', 'plj': 'Polci', 'plk': 'Kohistani Shina', 'pll': 'Shwe Palaung', 'pln': 'Palenquero', 'plo': 'Oluta Popoluca', 'plp': 'Palpa', 'plq': 'Palaic', 'plr': 'Palaka Senoufo', 'pls': 'San Marcos Tlacoyalco Popoloca', 'plt': 'Plateau Malagasy', 'plu': 'Palikúr', 'plv': 'Southwest Palawano', 'plw': "Brooke's Point Palawano", 'ply': 'Bolyu', 'plz': 'Paluan', 'pma': 'Paama', 'pmb': 'Pambia', 'pmd': 'Pallanganmiddang', 'pme': 'Pwaamei', 'pmf': 'Pamona', 'pmh': 'Māhārāṣṭri Prākrit', 'pmi': 'Northern Pumi', 'pmj': 'Southern Pumi', 'pmk': 'Pamlico', 'pml': 'Lingua Franca', 'pmm': 'Pomo', 'pmn': 'Pam', 'pmo': 'Pom', 'pmq': 'Northern Pame', 'pmr': 'Paynamar', 'pms': 'Piemontese', 'pmt': 'Tuamotuan', 'pmw': 'Plains Miwok', 'pmx': 'Poumei Naga', 'pmy': 'Papuan Malay', 'pmz': 'Southern Pame', 'pna': 'Punan Bah-Biau', 'pnb': 'Western Panjabi', 'pnc': 'Pannei', 'pnd': 'Mpinda', 'pne': 'Western Penan', 'png': 'Pongu', 'pnh': 'Penrhyn', 'pni': 'Aoheng', 'pnj': 'Pinjarup', 'pnk': 'Paunaka', 'pnl': 'Paleni', 'pnm': 'Punan Batu 1', 'pnn': 'Pinai-Hagahai', 'pno': 'Panobo', 'pnp': 'Pancana', 'pnq': 'Pana', 'pnr': 'Panim', 'pns': 'Ponosakan', 'pnt': 'Pontic', 'pnu': 'Jiongnai Bunu', 'pnv': 'Pinigura', 'pnw': 'Banyjima', 'pnx': 'Phong-Kniang', 'pny': 'Pinyin', 'pnz': 'Pana', 'poc': 'Poqomam', 'poe': 'San Juan Atzingo Popoloca', 'pof': 'Poke', 'pog': 'Potiguára', 'poh': "Poqomchi'", 'poi': 'Highland Popoluca', 'pok': 'Pokangá', 'pol': 'Polish', 'pom': 'Southeastern Pomo', 'pon': 'Pohnpeian', 'poo': 'Central Pomo', 'pop': 'Pwapwâ', 'poq': 'Texistepec Popoluca', 'por': 'Portuguese', 'pos': 'Sayula Popoluca', 'pot': 'Potawatomi', 'pov': 'Upper Guinea Crioulo', 'pow': 'San Felipe Otlaltepec Popoloca', 'pox': 'Polabian', 'poy': 'Pogolo', 'ppe': 'Papi', 'ppi': 'Paipai', 'ppk': 'Uma', 'ppl': 'Pipil', 'ppm': 'Papuma', 'ppn': 'Papapana', 'ppo': 'Folopa', 'ppp': 'Pelende', 'ppq': 'Pei', 'pps': 'San Luís Temalacayuca Popoloca', 'ppt': 'Pare', 'ppu': 'Papora', 'pqa': "Pa'a", 'pqm': 'Malecite-Passamaquoddy', 'prc': 'Parachi', 'prd': 'Parsi-Dari', 'pre': 'Principense', 'prf': 'Paranan', 'prg': 'Prussian', 'prh': 'Porohanon', 'pri': 'Paicî', 'prk': 'Parauk', 'prl': 'Peruvian Sign Language', 'prm': 'Kibiri', 'prn': 'Prasuni', 'pro': 'Old Provençal', 'prp': 'Parsi', 'prq': 'Ashéninka Perené', 'prr': 'Puri', 'prs': 'Dari', 'prt': 'Phai', 'pru': 'Puragi', 'prw': 'Parawen', 'prx': 'Purik', 'prz': 'Providencia Sign Language', 'psa': 'Asue Awyu', 'psc': 'Persian Sign Language', 'psd': 'Plains Indian Sign Language', 'pse': 'Central Malay', 'psg': 'Penang Sign Language', 'psh': 'Southwest Pashai', 'psi': 'Southeast Pashai', 'psl': 'Puerto Rican Sign Language', 'psm': 'Pauserna', 'psn': 'Panasuan', 'pso': 'Polish Sign Language', 'psp': 'Philippine Sign Language', 'psq': 'Pasi', 'psr': 'Portuguese Sign Language', 'pss': 'Kaulong', 'pst': 'Central Pashto', 'psu': 'Sauraseni Prākrit', 'psw': 'Port Sandwich', 'psy': 'Piscataway', 'pta': 'Pai Tavytera', 'pth': 'Pataxó Hã-Ha-Hãe', 'pti': 'Pindiini', 'ptn': 'Patani', 'pto': "Zo'é", 'ptp': 'Patep', 'ptq': 'Pattapu', 'ptr': 'Piamatsina', 'ptt': 'Enrekang', 'ptu': 'Bambam', 'ptv': 'Port Vato', 'ptw': 'Pentlatch', 'pty': 'Pathiya', 'pua': 'Western Highland Purepecha', 'pub': 'Purum', 'puc': 'Punan Merap', 'pud': 'Punan Aput', 'pue': 'Puelche', 'puf': 'Punan Merah', 'pug': 'Phuie', 'pui': 'Puinave', 'puj': 'Punan Tubu', 'pum': 'Puma', 'puo': 'Puoc', 'pup': 'Pulabu', 'puq': 'Puquina', 'pur': 'Puruborá', 'pus': 'Pashto', 'put': 'Putoh', 'puu': 'Punu', 'puw': 'Puluwatese', 'pux': 'Puare', 'puy': 'Purisimeño', 'pwa': 'Pawaia', 'pwb': 'Panawa', 'pwg': 'Gapapaiwa', 'pwi': 'Patwin', 'pwm': 'Molbog', 'pwn': 'Paiwan', 'pwo': 'Pwo Western Karen', 'pwr': 'Powari', 'pww': 'Pwo Northern Karen', 'pxm': 'Quetzaltepec Mixe', 'pye': 'Pye Krumen', 'pym': 'Fyam', 'pyn': 'Poyanáwa', 'pys': 'Paraguayan Sign Language', 'pyu': 'Puyuma', 'pyx': 'Pyu', 'pyy': 'Pyen', 'pzn': 'Para Naga', 'qua': 'Quapaw', 'qub': 'Huallaga Huánuco Quechua', 'quc': "K'iche'", 'qud': 'Calderón Highland Quichua', 'que': 'Quechua', 'quf': 'Lambayeque Quechua', 'qug': 'Chimborazo Highland Quichua', 'quh': 'South Bolivian Quechua', 'qui': 'Quileute', 'quk': 'Chachapoyas Quechua', 'qul': 'North Bolivian Quechua', 'qum': 'Sipacapense', 'qun': 'Quinault', 'qup': 'Southern Pastaza Quechua', 'quq': 'Quinqui', 'qur': 'Yanahuanca Pasco Quechua', 'qus': 'Santiago del Estero Quichua', 'quv': 'Sacapulteco', 'quw': 'Tena Lowland Quichua', 'qux': 'Yauyos Quechua', 'quy': 'Ayacucho Quechua', 'quz': 'Cusco Quechua', 'qva': 'Ambo-Pasco Quechua', 'qvc': 'Cajamarca Quechua', 'qve': 'Eastern Apurímac Quechua', 'qvh': 'Huamalíes-Dos de Mayo Huánuco Quechua', 'qvi': 'Imbabura Highland Quichua', 'qvj': 'Loja Highland Quichua', 'qvl': 'Cajatambo North Lima Quechua', 'qvm': 'Margos-Yarowilca-Lauricocha Quechua', 'qvn': 'North Junín Quechua', 'qvo': 'Napo Lowland Quechua', 'qvp': 'Pacaraos Quechua', 'qvs': 'San Martín Quechua', 'qvw': 'Huaylla Wanca Quechua', 'qvy': 'Queyu', 'qvz': 'Northern Pastaza Quichua', 'qwa': 'Corongo Ancash Quechua', 'qwc': 'Classical Quechua', 'qwh': 'Huaylas Ancash Quechua', 'qwm': 'Kuman', 'qws': 'Sihuas Ancash Quechua', 'qwt': 'Kwalhioqua-Tlatskanai', 'qxa': 'Chiquián Ancash Quechua', 'qxc': 'Chincha Quechua', 'qxh': 'Panao Huánuco Quechua', 'qxl': 'Salasaca Highland Quichua', 'qxn': 'Northern Conchucos Ancash Quechua', 'qxo': 'Southern Conchucos Ancash Quechua', 'qxp': 'Puno Quechua', 'qxq': "Qashqa'i", 'qxr': 'Cañar Highland Quichua', 'qxs': 'Southern Qiang', 'qxt': 'Santa Ana de Tusi Pasco Quechua', 'qxu': 'Arequipa-La Unión Quechua', 'qxw': 'Jauja Wanca Quechua', 'qya': 'Quenya', 'qyp': 'Quiripi', 'raa': 'Dungmali', 'rab': 'Camling', 'rac': 'Rasawa', 'rad': 'Rade', 'raf': 'Western Meohang', 'rag': 'Logooli', 'rah': 'Rabha', 'rai': 'Ramoaaina', 'raj': 'Rajasthani', 'rak': 'Tulu-Bohuai', 'ral': 'Ralte', 'ram': 'Canela', 'ran': 'Riantana', 'rao': 'Rao', 'rap': 'Rapanui', 'raq': 'Saam', 'rar': 'Rarotongan', 'ras': 'Tegali', 'rat': 'Razajerdi', 'rau': 'Raute', 'rav': 'Sampang', 'raw': 'Rawang', 'rax': 'Rang', 'ray': 'Rapa', 'raz': 'Rahambuu', 'rbb': 'Rumai Palaung', 'rbk': 'Northern Bontok', 'rbl': 'Miraya Bikol', 'rbp': 'Barababaraba', 'rcf': 'Réunion Creole French', 'rdb': 'Rudbari', 'rea': 'Rerau', 'reb': 'Rembong', 'ree': 'Rejang Kayan', 'reg': 'Kara', 'rei': 'Reli', 'rej': 'Rejang', 'rel': 'Rendille', 'rem': 'Remo', 'ren': 'Rengao', 'rer': 'Rer Bare', 'res': 'Reshe', 'ret': 'Retta', 'rey': 'Reyesano', 'rga': 'Roria', 'rge': 'Romano-Greek', 'rgk': 'Rangkas', 'rgn': 'Romagnol', 'rgr': 'Resígaro', 'rgs': 'Southern Roglai', 'rgu': 'Ringgou', 'rhg': 'Rohingya', 'rhp': 'Yahang', 'ria': 'Riang', 'rif': 'Tarifit', 'ril': 'Riang Lang', 'rim': 'Nyaturu', 'rin': 'Nungu', 'rir': 'Ribun', 'rit': 'Ritharrngu', 'riu': 'Riung', 'rjg': 'Rajong', 'rji': 'Raji', 'rjs': 'Rajbanshi', 'rka': 'Kraol', 'rkb': 'Rikbaktsa', 'rkh': 'Rakahanga-Manihiki', 'rki': 'Rakhine', 'rkm': 'Marka', 'rkt': 'Rangpuri', 'rkw': 'Arakwal', 'rma': 'Rama', 'rmb': 'Rembarrnga', 'rmc': 'Carpathian Romani', 'rmd': 'Traveller Danish', 'rme': 'Angloromani', 'rmf': 'Kalo Finnish Romani', 'rmg': 'Traveller Norwegian', 'rmh': 'Murkim', 'rmi': 'Lomavren', 'rmk': 'Romkun', 'rml': 'Baltic Romani', 'rmm': 'Roma', 'rmn': 'Balkan Romani', 'rmo': 'Sinte Romani', 'rmp': 'Rempi', 'rmq': 'Caló', 'rms': 'Romanian Sign Language', 'rmt': 'Domari', 'rmu': 'Tavringer Romani', 'rmv': 'Romanova', 'rmw': 'Welsh Romani', 'rmx': 'Romam', 'rmy': 'Vlax Romani', 'rmz': 'Marma', 'rnd': 'Ruund', 'rng': 'Ronga', 'rnl': 'Ranglong', 'rnn': 'Roon', 'rnp': 'Rongpo', 'rnr': 'Nari Nari', 'rnw': 'Rungwa', 'rob': "Tae'", 'roc': 'Cacgia Roglai', 'rod': 'Rogo', 'roe': 'Ronji', 'rof': 'Rombo', 'rog': 'Northern Roglai', 'roh': 'Romansh', 'rol': 'Romblomanon', 'rom': 'Romany', 'ron': 'Romanian', 'roo': 'Rotokas', 'rop': 'Kriol', 'ror': 'Rongga', 'rou': 'Runga', 'row': 'Dela-Oenale', 'rpn': 'Repanbitip', 'rpt': 'Rapting', 'rri': 'Ririo', 'rro': 'Waima', 'rrt': 'Arritinngithigh', 'rsb': 'Romano-Serbian', 'rsl': 'Russian Sign Language', 'rsm': 'Miriwoong Sign Language', 'rtc': 'Rungtu Chin', 'rth': 'Ratahan', 'rtm': 'Rotuman', 'rts': 'Yurats', 'rtw': 'Rathawi', 'rub': 'Gungu', 'ruc': 'Ruuli', 'rue': 'Rusyn', 'ruf': 'Luguru', 'rug': 'Roviana', 'ruh': 'Ruga', 'rui': 'Rufiji', 'ruk': 'Che', 'run': 'Rundi', 'ruo': 'Istro Romanian', 'rup': 'Aromanian', 'ruq': 'Megleno Romanian', 'rus': 'Russian', 'rut': 'Rutul', 'ruu': 'Lanas Lobu', 'ruy': 'Mala', 'ruz': 'Ruma', 'rwa': 'Rawo', 'rwk': 'Rwa', 'rwm': 'Amba', 'rwo': 'Rawa', 'rwr': 'Marwari', 'rxd': 'Ngardi', 'rxw': 'Karuwali', 'ryn': 'Northern Amami-Oshima', 'rys': 'Yaeyama', 'ryu': 'Central Okinawan', 'rzh': 'Rāziḥī', 'saa': 'Saba', 'sab': 'Buglere', 'sac': 'Meskwaki', 'sad': 'Sandawe', 'sae': 'Sabanê', 'saf': 'Safaliba', 'sag': 'Sango', 'sah': 'Sakha', 'saj': 'Sahu', 'sak': 'Sake', 'sam': 'Samaritan Aramaic', 'san': 'Sanskrit', 'sao': 'Sause', 'saq': 'Samburu', 'sar': 'Saraveca', 'sas': 'Sasak', 'sat': 'Santali', 'sau': 'Saleman', 'sav': 'Saafi-Saafi', 'saw': 'Sawi', 'sax': 'Sa', 'say': 'Saya', 'saz': 'Saurashtra', 'sba': 'Ngambay', 'sbb': 'Simbo', 'sbc': 'Kele', 'sbd': 'Southern Samo', 'sbe': 'Saliba', 'sbf': 'Chabu', 'sbg': 'Seget', 'sbh': 'Sori-Harengan', 'sbi': 'Seti', 'sbj': 'Surbakhal', 'sbk': 'Safwa', 'sbl': 'Botolan Sambal', 'sbm': 'Sagala', 'sbn': 'Sindhi Bhil', 'sbo': 'Sabüm', 'sbp': 'Sangu', 'sbq': 'Sileibi', 'sbr': 'Sembakung Murut', 'sbs': 'Subiya', 'sbt': 'Kimki', 'sbu': 'Stod Bhoti', 'sbv': 'Sabine', 'sbw': 'Simba', 'sbx': 'Seberuang', 'sby': 'Soli', 'sbz': 'Sara Kaba', 'scb': 'Chut', 'sce': 'Dongxiang', 'scf': 'San Miguel Creole French', 'scg': 'Sanggau', 'sch': 'Sakachep', 'sci': 'Sri Lankan Creole Malay', 'sck': 'Sadri', 'scl': 'Shina', 'scn': 'Sicilian', 'sco': 'Scots', 'scp': 'Hyolmo', 'scq': "Sa'och", 'scs': 'North Slavey', 'sct': 'Southern Katang', 'scu': 'Shumcho', 'scv': 'Sheni', 'scw': 'Sha', 'scx': 'Sicel', 'sda': "Toraja-Sa'dan", 'sdb': 'Shabak', 'sdc': 'Sassarese Sardinian', 'sde': 'Surubu', 'sdf': 'Sarli', 'sdg': 'Savi', 'sdh': 'Southern Kurdish', 'sdj': 'Suundi', 'sdk': 'Sos Kundi', 'sdl': 'Saudi Arabian Sign Language', 'sdm': 'Semandang', 'sdn': 'Gallurese Sardinian', 'sdo': 'Bukar-Sadung Bidayuh', 'sdp': 'Sherdukpen', 'sdr': 'Oraon Sadri', 'sds': 'Sened', 'sdt': 'Shuadit', 'sdu': 'Sarudu', 'sdx': 'Sibu Melanau', 'sdz': 'Sallands', 'sea': 'Semai', 'seb': 'Shempire Senoufo', 'sec': 'Sechelt', 'sed': 'Sedang', 'see': 'Seneca', 'sef': 'Cebaara Senoufo', 'seg': 'Segeju', 'seh': 'Sena', 'sei': 'Seri', 'sej': 'Sene', 'sek': 'Sekani', 'sel': 'Selkup', 'sen': 'Nanerigé Sénoufo', 'seo': 'Suarmin', 'sep': 'Sìcìté Sénoufo', 'seq': 'Senara Sénoufo', 'ser': 'Serrano', 'ses': 'Koyraboro Senni', 'set': 'Sentani', 'seu': 'Serui-Laut', 'sev': 'Nyarafolo Senoufo', 'sew': 'Sewa Bay', 'sey': 'Secoya', 'sez': 'Senthang Chin', 'sfb': 'Langue des signes de Belgique Francophone', 'sfe': 'Eastern Subanen', 'sfm': 'Small Flowery Miao', 'sfs': 'South African Sign Language', 'sfw': 'Sehwi', 'sga': 'Old Irish', 'sgb': 'Mag-antsi Ayta', 'sgc': 'Kipsigis', 'sgd': 'Surigaonon', 'sge': 'Segai', 'sgg': 'Swiss-German Sign Language', 'sgh': 'Shughni', 'sgi': 'Suga', 'sgj': 'Surgujia', 'sgk': 'Sangkong', 'sgm': 'Singa', 'sgp': 'Singpho', 'sgr': 'Sangisari', 'sgs': 'Samogitian', 'sgt': 'Brokpake', 'sgu': 'Salas', 'sgw': 'Sebat Bet Gurage', 'sgx': 'Sierra Leone Sign Language', 'sgy': 'Sanglechi', 'sgz': 'Sursurunga', 'sha': 'Shall-Zwall', 'shb': 'Ninam', 'shc': 'Sonde', 'shd': 'Kundal Shahi', 'she': 'Sheko', 'shg': 'Shua', 'shh': 'Shoshoni', 'shi': 'Tachelhit', 'shj': 'Shatt', 'shk': 'Shilluk', 'shl': 'Shendu', 'shm': 'Shahrudi', 'shn': 'Shan', 'sho': 'Shanga', 'shp': 'Shipibo-Conibo', 'shq': 'Sala', 'shr': 'Shi', 'shs': 'Shuswap', 'sht': 'Shasta', 'shu': 'Chadian Arabic', 'shv': 'Shehri', 'shw': 'Shwai', 'shx': 'She', 'shy': 'Tachawit', 'shz': 'Syenara Senoufo', 'sia': 'Akkala Sami', 'sib': 'Sebop', 'sid': 'Sidamo', 'sie': 'Simaa', 'sif': 'Siamou', 'sig': 'Paasaal', 'sih': 'Zire', 'sii': 'Shom Peng', 'sij': 'Numbami', 'sik': 'Sikiana', 'sil': 'Tumulung Sisaala', 'sim': 'Mende', 'sin': 'Sinhala', 'sip': 'Sikkimese', 'siq': 'Sonia', 'sir': 'Siri', 'sis': 'Siuslaw', 'siu': 'Sinagen', 'siv': 'Sumariup', 'siw': 'Siwai', 'six': 'Sumau', 'siy': 'Sivandi', 'siz': 'Siwi', 'sja': 'Epena', 'sjb': 'Sajau Basap', 'sjd': 'Kildin Sami', 'sje': 'Pite Sami', 'sjg': 'Assangori', 'sjk': 'Kemi Sami', 'sjl': 'Sajalong', 'sjm': 'Mapun', 'sjn': 'Sindarin', 'sjo': 'Xibe', 'sjp': 'Surjapuri', 'sjr': 'Siar-Lak', 'sjs': 'Senhaja De Srair', 'sjt': 'Ter Sami', 'sju': 'Ume Sami', 'sjw': 'Shawnee', 'ska': 'Skagit', 'skb': 'Saek', 'skc': 'Ma Manda', 'skd': 'Southern Sierra Miwok', 'ske': 'Seke', 'skf': 'Sakirabiá', 'skg': 'Sakalava Malagasy', 'skh': 'Sikule', 'ski': 'Sika', 'skj': 'Seke', 'skm': 'Kutong', 'skn': 'Kolibugan Subanon', 'sko': 'Seko Tengah', 'skp': 'Sekapan', 'skq': 'Sininkere', 'skr': 'Saraiki', 'sks': 'Maia', 'skt': 'Sakata', 'sku': 'Sakao', 'skv': 'Skou', 'skw': 'Skepi Creole Dutch', 'skx': 'Seko Padang', 'sky': 'Sikaiana', 'skz': 'Sekar', 'slc': 'Sáliba', 'sld': 'Sissala', 'sle': 'Sholaga', 'slf': 'Swiss-Italian Sign Language', 'slg': 'Selungai Murut', 'slh': 'Southern Puget Sound Salish', 'sli': 'Lower Silesian', 'slj': 'Salumá', 'slk': 'Slovak', 'sll': 'Salt-Yui', 'slm': 'Pangutaran Sama', 'sln': 'Salinan', 'slp': 'Lamaholot', 'slq': 'Salchuq', 'slr': 'Salar', 'sls': 'Singapore Sign Language', 'slt': 'Sila', 'slu': 'Selaru', 'slv': 'Slovenian', 'slw': 'Sialum', 'slx': 'Salampasu', 'sly': 'Selayar', 'slz': "Ma'ya", 'sma': 'Southern Sami', 'smb': 'Simbari', 'smc': 'Som', 'smd': 'Sama', 'sme': 'Northern Sami', 'smf': 'Auwe', 'smg': 'Simbali', 'smh': 'Samei', 'smj': 'Lule Sami', 'smk': 'Bolinao', 'sml': 'Central Sama', 'smm': 'Musasa', 'smn': 'Inari Sami', 'smo': 'Samoan', 'smp': 'Samaritan', 'smq': 'Samo', 'smr': 'Simeulue', 'sms': 'Skolt Sami', 'smt': 'Simte', 'smu': 'Somray', 'smv': 'Samvedi', 'smw': 'Sumbawa', 'smx': 'Samba', 'smy': 'Semnani', 'smz': 'Simeku', 'sna': 'Shona', 'snb': 'Sebuyau', 'snc': 'Sinaugoro', 'snd': 'Sindhi', 'sne': 'Bau Bidayuh', 'snf': 'Noon', 'sng': 'Sanga', 'sni': 'Sensi', 'snj': 'Riverain Sango', 'snk': 'Soninke', 'snl': 'Sangil', 'snm': "Southern Ma'di", 'snn': 'Siona', 'sno': 'Snohomish', 'snp': 'Siane', 'snq': 'Sangu', 'snr': 'Sihan', 'sns': 'South West Bay', 'snu': 'Senggi', 'snv': "Sa'ban", 'snw': 'Selee', 'snx': 'Sam', 'sny': 'Saniyo-Hiyewe', 'snz': 'Kou', 'soa': 'Thai Song', 'sob': 'Sobei', 'soc': 'So', 'sod': 'Songoora', 'soe': 'Songomeno', 'sog': 'Sogdien', 'soh': 'Aka', 'soi': 'Sonha', 'soj': 'Soi', 'sok': 'Sokoro', 'sol': 'Solos', 'som': 'Somali', 'soo': 'Songo', 'sop': 'Songe', 'soq': 'Kanasi', 'sor': 'Somrai', 'sos': 'Seeku', 'sot': 'Southern Sotho', 'sou': 'Southern Thai', 'sov': 'Sonsorol', 'sow': 'Sowanda', 'sox': 'Swo', 'soy': 'Miyobe', 'soz': 'Temi', 'spa': 'Spanish', 'spb': 'Sepa', 'spc': 'Sapé', 'spd': 'Saep', 'spe': 'Sepa', 'spg': 'Sian', 'spi': 'Saponi', 'spk': 'Sengo', 'spl': 'Selepet', 'spm': 'Akukem', 'spn': 'Sanapaná', 'spo': 'Spokane', 'spp': 'Supyire Senoufo', 'spq': 'Loreto-Ucayali Spanish', 'spr': 'Saparua', 'sps': 'Saposa', 'spt': 'Spiti Bhoti', 'spu': 'Sapuan', 'spv': 'Sambalpuri', 'spx': 'South Picene', 'spy': 'Sabaot', 'sqa': 'Shama-Sambuga', 'sqh': 'Shau', 'sqi': 'Albanian', 'sqk': 'Albanian Sign Language', 'sqm': 'Suma', 'sqn': 'Susquehannock', 'sqo': 'Sorkhei', 'sqq': 'Sou', 'sqr': 'Siculo Arabic', 'sqs': 'Sri Lankan Sign Language', 'sqt': 'Soqotri', 'squ': 'Squamish', 'sra': 'Saruga', 'srb': 'Sora', 'src': 'Logudorese Sardinian', 'srd': 'Sardinian', 'sre': 'Sara', 'srf': 'Nafi', 'srg': 'Sulod', 'srh': 'Sarikoli', 'sri': 'Siriano', 'srk': 'Serudung Murut', 'srl': 'Isirawa', 'srm': 'Saramaccan', 'srn': 'Sranan Tongo', 'sro': 'Campidanese Sardinian', 'srp': 'Serbian', 'srq': 'Sirionó', 'srr': 'Serer', 'srs': 'Sarsi', 'srt': 'Sauri', 'sru': 'Suruí', 'srv': 'Southern Sorsoganon', 'srw': 'Serua', 'srx': 'Sirmauri', 'sry': 'Sera', 'srz': 'Shahmirzadi', 'ssb': 'Southern Sama', 'ssc': 'Suba-Simbiti', 'ssd': 'Siroi', 'sse': 'Balangingi', 'ssf': 'Thao', 'ssg': 'Seimat', 'ssh': 'Shihhi Arabic', 'ssi': 'Sansi', 'ssj': 'Sausi', 'ssk': 'Sunam', 'ssl': 'Western Sisaala', 'ssm': 'Semnam', 'ssn': 'Waata', 'sso': 'Sissano', 'ssp': 'Spanish Sign Language', 'ssq': "So'a", 'ssr': 'Swiss-French Sign Language', 'sss': 'Sô', 'sst': 'Sinasina', 'ssu': 'Susuami', 'ssv': 'Shark Bay', 'ssw': 'Swati', 'ssx': 'Samberigi', 'ssy': 'Saho', 'ssz': 'Sengseng', 'sta': 'Settla', 'stb': 'Northern Subanen', 'std': 'Sentinel', 'ste': 'Liana-Seti', 'stf': 'Seta', 'stg': 'Trieng', 'sth': 'Shelta', 'sti': 'Bulo Stieng', 'stj': 'Matya Samo', 'stk': 'Arammba', 'stl': 'Stellingwerfs', 'stm': 'Setaman', 'stn': 'Owa', 'sto': 'Stoney', 'stp': 'Southeastern Tepehuan', 'stq': 'Saterfriesisch', 'str': 'Straits Salish', 'sts': 'Shumashti', 'stt': 'Budeh Stieng', 'stu': 'Samtao', 'stv': "Silt'e", 'stw': 'Satawalese', 'sty': 'Siberian Tatar', 'sua': 'Sulka', 'sub': 'Suku', 'suc': 'Western Subanon', 'sue': 'Suena', 'sug': 'Suganga', 'sui': 'Suki', 'suj': 'Shubi', 'suk': 'Sukuma', 'sun': 'Sundanese', 'suq': 'Suri', 'sur': 'Mwaghavul', 'sus': 'Susu', 'sut': 'Subtiaba', 'suv': 'Puroik', 'suw': 'Sumbwa', 'sux': 'Sumerian', 'suy': 'Suyá', 'suz': 'Sunwar', 'sva': 'Svan', 'svb': 'Ulau-Suain', 'svc': 'Vincentian Creole English', 'sve': 'Serili', 'svk': 'Slovakian Sign Language', 'svm': 'Slavomolisano', 'svs': 'Savosavo', 'svx': 'Skalvian', 'swa': 'Swahili', 'swb': 'Comorian', 'swc': 'Congo Swahili', 'swe': 'Swedish', 'swf': 'Sere', 'swg': 'Swabian', 'swh': 'Swahili', 'swi': 'Sui', 'swj': 'Sira', 'swk': 'Malawi Sena', 'swl': 'Swedish Sign Language', 'swm': 'Samosa', 'swn': 'Sawknah', 'swo': 'Shanenawa', 'swp': 'Suau', 'swq': 'Sharwa', 'swr': 'Saweru', 'sws': 'Seluwasan', 'swt': 'Sawila', 'swu': 'Suwawa', 'swv': 'Shekhawati', 'sww': 'Sowa', 'swx': 'Suruahá', 'swy': 'Sarua', 'sxb': 'Suba', 'sxc': 'Sicanian', 'sxe': 'Sighu', 'sxg': 'Shuhi', 'sxk': 'Southern Kalapuya', 'sxl': 'Selian', 'sxm': 'Samre', 'sxn': 'Sangir', 'sxo': 'Sorothaptic', 'sxr': 'Saaroa', 'sxs': 'Sasaru', 'sxu': 'Upper Saxon', 'sxw': 'Saxwe Gbe', 'sya': 'Siang', 'syb': 'Central Subanen', 'syc': 'Classical Syriac', 'syi': 'Seki', 'syk': 'Sukur', 'syl': 'Sylheti', 'sym': 'Maya Samo', 'syn': 'Senaya', 'syo': 'Suoy', 'syr': 'Syriac', 'sys': 'Sinyar', 'syw': 'Kagate', 'syx': 'Samay', 'syy': 'Al-Sayyid Bedouin Sign Language', 'sza': 'Semelai', 'szb': 'Ngalum', 'szc': 'Semaq Beri', 'szd': 'Seru', 'sze': 'Seze', 'szg': 'Sengele', 'szl': 'Silesian', 'szn': 'Sula', 'szp': 'Suabo', 'szs': 'Solomon Islands Sign Language', 'szv': 'Isu', 'szw': 'Sawai', 'szy': 'Sakizaya', 'taa': 'Lower Tanana', 'tab': 'Tabassaran', 'tac': 'Lowland Tarahumara', 'tad': 'Tause', 'tae': 'Tariana', 'taf': 'Tapirapé', 'tag': 'Tagoi', 'tah': 'Tahitian', 'taj': 'Eastern Tamang', 'tak': 'Tala', 'tal': 'Tal', 'tam': 'Tamil', 'tan': 'Tangale', 'tao': 'Yami', 'tap': 'Taabwa', 'taq': 'Tamasheq', 'tar': 'Central Tarahumara', 'tas': 'Tay Boi', 'tat': 'Tatar', 'tau': 'Upper Tanana', 'tav': 'Tatuyo', 'taw': 'Tai', 'tax': 'Tamki', 'tay': 'Atayal', 'taz': 'Tocho', 'tba': 'Aikanã', 'tbb': 'Tapeba', 'tbc': 'Takia', 'tbd': 'Kaki Ae', 'tbe': 'Tanimbili', 'tbf': 'Mandara', 'tbg': 'North Tairora', 'tbh': 'Dharawal', 'tbi': 'Gaam', 'tbj': 'Tiang', 'tbk': 'Calamian Tagbanwa', 'tbl': 'Tboli', 'tbm': 'Tagbu', 'tbn': 'Barro Negro Tunebo', 'tbo': 'Tawala', 'tbp': 'Taworta', 'tbr': 'Tumtum', 'tbs': 'Tanguat', 'tbt': 'Tembo', 'tbu': 'Tubar', 'tbv': 'Tobo', 'tbw': 'Tagbanwa', 'tbx': 'Kapin', 'tby': 'Tabaru', 'tbz': 'Ditammari', 'tca': 'Ticuna', 'tcb': 'Tanacross', 'tcc': 'Datooga', 'tcd': 'Tafi', 'tce': 'Southern Tutchone', 'tcf': "Malinaltepec Me'phaa", 'tcg': 'Tamagario', 'tch': 'Turks And Caicos Creole English', 'tci': 'Wára', 'tck': 'Tchitchege', 'tcl': 'Taman', 'tcm': 'Tanahmerah', 'tcn': 'Tichurong', 'tco': 'Taungyo', 'tcp': 'Tawr Chin', 'tcq': 'Kaiy', 'tcs': 'Torres Strait Creole', 'tct': "T'en", 'tcu': 'Southeastern Tarahumara', 'tcw': 'Tecpatlán Totonac', 'tcx': 'Toda', 'tcy': 'Tulu', 'tcz': 'Thado Chin', 'tda': 'Tagdal', 'tdb': 'Panchpargania', 'tdc': 'Emberá-Tadó', 'tdd': 'Tai Nüa', 'tde': 'Tiranige Diga Dogon', 'tdf': 'Talieng', 'tdg': 'Western Tamang', 'tdh': 'Thulung', 'tdi': 'Tomadino', 'tdj': 'Tajio', 'tdk': 'Tambas', 'tdl': 'Sur', 'tdm': 'Taruma', 'tdn': 'Tondano', 'tdo': 'Teme', 'tdq': 'Tita', 'tdr': 'Todrah', 'tds': 'Doutai', 'tdt': 'Tetun Dili', 'tdv': 'Toro', 'tdx': 'Tandroy-Mahafaly Malagasy', 'tdy': 'Tadyawan', 'tea': 'Temiar', 'teb': 'Tetete', 'tec': 'Terik', 'ted': 'Tepo Krumen', 'tee': 'Huehuetla Tepehua', 'tef': 'Teressa', 'teg': 'Teke-Tege', 'teh': 'Tehuelche', 'tei': 'Torricelli', 'tek': 'Ibali Teke', 'tel': 'Telugu', 'tem': 'Timne', 'ten': 'Tama', 'teo': 'Teso', 'tep': 'Tepecano', 'teq': 'Temein', 'ter': 'Tereno', 'tes': 'Tengger', 'tet': 'Tetum', 'teu': 'Soo', 'tev': 'Teor', 'tew': 'Tewa', 'tex': 'Tennet', 'tey': 'Tulishi', 'tez': 'Tetserret', 'tfi': 'Tofin Gbe', 'tfn': 'Tanaina', 'tfo': 'Tefaro', 'tfr': 'Teribe', 'tft': 'Ternate', 'tga': 'Sagalla', 'tgb': 'Tobilung', 'tgc': 'Tigak', 'tgd': 'Ciwogai', 'tge': 'Eastern Gorkha Tamang', 'tgf': 'Chalikha', 'tgh': 'Tobagonian Creole English', 'tgi': 'Lawunuia', 'tgj': 'Tagin', 'tgk': 'Tajik', 'tgl': 'Tagalog', 'tgn': 'Tandaganon', 'tgo': 'Sudest', 'tgp': 'Tangoa', 'tgq': 'Tring', 'tgr': 'Tareng', 'tgs': 'Nume', 'tgt': 'Central Tagbanwa', 'tgu': 'Tanggu', 'tgv': 'Tingui-Boto', 'tgw': 'Tagwana Senoufo', 'tgx': 'Tagish', 'tgy': 'Togoyo', 'tgz': 'Tagalaka', 'tha': 'Thai', 'thd': 'Kuuk Thaayorre', 'the': 'Chitwania Tharu', 'thf': 'Thangmi', 'thh': 'Northern Tarahumara', 'thi': 'Tai Long', 'thk': 'Tharaka', 'thl': 'Dangaura Tharu', 'thm': 'Aheu', 'thn': 'Thachanadan', 'thp': 'Thompson', 'thq': 'Kochila Tharu', 'thr': 'Rana Tharu', 'ths': 'Thakali', 'tht': 'Tahltan', 'thu': 'Thuri', 'thv': 'Tahaggart Tamahaq', 'thw': 'Thudam', 'thy': 'Tha', 'thz': 'Tayart Tamajeq', 'tia': 'Tidikelt Tamazight', 'tic': 'Tira', 'tif': 'Tifal', 'tig': 'Tigre', 'tih': 'Timugon Murut', 'tii': 'Tiene', 'tij': 'Tilung', 'tik': 'Tikar', 'til': 'Tillamook', 'tim': 'Timbe', 'tin': 'Tindi', 'tio': 'Teop', 'tip': 'Trimuris', 'tiq': 'Tiéfo', 'tir': 'Tigrinya', 'tis': 'Masadiit Itneg', 'tit': 'Tinigua', 'tiu': 'Adasen', 'tiv': 'Tiv', 'tiw': 'Tiwi', 'tix': 'Southern Tiwa', 'tiy': 'Tiruray', 'tiz': 'Tai Hongjin', 'tja': 'Tajuasohn', 'tjg': 'Tunjung', 'tji': 'Northern Tujia', 'tjj': 'Tjungundji', 'tjl': 'Tai Laing', 'tjm': 'Timucua', 'tjn': 'Tonjon', 'tjo': 'Temacine Tamazight', 'tjp': 'Tjupany', 'tjs': 'Southern Tujia', 'tju': 'Tjurruru', 'tjw': 'Djabwurrung', 'tka': 'Truká', 'tkb': 'Buksa', 'tkd': 'Tukudede', 'tke': 'Takwane', 'tkf': 'Tukumanféd', 'tkg': 'Tesaka Malagasy', 'tkl': 'Tokelau', 'tkm': 'Takelma', 'tkn': 'Toku-No-Shima', 'tkp': 'Tikopia', 'tkq': 'Tee', 'tkr': 'Tsakhur', 'tks': 'Takestani', 'tkt': 'Kathoriya Tharu', 'tku': 'Upper Necaxa Totonac', 'tkv': 'Mur Pano', 'tkw': 'Teanu', 'tkx': 'Tangko', 'tkz': 'Takua', 'tla': 'Southwestern Tepehuan', 'tlb': 'Tobelo', 'tlc': 'Yecuatla Totonac', 'tld': 'Talaud', 'tlf': 'Telefol', 'tlg': 'Tofanma', 'tlh': 'Klingon', 'tli': 'Tlingit', 'tlj': 'Talinga-Bwisi', 'tlk': 'Taloki', 'tll': 'Tetela', 'tlm': 'Tolomako', 'tln': "Talondo'", 'tlo': 'Talodi', 'tlp': 'Filomena Mata-Coahuitlán Totonac', 'tlq': 'Tai Loi', 'tlr': 'Talise', 'tls': 'Tambotalo', 'tlt': 'Sou Nama', 'tlu': 'Tulehu', 'tlv': 'Taliabu', 'tlx': 'Khehek', 'tly': 'Talysh', 'tma': 'Tama', 'tmb': 'Katbol', 'tmc': 'Tumak', 'tmd': 'Haruai', 'tme': 'Tremembé', 'tmf': 'Toba-Maskoy', 'tmg': 'Ternateño', 'tmh': 'Tamashek', 'tmi': 'Tutuba', 'tmj': 'Samarokena', 'tmk': 'Northwestern Tamang', 'tml': 'Tamnim Citak', 'tmm': 'Tai Thanh', 'tmn': 'Taman', 'tmo': 'Temoq', 'tmq': 'Tumleo', 'tmr': 'Jewish Babylonian Aramaic', 'tms': 'Tima', 'tmt': 'Tasmate', 'tmu': 'Iau', 'tmv': 'Tembo', 'tmw': 'Temuan', 'tmy': 'Tami', 'tmz': 'Tamanaku', 'tna': 'Tacana', 'tnb': 'Western Tunebo', 'tnc': 'Tanimuca-Retuarã', 'tnd': 'Angosturas Tunebo', 'tng': 'Tobanga', 'tnh': 'Maiani', 'tni': 'Tandia', 'tnk': 'Kwamera', 'tnl': 'Lenakel', 'tnm': 'Tabla', 'tnn': 'North Tanna', 'tno': 'Toromono', 'tnp': 'Whitesands', 'tnq': 'Taino', 'tnr': 'Ménik', 'tns': 'Tenis', 'tnt': 'Tontemboan', 'tnu': 'Tay Khang', 'tnv': 'Tangchangya', 'tnw': 'Tonsawang', 'tnx': 'Tanema', 'tny': 'Tongwe', 'tnz': "Ten'edn", 'tob': 'Toba', 'toc': 'Coyutla Totonac', 'tod': 'Toma', 'tof': 'Gizrra', 'tog': 'Nyasa Tonga', 'toh': 'Gitonga', 'toi': 'Tonga', 'toj': 'Tojolabal', 'tol': 'Tolowa', 'tom': 'Tombulu', 'ton': 'Tongan', 'too': 'Xicotepec De Juárez Totonac', 'top': 'Papantla Totonac', 'toq': 'Toposa', 'tor': 'Togbo-Vara Banda', 'tos': 'Highland Totonac', 'tou': 'Tho', 'tov': 'Upper Taromi', 'tow': 'Jemez', 'tox': 'Tobian', 'toy': 'Topoiyo', 'toz': 'To', 'tpa': 'Taupota', 'tpc': "Azoyú Me'phaa", 'tpe': 'Tippera', 'tpf': 'Tarpia', 'tpg': 'Kula', 'tpi': 'Tok Pisin', 'tpj': 'Tapieté', 'tpk': 'Tupinikin', 'tpl': "Tlacoapa Me'phaa", 'tpm': 'Tampulma', 'tpn': 'Tupinambá', 'tpo': 'Tai Pao', 'tpp': 'Pisaflores Tepehua', 'tpq': 'Tukpa', 'tpr': 'Tuparí', 'tpt': 'Tlachichilco Tepehua', 'tpu': 'Tampuan', 'tpv': 'Tanapag', 'tpw': 'Tupí', 'tpx': "Acatepec Me'phaa", 'tpy': 'Trumai', 'tpz': 'Tinputz', 'tqb': 'Tembé', 'tql': 'Lehali', 'tqm': 'Turumsa', 'tqn': 'Tenino', 'tqo': 'Toaripi', 'tqp': 'Tomoip', 'tqq': 'Tunni', 'tqr': 'Torona', 'tqt': 'Western Totonac', 'tqu': 'Touo', 'tqw': 'Tonkawa', 'tra': 'Tirahi', 'trb': 'Terebu', 'trc': 'Copala Triqui', 'trd': 'Turi', 'tre': 'East Tarangan', 'trf': 'Trinidadian Creole English', 'trg': 'Lishán Didán', 'trh': 'Turaka', 'tri': 'Trió', 'trj': 'Toram', 'trl': 'Traveller Scottish', 'trm': 'Tregami', 'trn': 'Trinitario', 'tro': 'Tarao Naga', 'trp': 'Kok Borok', 'trq': 'San Martín Itunyoso Triqui', 'trr': 'Taushiro', 'trs': 'Chicahuaxtla Triqui', 'trt': 'Tunggare', 'tru': 'Turoyo', 'trv': 'Taroko', 'trw': 'Torwali', 'trx': 'Tringgus-Sembaan Bidayuh', 'try': 'Turung', 'trz': 'Torá', 'tsa': 'Tsaangi', 'tsb': 'Tsamai', 'tsc': 'Tswa', 'tsd': 'Tsakonian', 'tse': 'Tunisian Sign Language', 'tsg': 'Tausug', 'tsh': 'Tsuvan', 'tsi': 'Tsimshian', 'tsj': 'Tshangla', 'tsk': 'Tseku', 'tsl': "Ts'ün-Lao", 'tsm': 'Turkish Sign Language', 'tsn': 'Tswana', 'tso': 'Tsonga', 'tsp': 'Northern Toussian', 'tsq': 'Thai Sign Language', 'tsr': 'Akei', 'tss': 'Taiwan Sign Language', 'tst': 'Tondi Songway Kiini', 'tsu': 'Tsou', 'tsv': 'Tsogo', 'tsw': 'Tsishingini', 'tsx': 'Mubami', 'tsy': 'Tebul Sign Language', 'tsz': 'Purepecha', 'tta': 'Tutelo', 'ttb': 'Gaa', 'ttc': 'Tektiteko', 'ttd': 'Tauade', 'tte': 'Bwanabwana', 'ttf': 'Tuotomb', 'ttg': 'Tutong', 'tth': "Upper Ta'oih", 'tti': 'Tobati', 'ttj': 'Tooro', 'ttk': 'Totoro', 'ttl': 'Totela', 'ttm': 'Northern Tutchone', 'ttn': 'Towei', 'tto': "Lower Ta'oih", 'ttp': 'Tombelala', 'ttq': 'Tawallammat Tamajaq', 'ttr': 'Tera', 'tts': 'Northeastern Thai', 'ttt': 'Muslim Tat', 'ttu': 'Torau', 'ttv': 'Titan', 'ttw': 'Long Wat', 'tty': 'Sikaritai', 'ttz': 'Tsum', 'tua': 'Wiarumus', 'tub': 'Tübatulabal', 'tuc': 'Mutu', 'tud': 'Tuxá', 'tue': 'Tuyuca', 'tuf': 'Central Tunebo', 'tug': 'Tunia', 'tuh': 'Taulil', 'tui': 'Tupuri', 'tuj': 'Tugutil', 'tuk': 'Turkmen', 'tul': 'Tula', 'tum': 'Tumbuka', 'tun': 'Tunica', 'tuo': 'Tucano', 'tuq': 'Tedaga', 'tur': 'Turkish', 'tus': 'Tuscarora', 'tuu': 'Tututni', 'tuv': 'Turkana', 'tux': 'Tuxináwa', 'tuy': 'Tugen', 'tuz': 'Turka', 'tva': 'Vaghua', 'tvd': 'Tsuvadi', 'tve': "Te'un", 'tvk': 'Southeast Ambrym', 'tvl': 'Tuvalu', 'tvm': 'Tela-Masbuar', 'tvn': 'Tavoyan', 'tvo': 'Tidore', 'tvs': 'Taveta', 'tvt': 'Tutsa Naga', 'tvu': 'Tunen', 'tvw': 'Sedoa', 'tvx': 'Taivoan', 'tvy': 'Timor Pidgin', 'twa': 'Twana', 'twb': 'Western Tawbuid', 'twc': 'Teshenawa', 'twd': 'Twents', 'twe': 'Tewa', 'twf': 'Northern Tiwa', 'twg': 'Tereweng', 'twh': 'Tai Dón', 'twi': 'Twi', 'twl': 'Tawara', 'twm': 'Tawang Monpa', 'twn': 'Twendi', 'two': 'Tswapong', 'twp': 'Ere', 'twq': 'Tasawaq', 'twr': 'Southwestern Tarahumara', 'twt': 'Turiwára', 'twu': 'Termanu', 'tww': 'Tuwari', 'twx': 'Tewe', 'twy': 'Tawoyan', 'txa': 'Tombonuo', 'txb': 'Tokharian B', 'txc': 'Tsetsaut', 'txe': 'Totoli', 'txg': 'Tangut', 'txh': 'Thracian', 'txi': 'Ikpeng', 'txj': 'Tarjumo', 'txm': 'Tomini', 'txn': 'West Tarangan', 'txo': 'Toto', 'txq': 'Tii', 'txr': 'Tartessian', 'txs': 'Tonsea', 'txt': 'Citak', 'txu': 'Kayapó', 'txx': 'Tatana', 'txy': 'Tanosy Malagasy', 'tya': 'Tauya', 'tye': 'Kyanga', 'tyh': "O'du", 'tyi': 'Teke-Tsaayi', 'tyj': 'Tai Do', 'tyl': 'Thu Lao', 'tyn': 'Kombai', 'typ': 'Thaypan', 'tyr': 'Tai Daeng', 'tys': 'Tày Sa Pa', 'tyt': 'Tày Tac', 'tyu': 'Kua', 'tyv': 'Tuvinian', 'tyx': 'Teke-Tyee', 'tyz': 'Tày', 'tza': 'Tanzanian Sign Language', 'tzh': 'Tzeltal', 'tzj': "Tz'utujil", 'tzl': 'Talossan', 'tzm': 'Central Atlas Tamazight', 'tzn': 'Tugun', 'tzo': 'Tzotzil', 'tzx': 'Tabriak', 'uam': 'Uamué', 'uan': 'Kuan', 'uar': 'Tairuma', 'uba': 'Ubang', 'ubi': 'Ubi', 'ubl': "Buhi'non Bikol", 'ubr': 'Ubir', 'ubu': 'Umbu-Ungu', 'uby': 'Ubykh', 'uda': 'Uda', 'ude': 'Udihe', 'udg': 'Muduga', 'udi': 'Udi', 'udj': 'Ujir', 'udl': 'Wuzlam', 'udm': 'Udmurt', 'udu': 'Uduk', 'ues': 'Kioko', 'ufi': 'Ufim', 'uga': 'Ugaritic', 'ugb': 'Kuku-Ugbanh', 'uge': 'Ughele', 'ugn': 'Ugandan Sign Language', 'ugo': 'Ugong', 'ugy': 'Uruguayan Sign Language', 'uha': 'Uhami', 'uhn': 'Damal', 'uig': 'Uyghur', 'uis': 'Uisai', 'uiv': 'Iyive', 'uji': 'Tanjijili', 'uka': 'Kaburi', 'ukg': 'Ukuriguma', 'ukh': 'Ukhwejo', 'ukk': 'Muak Sa-aak', 'ukl': 'Ukrainian Sign Language', 'ukp': 'Ukpe-Bayobiri', 'ukq': 'Ukwa', 'ukr': 'Ukrainian', 'uks': 'Urubú-Kaapor Sign Language', 'uku': 'Ukue', 'ukw': 'Ukwuani-Aboh-Ndoni', 'uky': 'Kuuk-Yak', 'ula': 'Fungwa', 'ulb': 'Ulukwumi', 'ulc': 'Ulch', 'ule': 'Lule', 'ulf': 'Usku', 'uli': 'Ulithian', 'ulk': 'Meriam Mir', 'ull': 'Ullatan', 'ulm': "Ulumanda'", 'uln': 'Unserdeutsch', 'ulu': "Uma' Lung", 'ulw': 'Ulwa', 'uma': 'Umatilla', 'umb': 'Umbundu', 'umc': 'Marrucinian', 'umd': 'Umbindhamu', 'umg': 'Morrobalama', 'umi': 'Ukit', 'umm': 'Umon', 'umn': 'Makyan Naga', 'umo': 'Umotína', 'ump': 'Umpila', 'umr': 'Umbugarla', 'ums': 'Pendau', 'umu': 'Munsee', 'una': 'North Watut', 'und': 'Undetermined', 'une': 'Uneme', 'ung': 'Ngarinyin', 'unk': 'Enawené-Nawé', 'unm': 'Unami', 'unn': 'Kurnai', 'unr': 'Mundari', 'unu': 'Unubahe', 'unx': 'Munda', 'unz': 'Unde Kaili', 'upi': 'Umeda', 'upv': 'Uripiv-Wala-Rano-Atchin', 'ura': 'Urarina', 'urb': 'Urubú-Kaapor', 'urc': 'Urningangg', 'urd': 'Urdu', 'ure': 'Uru', 'urf': 'Uradhi', 'urg': 'Urigina', 'urh': 'Urhobo', 'uri': 'Urim', 'urk': "Urak Lawoi'", 'url': 'Urali', 'urm': 'Urapmin', 'urn': 'Uruangnirin', 'uro': 'Ura', 'urp': 'Uru-Pa-In', 'urr': 'Lehalurup', 'urt': 'Urat', 'uru': 'Urumi', 'urv': 'Uruava', 'urw': 'Sop', 'urx': 'Urimo', 'ury': 'Orya', 'urz': 'Uru-Eu-Wau-Wau', 'usa': 'Usarufa', 'ush': 'Ushojo', 'usi': 'Usui', 'usk': 'Usaghade', 'usp': 'Uspanteco', 'uss': 'us-Saare', 'usu': 'Uya', 'uta': 'Otank', 'ute': 'Ute-Southern Paiute', 'uth': 'ut-Hun', 'utp': 'Amba', 'utr': 'Etulo', 'utu': 'Utu', 'uum': 'Urum', 'uun': 'Kulon-Pazeh', 'uur': 'Ura', 'uuu': 'U', 'uve': 'West Uvean', 'uvh': 'Uri', 'uvl': 'Lote', 'uwa': 'Kuku-Uwanh', 'uya': 'Doko-Uyanga', 'uzb': 'Uzbek', 'uzn': 'Northern Uzbek', 'uzs': 'Southern Uzbek', 'vaa': 'Vaagri Booli', 'vae': 'Vale', 'vaf': 'Vafsi', 'vag': 'Vagla', 'vah': 'Varhadi-Nagpuri', 'vai': 'Vai', 'vaj': 'Sekele', 'val': 'Vehes', 'vam': 'Vanimo', 'van': 'Valman', 'vao': 'Vao', 'vap': 'Vaiphei', 'var': 'Huarijio', 'vas': 'Vasavi', 'vau': 'Vanuma', 'vav': 'Varli', 'vay': 'Wayu', 'vbb': 'Southeast Babar', 'vbk': 'Southwestern Bontok', 'vec': 'Venetian', 'ved': 'Veddah', 'vel': 'Veluws', 'vem': 'Vemgo-Mabas', 'ven': 'Venda', 'veo': 'Ventureño', 'vep': 'Veps', 'ver': 'Mom Jango', 'vgr': 'Vaghri', 'vgt': 'Vlaamse Gebarentaal', 'vic': 'Virgin Islands Creole English', 'vid': 'Vidunda', 'vie': 'Vietnamese', 'vif': 'Vili', 'vig': 'Viemo', 'vil': 'Vilela', 'vin': 'Vinza', 'vis': 'Vishavan', 'vit': 'Viti', 'viv': 'Iduna', 'vka': 'Kariyarra', 'vki': 'Ija-Zuba', 'vkj': 'Kujarge', 'vkk': 'Kaur', 'vkl': 'Kulisusu', 'vkm': 'Kamakan', 'vko': 'Kodeoha', 'vkp': 'Korlai Creole Portuguese', 'vkt': 'Tenggarong Kutai Malay', 'vku': 'Kurrama', 'vlp': 'Valpei', 'vls': 'Vlaams', 'vma': 'Martuyhunira', 'vmb': 'Barbaram', 'vmc': 'Juxtlahuaca Mixtec', 'vmd': 'Mudu Koraga', 'vme': 'East Masela', 'vmf': 'Mainfränkisch', 'vmg': 'Lungalunga', 'vmh': 'Maraghei', 'vmi': 'Miwa', 'vmj': 'Ixtayutla Mixtec', 'vmk': 'Makhuwa-Shirima', 'vml': 'Malgana', 'vmm': 'Mitlatongo Mixtec', 'vmp': 'Soyaltepec Mazatec', 'vmq': 'Soyaltepec Mixtec', 'vmr': 'Marenje', 'vms': 'Moksela', 'vmu': 'Muluridyi', 'vmv': 'Valley Maidu', 'vmw': 'Makhuwa', 'vmx': 'Tamazola Mixtec', 'vmy': 'Ayautla Mazatec', 'vmz': 'Mazatlán Mazatec', 'vnk': 'Vano', 'vnm': 'Vinmavis', 'vnp': 'Vunapu', 'vol': 'Volapük', 'vor': 'Voro', 'vot': 'Votic', 'vra': "Vera'a", 'vro': 'Võro', 'vrs': 'Varisi', 'vrt': 'Burmbar', 'vsi': 'Moldova Sign Language', 'vsl': 'Venezuelan Sign Language', 'vsv': 'Valencian Sign Language', 'vto': 'Vitou', 'vum': 'Vumbu', 'vun': 'Vunjo', 'vut': 'Vute', 'vwa': 'Awa', 'waa': 'Walla Walla', 'wab': 'Wab', 'wac': 'Wasco-Wishram', 'wad': 'Wandamen', 'wae': 'Walser', 'waf': 'Wakoná', 'wag': "Wa'ema", 'wah': 'Watubela', 'wai': 'Wares', 'waj': 'Waffa', 'wal': 'Wolaytta', 'wam': 'Wampanoag', 'wan': 'Wan', 'wao': 'Wappo', 'wap': 'Wapishana', 'waq': 'Wagiman', 'war': 'Waray', 'was': 'Washo', 'wat': 'Kaninuwa', 'wau': 'Waurá', 'wav': 'Waka', 'waw': 'Waiwai', 'wax': 'Watam', 'way': 'Wayana', 'waz': 'Wampur', 'wba': 'Warao', 'wbb': 'Wabo', 'wbe': 'Waritai', 'wbf': 'Wara', 'wbh': 'Wanda', 'wbi': 'Vwanji', 'wbj': 'Alagwa', 'wbk': 'Waigali', 'wbl': 'Wakhi', 'wbm': 'Wa', 'wbp': 'Warlpiri', 'wbq': 'Waddar', 'wbr': 'Wagdi', 'wbs': 'West Bengal Sign Language', 'wbt': 'Warnman', 'wbv': 'Wajarri', 'wbw': 'Woi', 'wca': 'Yanomámi', 'wci': 'Waci Gbe', 'wdd': 'Wandji', 'wdg': 'Wadaginam', 'wdj': 'Wadjiginy', 'wdk': 'Wadikali', 'wdu': 'Wadjigu', 'wdy': 'Wadjabangayi', 'wea': 'Wewaw', 'wec': 'Wè Western', 'wed': 'Wedau', 'weg': 'Wergaia', 'weh': 'Weh', 'wei': 'Kiunum', 'wem': 'Weme Gbe', 'weo': 'Wemale', 'wep': 'Westphalien', 'wer': 'Weri', 'wes': 'Cameroon Pidgin', 'wet': 'Perai', 'weu': 'Rawngtu Chin', 'wew': 'Wejewa', 'wfg': 'Yafi', 'wga': 'Wagaya', 'wgb': 'Wagawaga', 'wgg': 'Wangkangurru', 'wgi': 'Wahgi', 'wgo': 'Waigeo', 'wgu': 'Wirangu', 'wgy': 'Warrgamay', 'wha': 'Sou Upaa', 'whg': 'North Wahgi', 'whk': 'Wahau Kenyah', 'whu': 'Wahau Kayan', 'wib': 'Southern Toussian', 'wic': 'Wichita', 'wie': 'Wik-Epa', 'wif': 'Wik-Keyangan', 'wig': 'Wik Ngathan', 'wih': "Wik-Me'anha", 'wii': 'Minidien', 'wij': 'Wik-Iiyanh', 'wik': 'Wikalkan', 'wil': 'Wilawila', 'wim': 'Wik-Mungkan', 'win': 'Ho-Chunk', 'wir': 'Wiraféd', 'wiu': 'Wiru', 'wiv': 'Vitu', 'wiy': 'Wiyot', 'wja': 'Waja', 'wji': 'Warji', 'wka': "Kw'adza", 'wkb': 'Kumbaran', 'wkd': 'Wakde', 'wkl': 'Kalanadi', 'wkr': 'Keerray-Woorroong', 'wku': 'Kunduvadi', 'wkw': 'Wakawaka', 'wky': 'Wangkayutyuru', 'wla': 'Walio', 'wlc': 'Mwali Comorian', 'wle': 'Wolane', 'wlg': 'Kunbarlang', 'wli': 'Waioli', 'wlk': 'Wailaki', 'wll': 'Wali', 'wlm': 'Middle Welsh', 'wln': 'Walloon', 'wlo': 'Wolio', 'wlr': 'Wailapa', 'wls': 'Wallisian', 'wlu': 'Wuliwuli', 'wlv': 'Wichí Lhamtés Vejoz', 'wlw': 'Walak', 'wlx': 'Wali', 'wly': 'Waling', 'wma': 'Mawa', 'wmb': 'Wambaya', 'wmc': 'Wamas', 'wmd': 'Mamaindé', 'wme': 'Wambule', 'wmh': "Waima'a", 'wmi': 'Wamin', 'wmm': 'Maiwa', 'wmn': 'Waamwang', 'wmo': 'Wom', 'wms': 'Wambon', 'wmt': 'Walmajarri', 'wmw': 'Mwani', 'wmx': 'Womo', 'wnb': 'Wanambre', 'wnc': 'Wantoat', 'wnd': 'Wandarang', 'wne': 'Waneci', 'wng': 'Wanggom', 'wni': 'Ndzwani Comorian', 'wnk': 'Wanukaka', 'wnm': 'Wanggamala', 'wnn': 'Wunumara', 'wno': 'Wano', 'wnp': 'Wanap', 'wnu': 'Usan', 'wnw': 'Wintu', 'wny': 'Wanyi', 'woa': 'Kuwema', 'wob': 'Wè Northern', 'woc': 'Wogeo', 'wod': 'Wolani', 'woe': 'Woleaian', 'wof': 'Gambian Wolof', 'wog': 'Wogamusin', 'woi': 'Kamang', 'wok': 'Longto', 'wol': 'Wolof', 'wom': 'Wom', 'won': 'Wongo', 'woo': 'Manombai', 'wor': 'Woria', 'wos': 'Hanga Hundi', 'wow': 'Wawonii', 'woy': 'Weyto', 'wpc': 'Maco', 'wra': 'Warapu', 'wrb': 'Waluwarra', 'wrd': 'Warduji', 'wrg': 'Warungu', 'wrh': 'Wiradjuri', 'wri': 'Wariyangga', 'wrk': 'Garrwa', 'wrl': 'Warlmanpa', 'wrm': 'Warumungu', 'wrn': 'Warnang', 'wro': 'Worrorra', 'wrp': 'Waropen', 'wrr': 'Wardaman', 'wrs': 'Waris', 'wru': 'Waru', 'wrv': 'Waruna', 'wrw': 'Gugu Warra', 'wrx': 'Wae Rana', 'wry': 'Merwari', 'wrz': 'Waray', 'wsa': 'Warembori', 'wsg': 'Adilabad Gondi', 'wsi': 'Wusi', 'wsk': 'Waskia', 'wsr': 'Owenia', 'wss': 'Wasa', 'wsu': 'Wasu', 'wsv': 'Wotapuri-Katarqalai', 'wtf': 'Watiwa', 'wth': 'Wathawurrung', 'wti': 'Berta', 'wtk': 'Watakataui', 'wtm': 'Mewati', 'wtw': 'Wotu', 'wua': 'Wikngenchera', 'wub': 'Wunambal', 'wud': 'Wudu', 'wuh': 'Wutunhua', 'wul': 'Silimo', 'wum': 'Wumbvu', 'wun': 'Bungu', 'wur': 'Wurrugu', 'wut': 'Wutung', 'wuu': 'Wu Chinese', 'wuv': 'Wuvulu-Aua', 'wux': 'Wulna', 'wuy': 'Wauyai', 'wwa': 'Waama', 'wwb': 'Wakabunga', 'wwo': 'Wetamut', 'wwr': 'Warrwa', 'www': 'Wawa', 'wxa': 'Waxianghua', 'wxw': 'Wardandi', 'wya': 'Wyandot', 'wyb': 'Wangaaybuwan-Ngiyambaa', 'wyi': 'Woiwurrung', 'wym': 'Wymysorys', 'wyr': 'Wayoró', 'wyy': 'Western Fijian', 'xaa': 'Andalusian Arabic', 'xab': 'Sambe', 'xac': 'Kachari', 'xad': 'Adai', 'xae': 'Aequian', 'xag': 'Aghwan', 'xai': 'Kaimbé', 'xaj': 'Ararandewára', 'xak': 'Máku', 'xal': 'Kalmyk', 'xam': 'ǀXam', 'xan': 'Xamtanga', 'xao': 'Khao', 'xap': 'Apalachee', 'xaq': 'Aquitanian', 'xar': 'Karami', 'xas': 'Kamas', 'xat': 'Katawixi', 'xau': 'Kauwera', 'xav': 'Xavánte', 'xaw': 'Kawaiisu', 'xay': 'Kayan Mahakam', 'xbb': 'Lower Burdekin', 'xbc': 'Bactrian', 'xbd': 'Bindal', 'xbe': 'Bigambal', 'xbg': 'Bunganditj', 'xbi': 'Kombio', 'xbj': 'Birrpayi', 'xbm': 'Middle Breton', 'xbn': 'Kenaboi', 'xbo': 'Bolgarian', 'xbp': 'Bibbulman', 'xbr': 'Kambera', 'xbw': 'Kambiwá', 'xby': 'Batjala', 'xcb': 'Cumbric', 'xcc': 'Camunic', 'xce': 'Celtiberian', 'xcg': 'Cisalpine Gaulish', 'xch': 'Chemakum', 'xcl': 'Classical Armenian', 'xcm': 'Comecrudo', 'xcn': 'Cotoname', 'xco': 'Chorasmian', 'xcr': 'Carian', 'xct': 'Classical Tibetan', 'xcu': 'Curonian', 'xcv': 'Chuvantsy', 'xcw': 'Coahuilteco', 'xcy': 'Cayuse', 'xda': 'Darkinyung', 'xdc': 'Dacian', 'xdk': 'Dharuk', 'xdm': 'Edomite', 'xdo': 'Kwandu', 'xdy': 'Malayic Dayak', 'xeb': 'Eblan', 'xed': 'Hdi', 'xeg': 'ǁXegwi', 'xel': 'Kelo', 'xem': 'Kembayan', 'xep': 'Epi-Olmec', 'xer': 'Xerénte', 'xes': 'Kesawai', 'xet': 'Xetá', 'xeu': 'Keoru-Ahia', 'xfa': 'Faliscan', 'xga': 'Galatian', 'xgb': 'Gbin', 'xgd': 'Gudang', 'xgf': 'Gabrielino-Fernandeño', 'xgg': 'Goreng', 'xgi': 'Garingbal', 'xgl': 'Galindan', 'xgm': 'Dharumbal', 'xgr': 'Garza', 'xgu': 'Unggumi', 'xgw': 'Guwa', 'xha': 'Harami', 'xhc': 'Hunnic', 'xhd': 'Hadrami', 'xhe': 'Khetrani', 'xho': 'Xhosa', 'xhr': 'Hernican', 'xht': 'Hattic', 'xhu': 'Hurrian', 'xhv': 'Khua', 'xib': 'Iberian', 'xii': 'Xiri', 'xil': 'Illyrian', 'xin': 'Xinca', 'xir': 'Xiriâna', 'xis': 'Kisan', 'xiv': 'Indus Valley Language', 'xiy': 'Xipaya', 'xjb': 'Minjungbal', 'xjt': 'Jaitmatang', 'xka': 'Kalkoti', 'xkb': 'Northern Nago', 'xkc': "Kho'ini", 'xkd': 'Mendalam Kayan', 'xke': 'Kereho', 'xkf': 'Khengkha', 'xkg': 'Kagoro', 'xki': 'Kenyan Sign Language', 'xkj': 'Kajali', 'xkk': "Kaco'", 'xkl': 'Mainstream Kenyah', 'xkn': 'Kayan River Kayan', 'xko': 'Kiorr', 'xkp': 'Kabatei', 'xkq': 'Koroni', 'xkr': 'Xakriabá', 'xks': 'Kumbewaha', 'xkt': 'Kantosi', 'xku': 'Kaamba', 'xkv': 'Kgalagadi', 'xkw': 'Kembra', 'xkx': 'Karore', 'xky': "Uma' Lasan", 'xkz': 'Kurtokha', 'xla': 'Kamula', 'xlb': 'Loup B', 'xlc': 'Lycian', 'xld': 'Lydian', 'xle': 'Lemnian', 'xlg': 'Ligurian', 'xli': 'Liburnian', 'xln': 'Alanic', 'xlo': 'Loup A', 'xlp': 'Lepontic', 'xls': 'Lusitanian', 'xlu': 'Cuneiform Luwian', 'xly': 'Elymian', 'xma': 'Mushungulu', 'xmb': 'Mbonga', 'xmc': 'Makhuwa-Marrevone', 'xmd': 'Mbudum', 'xme': 'Median', 'xmf': 'Mingrelian', 'xmg': 'Mengaka', 'xmh': 'Kugu-Muminh', 'xmj': 'Majera', 'xmk': 'Ancient Macedonian', 'xml': 'Malaysian Sign Language', 'xmm': 'Manado Malay', 'xmn': 'Manichaean Middle Persian', 'xmo': 'Morerebi', 'xmp': "Kuku-Mu'inh", 'xmq': 'Kuku-Mangk', 'xmr': 'Meroitic', 'xms': 'Moroccan Sign Language', 'xmt': 'Matbat', 'xmu': 'Kamu', 'xmv': 'Antankarana Malagasy', 'xmw': 'Tsimihety Malagasy', 'xmx': 'Maden', 'xmy': 'Mayaguduna', 'xmz': 'Mori Bawah', 'xna': 'Ancient North Arabian', 'xnb': 'Kanakanabu', 'xng': 'Middle Mongolian', 'xnh': 'Kuanhua', 'xni': 'Ngarigu', 'xnk': 'Nganakarti', 'xnn': 'Northern Kankanay', 'xno': 'Anglo-Norman', 'xnr': 'Kangri', 'xns': 'Kanashi', 'xnt': 'Narragansett', 'xnu': 'Nukunul', 'xny': 'Nyiyaparli', 'xnz': 'Kenzi', 'xoc': "O'chi'chi'", 'xod': 'Kokoda', 'xog': 'Soga', 'xoi': 'Kominimung', 'xok': 'Xokleng', 'xom': 'Komo', 'xon': 'Konkomba', 'xoo': 'Xukurú', 'xop': 'Kopar', 'xor': 'Korubo', 'xow': 'Kowaki', 'xpa': 'Pirriya', 'xpc': 'Pecheneg', 'xpe': 'Liberia Kpelle', 'xpg': 'Phrygian', 'xpi': 'Pictish', 'xpj': 'Mpalitjanh', 'xpk': 'Kulina Pano', 'xpm': 'Pumpokol', 'xpn': 'Kapinawá', 'xpo': 'Pochutec', 'xpp': 'Puyo-Paekche', 'xpq': 'Mohegan-Pequot', 'xpr': 'Parthian', 'xps': 'Pisidian', 'xpt': 'Punthamara', 'xpu': 'Punic', 'xpy': 'Puyo', 'xqa': 'Karakhanid', 'xqt': 'Qatabanian', 'xra': 'Krahô', 'xrb': 'Eastern Karaboro', 'xrd': 'Gundungurra', 'xre': 'Kreye', 'xrg': 'Minang', 'xri': 'Krikati-Timbira', 'xrm': 'Armazic', 'xrn': 'Arin', 'xrq': 'Karranga', 'xrr': 'Raetic', 'xrt': 'Aranama-Tamique', 'xru': 'Marriammu', 'xrw': 'Karawa', 'xsa': 'Sabaean', 'xsb': 'Sambal', 'xsc': 'Scythian', 'xsd': 'Sidetic', 'xse': 'Sempan', 'xsh': 'Shamang', 'xsi': 'Sio', 'xsj': 'Subi', 'xsl': 'South Slavey', 'xsm': 'Kasem', 'xsn': 'Sanga', 'xso': 'Solano', 'xsp': 'Silopi', 'xsq': 'Makhuwa-Saka', 'xsr': 'Sherpa', 'xss': 'Assan', 'xsu': 'Sanumá', 'xsv': 'Sudovian', 'xsy': 'Saisiyat', 'xta': 'Alcozauca Mixtec', 'xtb': 'Chazumba Mixtec', 'xtc': 'Katcha-Kadugli-Miri', 'xtd': 'Diuxi-Tilantongo Mixtec', 'xte': 'Ketengban', 'xtg': 'Transalpine Gaulish', 'xth': 'Yitha Yitha', 'xti': 'Sinicahua Mixtec', 'xtj': 'San Juan Teita Mixtec', 'xtl': 'Tijaltepec Mixtec', 'xtm': 'Magdalena Peñasco Mixtec', 'xtn': 'Northern Tlaxiaco Mixtec', 'xto': 'Tokharian A', 'xtp': 'San Miguel Piedras Mixtec', 'xtq': 'Tumshuqese', 'xtr': 'Early Tripuri', 'xts': 'Sindihui Mixtec', 'xtt': 'Tacahua Mixtec', 'xtu': 'Cuyamecalco Mixtec', 'xtv': 'Thawa', 'xtw': 'Tawandê', 'xty': 'Yoloxochitl Mixtec', 'xtz': 'Tasmanian', 'xua': 'Alu Kurumba', 'xub': 'Betta Kurumba', 'xud': 'Umiida', 'xug': 'Kunigami', 'xuj': 'Jennu Kurumba', 'xul': 'Ngunawal', 'xum': 'Umbrian', 'xun': 'Unggaranggu', 'xuo': 'Kuo', 'xup': 'Upper Umpqua', 'xur': 'Urartian', 'xut': 'Kuthant', 'xuu': 'Kxoe', 'xve': 'Venetic', 'xvi': 'Kamviri', 'xvn': 'Vandalic', 'xvo': 'Volscian', 'xvs': 'Vestinian', 'xwa': 'Kwaza', 'xwc': 'Woccon', 'xwd': 'Wadi Wadi', 'xwe': 'Xwela Gbe', 'xwg': 'Kwegu', 'xwj': 'Wajuk', 'xwk': 'Wangkumara', 'xwl': 'Western Xwla Gbe', 'xwo': 'Written Oirat', 'xwr': 'Kwerba Mamberamo', 'xwt': 'Wotjobaluk', 'xww': 'Wemba Wemba', 'xxb': 'Boro', 'xxk': "Ke'o", 'xxm': 'Minkin', 'xxr': 'Koropó', 'xxt': 'Tambora', 'xya': 'Yaygir', 'xyb': 'Yandjibara', 'xyj': 'Mayi-Yapi', 'xyk': 'Mayi-Kulan', 'xyl': 'Yalakalore', 'xyt': 'Mayi-Thakurti', 'xyy': 'Yorta Yorta', 'xzh': 'Zhang-Zhung', 'xzm': 'Zemgalian', 'xzp': 'Ancient Zapotec', 'yaa': 'Yaminahua', 'yab': 'Yuhup', 'yac': 'Pass Valley Yali', 'yad': 'Yagua', 'yae': 'Pumé', 'yaf': 'Yaka', 'yag': 'Yámana', 'yah': 'Yazgulyam', 'yai': 'Yagnobi', 'yaj': 'Banda-Yangere', 'yak': 'Yakama', 'yal': 'Yalunka', 'yam': 'Yamba', 'yan': 'Mayangna', 'yao': 'Yao', 'yap': 'Yapese', 'yaq': 'Yaqui', 'yar': 'Yabarana', 'yas': 'Nugunu', 'yat': 'Yambeta', 'yau': 'Yuwana', 'yav': 'Yangben', 'yaw': 'Yawalapití', 'yax': 'Yauma', 'yay': 'Agwagwune', 'yaz': 'Lokaa', 'yba': 'Yala', 'ybb': 'Yemba', 'ybe': 'West Yugur', 'ybh': 'Yakha', 'ybi': 'Yamphu', 'ybj': 'Hasha', 'ybk': 'Bokha', 'ybl': 'Yukuben', 'ybm': 'Yaben', 'ybn': 'Yabaâna', 'ybo': 'Yabong', 'ybx': 'Yawiyo', 'yby': 'Yaweyuha', 'ych': 'Chesu', 'ycl': 'Lolopo', 'ycn': 'Yucuna', 'ycp': 'Chepya', 'yda': 'Yanda', 'ydd': 'Eastern Yiddish', 'yde': 'Yangum Dey', 'ydg': 'Yidgha', 'ydk': 'Yoidik', 'yea': 'Ravula', 'yec': 'Yeniche', 'yee': 'Yimas', 'yei': 'Yeni', 'yej': 'Yevanic', 'yel': 'Yela', 'yer': 'Tarok', 'yes': 'Nyankpa', 'yet': 'Yetfa', 'yeu': 'Yerukula', 'yev': 'Yapunda', 'yey': 'Yeyi', 'yga': 'Malyangapa', 'ygi': 'Yiningayi', 'ygl': 'Yangum Gel', 'ygm': 'Yagomi', 'ygp': 'Gepo', 'ygr': 'Yagaria', 'ygs': 'Yolŋu Sign Language', 'ygu': 'Yugul', 'ygw': 'Yagwoia', 'yha': 'Baha Buyang', 'yhd': 'Judeo-Iraqi Arabic', 'yhl': 'Hlepho Phowa', 'yhs': 'Yan-nhaŋu Sign Language', 'yia': 'Yinggarda', 'yid': 'Yiddish', 'yif': 'Ache', 'yig': 'Wusa Nasu', 'yih': 'Western Yiddish', 'yii': 'Yidiny', 'yij': 'Yindjibarndi', 'yik': 'Dongshanba Lalo', 'yil': 'Yindjilandji', 'yim': 'Yimchungru Naga', 'yin': 'Riang Lai', 'yip': 'Pholo', 'yiq': 'Miqie', 'yir': 'North Awyu', 'yis': 'Yis', 'yit': 'Eastern Lalu', 'yiu': 'Awu', 'yiv': 'Northern Nisu', 'yix': 'Axi Yi', 'yiz': 'Azhe', 'yka': 'Yakan', 'ykg': 'Northern Yukaghir', 'yki': 'Yoke', 'ykk': 'Yakaikeke', 'ykl': 'Khlula', 'ykm': 'Kap', 'ykn': 'Kua-nsi', 'yko': 'Yasa', 'ykr': 'Yekora', 'ykt': 'Kathu', 'yku': 'Kuamasi', 'yky': 'Yakoma', 'yla': 'Yaul', 'ylb': 'Yaleba', 'yle': 'Yele', 'ylg': 'Yelogu', 'yli': 'Angguruk Yali', 'yll': 'Yil', 'ylm': 'Limi', 'yln': 'Langnian Buyang', 'ylo': 'Naluo Yi', 'ylr': 'Yalarnnga', 'ylu': 'Aribwaung', 'yly': 'Nyâlayu', 'ymb': 'Yambes', 'ymc': 'Southern Muji', 'ymd': 'Muda', 'yme': 'Yameo', 'ymg': 'Yamongeri', 'ymh': 'Mili', 'ymi': 'Moji', 'ymk': 'Makwe', 'yml': 'Iamalele', 'ymm': 'Maay', 'ymn': 'Yamna', 'ymo': 'Yangum Mon', 'ymp': 'Yamap', 'ymq': 'Qila Muji', 'ymr': 'Malasar', 'yms': 'Mysian', 'ymx': 'Northern Muji', 'ymz': 'Muzi', 'yna': 'Aluo', 'ynd': 'Yandruwandha', 'yne': "Lang'e", 'yng': 'Yango', 'ynk': 'Naukan Yupik', 'ynl': 'Yangulam', 'ynn': 'Yana', 'yno': 'Yong', 'ynq': 'Yendang', 'yns': 'Yansi', 'ynu': 'Yahuna', 'yob': 'Yoba', 'yog': 'Yogad', 'yoi': 'Yonaguni', 'yok': 'Yokuts', 'yol': 'Yola', 'yom': 'Yombe', 'yon': 'Yongkom', 'yor': 'Yoruba', 'yot': 'Yotti', 'yox': 'Yoron', 'yoy': 'Yoy', 'ypa': 'Phala', 'ypb': 'Labo Phowa', 'ypg': 'Phola', 'yph': 'Phupha', 'ypm': 'Phuma', 'ypn': 'Ani Phowa', 'ypo': 'Alo Phola', 'ypp': 'Phupa', 'ypz': 'Phuza', 'yra': 'Yerakai', 'yrb': 'Yareba', 'yre': 'Yaouré', 'yrk': 'Nenets', 'yrl': 'Nhengatu', 'yrm': 'Yirrk-Mel', 'yrn': 'Yerong', 'yro': 'Yaroamë', 'yrs': 'Yarsun', 'yrw': 'Yarawata', 'yry': 'Yarluyandi', 'ysc': 'Yassic', 'ysd': 'Samatao', 'ysg': 'Sonaga', 'ysl': 'Yugoslavian Sign Language', 'ysn': 'Sani', 'yso': 'Nisi', 'ysp': 'Southern Lolopo', 'ysr': 'Sirenik Yupik', 'yss': 'Yessan-Mayo', 'ysy': 'Sanie', 'yta': 'Talu', 'ytl': 'Tanglang', 'ytp': 'Thopho', 'ytw': 'Yout Wam', 'yty': 'Yatay', 'yua': 'Yucateco', 'yub': 'Yugambal', 'yuc': 'Yuchi', 'yud': 'Judeo-Tripolitanian Arabic', 'yue': 'Cantonese', 'yuf': 'Havasupai-Walapai-Yavapai', 'yug': 'Yug', 'yui': 'Yurutí', 'yuj': 'Karkar-Yuri', 'yuk': 'Yuki', 'yul': 'Yulu', 'yum': 'Quechan', 'yun': 'Bena', 'yup': 'Yukpa', 'yuq': 'Yuqui', 'yur': 'Yurok', 'yut': 'Yopno', 'yuw': 'Yau', 'yux': 'Southern Yukaghir', 'yuy': 'East Yugur', 'yuz': 'Yuracare', 'yva': 'Yawa', 'yvt': 'Yavitero', 'ywa': 'Kalou', 'ywg': 'Yinhawangka', 'ywl': 'Western Lalu', 'ywn': 'Yawanawa', 'ywq': 'Wuding-Luquan Yi', 'ywr': 'Yawuru', 'ywt': 'Xishanba Lalo', 'ywu': 'Wumeng Nasu', 'yww': 'Yawarawarga', 'yxa': 'Mayawali', 'yxg': 'Yagara', 'yxl': 'Yardliyawarra', 'yxm': 'Yinwum', 'yxu': 'Yuyu', 'yxy': 'Yabula Yabula', 'yyr': 'Yir Yoront', 'yyu': 'Yau', 'yyz': 'Ayizi', 'yzg': "E'ma Buyang", 'yzk': 'Zokhuo', 'zaa': 'Sierra de Juárez Zapotec', 'zab': 'Western Tlacolula Valley Zapotec', 'zac': 'Ocotlán Zapotec', 'zad': 'Cajonos Zapotec', 'zae': 'Yareni Zapotec', 'zaf': 'Ayoquesco Zapotec', 'zag': 'Zaghawa', 'zah': 'Zangwal', 'zai': 'Isthmus Zapotec', 'zaj': 'Zaramo', 'zak': 'Zanaki', 'zal': 'Zauzou', 'zam': 'Miahuatlán Zapotec', 'zao': 'Ozolotepec Zapotec', 'zap': 'Zapotec', 'zaq': 'Aloápam Zapotec', 'zar': 'Rincón Zapotec', 'zas': 'Santo Domingo Albarradas Zapotec', 'zat': 'Tabaa Zapotec', 'zau': 'Zangskari', 'zav': 'Yatzachi Zapotec', 'zaw': 'Mitla Zapotec', 'zax': 'Xadani Zapotec', 'zay': 'Zayse-Zergulla', 'zaz': 'Zari', 'zbc': 'Central Berawan', 'zbe': 'East Berawan', 'zbl': 'Blissymbols', 'zbt': 'Batui', 'zbw': 'West Berawan', 'zca': 'Coatecas Altas Zapotec', 'zch': 'Central Hongshuihe Zhuang', 'zdj': 'Ngazidja Comorian', 'zea': 'Zeeuws', 'zeg': 'Zenag', 'zeh': 'Eastern Hongshuihe Zhuang', 'zen': 'Zenaga', 'zga': 'Kinga', 'zgb': 'Guibei Zhuang', 'zgh': 'Standard Moroccan Tamazight', 'zgm': 'Minz Zhuang', 'zgn': 'Guibian Zhuang', 'zgr': 'Magori', 'zha': 'Zhuang', 'zhb': 'Zhaba', 'zhd': 'Dai Zhuang', 'zhi': 'Zhire', 'zhn': 'Nong Zhuang', 'zho': 'Chinese', 'zhw': 'Zhoa', 'zia': 'Zia', 'zib': 'Zimbabwe Sign Language', 'zik': 'Zimakani', 'zil': 'Zialo', 'zim': 'Mesme', 'zin': 'Zinza', 'zir': 'Ziriya', 'ziw': 'Zigula', 'ziz': 'Zizilivakan', 'zka': 'Kaimbulawa', 'zkb': 'Koibal', 'zkd': 'Kadu', 'zkg': 'Koguryo', 'zkh': 'Khorezmian', 'zkk': 'Karankawa', 'zkn': 'Kanan', 'zko': 'Kott', 'zkp': 'São Paulo Kaingáng', 'zkr': 'Zakhring', 'zkt': 'Kitan', 'zku': 'Kaurna', 'zkv': 'Krevinian', 'zkz': 'Khazar', 'zlj': 'Liujiang Zhuang', 'zlm': 'Malay', 'zln': 'Lianshan Zhuang', 'zlq': 'Liuqian Zhuang', 'zma': 'Manda', 'zmb': 'Zimba', 'zmc': 'Margany', 'zmd': 'Maridan', 'zme': 'Mangerr', 'zmf': 'Mfinu', 'zmg': 'Marti Ke', 'zmh': 'Makolkol', 'zmi': 'Negeri Sembilan Malay', 'zmj': 'Maridjabin', 'zmk': 'Mandandanyi', 'zml': 'Matngala', 'zmm': 'Marimanindji', 'zmn': 'Mbangwe', 'zmo': 'Molo', 'zmp': 'Mpuono', 'zmq': 'Mituku', 'zmr': 'Maranunggu', 'zms': 'Mbesa', 'zmt': 'Maringarr', 'zmu': 'Muruwari', 'zmv': 'Mbariman-Gudhinma', 'zmw': 'Mbo', 'zmx': 'Bomitaba', 'zmy': 'Mariyedi', 'zmz': 'Mbandja', 'zna': 'Zan Gula', 'zne': 'Zande', 'zng': 'Mang', 'znk': 'Manangkari', 'zns': 'Mangas', 'zoc': 'Copainalá Zoque', 'zoh': 'Chimalapa Zoque', 'zom': 'Zou', 'zoo': 'Asunción Mixtepec Zapotec', 'zoq': 'Tabasco Zoque', 'zor': 'Rayón Zoque', 'zos': 'Francisco León Zoque', 'zpa': 'Lachiguiri Zapotec', 'zpb': 'Yautepec Zapotec', 'zpc': 'Choapan Zapotec', 'zpd': 'Southeastern Ixtlán Zapotec', 'zpe': 'Petapa Zapotec', 'zpf': 'San Pedro Quiatoni Zapotec', 'zpg': 'Guevea De Humboldt Zapotec', 'zph': 'Totomachapan Zapotec', 'zpi': 'Santa María Quiegolani Zapotec', 'zpj': 'Quiavicuzas Zapotec', 'zpk': 'Tlacolulita Zapotec', 'zpl': 'Lachixío Zapotec', 'zpm': 'Mixtepec Zapotec', 'zpn': 'Santa Inés Yatzechi Zapotec', 'zpo': 'Amatlán Zapotec', 'zpp': 'El Alto Zapotec', 'zpq': 'Zoogocho Zapotec', 'zpr': 'Santiago Xanica Zapotec', 'zps': 'Coatlán Zapotec', 'zpt': 'San Vicente Coatlán Zapotec', 'zpu': 'Yalálag Zapotec', 'zpv': 'Chichicapan Zapotec', 'zpw': 'Zaniza Zapotec', 'zpx': 'San Baltazar Loxicha Zapotec', 'zpy': 'Mazaltepec Zapotec', 'zpz': 'Texmelucan Zapotec', 'zqe': 'Qiubei Zhuang', 'zra': 'Kara', 'zrg': 'Mirgan', 'zrn': 'Zerenkel', 'zro': 'Záparo', 'zrp': 'Zarphatic', 'zrs': 'Mairasi', 'zsa': 'Sarasira', 'zsk': 'Kaskean', 'zsl': 'Zambian Sign Language', 'zsm': 'Standard Malay', 'zsr': 'Southern Rincon Zapotec', 'zsu': 'Sukurum', 'zte': 'Elotepec Zapotec', 'ztg': 'Xanaguía Zapotec', 'ztl': 'Lapaguía-Guivini Zapotec', 'ztm': 'San Agustín Mixtepec Zapotec', 'ztn': 'Santa Catarina Albarradas Zapotec', 'ztp': 'Loxicha Zapotec', 'ztq': 'Quioquitani-Quierí Zapotec', 'zts': 'Tilquiapan Zapotec', 'ztt': 'Tejalapan Zapotec', 'ztu': 'Güilá Zapotec', 'ztx': 'Zaachila Zapotec', 'zty': 'Yatee Zapotec', 'zua': 'Zeem', 'zuh': 'Tokano', 'zul': 'Zulu', 'zum': 'Kumzari', 'zun': 'Zuni', 'zuy': 'Zumaya', 'zwa': 'Zay', 'zxx': 'No linguistic content', 'zyb': 'Yongbei Zhuang', 'zyg': 'Yang Zhuang', 'zyj': 'Youjiang Zhuang', 'zyn': 'Yongnan Zhuang', 'zyp': 'Zyphe Chin', 'zza': 'Zaza', 'zzj': 'Zuojiang Zhuang'}  # noqa: E501
iso639_codes = {'': 'zzj', 'aa': 'aar', 'ab': 'abk', 'af': 'afr', 'ak': 'aka', 'am': 'amh', 'ar': 'ara', 'an': 'arg', 'as': 'asm', 'av': 'ava', 'ae': 'ave', 'ay': 'aym', 'az': 'aze', 'ba': 'bak', 'bm': 'bam', 'be': 'bel', 'bn': 'ben', 'bi': 'bis', 'bo': 'bod', 'bs': 'bos', 'br': 'bre', 'bg': 'bul', 'ca': 'cat', 'cs': 'ces', 'ch': 'cha', 'ce': 'che', 'cu': 'chu', 'cv': 'chv', 'kw': 'cor', 'co': 'cos', 'cr': 'cre', 'cy': 'cym', 'da': 'dan', 'de': 'deu', 'dv': 'div', 'dz': 'dzo', 'el': 'ell', 'en': 'eng', 'eo': 'epo', 'et': 'est', 'eu': 'eus', 'ee': 'ewe', 'fo': 'fao', 'fa': 'fas', 'fj': 'fij', 'fi': 'fin', 'fr': 'fra', 'fy': 'fry', 'ff': 'ful', 'gd': 'gla', 'ga': 'gle', 'gl': 'glg', 'gv': 'glv', 'gn': 'grn', 'gu': 'guj', 'ht': 'hat', 'ha': 'hau', 'sh': 'hbs', 'he': 'heb', 'hz': 'her', 'hi': 'hin', 'ho': 'hmo', 'hr': 'hrv', 'hu': 'hun', 'hy': 'hye', 'ig': 'ibo', 'io': 'ido', 'ii': 'iii', 'iu': 'iku', 'ie': 'ile', 'ia': 'ina', 'id': 'ind', 'ik': 'ipk', 'is': 'isl', 'it': 'ita', 'jv': 'jav', 'ja': 'jpn', 'kl': 'kal', 'kn': 'kan', 'ks': 'kas', 'ka': 'kat', 'kr': 'kau', 'kk': 'kaz', 'km': 'khm', 'ki': 'kik', 'rw': 'kin', 'ky': 'kir', 'kv': 'kom', 'kg': 'kon', 'ko': 'kor', 'kj': 'kua', 'ku': 'kur', 'lo': 'lao', 'la': 'lat', 'lv': 'lav', 'li': 'lim', 'ln': 'lin', 'lt': 'lit', 'lb': 'ltz', 'lu': 'lub', 'lg': 'lug', 'mh': 'mah', 'ml': 'mal', 'mr': 'mar', 'mk': 'mkd', 'mg': 'mlg', 'mt': 'mlt', 'mn': 'mon', 'mi': 'mri', 'ms': 'msa', 'my': 'mya', 'na': 'nau', 'nv': 'nav', 'nr': 'nbl', 'nd': 'nde', 'ng': 'ndo', 'ne': 'nep', 'nl': 'nld', 'nn': 'nno', 'nb': 'nob', 'no': 'nor', 'ny': 'nya', 'oc': 'oci', 'oj': 'oji', 'or': 'ori', 'om': 'orm', 'os': 'oss', 'pa': 'pan', 'pi': 'pli', 'pl': 'pol', 'pt': 'por', 'ps': 'pus', 'qu': 'que', 'rm': 'roh', 'ro': 'ron', 'rn': 'run', 'ru': 'rus', 'sg': 'sag', 'sa': 'san', 'si': 'sin', 'sk': 'slk', 'sl': 'slv', 'se': 'sme', 'sm': 'smo', 'sn': 'sna', 'sd': 'snd', 'so': 'som', 'st': 'sot', 'es': 'spa', 'sq': 'sqi', 'sc': 'srd', 'sr': 'srp', 'ss': 'ssw', 'su': 'sun', 'sw': 'swa', 'sv': 'swe', 'ty': 'tah', 'ta': 'tam', 'tt': 'tat', 'te': 'tel', 'tg': 'tgk', 'tl': 'tgl', 'th': 'tha', 'ti': 'tir', 'to': 'ton', 'tn': 'tsn', 'ts': 'tso', 'tk': 'tuk', 'tr': 'tur', 'tw': 'twi', 'ug': 'uig', 'uk': 'ukr', 'ur': 'urd', 'uz': 'uzb', 've': 'ven', 'vi': 'vie', 'vo': 'vol', 'wa': 'wln', 'wo': 'wol', 'xh': 'xho', 'yi': 'yid', 'yo': 'yor', 'za': 'zha', 'zh': 'zho', 'zu': 'zul'}  # noqa: E501
# DO NOT MODIFY, USE `make` which calls `./updateBoostraper.py`

organization_name = 'apertium'
default_prefix = 'apertium'
default_email = 'apertium-stuff@lists.sourceforge.net'


def get_lang_name(code):  # type: (str) -> str
    code = iso639_codes[code] if len(code) > 2 and code in iso639_codes else code
    if code in english_lang_names:
        return english_lang_names[code]
    else:
        sys.stdout.write('Unable to find English language name for %s, using ISO code instead.\n' % code)
        return code


def read_manifest(files, conditionals):  # type: (Dict[str, bytes], List[str]) -> None
    manifest_byt = zlib.decompress(base64.b85decode(files['MANIFEST.txt']))
    manifest_txt = manifest_byt.decode('utf-8')
    manifest_ls = make_replacements(manifest_txt, {}, conditionals).splitlines()
    for f in list(files.keys()):
        if f not in any_module_files and f not in manifest_ls:
            del files[f]


def init_pair(args, email):  # type: (argparse.Namespace, str) -> Tuple[Dict[str, bytes], Dict[str, str], List[str]]
    language_code_1, language_code_2 = args.name.split('-')
    replacements = {
        'languageCode1': language_code_1,
        'languageCode2': language_code_2,
        'languageName1': get_lang_name(language_code_1),
        'languageName2': get_lang_name(language_code_2),
        'email': email,
    }

    conditionals = []
    if args.analyser == 'giella' or args.analyser1 == 'giella':
        conditionals.append('giella1')
    elif args.analyser in ['hfst', 'lexd'] or args.analyser1 in ['hfst', 'lexd']:
        conditionals.append('hfst1')
    else:
        conditionals.append('lttoolbox1')
    if args.analyser == 'giella' or args.analyser2 == 'giella':
        conditionals.append('giella2')
    elif args.analyser in ['hfst', 'lexd'] or args.analyser2 in ['hfst', 'lexd']:
        conditionals.append('hfst2')
    else:
        conditionals.append('lttoolbox2')
    if conditionals != ['lttoolbox1', 'lttoolbox2']:
        conditionals.append('hfst')

    conditionals += args.pair_conds or []
    conditionals.append(args.transfer)

    if not args.no_prob1:
        conditionals.append('prob1')
    if not args.no_prob2:
        conditionals.append('prob2')

    if not args.no_rlx1:
        conditionals.append('rlx1')
    if not args.no_rlx2:
        conditionals.append('rlx2')

    if not args.no_pgen1:
        conditionals.append('pgen1')
    if not args.no_pgen2:
        conditionals.append('pgen2')

    files = dict(bilingual_module_files, **any_module_files)
    read_manifest(files, conditionals)

    return files, replacements, conditionals


def init_lang_module(args, email):  # type: (argparse.Namespace, str) -> Tuple[Dict[str, bytes], Dict[str, str], List[str]]
    replacements = {
        'languageCode': args.name,
        'languageName': get_lang_name(args.name),
        'email': email,
    }

    conditionals = args.lang_conds or []

    if args.analyser in ['lt', 'lttoolbox']:
        files = dict(lttoolbox_language_module_files, **any_module_files)
    elif args.analyser in ['hfst', 'lexd']:
        if args.analyser == 'lexd':
            conditionals.append('lexd')
        files = dict(hfst_language_module_files, **any_module_files)
        read_manifest(files, conditionals)
    else:
        raise Exception('Unrecognized analyser: ' % args.analyser)

    return files, replacements, conditionals


def make_replacements(s, replacements, conditionals):  # type: (str, Dict[str, str], List[str]) -> str
    for _ in range(2):
        s = re.sub(r'{{if_(\w+)[^\n]*(.*?)\nif_\1}}', lambda x: x.group(2) if x.group(1) in conditionals else '', s, flags=re.DOTALL)
        s = re.sub(r'{{ifnot_(\w+)[^\n]*(.*?)\nifnot_\1}}', lambda x: x.group(2) if x.group(1) not in conditionals else '', s, flags=re.DOTALL)
    for replacement_name, replacement_value in replacements.items():
        s = s.replace('{{%s}}' % replacement_name, replacement_value)
    return s


def make_all_replacements(destination, files, replacements, conditionals):  # type: (str, Dict[str, bytes], Dict[str, str], List[str]) -> None
    for filename, encoded_file in files.items():
        replacements_filename = make_replacements(filename, replacements, conditionals)
        path = os.path.join(destination, replacements_filename)
        folder = os.path.dirname(path)
        if not os.path.isdir(folder):
            os.mkdir(folder)
        if os.path.exists(path):
            backup = os.path.join(folder, '.bak')
            if not os.path.isdir(backup):
                os.mkdir(backup)
            os.rename(path, os.path.join(backup, replacements_filename))
        with open(path, 'wb') as f:
            decomp = zlib.decompress(base64.b85decode(encoded_file))
            try:
                f.write(make_replacements(str(decomp, encoding='utf-8'), replacements, conditionals).encode('utf-8'))
            except UnicodeDecodeError:  # binary file
                f.write(decomp)


def push_to_github(args, folder, username):  # type: (argparse.Namespace, str, str) -> None
    remote_name = 'origin'
    repository_name = '{}-{}'.format(args.prefix, args.name)
    if '-' in args.name:
        code1, code2 = args.name.split('-')
        description = 'Apertium translation pair for {} and {}'.format(get_lang_name(code1), get_lang_name(code2))
    else:
        description = 'Apertium linguistic data for {}'.format(get_lang_name(args.name))

    def create_github_repository():  # type: () -> http.client.HTTPResponse
        password = getpass.getpass(prompt='GitHub Password ({}): '.format(username))
        data = bytes(json.dumps({
            'name': repository_name,
            'description': description,
        }), encoding='utf-8')
        req = urllib.request.Request('https://api.github.com/orgs/{}/repos'.format(organization_name), data=data)
        credentials = '{}:{}'.format(username, password)
        encoded_credentials = base64.b64encode(credentials.encode('ascii'))
        req.add_header('Authorization', 'Basic {}'.format(encoded_credentials.decode('ascii')))
        try:
            response = urllib.request.urlopen(req)
            print('Successfully created GitHub repository {}/{}.'.format(organization_name, repository_name))
            return response  # type: ignore
        except urllib.error.HTTPError as e:
            if e.getcode() == 401:
                print('Authentication failed. Retrying...')
                return create_github_repository()
            else:
                sys.stderr.write('Failed to create GitHub repository: {}.'.format(e))
                sys.exit(-1)

    response = create_github_repository()
    body = json.loads(response.read().decode('utf-8'))

    try:
        remote_url = body['ssh_url']
        subprocess.check_output(shlex.split('git remote add {} {}'.format(remote_name, remote_url)), cwd=args.destination, stderr=subprocess.STDOUT)
        print('Added GitHub remote {}.'.format(remote_url))
    except subprocess.CalledProcessError as e:
        sys.stderr.write('Adding remote {} ({}) failed: {}'.format(remote_name, remote_url, e.output))

    try:
        subprocess.check_output(shlex.split('git push {} master'.format(remote_name)), cwd=args.destination, stderr=subprocess.STDOUT)
        print('Pushed to GitHub. Visit your new repository at {}.'.format(body['html_url']))
    except subprocess.CalledProcessError as e:
        sys.stderr.write('Pushing to remote {} failed: {}'.format(remote_name, e.output))


def main(cli_args=None):  # type: (Optional[List[str]]) -> None
    parser = argparse.ArgumentParser(description='Bootstrap an Apertium language module/pair', allow_abbrev=True)
    parser.add_argument('name', help='name of new Apertium language module/pair using ISO-639-3 language code(s)')
    parser.add_argument('-d', '--destination', help='destination directory for new language module/pair (default: cwd)', default=os.getcwd())
    parser.add_argument('-p', '--push-new-to-github', help='push newly created repository to incubator on the Apertium organisation on GitHub (use with -u)',
                        action='store_true', default=False)
    parser.add_argument('--push-existing-to-github', '--pe', help='push existing repository to incubator on the Apertium organisation on GitHub', default=None)
    parser.add_argument('-u', '--username', help='override GitHub username (for pushing repository to GitHub); otherwise git config is used', default=None)
    parser.add_argument('--prefix', help='directory prefix (default: {})'.format(default_prefix), default=default_prefix)
    parser.add_argument('-r', '--rebuild', help='construct module or pair with different features using existing files',
                        action='store_true', default=False)

    parser.add_argument('-a', '--analyser', help='analyser to use for all languages', choices=['lt', 'lttoolbox', 'hfst', 'lexd', 'giella'], default='lt')
    parser.add_argument('--analyser1', '--a1', help='analyser to use for first language of pair', choices=['lt', 'lttoolbox', 'hfst', 'lexd', 'giella'],
                        default='lt')
    parser.add_argument('--analyser2', '--a2', help='analyser to use for second language of pair', choices=['lt', 'lttoolbox', 'hfst', 'lexd', 'giella'],
                        default='lt')

    parser.add_argument('-t', '--transfer', help='structural transfer module to use', choices=['chunk', 'rtx'], default='chunk')

    rlx_prob_group1 = parser.add_mutually_exclusive_group()
    rlx_prob_group1.add_argument('--no-rlx1', help='no .rlx present in first language of pair (only used for bilingual pairs)',
                                 action='store_true', default=False)
    rlx_prob_group1.add_argument('--no-prob1', help='no .prob present in first language of pair (only used for bilingual pairs)',
                                 action='store_true', default=False)

    rlx_prob_group2 = parser.add_mutually_exclusive_group()
    rlx_prob_group2.add_argument('--no-prob2', help='no .prob present in second language of pair (only used for bilingual pairs)',
                                 action='store_true', default=False)
    rlx_prob_group2.add_argument('--no-rlx2', help='no .rlx present in second language of pair (only used for bilingual pairs)',
                                 action='store_true', default=False)

    parser.add_argument('--no-pgen1', help='no post-dix present in first language of pair (only used for bilingual pairs)', action='store_true', default=False)
    parser.add_argument('--no-pgen2', help='no post-dix present in second language of pair (only used for bilingual pairs)', action='store_true', default=False)
    parser.add_argument('--with-twoc', help='include .twoc file (only used for monolingual hfst modules)', action='append_const',
                        const='twoc', dest='lang_conds')
    parser.add_argument('--with-lsx', '--with-separable', help='include apertium-separable .lsx files (only used for bilingual pairs)',
                        action='append_const', const='lsx', dest='pair_conds')
    parser.add_argument('--with-spellrelax', help='include spellrelax file (only used for monolingual hfst modules)', action='append_const',
                        const='spellrelax', dest='lang_conds')
    parser.add_argument('--with-anaphora', help='include anaphora resolution file (only used for bilingual pairs)', action='append_const',
                        const='anaphora', dest='pair_conds')

    args = parser.parse_args(cli_args)

    try:
        email = subprocess.check_output(shlex.split('git config user.email')).decode('utf-8').strip()
    except subprocess.CalledProcessError as e:
        email = default_email
        sys.stderr.write('Unable to get email, defaulting to %s: %s\n' % (email, str(e).strip()))

    username = args.username or email
    args.name = re.sub(r'^{}-'.format(re.escape(args.prefix)), '', args.name)
    repository_name = '{}-{}'.format(args.prefix, args.name)
    args.destination = os.path.join(args.destination, repository_name)

    if args.push_existing_to_github:
        if not os.path.isdir(args.push_existing_to_github):
            parser.error('--push_existing_to_github requires an existing directory')
        push_to_github(args, args.destination, username)
        return

    if '-' in args.name and args.name.count('-') == 1:
        if args.lang_conds:
            parser.error('--with-%s can only be used with monolingual modules' % args.lang_conds[0])
        if (args.analyser == 'giella' or args.analyser1 == 'giella') and (args.no_rlx1 or args.no_prob1):
            parser.error('--analyser=giella specifies the tagger')
        if (args.analyser == 'giella' or args.analyser2 == 'giella') and (args.no_rlx2 or args.no_prob2):
            parser.error('--analyser=giella specifies the tagger')
        files, replacements, conditionals = init_pair(args, email)
    elif '-' not in args.name:
        if args.pair_conds:
            parser.error('--with-%s can only be used with bilingual pairs' % args.pair_conds[0])
        if args.lang_conds:
            if args.analyser in ['lt', 'lttoolbox']:
                parser.error('--with-%s can only be used with hfst modules' % args.lang_conds[0])
                # this will have to be changed if we have options for lttoolbox modules
            elif args.analyser == 'lexd' and 'twoc' in args.lang_conds:
                parser.error('--analyser=lexd is not compatible with --with-twoc')
        if args.analyser == 'giella':
            parser.error('cannot generate Giella language modules')
        files, replacements, conditionals = init_lang_module(args, email)
    else:
        parser.error('Invalid language module name: %s' % args.name)

    if args.rebuild:
        if not os.path.exists(args.destination):
            sys.stderr.write('Directory {} does not exist, cannot rebuild, quitting.\n'.format(args.destination))
            sys.exit(-1)
        files_to_delete = []
        for filename in files:
            if filename in ['README', 'modes.xml', 'autogen.sh', 'configure.ac', 'Makefile.am']:
                continue
            if filename.endswith('.pc.in'):
                continue
            fname = make_replacements(filename, replacements, conditionals)
            if os.path.exists(os.path.join(args.destination, fname)):
                files_to_delete.append(filename)
        for filename in files_to_delete:
            del files[filename]
    elif os.path.exists(args.destination):
        sys.stderr.write('Directory {} already exists, quitting.\n'.format(args.destination))
        sys.exit(-1)
    else:
        os.makedirs(args.destination)

    make_all_replacements(args.destination, files, replacements, conditionals)

    autogen_path = os.path.join(args.destination, 'autogen.sh')
    os.chmod(autogen_path, os.stat(autogen_path).st_mode | stat.S_IEXEC)

    try:
        readme_path = os.path.join(args.destination, 'README')
        if args.rebuild:
            readme_md_path = os.path.join(args.destination, 'README.md')
            if os.path.exists(readme_md_path):
                os.remove(readme_md_path)
        if os.path.exists(readme_path):
            os.symlink('README', os.path.join(args.destination, 'README.md'))
    except OSError as err:  # e.g. on Windows without running as an admin
        sys.stderr.write('Unable to create symlink from README.md -> README: {}\n'.format(err))

    print('Successfully created %s.' % args.destination)

    try:
        subprocess.check_output(shlex.split('git init .'), cwd=args.destination, universal_newlines=True, stderr=subprocess.STDOUT)
        print('Initialized git repository {}.'.format(repository_name))
    except subprocess.CalledProcessError as e:
        sys.stderr.write('Unable to initialize git repository: {}'.format(e.output))
        sys.exit(-1)

    try:
        add_cmd = ['git', 'add', 'README.md']
        for filename in files:
            add_cmd.append(make_replacements(filename, replacements, conditionals))
        subprocess.check_output(add_cmd, cwd=args.destination, universal_newlines=True, stderr=subprocess.STDOUT)
        if not args.rebuild:
            subprocess.check_output(shlex.split('git commit -m "Initial commit"'), cwd=args.destination, universal_newlines=True, stderr=subprocess.STDOUT)
            print('Successfully added and committed files to git repository {}.'.format(repository_name))
        else:
            print('Successfully added updated files to git repository {}.'.format(repository_name))
    except subprocess.CalledProcessError as e:
        sys.stderr.write('Unable to add/commit files to git repository {}: {}'.format(repository_name, e.output))
        sys.exit(-1)

    if '-' not in args.name and not args.rebuild:
        try:
            subprocess.check_output('./autogen.sh', cwd=args.destination, universal_newlines=True, stderr=subprocess.STDOUT, shell=True)
            print('Successfully configure Makefile.')
        except subprocess.CalledProcessError as e:
            sys.stderr.write('Unable to configure Makefile, you may be missing some of the required tools: {}'.format(e.output))
            # don't exit here, since failing this doesn't interfere with pushing to github

    if args.push_new_to_github:
        push_to_github(args, args.destination, username)
    else:
        print('To push your new local repository to incubator in the {} organisation on GitHub:'.format(organization_name))
        print('\tapertium-init.py --pe {} {}'.format(args.destination, repository_name))

    if not args.rebuild:
        print("""
The directory you just created includes a GPLv3-or-later license.
If you would like to license it differently, please adjust or replace the COPYING file accordingly.
Please note that code included in the Apertium project should be GPLv2-or-later-compatible.
""")

    push_hook = os.path.join(args.destination, '.git/hooks/pre-push')
    if not os.path.exists(push_hook):
        with open(push_hook, 'w') as f:
            f.write("""#!/bin/bash
todos=`grep "TODO" README | grep -v "TODO("`
if [ ! -z "$todos" ]; then
        echo ""
        echo "WARNING: You have unresolved TODOs in your README."
        echo "You can resolve this message by replacing the TODOs with example"
        echo "sentences or by assigning them like TODO(Albert)"
        echo ""
fi
""")
            os.chmod(push_hook, os.stat(push_hook).st_mode | stat.S_IEXEC)


if __name__ == '__main__':
    main(sys.argv[1:])
